import time
import re
import pandas as pd
from pathlib import Path
import subprocess
import os, sys

def fetchGenCor(args, index_file_name, dict_gen_coordinates):
    bwtCommand = Path(args.bowtie_path)/"bowtie-inspect" if args.bowtie_path else "bowtie-inspect"
    bwtExec = str(bwtCommand) +" -n "+ str(index_file_name)
    bowtie = subprocess.run(str(bwtExec), shell=True, check=True, stdout=subprocess.PIPE, text=True, stderr=subprocess.PIPE, universal_newlines=True)
    if bowtie.returncode==0:
        bwtOut = bowtie.stdout
        bwtErr = bowtie.stderr
        for srow in bwtOut.split('\n'):
            if not "PATCH" in srow:
                header_line = srow.split(' ')
                try:
                    dict_gen_coordinates[header_line[0]] = header_line[2]
                except IndexError:
                    pass
    return dict_gen_coordinates
    #ENST00000516122.1 ncrna chromosome:GRCh38:12:59450673:59450772:-1 gene:ENSG00000251931.1 gene_biotype:snRNA transcript_biotype:snRNA gene_symbol:RNU6-871P description:RNA, U6 small nuclear 871, pseudogene [Source:HGNC Symbol;Acc:HGNC:47834]

def bow2bam(args, workDir, ref_db, df_list, base_names, index_file_name, rna_type, samName):
    samtoolsCommandPre = Path(args.samtools_path)/"samtools " if args.samtools_path else "samtools "
    dict_genCors = {}
    dict_genCors = fetchGenCor(args, index_file_name, dict_genCors) # Key: ENST00000516122.1 and value: chromosome:GRCh38:12:59450673:59450772:-1

    bam_expression_dict={}
    for seq in df_list:
        bam_expression_dict[seq[0]] = [int(x) for x in seq[2:]]
    
    req_sam = "miRge3_"+samName+".sam"
    otrna_samFile = Path(workDir)/req_sam
    with open(otrna_samFile) as miSam:
        for mi_idx, mi_sam in enumerate(miSam):
            mi_sam = mi_sam.strip()
            mi_sam_list = mi_sam.split("\t")
            try:
                sam_exprn_list = bam_expression_dict[mi_sam_list[0]] # list of expression values 
                try:
                    if args.organism_name == "hamster":
                        chromo = str(dict_genCors[mi_sam_list[2]].split(":")[2])
                    else:
                        chromo = "chr"+ str(dict_genCors[mi_sam_list[2]].split(":")[2])
                        if chromo == "chrMT": 
                            chromo = chromo.replace("chrMT", "chrM")
                    start = int(dict_genCors[mi_sam_list[2]].split(":")[3]) + int(mi_sam_list[3]) - 1
                    strand = dict_genCors[mi_sam_list[2]].split(":")[-1]
                    for ex_idx, exprn in enumerate(sam_exprn_list):
                        if exprn >= 1:
                            file_sam_name = str(base_names[ex_idx]) +".sam"
                            sam_name = Path(workDir)/file_sam_name
                            xbam = open(sam_name, "a+")
                            for numexp in range(exprn):
                                readname = mi_sam_list[0] + "_" + str(numexp)
                                phredQual = "I"*len(mi_sam_list[0])
                                #xbamout = readname+"\t"+mi_sam_list[1]+"\t"+genC+"\t"+str(genS)+"\t"+mi_sam_list[4]+"\t"+mi_sam_list[5]+"\t"+mi_sam_list[6]+"\t"+mi_sam_list[7]+"\t"+mi_sam_list[8]+"\t"+mi_sam_list[9]+"\t"+mi_sam_list[10]+"\n"
                                if strand == "1":
                                    xbamout = readname+"\t"+mi_sam_list[1]+"\t"+chromo+"\t"+str(start)+"\t"+mi_sam_list[4]+"\t"+mi_sam_list[5]+"\t"+mi_sam_list[6]+"\t"+mi_sam_list[7]+"\t"+mi_sam_list[8]+"\t"+mi_sam_list[0]+"\t"+phredQual+"\n"
                                else:
                                    xbamout = readname+"\t"+mi_sam_list[1]+"\t"+chromo+"\t"+str(start)+"\t"+mi_sam_list[4]+"\t"+mi_sam_list[5]+"\t"+mi_sam_list[6]+"\t"+mi_sam_list[7]+"\t"+mi_sam_list[8]+"\t"+mi_sam_list[0][::-1]+"\t"+phredQual+"\n"
                                xbam.write(xbamout)
                            xbam.close()
                except IndexError:    
                    pass
            except KeyError:
                pass


def createBAM(args, workDir, base_names):
    samtoolsCommandPre = Path(args.samtools_path)/"samtools " if args.samtools_path else "samtools "
    # SAM to BAM conversion
    for files_sam in base_names:
        file_sam_name = str(files_sam) +".sam"
        file_bam_name = str(files_sam) +".bam"
        file_Sortbam_name = str(files_sam) +"_sorted.bam"
        file_Sortbam_idx = str(files_sam) +"_sorted.bai"
        sam_name = Path(workDir)/file_sam_name
        bam_name = Path(workDir)/file_bam_name
        bam_sortname = Path(workDir)/file_Sortbam_name
        bam_sortidx = Path(workDir)/file_Sortbam_idx
        samCom2bam = str(samtoolsCommandPre) + "view -bS " + str(sam_name) + " > " + str(bam_name)
        samcreation = subprocess.run(str(samCom2bam), shell=True, check=True, stdout=subprocess.PIPE, text=True, stderr=subprocess.PIPE, universal_newlines=True)
        if samcreation.returncode !=0:
            print("Error in creating BAM file!. Ignoring this step\n")
            pass
        else:
            #os.remove(sam_name)
            pass
        bamsort = str(samtoolsCommandPre) + "sort -@ " + str(args.threads) + " " + str(bam_name) + " -o " + str(bam_sortname)
        bamsorting = subprocess.run(str(bamsort), shell=True, check=True, stdout=subprocess.PIPE, text=True, stderr=subprocess.PIPE, universal_newlines=True)
        if bamsorting.returncode !=0:
            print("Error in Sorting BAM file!. Ignoring this step\n")
            pass
        else:
            #os.remove(bam_name)
            pass
        bamindex = str(samtoolsCommandPre) + "index " + str(bam_sortname) + " " + str(bam_sortidx)
        bamindexing = subprocess.run(str(bamindex), shell=True, check=True, stdout=subprocess.PIPE, text=True, stderr=subprocess.PIPE, universal_newlines=True)
        if bamindexing.returncode !=0:
            print("Error indexing BAM file!. Ignoring this step\n")
            pass
        
def sam_header(args):
    if args.organism_name == "human":
        header = "@HD\tVN:1.0\tSO:unsorted\n@SQ\tSN:chr1\tLN:248956422\n@SQ\tSN:chr2\tLN:242193529\n@SQ\tSN:chr3\tLN:198295559\n@SQ\tSN:chr4\tLN:190214555\n@SQ\tSN:chr5\tLN:181538259\n@SQ\tSN:chr6\tLN:170805979\n@SQ\tSN:chr7\tLN:159345973\n@SQ\tSN:chr8\tLN:145138636\n@SQ\tSN:chr9\tLN:138394717\n@SQ\tSN:chr10\tLN:133797422\n@SQ\tSN:chr11\tLN:135086622\n@SQ\tSN:chr12\tLN:133275309\n@SQ\tSN:chr13\tLN:114364328\n@SQ\tSN:chr14\tLN:107043718\n@SQ\tSN:chr15\tLN:101991189\n@SQ\tSN:chr16\tLN:90338345\n@SQ\tSN:chr17\tLN:83257441\n@SQ\tSN:chr18\tLN:80373285\n@SQ\tSN:chr19\tLN:58617616\n@SQ\tSN:chr20\tLN:64444167\n@SQ\tSN:chr21\tLN:46709983\n@SQ\tSN:chr22\tLN:50818468\n@SQ\tSN:chrX\tLN:156040895\n@SQ\tSN:chrY\tLN:57227415\n@SQ\tSN:chrM\tLN:16569\n@PG\tID:Bowtie\tVN:1.2.3\tCL:\"bowtie-1.2.3-linux-x86_64/bowtie-align-s --wrapper basic-0 sample_index sample.fastq -S -p 12\"\n"
    elif args.organism_name == "mouse":
        header = "@HD\tVN:1.0\tSO:unsorted\n@SQ\tSN:chr1\tLN:195471971\n@SQ\tSN:chr2\tLN:182113224\n@SQ\tSN:chr3\tLN:160039680\n@SQ\tSN:chr4\tLN:156508116\n@SQ\tSN:chr5\tLN:151834684\n@SQ\tSN:chr6\tLN:149736546\n@SQ\tSN:chr7\tLN:145441459\n@SQ\tSN:chr8\tLN:129401213\n@SQ\tSN:chr9\tLN:124595110\n@SQ\tSN:chr10\tLN:130694993\n@SQ\tSN:chr11\tLN:122082543\n@SQ\tSN:chr12\tLN:120129022\n@SQ\tSN:chr13\tLN:120421639\n@SQ\tSN:chr14\tLN:124902244\n@SQ\tSN:chr15\tLN:104043685\n@SQ\tSN:chr16\tLN:98207768\n@SQ\tSN:chr17\tLN:94987271\n@SQ\tSN:chr18\tLN:90702639\n@SQ\tSN:chr19\tLN:61431566\n@SQ\tSN:chrX\tLN:171031299\n@SQ\tSN:chrY\tLN:91744698\n@SQ\tSN:chrM\tLN:16299\n@SQ\tSN:GL456210.1\tLN:169725\n@SQ\tSN:GL456211.1\tLN:241735\n@SQ\tSN:GL456212.1\tLN:153618\n@SQ\tSN:GL456213.1\tLN:39340\n@SQ\tSN:GL456216.1\tLN:66673\n@SQ\tSN:GL456219.1\tLN:175968\n@SQ\tSN:GL456221.1\tLN:206961\n@SQ\tSN:GL456233.1\tLN:336933\n@SQ\tSN:GL456239.1\tLN:40056\n@SQ\tSN:GL456350.1\tLN:227966\n@SQ\tSN:GL456354.1\tLN:195993\n@SQ\tSN:GL456359.1\tLN:22974\n@SQ\tSN:GL456360.1\tLN:31704\n@SQ\tSN:GL456366.1\tLN:47073\n@SQ\tSN:GL456367.1\tLN:42057\n@SQ\tSN:GL456368.1\tLN:20208\n@SQ\tSN:GL456370.1\tLN:26764\n@SQ\tSN:GL456372.1\tLN:28664\n@SQ\tSN:GL456378.1\tLN:31602\n@SQ\tSN:GL456379.1\tLN:72385\n@SQ\tSN:GL456381.1\tLN:25871\n@SQ\tSN:GL456382.1\tLN:23158\n@SQ\tSN:GL456383.1\tLN:38659\n@SQ\tSN:GL456385.1\tLN:35240\n@SQ\tSN:GL456387.1\tLN:24685\n@SQ\tSN:GL456389.1\tLN:28772\n@SQ\tSN:GL456390.1\tLN:24668\n@SQ\tSN:GL456392.1\tLN:23629\n@SQ\tSN:GL456393.1\tLN:55711\n@SQ\tSN:GL456394.1\tLN:24323\n@SQ\tSN:GL456396.1\tLN:21240\n@SQ\tSN:JH584292.1\tLN:14945\n@SQ\tSN:JH584293.1\tLN:207968\n@SQ\tSN:JH584294.1\tLN:191905\n@SQ\tSN:JH584295.1\tLN:1976\n@SQ\tSN:JH584296.1\tLN:199368\n@SQ\tSN:JH584297.1\tLN:205776\n@SQ\tSN:JH584298.1\tLN:184189\n@SQ\tSN:JH584299.1\tLN:953012\n@SQ\tSN:JH584300.1\tLN:182347\n@SQ\tSN:JH584301.1\tLN:259875\n@SQ\tSN:JH584302.1\tLN:155838\n@SQ\tSN:JH584303.1\tLN:158099\n@SQ\tSN:JH584304.1\tLN:114452\n@SQ\tSN:KQ030490.1\tLN:120154\n@SQ\tSN:KB469738.3\tLN:210641\n@SQ\tSN:JH792830.1\tLN:246751\n@SQ\tSN:KK082442.1\tLN:154766\n@SQ\tSN:KQ030495.1\tLN:490000\n@SQ\tSN:KQ030485.1\tLN:185548\n@SQ\tSN:KQ030486.1\tLN:399265\n@SQ\tSN:KQ030487.1\tLN:316842\n@SQ\tSN:KB469739.1\tLN:331111\n@SQ\tSN:KB469741.1\tLN:267241\n@SQ\tSN:JH792829.1\tLN:352455\n@SQ\tSN:JH792826.1\tLN:368286\n@SQ\tSN:JH792828.1\tLN:473738\n@SQ\tSN:KB469740.1\tLN:316140\n@SQ\tSN:JH792832.1\tLN:544189\n@SQ\tSN:JH792833.1\tLN:221588\n@SQ\tSN:JH792827.1\tLN:205713\n@SQ\tSN:JH792834.1\tLN:331480\n@SQ\tSN:JH792831.1\tLN:182256\n@SQ\tSN:KB469742.1\tLN:1059955\n@SQ\tSN:KQ030484.1\tLN:214957\n@SQ\tSN:KQ030494.1\tLN:506812\n@SQ\tSN:KQ030496.1\tLN:260447\n@SQ\tSN:KQ030497.1\tLN:219721\n@SQ\tSN:KQ030492.1\tLN:166012\n@SQ\tSN:KQ030493.1\tLN:269476\n@SQ\tSN:KQ030491.1\tLN:129865\n@SQ\tSN:KQ030488.1\tLN:45901\n@SQ\tSN:KQ030489.1\tLN:188269\n@SQ\tSN:KK082441.1\tLN:456798\n@PG\tID:Bowtie\tVN:1.2.3\tCL:\"bowtie-1.2.3-linux-x86_64/bowtie-align-s --wrapper basic-0 sample_index sample.fastq -S -p 12\"\n"
    elif args.organism_name == "rat":
        header = "@HD\tVN:1.0\tSO:unsorted\n@SQ\tSN:chr1\tLN:282763074\n@SQ\tSN:chr10\tLN:112626471\n@SQ\tSN:chr10_KL568008v1_random\tLN:2704\n@SQ\tSN:chr10_KL568009v1_random\tLN:27282\n@SQ\tSN:chr10_KL568010v1_random\tLN:28524\n@SQ\tSN:chr10_AABR07050887v1_random\tLN:1962\n@SQ\tSN:chr10_KL568011v1_random\tLN:24114\n@SQ\tSN:chr10_AABR07050894v1_random\tLN:590\n@SQ\tSN:chr10_KL568012v1_random\tLN:22748\n@SQ\tSN:chr10_KL568013v1_random\tLN:5986\n@SQ\tSN:chr10_AABR07050850v1_random\tLN:548\n@SQ\tSN:chr10_KL568014v1_random\tLN:8466\n@SQ\tSN:chr10_KL568015v1_random\tLN:15525\n@SQ\tSN:chr10_KL568016v1_random\tLN:26063\n@SQ\tSN:chr10_KL568017v1_random\tLN:16434\n@SQ\tSN:chr10_KL568018v1_random\tLN:29483\n@SQ\tSN:chr11\tLN:90463843\n@SQ\tSN:chr11_KL568019v1_random\tLN:48508\n@SQ\tSN:chr11_KL568020v1_random\tLN:24193\n@SQ\tSN:chr11_KL568021v1_random\tLN:24537\n@SQ\tSN:chr11_KL568022v1_random\tLN:7520\n@SQ\tSN:chr11_AABR07050825v1_random\tLN:1274\n@SQ\tSN:chr11_KL568023v1_random\tLN:1603\n@SQ\tSN:chr11_KL568024v1_random\tLN:28231\n@SQ\tSN:chr11_KL568025v1_random\tLN:19565\n@SQ\tSN:chr11_KL568026v1_random\tLN:15784\n@SQ\tSN:chr11_KL568027v1_random\tLN:2724\n@SQ\tSN:chr11_KL568028v1_random\tLN:8337\n@SQ\tSN:chr11_KL568029v1_random\tLN:35203\n@SQ\tSN:chr11_KL568030v1_random\tLN:11773\n@SQ\tSN:chr11_AABR07050811v1_random\tLN:917\n@SQ\tSN:chr11_KL568031v1_random\tLN:8183\n@SQ\tSN:chr11_AABR07050815v1_random\tLN:1204\n@SQ\tSN:chr12\tLN:52716770\n@SQ\tSN:chr12_KL568032v1_random\tLN:10672\n@SQ\tSN:chr12_KL568033v1_random\tLN:14885\n@SQ\tSN:chr12_AABR07051089v1_random\tLN:580\n@SQ\tSN:chr12_AABR07051090v1_random\tLN:3027\n@SQ\tSN:chr12_KL568034v1_random\tLN:3214\n@SQ\tSN:chr12_KL568035v1_random\tLN:7095\n@SQ\tSN:chr12_AABR07051059v1_random\tLN:4594\n@SQ\tSN:chr12_KL568036v1_random\tLN:18420\n@SQ\tSN:chr12_KL568037v1_random\tLN:6770\n@SQ\tSN:chr12_KL568038v1_random\tLN:17009\n@SQ\tSN:chr12_KL568039v1_random\tLN:17744\n@SQ\tSN:chr12_KL568040v1_random\tLN:11557\n@SQ\tSN:chr13\tLN:114033958\n@SQ\tSN:chr13_KL568041v1_random\tLN:22880\n@SQ\tSN:chr13_KL568042v1_random\tLN:22393\n@SQ\tSN:chr13_KL568043v1_random\tLN:4810\n@SQ\tSN:chr13_AABR07050784v1_random\tLN:3876\n@SQ\tSN:chr13_KL568044v1_random\tLN:21067\n@SQ\tSN:chr13_KL568045v1_random\tLN:40838\n@SQ\tSN:chr13_KL568046v1_random\tLN:23864\n@SQ\tSN:chr13_KL568047v1_random\tLN:4212\n@SQ\tSN:chr13_KL568048v1_random\tLN:17062\n@SQ\tSN:chr13_KL568049v1_random\tLN:19070\n@SQ\tSN:chr13_KL568050v1_random\tLN:2905\n@SQ\tSN:chr13_KL568051v1_random\tLN:60838\n@SQ\tSN:chr14\tLN:115493446\n@SQ\tSN:chr14_KL568052v1_random\tLN:23128\n@SQ\tSN:chr14_KL568053v1_random\tLN:33884\n@SQ\tSN:chr14_KL568054v1_random\tLN:31451\n@SQ\tSN:chr14_KL568055v1_random\tLN:6984\n@SQ\tSN:chr14_KL568056v1_random\tLN:2940\n@SQ\tSN:chr14_KL568057v1_random\tLN:35355\n@SQ\tSN:chr14_KL568058v1_random\tLN:16413\n@SQ\tSN:chr14_KL568059v1_random\tLN:27955\n@SQ\tSN:chr14_KL568060v1_random\tLN:3352\n@SQ\tSN:chr14_KL568061v1_random\tLN:4767\n@SQ\tSN:chr15\tLN:111246239\n@SQ\tSN:chr15_KL568062v1_random\tLN:5881\n@SQ\tSN:chr15_KL568063v1_random\tLN:15622\n@SQ\tSN:chr15_KL568064v1_random\tLN:39113\n@SQ\tSN:chr15_KL568065v1_random\tLN:2068\n@SQ\tSN:chr15_KL568066v1_random\tLN:16414\n@SQ\tSN:chr15_KL568067v1_random\tLN:76800\n@SQ\tSN:chr15_KL568068v1_random\tLN:28441\n@SQ\tSN:chr15_KL568069v1_random\tLN:3057\n@SQ\tSN:chr15_KL568070v1_random\tLN:13105\n@SQ\tSN:chr15_KL568071v1_random\tLN:5890\n@SQ\tSN:chr15_KL568072v1_random\tLN:27900\n@SQ\tSN:chr15_KL568073v1_random\tLN:13013\n@SQ\tSN:chr15_AABR07046563v1_random\tLN:1113\n@SQ\tSN:chr15_KL568074v1_random\tLN:11065\n@SQ\tSN:chr16\tLN:90668790\n@SQ\tSN:chr16_KL568075v1_random\tLN:15415\n@SQ\tSN:chr16_AABR07050989v1_random\tLN:2001\n@SQ\tSN:chr16_KL568076v1_random\tLN:33299\n@SQ\tSN:chr16_KL568077v1_random\tLN:9129\n@SQ\tSN:chr16_KL568078v1_random\tLN:25637\n@SQ\tSN:chr16_AABR07050959v1_random\tLN:2278\n@SQ\tSN:chr16_KL568079v1_random\tLN:45872\n@SQ\tSN:chr16_KL568080v1_random\tLN:49795\n@SQ\tSN:chr16_KL568081v1_random\tLN:17953\n@SQ\tSN:chr16_AABR07050985v1_random\tLN:742\n@SQ\tSN:chr16_AABR07050986v1_random\tLN:3473\n@SQ\tSN:chr16_KL568082v1_random\tLN:2971\n@SQ\tSN:chr17\tLN:90843779\n@SQ\tSN:chr17_KL568083v1_random\tLN:2923\n@SQ\tSN:chr17_KL568084v1_random\tLN:15805\n@SQ\tSN:chr17_KL568085v1_random\tLN:31300\n@SQ\tSN:chr17_KL568086v1_random\tLN:7522\n@SQ\tSN:chr17_KL568087v1_random\tLN:20486\n@SQ\tSN:chr17_KL568088v1_random\tLN:23848\n@SQ\tSN:chr17_KL568089v1_random\tLN:17431\n@SQ\tSN:chr17_KL568090v1_random\tLN:4623\n@SQ\tSN:chr17_KL568091v1_random\tLN:9189\n@SQ\tSN:chr17_AABR07050910v1_random\tLN:3308\n@SQ\tSN:chr17_AABR07050911v1_random\tLN:2566\n@SQ\tSN:chr17_AABR07050912v1_random\tLN:743\n@SQ\tSN:chr17_KL568092v1_random\tLN:33190\n@SQ\tSN:chr17_AABR07050916v1_random\tLN:825\n@SQ\tSN:chr18\tLN:88201929\n@SQ\tSN:chr18_KL568093v1_random\tLN:12008\n@SQ\tSN:chr18_KL568094v1_random\tLN:3318\n@SQ\tSN:chr18_KL568095v1_random\tLN:7639\n@SQ\tSN:chr18_AABR07051098v1_random\tLN:572\n@SQ\tSN:chr18_AABR07051099v1_random\tLN:1185\n@SQ\tSN:chr18_KL568096v1_random\tLN:45622\n@SQ\tSN:chr18_KL568097v1_random\tLN:57850\n@SQ\tSN:chr18_AABR07051126v1_random\tLN:2299\n@SQ\tSN:chr18_KL568098v1_random\tLN:4827\n@SQ\tSN:chr18_KL568099v1_random\tLN:12402\n@SQ\tSN:chr19\tLN:62275575\n@SQ\tSN:chr19_KL568100v1_random\tLN:24817\n@SQ\tSN:chr19_KL568101v1_random\tLN:59862\n@SQ\tSN:chr19_KL568102v1_random\tLN:53245\n@SQ\tSN:chr1_AABR07046142v1_random\tLN:4043\n@SQ\tSN:chr1_KL567879v1_random\tLN:4483\n@SQ\tSN:chr1_AABR07046182v1_random\tLN:659\n@SQ\tSN:chr1_KL567880v1_random\tLN:16921\n@SQ\tSN:chr1_AABR07046186v1_random\tLN:881\n@SQ\tSN:chr1_AABR07046187v1_random\tLN:2999\n@SQ\tSN:chr1_KL567881v1_random\tLN:28452\n@SQ\tSN:chr1_KL567882v1_random\tLN:28706\n@SQ\tSN:chr1_KL567883v1_random\tLN:3546\n@SQ\tSN:chr1_AABR07046211v1_random\tLN:1042\n@SQ\tSN:chr1_AABR07046212v1_random\tLN:3264\n@SQ\tSN:chr1_KL567884v1_random\tLN:19577\n@SQ\tSN:chr1_KL567885v1_random\tLN:6757\n@SQ\tSN:chr1_KL567886v1_random\tLN:16175\n@SQ\tSN:chr1_AABR07046222v1_random\tLN:2978\n@SQ\tSN:chr1_KL567887v1_random\tLN:5668\n@SQ\tSN:chr1_KL567888v1_random\tLN:5884\n@SQ\tSN:chr1_AABR07046230v1_random\tLN:6554\n@SQ\tSN:chr1_AABR07046231v1_random\tLN:31509\n@SQ\tSN:chr1_KL567889v1_random\tLN:24468\n@SQ\tSN:chr1_KL567890v1_random\tLN:2119\n@SQ\tSN:chr1_KL567891v1_random\tLN:53404\n@SQ\tSN:chr1_AABR07046150v1_random\tLN:1041\n@SQ\tSN:chr1_KL567892v1_random\tLN:34086\n@SQ\tSN:chr1_AABR07046158v1_random\tLN:3018\n@SQ\tSN:chr1_AABR07046159v1_random\tLN:3224\n@SQ\tSN:chr1_KL567893v1_random\tLN:30950\n@SQ\tSN:chr1_KL567894v1_random\tLN:30438\n@SQ\tSN:chr1_KL567895v1_random\tLN:26645\n@SQ\tSN:chr2\tLN:266435125\n@SQ\tSN:chr20\tLN:56205956\n@SQ\tSN:chr20_AABR07055056v1_random\tLN:2941\n@SQ\tSN:chr20_KL568103v1_random\tLN:4554\n@SQ\tSN:chr20_KL568104v1_random\tLN:16888\n@SQ\tSN:chr20_KL568105v1_random\tLN:2619\n@SQ\tSN:chr20_AABR07055065v1_random\tLN:1347\n@SQ\tSN:chr20_KL568106v1_random\tLN:5546\n@SQ\tSN:chr20_KL568107v1_random\tLN:4592\n@SQ\tSN:chr20_KL568108v1_random\tLN:44883\n@SQ\tSN:chr20_KL568109v1_random\tLN:29266\n@SQ\tSN:chr20_KL568110v1_random\tLN:8294\n@SQ\tSN:chr2_AABR07045875v1_random\tLN:515\n@SQ\tSN:chr2_KL567896v1_random\tLN:8590\n@SQ\tSN:chr2_KL567897v1_random\tLN:4528\n@SQ\tSN:chr2_KL567898v1_random\tLN:34630\n@SQ\tSN:chr2_KL567899v1_random\tLN:11090\n@SQ\tSN:chr2_KL567900v1_random\tLN:14052\n@SQ\tSN:chr2_KL567901v1_random\tLN:46970\n@SQ\tSN:chr2_AABR07045975v1_random\tLN:4223\n@SQ\tSN:chr2_KL567902v1_random\tLN:33155\n@SQ\tSN:chr2_KL567903v1_random\tLN:32912\n@SQ\tSN:chr2_KL567904v1_random\tLN:11839\n@SQ\tSN:chr2_KL567905v1_random\tLN:3364\n@SQ\tSN:chr2_KL567906v1_random\tLN:31912\n@SQ\tSN:chr2_KL567907v1_random\tLN:53909\n@SQ\tSN:chr2_AABR07046014v1_random\tLN:955\n@SQ\tSN:chr2_KL567908v1_random\tLN:61811\n@SQ\tSN:chr2_KL567909v1_random\tLN:11554\n@SQ\tSN:chr2_KL567910v1_random\tLN:22191\n@SQ\tSN:chr2_KL567911v1_random\tLN:23371\n@SQ\tSN:chr2_KL567912v1_random\tLN:8936\n@SQ\tSN:chr2_KL567913v1_random\tLN:34458\n@SQ\tSN:chr2_KL567914v1_random\tLN:57161\n@SQ\tSN:chr2_KL567915v1_random\tLN:19935\n@SQ\tSN:chr3\tLN:177699992\n@SQ\tSN:chr3_AABR07046243v1_random\tLN:1049\n@SQ\tSN:chr3_AABR07046267v1_random\tLN:1821\n@SQ\tSN:chr3_KL567916v1_random\tLN:18861\n@SQ\tSN:chr3_KL567917v1_random\tLN:33261\n@SQ\tSN:chr3_AABR07046283v1_random\tLN:567\n@SQ\tSN:chr3_KL567918v1_random\tLN:5278\n@SQ\tSN:chr3_KL567919v1_random\tLN:100126\n@SQ\tSN:chr3_AABR07046296v1_random\tLN:2362\n@SQ\tSN:chr3_KL567920v1_random\tLN:17963\n@SQ\tSN:chr3_KL567921v1_random\tLN:15352\n@SQ\tSN:chr3_KL567922v1_random\tLN:5545\n@SQ\tSN:chr3_KL567923v1_random\tLN:9678\n@SQ\tSN:chr3_KL567924v1_random\tLN:25463\n@SQ\tSN:chr3_KL567925v1_random\tLN:1808\n@SQ\tSN:chr3_AABR07046319v1_random\tLN:2826\n@SQ\tSN:chr3_KL567926v1_random\tLN:59501\n@SQ\tSN:chr3_KL567927v1_random\tLN:13550\n@SQ\tSN:chr3_AABR07046248v1_random\tLN:619\n@SQ\tSN:chr3_AABR07046249v1_random\tLN:1163\n@SQ\tSN:chr3_KL567928v1_random\tLN:4407\n@SQ\tSN:chr3_KL567929v1_random\tLN:2912\n@SQ\tSN:chr3_KL567930v1_random\tLN:5384\n@SQ\tSN:chr3_KL567931v1_random\tLN:18329\n@SQ\tSN:chr3_KL567932v1_random\tLN:8306\n@SQ\tSN:chr4\tLN:184226339\n@SQ\tSN:chr4_KL567933v1_random\tLN:27386\n@SQ\tSN:chr4_AABR07046405v1_random\tLN:682\n@SQ\tSN:chr4_KL567934v1_random\tLN:6638\n@SQ\tSN:chr4_KL567935v1_random\tLN:14953\n@SQ\tSN:chr4_KL567936v1_random\tLN:14424\n@SQ\tSN:chr4_KL567937v1_random\tLN:28091\n@SQ\tSN:chr4_KL567938v1_random\tLN:21336\n@SQ\tSN:chr4_KL567939v1_random\tLN:227955\n@SQ\tSN:chr4_KL567940v1_random\tLN:77814\n@SQ\tSN:chr4_KL567941v1_random\tLN:54041\n@SQ\tSN:chr4_KL567942v1_random\tLN:8128\n@SQ\tSN:chr4_KL567943v1_random\tLN:20550\n@SQ\tSN:chr4_KL567944v1_random\tLN:25173\n@SQ\tSN:chr4_KL567945v1_random\tLN:16464\n@SQ\tSN:chr4_KL567946v1_random\tLN:66194\n@SQ\tSN:chr4_KL567947v1_random\tLN:56466\n@SQ\tSN:chr5\tLN:173707219\n@SQ\tSN:chr5_KL567948v1_random\tLN:3195\n@SQ\tSN:chr5_KL567949v1_random\tLN:4694\n@SQ\tSN:chr5_KL567950v1_random\tLN:6510\n@SQ\tSN:chr5_KL567951v1_random\tLN:40651\n@SQ\tSN:chr5_KL567952v1_random\tLN:12293\n@SQ\tSN:chr5_KL567953v1_random\tLN:17865\n@SQ\tSN:chr5_KL567954v1_random\tLN:33929\n@SQ\tSN:chr5_AABR07046507v1_random\tLN:1207\n@SQ\tSN:chr5_KL567955v1_random\tLN:2942\n@SQ\tSN:chr5_KL567956v1_random\tLN:667\n@SQ\tSN:chr5_KL567957v1_random\tLN:32762\n@SQ\tSN:chr5_AABR07046433v1_random\tLN:2834\n@SQ\tSN:chr5_KL567958v1_random\tLN:27327\n@SQ\tSN:chr5_KL567959v1_random\tLN:147722\n@SQ\tSN:chr5_KL567960v1_random\tLN:4527\n@SQ\tSN:chr5_KL567961v1_random\tLN:10282\n@SQ\tSN:chr5_KL567962v1_random\tLN:6046\n@SQ\tSN:chr5_KL567963v1_random\tLN:11717\n@SQ\tSN:chr5_KL567964v1_random\tLN:6173\n@SQ\tSN:chr6\tLN:147991367\n@SQ\tSN:chr6_KL567965v1_random\tLN:26164\n@SQ\tSN:chr6_KL567966v1_random\tLN:11408\n@SQ\tSN:chr6_KL567967v1_random\tLN:13829\n@SQ\tSN:chr6_KL567968v1_random\tLN:14678\n@SQ\tSN:chr6_KL567969v1_random\tLN:4340\n@SQ\tSN:chr6_KL567970v1_random\tLN:16625\n@SQ\tSN:chr6_KL567971v1_random\tLN:14904\n@SQ\tSN:chr6_KL567972v1_random\tLN:25590\n@SQ\tSN:chr6_AABR07055042v1_random\tLN:1118\n@SQ\tSN:chr6_KL567973v1_random\tLN:15169\n@SQ\tSN:chr6_KL567974v1_random\tLN:16318\n@SQ\tSN:chr7\tLN:145729302\n@SQ\tSN:chr7_AABR07046019v1_random\tLN:523\n@SQ\tSN:chr7_KL567975v1_random\tLN:26321\n@SQ\tSN:chr7_KL567976v1_random\tLN:24724\n@SQ\tSN:chr7_KL567977v1_random\tLN:11537\n@SQ\tSN:chr7_KL567978v1_random\tLN:3931\n@SQ\tSN:chr7_KL567979v1_random\tLN:569\n@SQ\tSN:chr7_KL567980v1_random\tLN:14205\n@SQ\tSN:chr7_KL567981v1_random\tLN:38234\n@SQ\tSN:chr7_KL567982v1_random\tLN:15070\n@SQ\tSN:chr7_KL567983v1_random\tLN:13399\n@SQ\tSN:chr7_KL567984v1_random\tLN:39602\n@SQ\tSN:chr7_KL567985v1_random\tLN:4799\n@SQ\tSN:chr7_KL567986v1_random\tLN:25064\n@SQ\tSN:chr7_KL567987v1_random\tLN:14346\n@SQ\tSN:chr7_AABR07046136v1_random\tLN:16358\n@SQ\tSN:chr7_AABR07046137v1_random\tLN:1393\n@SQ\tSN:chr7_KL567988v1_random\tLN:36409\n@SQ\tSN:chr7_KL567989v1_random\tLN:1608\n@SQ\tSN:chr7_KL567990v1_random\tLN:2196\n@SQ\tSN:chr7_KL567991v1_random\tLN:1075\n@SQ\tSN:chr7_KL567992v1_random\tLN:2204\n@SQ\tSN:chr7_AABR07046034v1_random\tLN:530\n@SQ\tSN:chr7_KL567993v1_random\tLN:26319\n@SQ\tSN:chr7_KL567994v1_random\tLN:69252\n@SQ\tSN:chr8\tLN:133307652\n@SQ\tSN:chr8_KL567995v1_random\tLN:18840\n@SQ\tSN:chr8_AABR07050727v1_random\tLN:2164\n@SQ\tSN:chr8_KL567996v1_random\tLN:2893\n@SQ\tSN:chr8_AABR07050661v1_random\tLN:586\n@SQ\tSN:chr8_KL567997v1_random\tLN:36789\n@SQ\tSN:chr8_KL567998v1_random\tLN:11262\n@SQ\tSN:chr8_KL567999v1_random\tLN:17960\n@SQ\tSN:chr8_KL568000v1_random\tLN:3475\n@SQ\tSN:chr8_AABR07050689v1_random\tLN:760\n@SQ\tSN:chr8_KL568001v1_random\tLN:95634\n@SQ\tSN:chr8_KL568002v1_random\tLN:23102\n@SQ\tSN:chr9\tLN:122095297\n@SQ\tSN:chr9_KL568003v1_random\tLN:104398\n@SQ\tSN:chr9_KL568004v1_random\tLN:3829\n@SQ\tSN:chr9_AABR07051154v1_random\tLN:520\n@SQ\tSN:chr9_AABR07051155v1_random\tLN:4212\n@SQ\tSN:chr9_KL568005v1_random\tLN:48638\n@SQ\tSN:chr9_KL568006v1_random\tLN:29490\n@SQ\tSN:chr9_KL568007v1_random\tLN:19393\n@SQ\tSN:chrM\tLN:16313\n@SQ\tSN:chrUn_KL568167v1\tLN:11182\n@SQ\tSN:chrUn_KL568168v1\tLN:2015\n@SQ\tSN:chrUn_KL568169v1\tLN:21595\n@SQ\tSN:chrUn_AABR07022478v1\tLN:530\n@SQ\tSN:chrUn_AABR07022479v1\tLN:503\n@SQ\tSN:chrUn_KL568170v1\tLN:12470\n@SQ\tSN:chrUn_KL568171v1\tLN:2141\n@SQ\tSN:chrUn_KL568172v1\tLN:2699\n@SQ\tSN:chrUn_KL568173v1\tLN:11069\n@SQ\tSN:chrUn_KL568174v1\tLN:12149\n@SQ\tSN:chrUn_KL568175v1\tLN:1861\n@SQ\tSN:chrUn_KL568176v1\tLN:21235\n@SQ\tSN:chrUn_KL568177v1\tLN:5691\n@SQ\tSN:chrUn_KL568178v1\tLN:2131\n@SQ\tSN:chrUn_AABR07022504v1\tLN:555\n@SQ\tSN:chrUn_KL568179v1\tLN:8008\n@SQ\tSN:chrUn_KL568180v1\tLN:7344\n@SQ\tSN:chrUn_AABR07022511v1\tLN:3545\n@SQ\tSN:chrUn_KL568181v1\tLN:1130\n@SQ\tSN:chrUn_AABR07022514v1\tLN:450\n@SQ\tSN:chrUn_KL568182v1\tLN:1923\n@SQ\tSN:chrUn_AABR07022517v1\tLN:942\n@SQ\tSN:chrUn_KL568183v1\tLN:3177\n@SQ\tSN:chrUn_AABR07022519v1\tLN:663\n@SQ\tSN:chrUn_KL568184v1\tLN:1761\n@SQ\tSN:chrUn_KL568185v1\tLN:34391\n@SQ\tSN:chrUn_KL568186v1\tLN:4076\n@SQ\tSN:chrUn_AABR07022531v1\tLN:766\n@SQ\tSN:chrUn_AABR07022532v1\tLN:503\n@SQ\tSN:chrUn_KL568187v1\tLN:34792\n@SQ\tSN:chrUn_KL568188v1\tLN:2287\n@SQ\tSN:chrUn_KL568189v1\tLN:1389\n@SQ\tSN:chrUn_KL568190v1\tLN:11903\n@SQ\tSN:chrUn_AABR07022257v1\tLN:562\n@SQ\tSN:chrUn_KL568191v1\tLN:33866\n@SQ\tSN:chrUn_AABR07022559v1\tLN:609\n@SQ\tSN:chrUn_KL568192v1\tLN:3219\n@SQ\tSN:chrUn_KL568193v1\tLN:31523\n@SQ\tSN:chrUn_AABR07022573v1\tLN:1063\n@SQ\tSN:chrUn_KL568194v1\tLN:2533\n@SQ\tSN:chrUn_KL568195v1\tLN:5841\n@SQ\tSN:chrUn_KL568196v1\tLN:29796\n@SQ\tSN:chrUn_KL568197v1\tLN:6090\n@SQ\tSN:chrUn_AABR07022594v1\tLN:1852\n@SQ\tSN:chrUn_AABR07022258v1\tLN:875\n@SQ\tSN:chrUn_KL568198v1\tLN:15369\n@SQ\tSN:chrUn_KL568199v1\tLN:12984\n@SQ\tSN:chrUn_KL568200v1\tLN:5023\n@SQ\tSN:chrUn_KL568201v1\tLN:5537\n@SQ\tSN:chrUn_AABR07022608v1\tLN:790\n@SQ\tSN:chrUn_KL568202v1\tLN:7012\n@SQ\tSN:chrUn_AABR07022616v1\tLN:815\n@SQ\tSN:chrUn_KL568203v1\tLN:1485\n@SQ\tSN:chrUn_AABR07022619v1\tLN:663\n@SQ\tSN:chrUn_AABR07022620v1\tLN:2057\n@SQ\tSN:chrUn_AABR07022259v1\tLN:667\n@SQ\tSN:chrUn_AABR07022621v1\tLN:547\n@SQ\tSN:chrUn_KL568204v1\tLN:1028\n@SQ\tSN:chrUn_KL568205v1\tLN:2858\n@SQ\tSN:chrUn_AABR07022626v1\tLN:804\n@SQ\tSN:chrUn_AABR07022627v1\tLN:795\n@SQ\tSN:chrUn_AABR07022628v1\tLN:535\n@SQ\tSN:chrUn_AABR07022629v1\tLN:613\n@SQ\tSN:chrUn_AABR07022630v1\tLN:2877\n@SQ\tSN:chrUn_KL568206v1\tLN:795\n@SQ\tSN:chrUn_KL568207v1\tLN:2985\n@SQ\tSN:chrUn_KL568208v1\tLN:6280\n@SQ\tSN:chrUn_KL568209v1\tLN:1619\n@SQ\tSN:chrUn_KL568210v1\tLN:1709\n@SQ\tSN:chrUn_AABR07022645v1\tLN:523\n@SQ\tSN:chrUn_KL568211v1\tLN:1424\n@SQ\tSN:chrUn_KL568212v1\tLN:17641\n@SQ\tSN:chrUn_AABR07022654v1\tLN:1981\n@SQ\tSN:chrUn_KL568213v1\tLN:3120\n@SQ\tSN:chrUn_KL568214v1\tLN:3273\n@SQ\tSN:chrUn_KL568215v1\tLN:15161\n@SQ\tSN:chrUn_AABR07022263v1\tLN:626\n@SQ\tSN:chrUn_KL568216v1\tLN:1404\n@SQ\tSN:chrUn_AABR07022671v1\tLN:563\n@SQ\tSN:chrUn_AABR07022672v1\tLN:706\n@SQ\tSN:chrUn_KL568217v1\tLN:2047\n@SQ\tSN:chrUn_AABR07022676v1\tLN:690\n@SQ\tSN:chrUn_KL568218v1\tLN:14221\n@SQ\tSN:chrUn_KL568219v1\tLN:18520\n@SQ\tSN:chrUn_AABR07022684v1\tLN:681\n@SQ\tSN:chrUn_KL568220v1\tLN:3003\n@SQ\tSN:chrUn_KL568221v1\tLN:2110\n@SQ\tSN:chrUn_AABR07022264v1\tLN:714\n@SQ\tSN:chrUn_KL568222v1\tLN:1709\n@SQ\tSN:chrUn_KL568223v1\tLN:7105\n@SQ\tSN:chrUn_KL568224v1\tLN:13776\n@SQ\tSN:chrUn_KL568225v1\tLN:11178\n@SQ\tSN:chrUn_AABR07022707v1\tLN:3741\n@SQ\tSN:chrUn_KL568226v1\tLN:6062\n@SQ\tSN:chrUn_KL568227v1\tLN:2774\n@SQ\tSN:chrUn_KL568228v1\tLN:26706\n@SQ\tSN:chrUn_AABR07022265v1\tLN:675\n@SQ\tSN:chrUn_KL568229v1\tLN:1413\n@SQ\tSN:chrUn_AABR07022726v1\tLN:588\n@SQ\tSN:chrUn_KL568230v1\tLN:1324\n@SQ\tSN:chrUn_AABR07022729v1\tLN:740\n@SQ\tSN:chrUn_KL568231v1\tLN:2132\n@SQ\tSN:chrUn_KL568232v1\tLN:2600\n@SQ\tSN:chrUn_KL568233v1\tLN:3210\n@SQ\tSN:chrUn_AABR07022737v1\tLN:2840\n@SQ\tSN:chrUn_AABR07022738v1\tLN:588\n@SQ\tSN:chrUn_KL568234v1\tLN:5584\n@SQ\tSN:chrUn_KL568235v1\tLN:7064\n@SQ\tSN:chrUn_AABR07022266v1\tLN:650\n@SQ\tSN:chrUn_KL568236v1\tLN:1497\n@SQ\tSN:chrUn_KL568237v1\tLN:4201\n@SQ\tSN:chrUn_KL568238v1\tLN:1101\n@SQ\tSN:chrUn_KL568239v1\tLN:1652\n@SQ\tSN:chrUn_AABR07022753v1\tLN:529\n@SQ\tSN:chrUn_KL568240v1\tLN:1765\n@SQ\tSN:chrUn_KL568241v1\tLN:1994\n@SQ\tSN:chrUn_AABR07022759v1\tLN:741\n@SQ\tSN:chrUn_AABR07022760v1\tLN:658\n@SQ\tSN:chrUn_KL568242v1\tLN:4688\n@SQ\tSN:chrUn_KL568243v1\tLN:1724\n@SQ\tSN:chrUn_KL568244v1\tLN:1998\n@SQ\tSN:chrUn_KL568245v1\tLN:21811\n@SQ\tSN:chrUn_KL568246v1\tLN:5769\n@SQ\tSN:chrUn_KL568247v1\tLN:3663\n@SQ\tSN:chrUn_KL568248v1\tLN:22287\n@SQ\tSN:chrUn_KL568249v1\tLN:1218\n@SQ\tSN:chrUn_AABR07022783v1\tLN:560\n@SQ\tSN:chrUn_KL568250v1\tLN:1250\n@SQ\tSN:chrUn_KL568251v1\tLN:15341\n@SQ\tSN:chrUn_AABR07022273v1\tLN:556\n@SQ\tSN:chrUn_KL568252v1\tLN:2198\n@SQ\tSN:chrUn_AABR07022793v1\tLN:493\n@SQ\tSN:chrUn_KL568253v1\tLN:1810\n@SQ\tSN:chrUn_KL568254v1\tLN:5473\n@SQ\tSN:chrUn_KL568255v1\tLN:1519\n@SQ\tSN:chrUn_AABR07022802v1\tLN:521\n@SQ\tSN:chrUn_KL568256v1\tLN:4854\n@SQ\tSN:chrUn_KL568257v1\tLN:35119\n@SQ\tSN:chrUn_KL568258v1\tLN:2384\n@SQ\tSN:chrUn_KL568259v1\tLN:4341\n@SQ\tSN:chrUn_KL568260v1\tLN:4168\n@SQ\tSN:chrUn_KL568261v1\tLN:1528\n@SQ\tSN:chrUn_AABR07022827v1\tLN:619\n@SQ\tSN:chrUn_AABR07022828v1\tLN:664\n@SQ\tSN:chrUn_AABR07022829v1\tLN:549\n@SQ\tSN:chrUn_AABR07022830v1\tLN:1094\n@SQ\tSN:chrUn_KL568262v1\tLN:2018\n@SQ\tSN:chrUn_KL568263v1\tLN:5941\n@SQ\tSN:chrUn_KL568264v1\tLN:1570\n@SQ\tSN:chrUn_KL568265v1\tLN:1130\n@SQ\tSN:chrUn_AABR07022279v1\tLN:704\n@SQ\tSN:chrUn_KL568266v1\tLN:9310\n@SQ\tSN:chrUn_KL568267v1\tLN:3782\n@SQ\tSN:chrUn_KL568268v1\tLN:5463\n@SQ\tSN:chrUn_KL568269v1\tLN:1156\n@SQ\tSN:chrUn_AABR07022857v1\tLN:996\n@SQ\tSN:chrUn_KL568270v1\tLN:19998\n@SQ\tSN:chrUn_KL568271v1\tLN:5328\n@SQ\tSN:chrUn_AABR07022871v1\tLN:1098\n@SQ\tSN:chrUn_KL568272v1\tLN:17134\n@SQ\tSN:chrUn_AABR07022880v1\tLN:577\n@SQ\tSN:chrUn_KL568273v1\tLN:3880\n@SQ\tSN:chrUn_AABR07022881v1\tLN:642\n@SQ\tSN:chrUn_KL568274v1\tLN:5820\n@SQ\tSN:chrUn_AABR07022884v1\tLN:614\n@SQ\tSN:chrUn_AABR07022885v1\tLN:265\n@SQ\tSN:chrUn_KL568275v1\tLN:1066\n@SQ\tSN:chrUn_KL568276v1\tLN:1684\n@SQ\tSN:chrUn_KL568277v1\tLN:1370\n@SQ\tSN:chrUn_KL568278v1\tLN:1760\n@SQ\tSN:chrUn_KL568279v1\tLN:1061\n@SQ\tSN:chrUn_AABR07022284v1\tLN:700\n@SQ\tSN:chrUn_KL568280v1\tLN:4786\n@SQ\tSN:chrUn_KL568281v1\tLN:5240\n@SQ\tSN:chrUn_AABR07022905v1\tLN:763\n@SQ\tSN:chrUn_AABR07022906v1\tLN:453\n@SQ\tSN:chrUn_AABR07022907v1\tLN:670\n@SQ\tSN:chrUn_KL568282v1\tLN:48841\n@SQ\tSN:chrUn_AABR07022920v1\tLN:515\n@SQ\tSN:chrUn_AABR07022921v1\tLN:649\n@SQ\tSN:chrUn_AABR07022922v1\tLN:567\n@SQ\tSN:chrUn_KL568283v1\tLN:11645\n@SQ\tSN:chrUn_AABR07022923v1\tLN:2226\n@SQ\tSN:chrUn_KL568284v1\tLN:1512\n@SQ\tSN:chrUn_AABR07022926v1\tLN:1138\n@SQ\tSN:chrUn_KL568285v1\tLN:12244\n@SQ\tSN:chrUn_KL568286v1\tLN:5311\n@SQ\tSN:chrUn_AABR07022934v1\tLN:743\n@SQ\tSN:chrUn_KL568287v1\tLN:3520\n@SQ\tSN:chrUn_KL568288v1\tLN:7455\n@SQ\tSN:chrUn_AABR07022944v1\tLN:238\n@SQ\tSN:chrUn_KL568289v1\tLN:5072\n@SQ\tSN:chrUn_AABR07022287v1\tLN:683\n@SQ\tSN:chrUn_KL568290v1\tLN:5288\n@SQ\tSN:chrUn_KL568291v1\tLN:2924\n@SQ\tSN:chrUn_AABR07022957v1\tLN:575\n@SQ\tSN:chrUn_KL568292v1\tLN:38332\n@SQ\tSN:chrUn_KL568293v1\tLN:5847\n@SQ\tSN:chrUn_AABR07022973v1\tLN:786\n@SQ\tSN:chrUn_KL568294v1\tLN:2680\n@SQ\tSN:chrUn_KL568295v1\tLN:25592\n@SQ\tSN:chrUn_AABR07022990v1\tLN:622\n@SQ\tSN:chrUn_KL568296v1\tLN:1127\n@SQ\tSN:chrUn_AABR07022993v1\tLN:642\n@SQ\tSN:chrUn_AABR07022994v1\tLN:526\n@SQ\tSN:chrUn_KL568297v1\tLN:5492\n@SQ\tSN:chrUn_KL568298v1\tLN:1200\n@SQ\tSN:chrUn_KL568299v1\tLN:4870\n@SQ\tSN:chrUn_KL568300v1\tLN:10110\n@SQ\tSN:chrUn_KL568301v1\tLN:2759\n@SQ\tSN:chrUn_KL568302v1\tLN:1571\n@SQ\tSN:chrUn_AABR07022288v1\tLN:522\n@SQ\tSN:chrUn_AABR07023014v1\tLN:529\n@SQ\tSN:chrUn_KL568303v1\tLN:22032\n@SQ\tSN:chrUn_KL568304v1\tLN:10256\n@SQ\tSN:chrUn_KL568305v1\tLN:2760\n@SQ\tSN:chrUn_AABR07023024v1\tLN:748\n@SQ\tSN:chrUn_KL568306v1\tLN:6288\n@SQ\tSN:chrUn_AABR07023031v1\tLN:813\n@SQ\tSN:chrUn_KL568307v1\tLN:29238\n@SQ\tSN:chrUn_KL568308v1\tLN:1740\n@SQ\tSN:chrUn_KL568309v1\tLN:3422\n@SQ\tSN:chrUn_KL568310v1\tLN:6164\n@SQ\tSN:chrUn_AABR07023052v1\tLN:1106\n@SQ\tSN:chrUn_KL568311v1\tLN:3190\n@SQ\tSN:chrUn_KL568312v1\tLN:20693\n@SQ\tSN:chrUn_KL568313v1\tLN:5919\n@SQ\tSN:chrUn_AABR07023067v1\tLN:774\n@SQ\tSN:chrUn_AABR07023068v1\tLN:2217\n@SQ\tSN:chrUn_KL568314v1\tLN:33342\n@SQ\tSN:chrUn_KL568315v1\tLN:91871\n@SQ\tSN:chrUn_KL568316v1\tLN:16204\n@SQ\tSN:chrUn_KL568317v1\tLN:16248\n@SQ\tSN:chrUn_KL568318v1\tLN:125475\n@SQ\tSN:chrUn_KL568319v1\tLN:119946\n@SQ\tSN:chrUn_KL568320v1\tLN:2745\n@SQ\tSN:chrUn_KL568321v1\tLN:26605\n@SQ\tSN:chrUn_KL568322v1\tLN:33480\n@SQ\tSN:chrUn_AABR07023168v1\tLN:2153\n@SQ\tSN:chrUn_KL568323v1\tLN:14207\n@SQ\tSN:chrUn_KL568324v1\tLN:66040\n@SQ\tSN:chrUn_KL568325v1\tLN:54929\n@SQ\tSN:chrUn_KL568326v1\tLN:11525\n@SQ\tSN:chrUn_KL568327v1\tLN:3635\n@SQ\tSN:chrUn_KL568328v1\tLN:79909\n@SQ\tSN:chrUn_KL568329v1\tLN:16490\n@SQ\tSN:chrUn_KL568330v1\tLN:30684\n@SQ\tSN:chrUn_KL568331v1\tLN:13633\n@SQ\tSN:chrUn_KL568332v1\tLN:7699\n@SQ\tSN:chrUn_KL568333v1\tLN:5195\n@SQ\tSN:chrUn_KL568334v1\tLN:86017\n@SQ\tSN:chrUn_KL568335v1\tLN:10099\n@SQ\tSN:chrUn_KL568336v1\tLN:91174\n@SQ\tSN:chrUn_AABR07022298v1\tLN:428\n@SQ\tSN:chrUn_KL568337v1\tLN:70310\n@SQ\tSN:chrUn_AABR07023321v1\tLN:656\n@SQ\tSN:chrUn_KL568338v1\tLN:1318\n@SQ\tSN:chrUn_AABR07023324v1\tLN:503\n@SQ\tSN:chrUn_AABR07023325v1\tLN:1839\n@SQ\tSN:chrUn_KL568339v1\tLN:3656\n@SQ\tSN:chrUn_KL568340v1\tLN:13915\n@SQ\tSN:chrUn_KL568341v1\tLN:11068\n@SQ\tSN:chrUn_KL568342v1\tLN:46249\n@SQ\tSN:chrUn_KL568343v1\tLN:23983\n@SQ\tSN:chrUn_AABR07022299v1\tLN:1106\n@SQ\tSN:chrUn_KL568344v1\tLN:47276\n@SQ\tSN:chrUn_KL568345v1\tLN:35857\n@SQ\tSN:chrUn_KL568346v1\tLN:83525\n@SQ\tSN:chrUn_KL568347v1\tLN:3871\n@SQ\tSN:chrUn_KL568348v1\tLN:34944\n@SQ\tSN:chrUn_KL568349v1\tLN:21578\n@SQ\tSN:chrUn_KL568350v1\tLN:44681\n@SQ\tSN:chrUn_AABR07023445v1\tLN:789\n@SQ\tSN:chrUn_KL568351v1\tLN:16017\n@SQ\tSN:chrUn_KL568352v1\tLN:2296\n@SQ\tSN:chrUn_AABR07022300v1\tLN:584\n@SQ\tSN:chrUn_KL568353v1\tLN:246307\n@SQ\tSN:chrUn_KL568354v1\tLN:113311\n@SQ\tSN:chrUn_AABR07023534v1\tLN:647\n@SQ\tSN:chrUn_KL568355v1\tLN:51892\n@SQ\tSN:chrUn_KL568356v1\tLN:24824\n@SQ\tSN:chrUn_AABR07023560v1\tLN:592\n@SQ\tSN:chrUn_KL568357v1\tLN:42088\n@SQ\tSN:chrUn_KL568358v1\tLN:9478\n@SQ\tSN:chrUn_KL568359v1\tLN:25619\n@SQ\tSN:chrUn_KL568360v1\tLN:78647\n@SQ\tSN:chrUn_AABR07022301v1\tLN:482\n@SQ\tSN:chrUn_KL568361v1\tLN:38115\n@SQ\tSN:chrUn_KL568362v1\tLN:110326\n@SQ\tSN:chrUn_KL568363v1\tLN:4501\n@SQ\tSN:chrUn_KL568364v1\tLN:40094\n@SQ\tSN:chrUn_KL568365v1\tLN:3788\n@SQ\tSN:chrUn_KL568366v1\tLN:89457\n@SQ\tSN:chrUn_KL568367v1\tLN:7294\n@SQ\tSN:chrUn_KL568368v1\tLN:3026\n@SQ\tSN:chrUn_KL568369v1\tLN:1310\n@SQ\tSN:chrUn_KL568370v1\tLN:45784\n@SQ\tSN:chrUn_KL568371v1\tLN:1945\n@SQ\tSN:chrUn_KL568372v1\tLN:4252\n@SQ\tSN:chrUn_KL568373v1\tLN:12016\n@SQ\tSN:chrUn_KL568374v1\tLN:333641\n@SQ\tSN:chrUn_KL568375v1\tLN:1421\n@SQ\tSN:chrUn_KL568376v1\tLN:22589\n@SQ\tSN:chrUn_KL568377v1\tLN:78358\n@SQ\tSN:chrUn_KL568378v1\tLN:2442\n@SQ\tSN:chrUn_KL568379v1\tLN:85300\n@SQ\tSN:chrUn_KL568380v1\tLN:15687\n@SQ\tSN:chrUn_KL568381v1\tLN:64584\n@SQ\tSN:chrUn_AABR07022304v1\tLN:714\n@SQ\tSN:chrUn_KL568382v1\tLN:6932\n@SQ\tSN:chrUn_KL568383v1\tLN:7756\n@SQ\tSN:chrUn_KL568384v1\tLN:12708\n@SQ\tSN:chrUn_KL568385v1\tLN:1647\n@SQ\tSN:chrUn_KL568386v1\tLN:1285\n@SQ\tSN:chrUn_KL568387v1\tLN:31396\n@SQ\tSN:chrUn_KL568388v1\tLN:70933\n@SQ\tSN:chrUn_KL568389v1\tLN:23929\n@SQ\tSN:chrUn_KL568390v1\tLN:14001\n@SQ\tSN:chrUn_AABR07023949v1\tLN:515\n@SQ\tSN:chrUn_KL568391v1\tLN:25619\n@SQ\tSN:chrUn_KL568392v1\tLN:3563\n@SQ\tSN:chrUn_KL568393v1\tLN:5972\n@SQ\tSN:chrUn_KL568394v1\tLN:22601\n@SQ\tSN:chrUn_KL568395v1\tLN:56177\n@SQ\tSN:chrUn_AABR07023967v1\tLN:516\n@SQ\tSN:chrUn_AABR07023968v1\tLN:1301\n@SQ\tSN:chrUn_KL568396v1\tLN:12101\n@SQ\tSN:chrUn_KL568397v1\tLN:75068\n@SQ\tSN:chrUn_KL568398v1\tLN:68568\n@SQ\tSN:chrUn_KL568399v1\tLN:30444\n@SQ\tSN:chrUn_KL568400v1\tLN:29228\n@SQ\tSN:chrUn_KL568401v1\tLN:3168\n@SQ\tSN:chrUn_KL568402v1\tLN:36615\n@SQ\tSN:chrUn_AABR07023990v1\tLN:4561\n@SQ\tSN:chrUn_KL568403v1\tLN:22089\n@SQ\tSN:chrUn_KL568404v1\tLN:24694\n@SQ\tSN:chrUn_KL568405v1\tLN:151075\n@SQ\tSN:chrUn_KL568406v1\tLN:28554\n@SQ\tSN:chrUn_AABR07024005v1\tLN:665\n@SQ\tSN:chrUn_AABR07024006v1\tLN:657\n@SQ\tSN:chrUn_AABR07024007v1\tLN:828\n@SQ\tSN:chrUn_KL568407v1\tLN:2094\n@SQ\tSN:chrUn_KL568408v1\tLN:46319\n@SQ\tSN:chrUn_KL568409v1\tLN:409149\n@SQ\tSN:chrUn_AABR07024031v1\tLN:62230\n@SQ\tSN:chrUn_AABR07024032v1\tLN:24546\n@SQ\tSN:chrUn_KL568410v1\tLN:197620\n@SQ\tSN:chrUn_AABR07024039v1\tLN:65089\n@SQ\tSN:chrUn_AABR07024040v1\tLN:11025\n@SQ\tSN:chrUn_AABR07024041v1\tLN:31641\n@SQ\tSN:chrUn_AABR07024042v1\tLN:35846\n@SQ\tSN:chrUn_AABR07024043v1\tLN:665\n@SQ\tSN:chrUn_KL568411v1\tLN:21210\n@SQ\tSN:chrUn_AABR07024044v1\tLN:21485\n@SQ\tSN:chrUn_AABR07024045v1\tLN:2041\n@SQ\tSN:chrUn_AABR07024046v1\tLN:4613\n@SQ\tSN:chrUn_AABR07024047v1\tLN:128550\n@SQ\tSN:chrUn_KL568412v1\tLN:69990\n@SQ\tSN:chrUn_KL568413v1\tLN:115560\n@SQ\tSN:chrUn_KL568414v1\tLN:134730\n@SQ\tSN:chrUn_KL568415v1\tLN:110043\n@SQ\tSN:chrUn_AABR07024066v1\tLN:44061\n@SQ\tSN:chrUn_AABR07024067v1\tLN:4328\n@SQ\tSN:chrUn_KL568416v1\tLN:3052\n@SQ\tSN:chrUn_KL568417v1\tLN:62095\n@SQ\tSN:chrUn_AABR07024071v1\tLN:21256\n@SQ\tSN:chrUn_KL568418v1\tLN:276968\n@SQ\tSN:chrUn_AABR07024080v1\tLN:991\n@SQ\tSN:chrUn_KL568419v1\tLN:82153\n@SQ\tSN:chrUn_KL568420v1\tLN:33038\n@SQ\tSN:chrUn_AABR07024092v1\tLN:669\n@SQ\tSN:chrUn_KL568421v1\tLN:106580\n@SQ\tSN:chrUn_AABR07024100v1\tLN:507\n@SQ\tSN:chrUn_AABR07024101v1\tLN:4996\n@SQ\tSN:chrUn_KL568422v1\tLN:1106\n@SQ\tSN:chrUn_AABR07024102v1\tLN:54789\n@SQ\tSN:chrUn_AABR07024103v1\tLN:832\n@SQ\tSN:chrUn_AABR07024104v1\tLN:66549\n@SQ\tSN:chrUn_AABR07024105v1\tLN:4462\n@SQ\tSN:chrUn_AABR07024106v1\tLN:41833\n@SQ\tSN:chrUn_KL568423v1\tLN:57880\n@SQ\tSN:chrUn_KL568424v1\tLN:52566\n@SQ\tSN:chrUn_AABR07024114v1\tLN:836\n@SQ\tSN:chrUn_AABR07024115v1\tLN:4365\n@SQ\tSN:chrUn_KL568425v1\tLN:11782\n@SQ\tSN:chrUn_KL568426v1\tLN:2831\n@SQ\tSN:chrUn_AABR07024118v1\tLN:4550\n@SQ\tSN:chrUn_AABR07024119v1\tLN:12249\n@SQ\tSN:chrUn_AABR07024120v1\tLN:52816\n@SQ\tSN:chrUn_AABR07024121v1\tLN:586\n@SQ\tSN:chrUn_AABR07024122v1\tLN:18491\n@SQ\tSN:chrUn_AABR07024123v1\tLN:3961\n@SQ\tSN:chrUn_AABR07024124v1\tLN:82313\n@SQ\tSN:chrUn_AABR07024125v1\tLN:904\n@SQ\tSN:chrUn_KL568427v1\tLN:24952\n@SQ\tSN:chrUn_KL568428v1\tLN:15511\n@SQ\tSN:chrUn_KL568429v1\tLN:1681\n@SQ\tSN:chrUn_KL568430v1\tLN:55205\n@SQ\tSN:chrUn_KL568431v1\tLN:45117\n@SQ\tSN:chrUn_AABR07024138v1\tLN:897\n@SQ\tSN:chrUn_KL568432v1\tLN:170578\n@SQ\tSN:chrUn_AABR07024145v1\tLN:68209\n@SQ\tSN:chrUn_KL568433v1\tLN:51123\n@SQ\tSN:chrUn_AABR07024150v1\tLN:10542\n@SQ\tSN:chrUn_KL568434v1\tLN:100599\n@SQ\tSN:chrUn_AABR07024159v1\tLN:3318\n@SQ\tSN:chrUn_AABR07024160v1\tLN:980\n@SQ\tSN:chrUn_KL568435v1\tLN:2121\n@SQ\tSN:chrUn_KL568436v1\tLN:32325\n@SQ\tSN:chrUn_AABR07024165v1\tLN:2419\n@SQ\tSN:chrUn_KL568437v1\tLN:13579\n@SQ\tSN:chrUn_KL568438v1\tLN:140435\n@SQ\tSN:chrUn_AABR07024177v1\tLN:602\n@SQ\tSN:chrUn_AABR07024178v1\tLN:1101\n@SQ\tSN:chrUn_KL568439v1\tLN:31478\n@SQ\tSN:chrUn_AABR07024182v1\tLN:920\n@SQ\tSN:chrUn_KL568440v1\tLN:62701\n@SQ\tSN:chrUn_AABR07024187v1\tLN:3745\n@SQ\tSN:chrUn_AABR07022333v1\tLN:391\n@SQ\tSN:chrUn_AABR07024188v1\tLN:156216\n@SQ\tSN:chrUn_AABR07024189v1\tLN:659\n@SQ\tSN:chrUn_KL568441v1\tLN:15269\n@SQ\tSN:chrUn_AABR07024192v1\tLN:32611\n@SQ\tSN:chrUn_AABR07024193v1\tLN:3838\n@SQ\tSN:chrUn_AABR07024194v1\tLN:559\n@SQ\tSN:chrUn_AABR07024195v1\tLN:1593\n@SQ\tSN:chrUn_AABR07024196v1\tLN:1098\n@SQ\tSN:chrUn_KL568442v1\tLN:35498\n@SQ\tSN:chrUn_KL568443v1\tLN:61029\n@SQ\tSN:chrUn_KL568444v1\tLN:3439\n@SQ\tSN:chrUn_AABR07022334v1\tLN:815\n@SQ\tSN:chrUn_AABR07024203v1\tLN:96120\n@SQ\tSN:chrUn_AABR07024204v1\tLN:1554\n@SQ\tSN:chrUn_AABR07024205v1\tLN:8757\n@SQ\tSN:chrUn_AABR07024206v1\tLN:20997\n@SQ\tSN:chrUn_KL568445v1\tLN:55656\n@SQ\tSN:chrUn_KL568446v1\tLN:122070\n@SQ\tSN:chrUn_KL568447v1\tLN:122693\n@SQ\tSN:chrUn_AABR07024221v1\tLN:1065\n@SQ\tSN:chrUn_AABR07024222v1\tLN:4316\n@SQ\tSN:chrUn_AABR07024223v1\tLN:754\n@SQ\tSN:chrUn_AABR07022335v1\tLN:654\n@SQ\tSN:chrUn_KL568448v1\tLN:11863\n@SQ\tSN:chrUn_AABR07024226v1\tLN:550\n@SQ\tSN:chrUn_AABR07024227v1\tLN:693\n@SQ\tSN:chrUn_AABR07024228v1\tLN:3757\n@SQ\tSN:chrUn_AABR07024229v1\tLN:1833\n@SQ\tSN:chrUn_KL568449v1\tLN:148379\n@SQ\tSN:chrUn_KL568450v1\tLN:81653\n@SQ\tSN:chrUn_KL568451v1\tLN:259454\n@SQ\tSN:chrUn_AABR07024262v1\tLN:15893\n@SQ\tSN:chrUn_AABR07024263v1\tLN:26083\n@SQ\tSN:chrUn_AABR07022336v1\tLN:723\n@SQ\tSN:chrUn_AABR07024264v1\tLN:11303\n@SQ\tSN:chrUn_AABR07024265v1\tLN:1285\n@SQ\tSN:chrUn_AABR07024266v1\tLN:594\n@SQ\tSN:chrUn_AABR07024267v1\tLN:3745\n@SQ\tSN:chrUn_AABR07024268v1\tLN:230\n@SQ\tSN:chrUn_AABR07024269v1\tLN:1048\n@SQ\tSN:chrUn_KL568452v1\tLN:36554\n@SQ\tSN:chrUn_KL568453v1\tLN:56678\n@SQ\tSN:chrUn_KL568454v1\tLN:75706\n@SQ\tSN:chrUn_KL568455v1\tLN:11965\n@SQ\tSN:chrUn_AABR07022337v1\tLN:564\n@SQ\tSN:chrUn_AABR07024286v1\tLN:18032\n@SQ\tSN:chrUn_KL568456v1\tLN:12647\n@SQ\tSN:chrUn_AABR07024289v1\tLN:692\n@SQ\tSN:chrUn_AABR07024290v1\tLN:3036\n@SQ\tSN:chrUn_AABR07024291v1\tLN:140190\n@SQ\tSN:chrUn_AABR07024292v1\tLN:5784\n@SQ\tSN:chrUn_AABR07024293v1\tLN:1238\n@SQ\tSN:chrUn_AABR07024294v1\tLN:678\n@SQ\tSN:chrUn_KL568457v1\tLN:30706\n@SQ\tSN:chrUn_KL568458v1\tLN:179901\n@SQ\tSN:chrUn_KL568459v1\tLN:3288\n@SQ\tSN:chrUn_AABR07024304v1\tLN:568\n@SQ\tSN:chrUn_KL568460v1\tLN:96610\n@SQ\tSN:chrUn_KL568461v1\tLN:43373\n@SQ\tSN:chrUn_KL568462v1\tLN:47307\n@SQ\tSN:chrUn_AABR07024319v1\tLN:708\n@SQ\tSN:chrUn_AABR07024320v1\tLN:613\n@SQ\tSN:chrUn_AABR07024321v1\tLN:6849\n@SQ\tSN:chrUn_AABR07024322v1\tLN:992\n@SQ\tSN:chrUn_AABR07024323v1\tLN:1633\n@SQ\tSN:chrUn_KL568463v1\tLN:78222\n@SQ\tSN:chrUn_AABR07022342v1\tLN:785\n@SQ\tSN:chrUn_AABR07024331v1\tLN:1116\n@SQ\tSN:chrUn_AABR07024332v1\tLN:1222\n@SQ\tSN:chrUn_KL568464v1\tLN:65989\n@SQ\tSN:chrUn_KL568465v1\tLN:161686\n@SQ\tSN:chrUn_AABR07024349v1\tLN:666\n@SQ\tSN:chrUn_AABR07024350v1\tLN:20296\n@SQ\tSN:chrUn_AABR07024351v1\tLN:628\n@SQ\tSN:chrUn_KL568466v1\tLN:44605\n@SQ\tSN:chrUn_KL568467v1\tLN:46639\n@SQ\tSN:chrUn_KL568468v1\tLN:117679\n@SQ\tSN:chrUn_KL568469v1\tLN:5093\n@SQ\tSN:chrUn_KL568470v1\tLN:78834\n@SQ\tSN:chrUn_KL568471v1\tLN:37571\n@SQ\tSN:chrUn_AABR07024371v1\tLN:721\n@SQ\tSN:chrUn_KL568472v1\tLN:45419\n@SQ\tSN:chrUn_AABR07024374v1\tLN:1080\n@SQ\tSN:chrUn_KL568473v1\tLN:555557\n@SQ\tSN:chrUn_AABR07024382v1\tLN:161493\n@SQ\tSN:chrUn_AABR07024383v1\tLN:744\n@SQ\tSN:chrUn_KL568474v1\tLN:20991\n@SQ\tSN:chrUn_KL568475v1\tLN:29518\n@SQ\tSN:chrUn_AABR07022350v1\tLN:745\n@SQ\tSN:chrUn_AABR07024390v1\tLN:2896\n@SQ\tSN:chrUn_KL568476v1\tLN:14444\n@SQ\tSN:chrUn_AABR07024393v1\tLN:673\n@SQ\tSN:chrUn_AABR07024394v1\tLN:13714\n@SQ\tSN:chrUn_AABR07024395v1\tLN:821\n@SQ\tSN:chrUn_AABR07024396v1\tLN:736\n@SQ\tSN:chrUn_AABR07024397v1\tLN:2454\n@SQ\tSN:chrUn_AABR07024398v1\tLN:44505\n@SQ\tSN:chrUn_AABR07024399v1\tLN:2218\n@SQ\tSN:chrUn_KL568477v1\tLN:79564\n@SQ\tSN:chrUn_KL568478v1\tLN:23222\n@SQ\tSN:chrUn_KL568479v1\tLN:38297\n@SQ\tSN:chrUn_KL568480v1\tLN:41802\n@SQ\tSN:chrUn_KL568481v1\tLN:30624\n@SQ\tSN:chrUn_KL568482v1\tLN:97190\n@SQ\tSN:chrUn_KL568483v1\tLN:36071\n@SQ\tSN:chrUn_AABR07024421v1\tLN:97361\n@SQ\tSN:chrUn_KL568484v1\tLN:11932\n@SQ\tSN:chrUn_KL568485v1\tLN:27645\n@SQ\tSN:chrUn_AABR07024427v1\tLN:1529\n@SQ\tSN:chrUn_AABR07024428v1\tLN:1455\n@SQ\tSN:chrUn_KL568486v1\tLN:15907\n@SQ\tSN:chrUn_KL568487v1\tLN:150036\n@SQ\tSN:chrUn_AABR07024432v1\tLN:579\n@SQ\tSN:chrUn_AABR07024433v1\tLN:637\n@SQ\tSN:chrUn_AABR07022239v1\tLN:607\n@SQ\tSN:chrUn_AABR07022359v1\tLN:723\n@SQ\tSN:chrUn_KL568488v1\tLN:23475\n@SQ\tSN:chrUn_AABR07022367v1\tLN:641\n@SQ\tSN:chrUn_AABR07022368v1\tLN:552\n@SQ\tSN:chrUn_KL568489v1\tLN:1590\n@SQ\tSN:chrUn_KL568490v1\tLN:23674\n@SQ\tSN:chrUn_KL568491v1\tLN:2344\n@SQ\tSN:chrUn_AABR07022378v1\tLN:849\n@SQ\tSN:chrUn_KL568492v1\tLN:21680\n@SQ\tSN:chrUn_KL568493v1\tLN:6345\n@SQ\tSN:chrUn_KL568494v1\tLN:1167\n@SQ\tSN:chrUn_KL568495v1\tLN:11737\n@SQ\tSN:chrUn_KL568496v1\tLN:3657\n@SQ\tSN:chrUn_KL568497v1\tLN:4939\n@SQ\tSN:chrUn_KL568498v1\tLN:13834\n@SQ\tSN:chrUn_AABR07022404v1\tLN:754\n@SQ\tSN:chrUn_AABR07022405v1\tLN:816\n@SQ\tSN:chrUn_KL568499v1\tLN:13135\n@SQ\tSN:chrUn_KL568500v1\tLN:1783\n@SQ\tSN:chrUn_KL568501v1\tLN:1397\n@SQ\tSN:chrUn_AABR07022416v1\tLN:691\n@SQ\tSN:chrUn_KL568502v1\tLN:1892\n@SQ\tSN:chrUn_KL568503v1\tLN:2826\n@SQ\tSN:chrUn_KL568504v1\tLN:1296\n@SQ\tSN:chrUn_KL568505v1\tLN:11671\n@SQ\tSN:chrUn_AABR07022425v1\tLN:559\n@SQ\tSN:chrUn_KL568506v1\tLN:1171\n@SQ\tSN:chrUn_AABR07022428v1\tLN:605\n@SQ\tSN:chrUn_KL568507v1\tLN:24931\n@SQ\tSN:chrUn_AABR07022431v1\tLN:534\n@SQ\tSN:chrUn_KL568508v1\tLN:1166\n@SQ\tSN:chrUn_KL568509v1\tLN:2750\n@SQ\tSN:chrUn_KL568510v1\tLN:37283\n@SQ\tSN:chrUn_KL568511v1\tLN:24582\n@SQ\tSN:chrUn_KL568512v1\tLN:23752\n@SQ\tSN:chrUn_KL568513v1\tLN:4908\n@SQ\tSN:chrUn_KL568514v1\tLN:11876\n@SQ\tSN:chrUn_AABR07022456v1\tLN:351\n@SQ\tSN:chrUn_KL568515v1\tLN:2232\n@SQ\tSN:chrUn_KL568516v1\tLN:5687\n@SQ\tSN:chrUn_KL568517v1\tLN:13491\n@SQ\tSN:chrUn_KL568518v1\tLN:5301\n@SQ\tSN:chrX\tLN:159970021\n@SQ\tSN:chrX_AABR07045681v1_random\tLN:712\n@SQ\tSN:chrX_KL568111v1_random\tLN:17895\n@SQ\tSN:chrX_KL568112v1_random\tLN:9469\n@SQ\tSN:chrX_KL568113v1_random\tLN:17247\n@SQ\tSN:chrX_KL568114v1_random\tLN:49370\n@SQ\tSN:chrX_AABR07045742v1_random\tLN:766\n@SQ\tSN:chrX_AABR07045743v1_random\tLN:702\n@SQ\tSN:chrX_KL568115v1_random\tLN:1634\n@SQ\tSN:chrX_KL568116v1_random\tLN:40570\n@SQ\tSN:chrX_KL568117v1_random\tLN:13665\n@SQ\tSN:chrX_KL568118v1_random\tLN:42845\n@SQ\tSN:chrX_KL568119v1_random\tLN:655\n@SQ\tSN:chrX_AABR07045766v1_random\tLN:2378\n@SQ\tSN:chrX_KL568120v1_random\tLN:4293\n@SQ\tSN:chrX_KL568121v1_random\tLN:14896\n@SQ\tSN:chrX_KL568122v1_random\tLN:32860\n@SQ\tSN:chrX_AABR07045776v1_random\tLN:2721\n@SQ\tSN:chrX_KL568123v1_random\tLN:4208\n@SQ\tSN:chrX_KL568124v1_random\tLN:3436\n@SQ\tSN:chrX_KL568125v1_random\tLN:72847\n@SQ\tSN:chrX_KL568126v1_random\tLN:69551\n@SQ\tSN:chrX_KL568127v1_random\tLN:9581\n@SQ\tSN:chrX_KL568128v1_random\tLN:5682\n@SQ\tSN:chrX_KL568129v1_random\tLN:22842\n@SQ\tSN:chrX_KL568130v1_random\tLN:29690\n@SQ\tSN:chrX_KL568131v1_random\tLN:13600\n@SQ\tSN:chrX_KL568132v1_random\tLN:13907\n@SQ\tSN:chrX_KL568133v1_random\tLN:29461\n@SQ\tSN:chrX_KL568134v1_random\tLN:31813\n@SQ\tSN:chrX_KL568135v1_random\tLN:16979\n@SQ\tSN:chrX_AABR07045688v1_random\tLN:2649\n@SQ\tSN:chrX_AABR07045689v1_random\tLN:3045\n@SQ\tSN:chrX_KL568136v1_random\tLN:41179\n@SQ\tSN:chrX_KL568137v1_random\tLN:47458\n@SQ\tSN:chrX_KL568138v1_random\tLN:4289\n@SQ\tSN:chrY\tLN:3310458\n@SQ\tSN:chrY_KL568139v1_random\tLN:9752924\n@SQ\tSN:chrY_KL568140v1_random\tLN:1351663\n@SQ\tSN:chrY_KL568141v1_random\tLN:2733323\n@SQ\tSN:chrY_KL568142v1_random\tLN:332284\n@SQ\tSN:chrY_KL568143v1_random\tLN:343819\n@SQ\tSN:chrY_KL568144v1_random\tLN:209128\n@SQ\tSN:chrY_KL568145v1_random\tLN:180016\n@SQ\tSN:chrY_KL568146v1_random\tLN:122062\n@SQ\tSN:chrY_KL568147v1_random\tLN:464092\n@SQ\tSN:chrY_KL568148v1_random\tLN:6483517\n@SQ\tSN:chrY_KL568149v1_random\tLN:3292674\n@SQ\tSN:chrY_KL568150v1_random\tLN:866433\n@SQ\tSN:chrY_KL568151v1_random\tLN:3931032\n@SQ\tSN:chrY_KL568152v1_random\tLN:1069101\n@SQ\tSN:chrY_KL568153v1_random\tLN:239643\n@SQ\tSN:chrY_KL568154v1_random\tLN:215559\n@SQ\tSN:chrY_KL568155v1_random\tLN:1365599\n@SQ\tSN:chrY_KL568156v1_random\tLN:2193381\n@SQ\tSN:chrY_KL568157v1_random\tLN:5447879\n@SQ\tSN:chrY_KL568158v1_random\tLN:1284477\n@SQ\tSN:chrY_KL568159v1_random\tLN:1977169\n@SQ\tSN:chrY_KL568160v1_random\tLN:4317250\n@SQ\tSN:chrY_KL568161v1_random\tLN:7627431\n@SQ\tSN:chrY_KL568162v1_random\tLN:10937627\n@SQ\tSN:chrY_KL568163v1_random\tLN:753291\n@SQ\tSN:chrY_KL568164v1_random\tLN:1009277\n@SQ\tSN:chrY_KL568165v1_random\tLN:398163\n@SQ\tSN:chrY_KL568166v1_random\tLN:188438\n@PG\tID:Bowtie\tVN:1.2.3\tCL:\"bowtie-1.2.3-linux-x86_64/bowtie-align-s --wrapper basic-0 sample_index sample.fastq -S -p 12\"\n"
    elif args.organism_name == "zebrafish":
        header = "@HD\tVN:1.0\tSO:unsorted\n@SQ\tSN:chr1_KZ114997v1_alt\tLN:304771\n@SQ\tSN:chr1_KZ114998v1_alt\tLN:385560\n@SQ\tSN:chr1_KZ114999v1_alt\tLN:349100\n@SQ\tSN:chr1_KZ115000v1_alt\tLN:266532\n@SQ\tSN:chr1_KZ115001v1_alt\tLN:286458\n@SQ\tSN:chr1_KZ115002v1_alt\tLN:306795\n@SQ\tSN:chr1_KZ115003v1_alt\tLN:196368\n@SQ\tSN:chr1_KZ115004v1_alt\tLN:349565\n@SQ\tSN:chr1_KZ115005v1_alt\tLN:295602\n@SQ\tSN:chr1_KZ115006v1_alt\tLN:372328\n@SQ\tSN:chr1_KZ115007v1_alt\tLN:411572\n@SQ\tSN:chr1_KZ115008v1_alt\tLN:273158\n@SQ\tSN:chr1_KZ115009v1_alt\tLN:296299\n@SQ\tSN:chr1_KZ115010v1_alt\tLN:438146\n@SQ\tSN:chr1_KZ115011v1_alt\tLN:355957\n@SQ\tSN:chr1_KZ115012v1_alt\tLN:408214\n@SQ\tSN:chr1_KZ115013v1_alt\tLN:372392\n@SQ\tSN:chr1_KZ115014v1_alt\tLN:302727\n@SQ\tSN:chr1_KZ115015v1_alt\tLN:294840\n@SQ\tSN:chr1_KZ115016v1_alt\tLN:339135\n@SQ\tSN:chr1_KZ115017v1_alt\tLN:209066\n@SQ\tSN:chr1_KZ115018v1_alt\tLN:358644\n@SQ\tSN:chr1_KZ115019v1_alt\tLN:350062\n@SQ\tSN:chr1_KZ115020v1_alt\tLN:592196\n@SQ\tSN:chr1_KZ115021v1_alt\tLN:460984\n@SQ\tSN:chr1_KZ115022v1_alt\tLN:343421\n@SQ\tSN:chr1_KZ115023v1_alt\tLN:334836\n@SQ\tSN:chr1_KZ115024v1_alt\tLN:305403\n@SQ\tSN:chr1_KZ115025v1_alt\tLN:231440\n@SQ\tSN:chr1_KZ115026v1_alt\tLN:192626\n@SQ\tSN:chr1_KZ115027v1_alt\tLN:349924\n@SQ\tSN:chr1_KZ115028v1_alt\tLN:439994\n@SQ\tSN:chr1_KZ115029v1_alt\tLN:291721\n@SQ\tSN:chr1_KZ115030v1_alt\tLN:499197\n@SQ\tSN:chr1_KZ115031v1_alt\tLN:386050\n@SQ\tSN:chr1_KZ115032v1_alt\tLN:276827\n@SQ\tSN:chr1_KZ115033v1_alt\tLN:230131\n@SQ\tSN:chr1_KZ115034v1_alt\tLN:410442\n@SQ\tSN:chr1_KZ115035v1_alt\tLN:194576\n@SQ\tSN:chr1_KZ115036v1_alt\tLN:197068\n@SQ\tSN:chr1_KZ115037v1_alt\tLN:248493\n@SQ\tSN:chr1_KZ115038v1_alt\tLN:249303\n@SQ\tSN:chr1_KZ115039v1_alt\tLN:240512\n@SQ\tSN:chr1_KZ115040v1_alt\tLN:146921\n@SQ\tSN:chr2_KZ115041v1_alt\tLN:330156\n@SQ\tSN:chr2_KZ115042v1_alt\tLN:116439\n@SQ\tSN:chr2_KZ115043v1_alt\tLN:503720\n@SQ\tSN:chr2_KZ115044v1_alt\tLN:401442\n@SQ\tSN:chr2_KZ115045v1_alt\tLN:294473\n@SQ\tSN:chr2_KZ115046v1_alt\tLN:269465\n@SQ\tSN:chr2_KZ115047v1_alt\tLN:341552\n@SQ\tSN:chr2_KZ115048v1_alt\tLN:270392\n@SQ\tSN:chr2_KZ115049v1_alt\tLN:364595\n@SQ\tSN:chr2_KZ115050v1_alt\tLN:383009\n@SQ\tSN:chr2_KZ115051v1_alt\tLN:301823\n@SQ\tSN:chr2_KZ115052v1_alt\tLN:398689\n@SQ\tSN:chr3_KZ115082v1_alt\tLN:332058\n@SQ\tSN:chr3_KZ115053v1_alt\tLN:167415\n@SQ\tSN:chr3_KZ115054v1_alt\tLN:332220\n@SQ\tSN:chr3_KZ115055v1_alt\tLN:172568\n@SQ\tSN:chr3_KZ115056v1_alt\tLN:183873\n@SQ\tSN:chr3_KZ115083v1_alt\tLN:394589\n@SQ\tSN:chr3_KZ115057v1_alt\tLN:290930\n@SQ\tSN:chr3_KZ115058v1_alt\tLN:269398\n@SQ\tSN:chr3_KZ115059v1_alt\tLN:191218\n@SQ\tSN:chr3_KZ115060v1_alt\tLN:271010\n@SQ\tSN:chr3_KZ115061v1_alt\tLN:317307\n@SQ\tSN:chr3_KZ115062v1_alt\tLN:343318\n@SQ\tSN:chr3_KZ115063v1_alt\tLN:199941\n@SQ\tSN:chr3_KZ115064v1_alt\tLN:493295\n@SQ\tSN:chr3_KZ115065v1_alt\tLN:101873\n@SQ\tSN:chr3_KZ115066v1_alt\tLN:346617\n@SQ\tSN:chr3_KZ115067v1_alt\tLN:405304\n@SQ\tSN:chr3_KZ115068v1_alt\tLN:374483\n@SQ\tSN:chr3_KZ115069v1_alt\tLN:427271\n@SQ\tSN:chr3_KZ115070v1_alt\tLN:516292\n@SQ\tSN:chr3_KZ115071v1_alt\tLN:257006\n@SQ\tSN:chr3_KZ115072v1_alt\tLN:357266\n@SQ\tSN:chr3_KZ115078v1_alt\tLN:269670\n@SQ\tSN:chr3_KZ115073v1_alt\tLN:332971\n@SQ\tSN:chr3_KZ115074v1_alt\tLN:256795\n@SQ\tSN:chr3_KZ115075v1_alt\tLN:265738\n@SQ\tSN:chr3_KZ115076v1_alt\tLN:476433\n@SQ\tSN:chr3_KZ115077v1_alt\tLN:269290\n@SQ\tSN:chr3_KZ115079v1_alt\tLN:347777\n@SQ\tSN:chr3_KZ115080v1_alt\tLN:258123\n@SQ\tSN:chr3_KZ115081v1_alt\tLN:227105\n@SQ\tSN:chr4_KZ115084v1_alt\tLN:136520\n@SQ\tSN:chr4_KZ115085v1_alt\tLN:377459\n@SQ\tSN:chr4_KZ115086v1_alt\tLN:362143\n@SQ\tSN:chr4_KZ115087v1_alt\tLN:312415\n@SQ\tSN:chr4_KZ115088v1_alt\tLN:360976\n@SQ\tSN:chr4_KZ115089v1_alt\tLN:244615\n@SQ\tSN:chr4_KZ115090v1_alt\tLN:357974\n@SQ\tSN:chr4_KZ115091v1_alt\tLN:308990\n@SQ\tSN:chr4_KZ115092v1_alt\tLN:301968\n@SQ\tSN:chr4_KZ115093v1_alt\tLN:379586\n@SQ\tSN:chr4_KZ115094v1_alt\tLN:238896\n@SQ\tSN:chr4_KZ115095v1_alt\tLN:340527\n@SQ\tSN:chr4_KZ115096v1_alt\tLN:362204\n@SQ\tSN:chr4_KZ115097v1_alt\tLN:245685\n@SQ\tSN:chr4_KZ115098v1_alt\tLN:204803\n@SQ\tSN:chr5_KZ115099v1_alt\tLN:224304\n@SQ\tSN:chr5_KZ115100v1_alt\tLN:254236\n@SQ\tSN:chr5_KZ115101v1_alt\tLN:338105\n@SQ\tSN:chr5_KZ115102v1_alt\tLN:225477\n@SQ\tSN:chr5_KZ115103v1_alt\tLN:309980\n@SQ\tSN:chr5_KZ115104v1_alt\tLN:306803\n@SQ\tSN:chr5_KZ115105v1_alt\tLN:259110\n@SQ\tSN:chr5_KZ115106v1_alt\tLN:421493\n@SQ\tSN:chr5_KZ115107v1_alt\tLN:342180\n@SQ\tSN:chr5_KZ115108v1_alt\tLN:356628\n@SQ\tSN:chr5_KZ115109v1_alt\tLN:460693\n@SQ\tSN:chr5_KZ115110v1_alt\tLN:300029\n@SQ\tSN:chr5_KZ115111v1_alt\tLN:330900\n@SQ\tSN:chr5_KZ115112v1_alt\tLN:335323\n@SQ\tSN:chr5_KZ115113v1_alt\tLN:400529\n@SQ\tSN:chr5_KZ115114v1_alt\tLN:414026\n@SQ\tSN:chr5_KZ115115v1_alt\tLN:315499\n@SQ\tSN:chr5_KZ115116v1_alt\tLN:236053\n@SQ\tSN:chr5_KZ115117v1_alt\tLN:339791\n@SQ\tSN:chr5_KZ115118v1_alt\tLN:206835\n@SQ\tSN:chr5_KZ115119v1_alt\tLN:238875\n@SQ\tSN:chr5_KZ115120v1_alt\tLN:357527\n@SQ\tSN:chr5_KZ115121v1_alt\tLN:337020\n@SQ\tSN:chr5_KZ115122v1_alt\tLN:287444\n@SQ\tSN:chr5_KZ115123v1_alt\tLN:392328\n@SQ\tSN:chr5_KZ115124v1_alt\tLN:282904\n@SQ\tSN:chr5_KZ115125v1_alt\tLN:705686\n@SQ\tSN:chr5_KZ115126v1_alt\tLN:306203\n@SQ\tSN:chr5_KZ115127v1_alt\tLN:305512\n@SQ\tSN:chr5_KZ115128v1_alt\tLN:363112\n@SQ\tSN:chr5_KZ115129v1_alt\tLN:419803\n@SQ\tSN:chr5_KZ115130v1_alt\tLN:186065\n@SQ\tSN:chr5_KZ115131v1_alt\tLN:306218\n@SQ\tSN:chr5_KZ115132v1_alt\tLN:577816\n@SQ\tSN:chr5_KZ115133v1_alt\tLN:385998\n@SQ\tSN:chr5_KZ115134v1_alt\tLN:255017\n@SQ\tSN:chr5_KZ115135v1_alt\tLN:607386\n@SQ\tSN:chr5_KZ115136v1_alt\tLN:497457\n@SQ\tSN:chr5_KZ115137v1_alt\tLN:182561\n@SQ\tSN:chr5_KZ115138v1_alt\tLN:397821\n@SQ\tSN:chr5_KZ115139v1_alt\tLN:444980\n@SQ\tSN:chr5_KZ115140v1_alt\tLN:355867\n@SQ\tSN:chr5_KZ115141v1_alt\tLN:355757\n@SQ\tSN:chr5_KZ115142v1_alt\tLN:236643\n@SQ\tSN:chr5_KZ115143v1_alt\tLN:174280\n@SQ\tSN:chr5_KZ115144v1_alt\tLN:310313\n@SQ\tSN:chr5_KZ115145v1_alt\tLN:205097\n@SQ\tSN:chr5_KZ115146v1_alt\tLN:275051\n@SQ\tSN:chr5_KZ115147v1_alt\tLN:316760\n@SQ\tSN:chr5_KZ115148v1_alt\tLN:422556\n@SQ\tSN:chr5_KZ115149v1_alt\tLN:300983\n@SQ\tSN:chr5_KZ115150v1_alt\tLN:313052\n@SQ\tSN:chr5_KZ115151v1_alt\tLN:302489\n@SQ\tSN:chr5_KZ115152v1_alt\tLN:311968\n@SQ\tSN:chr5_KZ115153v1_alt\tLN:254919\n@SQ\tSN:chr5_KZ115154v1_alt\tLN:448785\n@SQ\tSN:chr5_KZ115155v1_alt\tLN:225293\n@SQ\tSN:chr5_KZ115156v1_alt\tLN:312569\n@SQ\tSN:chr5_KZ115157v1_alt\tLN:236588\n@SQ\tSN:chr5_KZ115158v1_alt\tLN:187812\n@SQ\tSN:chr5_KZ115159v1_alt\tLN:222586\n@SQ\tSN:chr6_KZ115160v1_alt\tLN:274494\n@SQ\tSN:chr6_KZ115161v1_alt\tLN:501422\n@SQ\tSN:chr6_KZ115162v1_alt\tLN:256996\n@SQ\tSN:chr6_KZ115163v1_alt\tLN:242179\n@SQ\tSN:chr6_KZ115164v1_alt\tLN:300654\n@SQ\tSN:chr6_KZ115165v1_alt\tLN:247951\n@SQ\tSN:chr6_KZ115166v1_alt\tLN:323745\n@SQ\tSN:chr6_KZ115167v1_alt\tLN:459142\n@SQ\tSN:chr6_KZ115168v1_alt\tLN:328171\n@SQ\tSN:chr6_KZ115173v1_alt\tLN:325712\n@SQ\tSN:chr6_KZ115174v1_alt\tLN:809863\n@SQ\tSN:chr6_KZ115175v1_alt\tLN:409494\n@SQ\tSN:chr6_KZ115176v1_alt\tLN:238246\n@SQ\tSN:chr6_KZ115170v1_alt\tLN:452635\n@SQ\tSN:chr6_KZ115171v1_alt\tLN:183825\n@SQ\tSN:chr6_KZ115172v1_alt\tLN:553998\n@SQ\tSN:chr6_KZ115169v1_alt\tLN:238568\n@SQ\tSN:chr6_KZ115177v1_alt\tLN:314887\n@SQ\tSN:chr6_KZ115178v1_alt\tLN:280482\n@SQ\tSN:chr6_KZ115179v1_alt\tLN:348923\n@SQ\tSN:chr6_KZ115180v1_alt\tLN:372155\n@SQ\tSN:chr6_KZ115181v1_alt\tLN:247602\n@SQ\tSN:chr6_KZ115182v1_alt\tLN:618419\n@SQ\tSN:chr6_KZ115183v1_alt\tLN:575499\n@SQ\tSN:chr6_KZ115184v1_alt\tLN:362211\n@SQ\tSN:chr6_KZ115185v1_alt\tLN:323055\n@SQ\tSN:chr6_KZ115186v1_alt\tLN:252260\n@SQ\tSN:chr6_KZ115187v1_alt\tLN:497532\n@SQ\tSN:chr6_KZ115188v1_alt\tLN:334098\n@SQ\tSN:chr6_KZ115189v1_alt\tLN:267098\n@SQ\tSN:chr6_KZ115190v1_alt\tLN:339727\n@SQ\tSN:chr6_KZ115191v1_alt\tLN:354480\n@SQ\tSN:chr6_KZ115192v1_alt\tLN:556191\n@SQ\tSN:chr6_KZ115193v1_alt\tLN:349660\n@SQ\tSN:chr6_KZ115194v1_alt\tLN:361760\n@SQ\tSN:chr6_KZ115195v1_alt\tLN:260150\n@SQ\tSN:chr6_KZ115196v1_alt\tLN:488083\n@SQ\tSN:chr6_KZ115197v1_alt\tLN:228805\n@SQ\tSN:chr6_KZ115198v1_alt\tLN:295552\n@SQ\tSN:chr6_KZ115199v1_alt\tLN:396430\n@SQ\tSN:chr6_KZ115200v1_alt\tLN:280864\n@SQ\tSN:chr6_KZ115201v1_alt\tLN:400625\n@SQ\tSN:chr6_KZ115202v1_alt\tLN:233265\n@SQ\tSN:chr6_KZ115203v1_alt\tLN:393027\n@SQ\tSN:chr6_KZ115204v1_alt\tLN:329732\n@SQ\tSN:chr6_KZ115205v1_alt\tLN:293235\n@SQ\tSN:chr6_KZ115206v1_alt\tLN:228596\n@SQ\tSN:chr6_KZ115207v1_alt\tLN:217681\n@SQ\tSN:chr7_KZ115208v1_alt\tLN:156849\n@SQ\tSN:chr7_KZ115209v1_alt\tLN:210204\n@SQ\tSN:chr7_KZ115210v1_alt\tLN:287653\n@SQ\tSN:chr7_KZ115211v1_alt\tLN:217394\n@SQ\tSN:chr7_KZ115212v1_alt\tLN:191851\n@SQ\tSN:chr7_KZ115213v1_alt\tLN:316778\n@SQ\tSN:chr7_KZ115214v1_alt\tLN:155180\n@SQ\tSN:chr7_KZ115215v1_alt\tLN:279964\n@SQ\tSN:chr7_KZ115216v1_alt\tLN:260931\n@SQ\tSN:chr7_KZ115217v1_alt\tLN:406317\n@SQ\tSN:chr7_KZ115218v1_alt\tLN:271479\n@SQ\tSN:chr7_KZ115219v1_alt\tLN:249621\n@SQ\tSN:chr7_KZ115220v1_alt\tLN:372484\n@SQ\tSN:chr7_KZ115221v1_alt\tLN:308018\n@SQ\tSN:chr7_KZ115222v1_alt\tLN:347264\n@SQ\tSN:chr7_KZ115223v1_alt\tLN:244704\n@SQ\tSN:chr7_KZ115224v1_alt\tLN:307982\n@SQ\tSN:chr7_KZ115225v1_alt\tLN:488679\n@SQ\tSN:chr7_KZ115226v1_alt\tLN:236652\n@SQ\tSN:chr7_KZ115227v1_alt\tLN:284008\n@SQ\tSN:chr7_KZ115228v1_alt\tLN:374638\n@SQ\tSN:chr7_KZ115229v1_alt\tLN:289685\n@SQ\tSN:chr7_KZ115230v1_alt\tLN:239132\n@SQ\tSN:chr7_KZ115231v1_alt\tLN:446517\n@SQ\tSN:chr7_KZ115232v1_alt\tLN:282269\n@SQ\tSN:chr7_KZ115233v1_alt\tLN:361030\n@SQ\tSN:chr7_KZ115234v1_alt\tLN:296643\n@SQ\tSN:chr7_KZ115235v1_alt\tLN:368137\n@SQ\tSN:chr7_KZ115236v1_alt\tLN:361610\n@SQ\tSN:chr7_KZ115237v1_alt\tLN:574220\n@SQ\tSN:chr7_KZ115238v1_alt\tLN:213286\n@SQ\tSN:chr7_KZ115239v1_alt\tLN:246692\n@SQ\tSN:chr7_KZ115240v1_alt\tLN:326189\n@SQ\tSN:chr7_KZ115252v1_alt\tLN:293853\n@SQ\tSN:chr7_KZ115241v1_alt\tLN:224984\n@SQ\tSN:chr7_KZ115242v1_alt\tLN:304230\n@SQ\tSN:chr7_KZ115243v1_alt\tLN:227237\n@SQ\tSN:chr7_KZ115244v1_alt\tLN:277494\n@SQ\tSN:chr7_KZ115245v1_alt\tLN:317728\n@SQ\tSN:chr7_KZ115246v1_alt\tLN:395288\n@SQ\tSN:chr7_KZ115247v1_alt\tLN:387049\n@SQ\tSN:chr7_KZ115248v1_alt\tLN:208605\n@SQ\tSN:chr7_KZ115249v1_alt\tLN:652584\n@SQ\tSN:chr7_KZ115250v1_alt\tLN:305652\n@SQ\tSN:chr7_KZ115251v1_alt\tLN:288803\n@SQ\tSN:chr8_KZ115253v1_alt\tLN:250412\n@SQ\tSN:chr8_KZ115254v1_alt\tLN:406262\n@SQ\tSN:chr8_KZ115255v1_alt\tLN:443293\n@SQ\tSN:chr8_KZ115256v1_alt\tLN:388066\n@SQ\tSN:chr8_KZ115257v1_alt\tLN:286344\n@SQ\tSN:chr8_KZ115258v1_alt\tLN:344964\n@SQ\tSN:chr8_KZ115259v1_alt\tLN:275410\n@SQ\tSN:chr8_KZ115260v1_alt\tLN:345340\n@SQ\tSN:chr8_KZ115261v1_alt\tLN:357769\n@SQ\tSN:chr8_KZ115262v1_alt\tLN:483278\n@SQ\tSN:chr8_KZ115263v1_alt\tLN:553899\n@SQ\tSN:chr8_KZ115264v1_alt\tLN:976511\n@SQ\tSN:chr8_KZ115265v1_alt\tLN:268033\n@SQ\tSN:chr8_KZ115266v1_alt\tLN:402971\n@SQ\tSN:chr8_KZ115267v1_alt\tLN:489053\n@SQ\tSN:chr8_KZ115268v1_alt\tLN:351082\n@SQ\tSN:chr8_KZ115269v1_alt\tLN:476627\n@SQ\tSN:chr8_KZ115270v1_alt\tLN:407003\n@SQ\tSN:chr8_KZ115271v1_alt\tLN:280015\n@SQ\tSN:chr8_KZ115272v1_alt\tLN:268747\n@SQ\tSN:chr8_KZ115273v1_alt\tLN:252521\n@SQ\tSN:chr8_KZ115274v1_alt\tLN:417722\n@SQ\tSN:chr8_KZ115275v1_alt\tLN:252025\n@SQ\tSN:chr8_KZ115276v1_alt\tLN:315028\n@SQ\tSN:chr8_KZ115277v1_alt\tLN:205742\n@SQ\tSN:chr8_KZ115278v1_alt\tLN:240229\n@SQ\tSN:chr8_KZ115279v1_alt\tLN:287425\n@SQ\tSN:chr9_KZ115280v1_alt\tLN:519090\n@SQ\tSN:chr9_KZ115281v1_alt\tLN:324239\n@SQ\tSN:chr9_KZ115282v1_alt\tLN:659395\n@SQ\tSN:chr9_KZ115283v1_alt\tLN:389052\n@SQ\tSN:chr9_KZ115284v1_alt\tLN:340422\n@SQ\tSN:chr9_KZ115285v1_alt\tLN:419747\n@SQ\tSN:chr9_KZ115286v1_alt\tLN:305747\n@SQ\tSN:chr9_KZ115287v1_alt\tLN:361093\n@SQ\tSN:chr9_KZ115288v1_alt\tLN:484793\n@SQ\tSN:chr9_KZ115289v1_alt\tLN:435353\n@SQ\tSN:chr9_KZ115290v1_alt\tLN:497249\n@SQ\tSN:chr9_KZ115291v1_alt\tLN:292027\n@SQ\tSN:chr9_KZ115292v1_alt\tLN:387492\n@SQ\tSN:chr9_KZ115293v1_alt\tLN:227167\n@SQ\tSN:chr9_KZ115294v1_alt\tLN:315627\n@SQ\tSN:chr9_KZ115295v1_alt\tLN:217271\n@SQ\tSN:chr9_KZ115296v1_alt\tLN:389430\n@SQ\tSN:chr9_KZ115297v1_alt\tLN:600188\n@SQ\tSN:chr9_KZ115298v1_alt\tLN:369518\n@SQ\tSN:chr9_KZ115299v1_alt\tLN:165071\n@SQ\tSN:chr10_KZ115336v1_alt\tLN:74601\n@SQ\tSN:chr10_KZ115300v1_alt\tLN:228545\n@SQ\tSN:chr10_KZ115301v1_alt\tLN:235300\n@SQ\tSN:chr10_KZ115302v1_alt\tLN:284948\n@SQ\tSN:chr10_KZ115303v1_alt\tLN:194792\n@SQ\tSN:chr10_KZ115305v1_alt\tLN:278462\n@SQ\tSN:chr10_KZ115306v1_alt\tLN:269294\n@SQ\tSN:chr10_KZ115307v1_alt\tLN:266048\n@SQ\tSN:chr10_KZ115304v1_alt\tLN:46171\n@SQ\tSN:chr10_KZ115308v1_alt\tLN:274601\n@SQ\tSN:chr10_KZ115309v1_alt\tLN:332556\n@SQ\tSN:chr10_KZ115310v1_alt\tLN:275231\n@SQ\tSN:chr10_KZ115311v1_alt\tLN:203043\n@SQ\tSN:chr10_KZ115312v1_alt\tLN:323031\n@SQ\tSN:chr10_KZ115313v1_alt\tLN:329581\n@SQ\tSN:chr10_KZ115314v1_alt\tLN:190671\n@SQ\tSN:chr10_KZ115315v1_alt\tLN:171433\n@SQ\tSN:chr10_KZ115316v1_alt\tLN:264648\n@SQ\tSN:chr10_KZ115317v1_alt\tLN:562656\n@SQ\tSN:chr10_KZ115318v1_alt\tLN:345064\n@SQ\tSN:chr10_KZ115319v1_alt\tLN:503112\n@SQ\tSN:chr10_KZ115320v1_alt\tLN:302550\n@SQ\tSN:chr10_KZ115321v1_alt\tLN:561500\n@SQ\tSN:chr10_KZ115322v1_alt\tLN:584048\n@SQ\tSN:chr10_KZ115323v1_alt\tLN:425083\n@SQ\tSN:chr10_KZ115324v1_alt\tLN:395693\n@SQ\tSN:chr10_KZ115325v1_alt\tLN:376018\n@SQ\tSN:chr10_KZ115326v1_alt\tLN:386823\n@SQ\tSN:chr10_KZ115327v1_alt\tLN:241699\n@SQ\tSN:chr10_KZ115328v1_alt\tLN:229321\n@SQ\tSN:chr10_KZ115329v1_alt\tLN:136849\n@SQ\tSN:chr10_KZ115330v1_alt\tLN:761247\n@SQ\tSN:chr10_KZ115331v1_alt\tLN:200496\n@SQ\tSN:chr10_KZ115332v1_alt\tLN:379829\n@SQ\tSN:chr10_KZ115333v1_alt\tLN:269259\n@SQ\tSN:chr10_KZ115334v1_alt\tLN:295331\n@SQ\tSN:chr10_KZ115335v1_alt\tLN:271174\n@SQ\tSN:chr11_KZ115337v1_alt\tLN:375017\n@SQ\tSN:chr11_KZ115338v1_alt\tLN:246644\n@SQ\tSN:chr11_KZ115339v1_alt\tLN:347320\n@SQ\tSN:chr11_KZ115340v1_alt\tLN:194333\n@SQ\tSN:chr11_KZ115341v1_alt\tLN:490440\n@SQ\tSN:chr11_KZ115342v1_alt\tLN:233964\n@SQ\tSN:chr11_KZ115365v1_alt\tLN:198986\n@SQ\tSN:chr11_KZ115343v1_alt\tLN:330295\n@SQ\tSN:chr11_KZ115344v1_alt\tLN:275107\n@SQ\tSN:chr11_KZ115345v1_alt\tLN:354409\n@SQ\tSN:chr11_KZ115346v1_alt\tLN:466086\n@SQ\tSN:chr11_KZ115347v1_alt\tLN:452838\n@SQ\tSN:chr11_KZ115348v1_alt\tLN:360241\n@SQ\tSN:chr11_KZ115349v1_alt\tLN:341199\n@SQ\tSN:chr11_KZ115350v1_alt\tLN:421379\n@SQ\tSN:chr11_KZ115351v1_alt\tLN:453706\n@SQ\tSN:chr11_KZ115352v1_alt\tLN:241652\n@SQ\tSN:chr11_KZ115353v1_alt\tLN:340605\n@SQ\tSN:chr11_KZ115354v1_alt\tLN:273291\n@SQ\tSN:chr11_KZ115355v1_alt\tLN:261914\n@SQ\tSN:chr11_KZ115356v1_alt\tLN:297378\n@SQ\tSN:chr11_KZ115357v1_alt\tLN:309108\n@SQ\tSN:chr11_KZ115358v1_alt\tLN:266774\n@SQ\tSN:chr11_KZ115359v1_alt\tLN:411340\n@SQ\tSN:chr11_KZ115360v1_alt\tLN:246265\n@SQ\tSN:chr11_KZ115361v1_alt\tLN:450983\n@SQ\tSN:chr11_KZ115362v1_alt\tLN:380476\n@SQ\tSN:chr11_KZ115363v1_alt\tLN:409943\n@SQ\tSN:chr11_KZ115364v1_alt\tLN:239684\n@SQ\tSN:chr12_KZ115366v1_alt\tLN:164129\n@SQ\tSN:chr12_KZ115367v1_alt\tLN:307903\n@SQ\tSN:chr12_KZ115368v1_alt\tLN:416022\n@SQ\tSN:chr12_KZ115369v1_alt\tLN:306930\n@SQ\tSN:chr12_KZ115370v1_alt\tLN:330705\n@SQ\tSN:chr12_KZ115371v1_alt\tLN:159593\n@SQ\tSN:chr12_KZ115372v1_alt\tLN:937928\n@SQ\tSN:chr12_KZ115373v1_alt\tLN:432949\n@SQ\tSN:chr12_KZ115374v1_alt\tLN:304097\n@SQ\tSN:chr12_KZ115375v1_alt\tLN:201822\n@SQ\tSN:chr12_KZ115376v1_alt\tLN:476190\n@SQ\tSN:chr12_KZ115377v1_alt\tLN:339721\n@SQ\tSN:chr12_KZ115378v1_alt\tLN:227925\n@SQ\tSN:chr12_KZ115379v1_alt\tLN:369007\n@SQ\tSN:chr12_KZ115380v1_alt\tLN:405208\n@SQ\tSN:chr12_KZ115381v1_alt\tLN:290378\n@SQ\tSN:chr12_KZ115382v1_alt\tLN:465159\n@SQ\tSN:chr12_KZ115383v1_alt\tLN:251440\n@SQ\tSN:chr12_KZ115384v1_alt\tLN:587238\n@SQ\tSN:chr12_KZ115385v1_alt\tLN:316251\n@SQ\tSN:chr12_KZ115386v1_alt\tLN:384335\n@SQ\tSN:chr12_KZ115387v1_alt\tLN:195919\n@SQ\tSN:chr12_KZ115388v1_alt\tLN:346612\n@SQ\tSN:chr12_KZ115389v1_alt\tLN:265246\n@SQ\tSN:chr12_KZ115390v1_alt\tLN:357490\n@SQ\tSN:chr12_KZ115391v1_alt\tLN:352594\n@SQ\tSN:chr12_KZ115392v1_alt\tLN:343266\n@SQ\tSN:chr12_KZ115393v1_alt\tLN:302186\n@SQ\tSN:chr12_KZ115395v1_alt\tLN:329615\n@SQ\tSN:chr12_KZ115394v1_alt\tLN:187258\n@SQ\tSN:chr12_KZ115396v1_alt\tLN:271341\n@SQ\tSN:chr13_KZ115397v1_alt\tLN:282982\n@SQ\tSN:chr13_KZ115398v1_alt\tLN:256327\n@SQ\tSN:chr13_KZ115399v1_alt\tLN:306040\n@SQ\tSN:chr13_KZ115400v1_alt\tLN:362749\n@SQ\tSN:chr13_KZ115401v1_alt\tLN:433741\n@SQ\tSN:chr13_KZ115402v1_alt\tLN:542290\n@SQ\tSN:chr13_KZ115403v1_alt\tLN:306103\n@SQ\tSN:chr13_KZ115404v1_alt\tLN:254573\n@SQ\tSN:chr13_KZ115405v1_alt\tLN:541739\n@SQ\tSN:chr13_KZ115406v1_alt\tLN:324545\n@SQ\tSN:chr13_KZ115407v1_alt\tLN:196984\n@SQ\tSN:chr13_KZ115408v1_alt\tLN:248704\n@SQ\tSN:chr13_KZ115409v1_alt\tLN:280045\n@SQ\tSN:chr13_KZ115410v1_alt\tLN:491046\n@SQ\tSN:chr13_KZ115411v1_alt\tLN:372652\n@SQ\tSN:chr13_KZ115412v1_alt\tLN:310513\n@SQ\tSN:chr13_KZ115413v1_alt\tLN:308015\n@SQ\tSN:chr13_KZ115414v1_alt\tLN:386499\n@SQ\tSN:chr13_KZ115415v1_alt\tLN:220454\n@SQ\tSN:chr13_KZ115416v1_alt\tLN:386970\n@SQ\tSN:chr13_KZ115417v1_alt\tLN:235981\n@SQ\tSN:chr13_KZ115418v1_alt\tLN:429575\n@SQ\tSN:chr13_KZ115419v1_alt\tLN:279786\n@SQ\tSN:chr13_KZ115420v1_alt\tLN:452677\n@SQ\tSN:chr13_KZ115421v1_alt\tLN:459235\n@SQ\tSN:chr13_KZ115422v1_alt\tLN:407902\n@SQ\tSN:chr13_KZ115423v1_alt\tLN:278156\n@SQ\tSN:chr13_KZ115424v1_alt\tLN:138060\n@SQ\tSN:chr13_KZ115425v1_alt\tLN:206034\n@SQ\tSN:chr13_KZ115426v1_alt\tLN:191911\n@SQ\tSN:chr13_KZ115427v1_alt\tLN:268584\n@SQ\tSN:chr14_KZ115428v1_alt\tLN:247409\n@SQ\tSN:chr14_KZ115429v1_alt\tLN:261755\n@SQ\tSN:chr14_KZ115430v1_alt\tLN:517989\n@SQ\tSN:chr14_KZ115431v1_alt\tLN:306384\n@SQ\tSN:chr14_KZ115432v1_alt\tLN:272653\n@SQ\tSN:chr14_KZ115433v1_alt\tLN:399735\n@SQ\tSN:chr14_KZ115434v1_alt\tLN:538657\n@SQ\tSN:chr14_KZ115435v1_alt\tLN:437632\n@SQ\tSN:chr14_KZ115436v1_alt\tLN:233064\n@SQ\tSN:chr14_KZ115437v1_alt\tLN:462420\n@SQ\tSN:chr14_KZ115438v1_alt\tLN:201735\n@SQ\tSN:chr14_KZ115439v1_alt\tLN:432449\n@SQ\tSN:chr14_KZ115440v1_alt\tLN:470430\n@SQ\tSN:chr14_KZ115441v1_alt\tLN:341328\n@SQ\tSN:chr14_KZ115442v1_alt\tLN:356617\n@SQ\tSN:chr14_KZ115443v1_alt\tLN:208670\n@SQ\tSN:chr14_KZ115444v1_alt\tLN:273812\n@SQ\tSN:chr14_KZ115445v1_alt\tLN:325288\n@SQ\tSN:chr14_KZ115446v1_alt\tLN:716762\n@SQ\tSN:chr14_KZ115447v1_alt\tLN:648871\n@SQ\tSN:chr14_KZ115448v1_alt\tLN:268560\n@SQ\tSN:chr14_KZ115449v1_alt\tLN:331089\n@SQ\tSN:chr14_KZ115450v1_alt\tLN:324328\n@SQ\tSN:chr14_KZ115451v1_alt\tLN:419062\n@SQ\tSN:chr14_KZ115452v1_alt\tLN:332763\n@SQ\tSN:chr14_KZ115453v1_alt\tLN:339322\n@SQ\tSN:chr14_KZ115454v1_alt\tLN:404410\n@SQ\tSN:chr14_KZ115455v1_alt\tLN:304174\n@SQ\tSN:chr14_KZ115456v1_alt\tLN:288817\n@SQ\tSN:chr14_KZ115457v1_alt\tLN:190328\n@SQ\tSN:chr14_KZ115458v1_alt\tLN:432035\n@SQ\tSN:chr14_KZ115459v1_alt\tLN:209046\n@SQ\tSN:chr14_KZ115460v1_alt\tLN:313967\n@SQ\tSN:chr14_KZ115461v1_alt\tLN:348904\n@SQ\tSN:chr14_KZ115462v1_alt\tLN:503229\n@SQ\tSN:chr14_KZ115463v1_alt\tLN:167774\n@SQ\tSN:chr14_KZ115464v1_alt\tLN:380754\n@SQ\tSN:chr14_KZ115465v1_alt\tLN:340306\n@SQ\tSN:chr14_KZ115466v1_alt\tLN:286675\n@SQ\tSN:chr14_KZ115467v1_alt\tLN:318922\n@SQ\tSN:chr14_KZ115468v1_alt\tLN:182471\n@SQ\tSN:chr15_KZ115469v1_alt\tLN:253072\n@SQ\tSN:chr15_KZ115470v1_alt\tLN:193844\n@SQ\tSN:chr15_KZ115471v1_alt\tLN:382146\n@SQ\tSN:chr15_KZ115472v1_alt\tLN:208964\n@SQ\tSN:chr15_KZ115473v1_alt\tLN:152287\n@SQ\tSN:chr15_KZ115474v1_alt\tLN:199297\n@SQ\tSN:chr15_KZ115475v1_alt\tLN:187915\n@SQ\tSN:chr15_KZ115476v1_alt\tLN:204280\n@SQ\tSN:chr15_KZ115477v1_alt\tLN:254313\n@SQ\tSN:chr15_KZ115478v1_alt\tLN:310817\n@SQ\tSN:chr15_KZ115479v1_alt\tLN:276620\n@SQ\tSN:chr15_KZ115480v1_alt\tLN:325154\n@SQ\tSN:chr15_KZ115481v1_alt\tLN:392972\n@SQ\tSN:chr15_KZ115482v1_alt\tLN:451661\n@SQ\tSN:chr15_KZ115483v1_alt\tLN:579432\n@SQ\tSN:chr15_KZ115484v1_alt\tLN:616551\n@SQ\tSN:chr15_KZ115485v1_alt\tLN:205829\n@SQ\tSN:chr15_KZ115486v1_alt\tLN:404091\n@SQ\tSN:chr16_KZ115487v1_alt\tLN:292136\n@SQ\tSN:chr16_KZ115488v1_alt\tLN:356290\n@SQ\tSN:chr16_KZ115489v1_alt\tLN:179144\n@SQ\tSN:chr16_KZ115490v1_alt\tLN:192534\n@SQ\tSN:chr16_KZ115491v1_alt\tLN:115276\n@SQ\tSN:chr16_KZ115492v1_alt\tLN:261552\n@SQ\tSN:chr16_KZ115493v1_alt\tLN:289658\n@SQ\tSN:chr16_KZ115494v1_alt\tLN:457980\n@SQ\tSN:chr16_KZ115495v1_alt\tLN:186301\n@SQ\tSN:chr16_KZ115496v1_alt\tLN:238178\n@SQ\tSN:chr16_KZ115497v1_alt\tLN:243176\n@SQ\tSN:chr16_KZ115498v1_alt\tLN:345561\n@SQ\tSN:chr16_KZ115499v1_alt\tLN:351093\n@SQ\tSN:chr16_KZ115500v1_alt\tLN:181814\n@SQ\tSN:chr16_KZ115501v1_alt\tLN:348207\n@SQ\tSN:chr16_KZ115502v1_alt\tLN:434844\n@SQ\tSN:chr16_KZ115503v1_alt\tLN:291646\n@SQ\tSN:chr16_KZ115504v1_alt\tLN:422286\n@SQ\tSN:chr16_KZ115505v1_alt\tLN:252757\n@SQ\tSN:chr16_KZ115506v1_alt\tLN:276878\n@SQ\tSN:chr16_KZ115507v1_alt\tLN:528292\n@SQ\tSN:chr16_KZ115508v1_alt\tLN:166990\n@SQ\tSN:chr16_KZ115509v1_alt\tLN:243178\n@SQ\tSN:chr17_KZ115510v1_alt\tLN:279252\n@SQ\tSN:chr17_KZ115511v1_alt\tLN:313894\n@SQ\tSN:chr17_KZ115512v1_alt\tLN:215242\n@SQ\tSN:chr17_KZ115513v1_alt\tLN:262788\n@SQ\tSN:chr17_KZ115514v1_alt\tLN:304849\n@SQ\tSN:chr17_KZ115515v1_alt\tLN:299012\n@SQ\tSN:chr17_KZ115516v1_alt\tLN:410139\n@SQ\tSN:chr17_KZ115517v1_alt\tLN:321972\n@SQ\tSN:chr17_KZ115518v1_alt\tLN:394180\n@SQ\tSN:chr17_KZ115519v1_alt\tLN:217339\n@SQ\tSN:chr17_KZ115520v1_alt\tLN:273719\n@SQ\tSN:chr17_KZ115521v1_alt\tLN:250209\n@SQ\tSN:chr17_KZ115522v1_alt\tLN:310288\n@SQ\tSN:chr17_KZ115523v1_alt\tLN:576670\n@SQ\tSN:chr17_KZ115524v1_alt\tLN:307559\n@SQ\tSN:chr17_KZ115525v1_alt\tLN:593468\n@SQ\tSN:chr17_KZ115526v1_alt\tLN:268222\n@SQ\tSN:chr17_KZ115527v1_alt\tLN:293401\n@SQ\tSN:chr17_KZ115528v1_alt\tLN:326300\n@SQ\tSN:chr17_KZ115529v1_alt\tLN:408240\n@SQ\tSN:chr17_KZ115530v1_alt\tLN:364908\n@SQ\tSN:chr17_KZ115531v1_alt\tLN:304346\n@SQ\tSN:chr17_KZ115532v1_alt\tLN:567316\n@SQ\tSN:chr17_KZ115533v1_alt\tLN:272427\n@SQ\tSN:chr17_KZ115534v1_alt\tLN:532793\n@SQ\tSN:chr17_KZ115535v1_alt\tLN:407078\n@SQ\tSN:chr17_KZ115536v1_alt\tLN:208907\n@SQ\tSN:chr17_KZ115537v1_alt\tLN:241347\n@SQ\tSN:chr18_KZ115538v1_alt\tLN:268743\n@SQ\tSN:chr18_KZ115539v1_alt\tLN:190152\n@SQ\tSN:chr18_KZ115540v1_alt\tLN:365608\n@SQ\tSN:chr18_KZ115541v1_alt\tLN:165062\n@SQ\tSN:chr18_KZ115542v1_alt\tLN:396672\n@SQ\tSN:chr18_KZ115543v1_alt\tLN:335599\n@SQ\tSN:chr18_KZ115544v1_alt\tLN:316147\n@SQ\tSN:chr18_KZ115545v1_alt\tLN:196552\n@SQ\tSN:chr18_KZ115546v1_alt\tLN:229368\n@SQ\tSN:chr18_KZ115547v1_alt\tLN:309897\n@SQ\tSN:chr18_KZ115548v1_alt\tLN:191916\n@SQ\tSN:chr18_KZ115549v1_alt\tLN:186389\n@SQ\tSN:chr18_KZ115550v1_alt\tLN:212662\n@SQ\tSN:chr18_KZ115551v1_alt\tLN:545038\n@SQ\tSN:chr18_KZ115552v1_alt\tLN:452972\n@SQ\tSN:chr18_KZ115553v1_alt\tLN:221110\n@SQ\tSN:chr18_KZ115554v1_alt\tLN:659050\n@SQ\tSN:chr18_KZ115555v1_alt\tLN:458788\n@SQ\tSN:chr18_KZ115556v1_alt\tLN:424313\n@SQ\tSN:chr18_KZ115557v1_alt\tLN:658146\n@SQ\tSN:chr18_KZ115558v1_alt\tLN:341731\n@SQ\tSN:chr18_KZ115559v1_alt\tLN:615275\n@SQ\tSN:chr18_KZ115560v1_alt\tLN:360995\n@SQ\tSN:chr18_KZ115561v1_alt\tLN:334391\n@SQ\tSN:chr18_KZ115562v1_alt\tLN:353463\n@SQ\tSN:chr18_KZ115563v1_alt\tLN:229721\n@SQ\tSN:chr18_KZ115564v1_alt\tLN:431433\n@SQ\tSN:chr18_KZ115565v1_alt\tLN:287802\n@SQ\tSN:chr18_KZ115566v1_alt\tLN:301292\n@SQ\tSN:chr18_KZ115567v1_alt\tLN:302625\n@SQ\tSN:chr18_KZ115568v1_alt\tLN:423445\n@SQ\tSN:chr18_KZ115569v1_alt\tLN:237175\n@SQ\tSN:chr18_KZ115570v1_alt\tLN:335505\n@SQ\tSN:chr18_KZ115571v1_alt\tLN:214726\n@SQ\tSN:chr18_KZ115572v1_alt\tLN:265212\n@SQ\tSN:chr18_KZ115573v1_alt\tLN:527855\n@SQ\tSN:chr18_KZ115574v1_alt\tLN:338615\n@SQ\tSN:chr18_KZ115575v1_alt\tLN:141539\n@SQ\tSN:chr18_KZ115576v1_alt\tLN:217517\n@SQ\tSN:chr18_KZ115577v1_alt\tLN:293382\n@SQ\tSN:chr18_KZ115578v1_alt\tLN:311281\n@SQ\tSN:chr18_KZ115579v1_alt\tLN:451466\n@SQ\tSN:chr18_KZ115580v1_alt\tLN:265039\n@SQ\tSN:chr18_KZ115581v1_alt\tLN:344932\n@SQ\tSN:chr18_KZ115582v1_alt\tLN:300951\n@SQ\tSN:chr18_KZ115583v1_alt\tLN:277214\n@SQ\tSN:chr18_KZ115584v1_alt\tLN:244826\n@SQ\tSN:chr18_KZ115585v1_alt\tLN:194058\n@SQ\tSN:chr18_KZ115586v1_alt\tLN:261955\n@SQ\tSN:chr19_KZ115587v1_alt\tLN:267719\n@SQ\tSN:chr19_KZ115588v1_alt\tLN:209995\n@SQ\tSN:chr19_KZ115589v1_alt\tLN:670230\n@SQ\tSN:chr19_KZ115590v1_alt\tLN:270176\n@SQ\tSN:chr19_KZ115591v1_alt\tLN:230187\n@SQ\tSN:chr19_KZ115592v1_alt\tLN:316524\n@SQ\tSN:chr19_KZ115593v1_alt\tLN:338889\n@SQ\tSN:chr19_KZ115594v1_alt\tLN:232616\n@SQ\tSN:chr19_KZ115595v1_alt\tLN:206993\n@SQ\tSN:chr19_KZ115596v1_alt\tLN:311346\n@SQ\tSN:chr20_KZ115597v1_alt\tLN:214249\n@SQ\tSN:chr20_KZ115598v1_alt\tLN:191003\n@SQ\tSN:chr20_KZ115599v1_alt\tLN:374368\n@SQ\tSN:chr20_KZ115600v1_alt\tLN:406575\n@SQ\tSN:chr20_KZ115601v1_alt\tLN:197156\n@SQ\tSN:chr20_KZ115602v1_alt\tLN:209623\n@SQ\tSN:chr20_KZ115603v1_alt\tLN:234239\n@SQ\tSN:chr20_KZ115604v1_alt\tLN:271627\n@SQ\tSN:chr20_KZ115605v1_alt\tLN:336822\n@SQ\tSN:chr20_KZ115606v1_alt\tLN:352803\n@SQ\tSN:chr20_KZ115607v1_alt\tLN:362523\n@SQ\tSN:chr20_KZ115608v1_alt\tLN:240083\n@SQ\tSN:chr20_KZ115609v1_alt\tLN:242231\n@SQ\tSN:chr20_KZ115610v1_alt\tLN:285853\n@SQ\tSN:chr20_KZ115611v1_alt\tLN:770119\n@SQ\tSN:chr20_KZ115612v1_alt\tLN:402394\n@SQ\tSN:chr20_KZ115613v1_alt\tLN:355423\n@SQ\tSN:chr20_KZ115614v1_alt\tLN:268660\n@SQ\tSN:chr21_KZ115615v1_alt\tLN:268215\n@SQ\tSN:chr21_KZ115616v1_alt\tLN:305324\n@SQ\tSN:chr21_KZ115617v1_alt\tLN:394364\n@SQ\tSN:chr21_KZ115618v1_alt\tLN:270861\n@SQ\tSN:chr21_KZ115619v1_alt\tLN:225520\n@SQ\tSN:chr21_KZ115620v1_alt\tLN:280155\n@SQ\tSN:chr21_KZ115621v1_alt\tLN:256595\n@SQ\tSN:chr21_KZ115622v1_alt\tLN:380813\n@SQ\tSN:chr21_KZ115623v1_alt\tLN:274145\n@SQ\tSN:chr21_KZ115624v1_alt\tLN:540923\n@SQ\tSN:chr21_KZ115625v1_alt\tLN:369431\n@SQ\tSN:chr21_KZ115626v1_alt\tLN:381043\n@SQ\tSN:chr21_KZ115627v1_alt\tLN:279256\n@SQ\tSN:chr21_KZ115628v1_alt\tLN:336481\n@SQ\tSN:chr21_KZ115629v1_alt\tLN:206264\n@SQ\tSN:chr21_KZ115630v1_alt\tLN:320250\n@SQ\tSN:chr21_KZ115631v1_alt\tLN:494100\n@SQ\tSN:chr21_KZ115632v1_alt\tLN:247425\n@SQ\tSN:chr21_KZ115633v1_alt\tLN:340869\n@SQ\tSN:chr21_KZ115634v1_alt\tLN:485123\n@SQ\tSN:chr22_KZ115635v1_alt\tLN:273641\n@SQ\tSN:chr22_KZ115636v1_alt\tLN:385865\n@SQ\tSN:chr22_KZ115637v1_alt\tLN:299024\n@SQ\tSN:chr22_KZ115638v1_alt\tLN:223998\n@SQ\tSN:chr22_KZ115639v1_alt\tLN:513040\n@SQ\tSN:chr22_KZ115640v1_alt\tLN:424445\n@SQ\tSN:chr22_KZ115641v1_alt\tLN:369504\n@SQ\tSN:chr22_KZ115642v1_alt\tLN:311744\n@SQ\tSN:chr22_KZ115643v1_alt\tLN:364070\n@SQ\tSN:chr22_KZ115644v1_alt\tLN:569344\n@SQ\tSN:chr22_KZ115645v1_alt\tLN:377862\n@SQ\tSN:chr22_KZ115646v1_alt\tLN:196217\n@SQ\tSN:chr22_KZ115647v1_alt\tLN:261250\n@SQ\tSN:chr22_KZ115648v1_alt\tLN:201639\n@SQ\tSN:chr22_KZ115649v1_alt\tLN:280493\n@SQ\tSN:chr22_KZ115663v1_alt\tLN:133770\n@SQ\tSN:chr22_KZ115650v1_alt\tLN:304572\n@SQ\tSN:chr22_KZ115651v1_alt\tLN:436309\n@SQ\tSN:chr22_KZ115652v1_alt\tLN:382321\n@SQ\tSN:chr22_KZ115653v1_alt\tLN:197722\n@SQ\tSN:chr22_KZ115654v1_alt\tLN:354886\n@SQ\tSN:chr22_KZ115655v1_alt\tLN:311894\n@SQ\tSN:chr22_KZ115656v1_alt\tLN:243845\n@SQ\tSN:chr22_KZ115657v1_alt\tLN:398092\n@SQ\tSN:chr22_KZ115658v1_alt\tLN:476925\n@SQ\tSN:chr22_KZ115659v1_alt\tLN:92363\n@SQ\tSN:chr22_KZ115660v1_alt\tLN:212011\n@SQ\tSN:chr22_KZ115661v1_alt\tLN:211789\n@SQ\tSN:chr22_KZ115662v1_alt\tLN:241919\n@SQ\tSN:chr23_KZ115664v1_alt\tLN:365380\n@SQ\tSN:chr23_KZ115665v1_alt\tLN:269666\n@SQ\tSN:chr23_KZ115666v1_alt\tLN:251517\n@SQ\tSN:chr23_KZ115667v1_alt\tLN:280452\n@SQ\tSN:chr23_KZ115669v1_alt\tLN:470170\n@SQ\tSN:chr23_KZ115670v1_alt\tLN:254925\n@SQ\tSN:chr23_KZ115671v1_alt\tLN:325751\n@SQ\tSN:chr23_KZ115672v1_alt\tLN:282484\n@SQ\tSN:chr23_KZ115673v1_alt\tLN:451509\n@SQ\tSN:chr23_KZ115674v1_alt\tLN:387644\n@SQ\tSN:chr23_KZ115675v1_alt\tLN:393204\n@SQ\tSN:chr23_KZ115668v1_alt\tLN:103453\n@SQ\tSN:chr23_KZ115676v1_alt\tLN:331626\n@SQ\tSN:chr23_KZ115677v1_alt\tLN:307977\n@SQ\tSN:chr23_KZ115678v1_alt\tLN:395354\n@SQ\tSN:chr23_KZ115679v1_alt\tLN:365445\n@SQ\tSN:chr23_KZ115680v1_alt\tLN:350156\n@SQ\tSN:chr23_KZ115681v1_alt\tLN:482266\n@SQ\tSN:chr23_KZ115682v1_alt\tLN:521459\n@SQ\tSN:chr23_KZ115683v1_alt\tLN:312204\n@SQ\tSN:chr23_KZ115684v1_alt\tLN:165615\n@SQ\tSN:chr23_KZ115685v1_alt\tLN:353548\n@SQ\tSN:chr23_KZ115686v1_alt\tLN:204530\n@SQ\tSN:chr23_KZ115687v1_alt\tLN:316693\n@SQ\tSN:chr23_KZ115688v1_alt\tLN:341126\n@SQ\tSN:chr23_KZ115689v1_alt\tLN:233653\n@SQ\tSN:chr23_KZ115690v1_alt\tLN:309774\n@SQ\tSN:chr23_KZ115691v1_alt\tLN:461899\n@SQ\tSN:chr23_KZ115692v1_alt\tLN:640557\n@SQ\tSN:chr23_KZ115693v1_alt\tLN:133643\n@SQ\tSN:chr23_KZ115694v1_alt\tLN:308396\n@SQ\tSN:chr23_KZ115695v1_alt\tLN:663362\n@SQ\tSN:chr23_KZ115696v1_alt\tLN:439737\n@SQ\tSN:chr23_KZ115697v1_alt\tLN:224129\n@SQ\tSN:chr23_KZ115698v1_alt\tLN:387601\n@SQ\tSN:chr23_KZ115699v1_alt\tLN:229019\n@SQ\tSN:chr23_KZ115700v1_alt\tLN:125453\n@SQ\tSN:chr24_KZ115701v1_alt\tLN:211253\n@SQ\tSN:chr24_KZ115702v1_alt\tLN:390171\n@SQ\tSN:chr24_KZ115703v1_alt\tLN:225905\n@SQ\tSN:chr24_KZ115704v1_alt\tLN:283692\n@SQ\tSN:chr24_KZ115705v1_alt\tLN:354657\n@SQ\tSN:chr24_KZ115706v1_alt\tLN:314956\n@SQ\tSN:chr24_KZ115707v1_alt\tLN:209790\n@SQ\tSN:chr24_KZ115708v1_alt\tLN:477721\n@SQ\tSN:chr24_KZ115709v1_alt\tLN:281531\n@SQ\tSN:chr24_KZ115710v1_alt\tLN:349948\n@SQ\tSN:chr24_KZ115711v1_alt\tLN:386244\n@SQ\tSN:chr24_KZ115712v1_alt\tLN:217653\n@SQ\tSN:chr24_KZ115713v1_alt\tLN:349787\n@SQ\tSN:chr24_KZ115714v1_alt\tLN:275419\n@SQ\tSN:chr24_KZ115715v1_alt\tLN:329630\n@SQ\tSN:chr24_KZ115716v1_alt\tLN:351302\n@SQ\tSN:chr24_KZ115717v1_alt\tLN:185419\n@SQ\tSN:chr24_KZ115718v1_alt\tLN:226561\n@SQ\tSN:chr24_KZ115719v1_alt\tLN:262886\n@SQ\tSN:chr24_KZ115720v1_alt\tLN:250837\n@SQ\tSN:chr24_KZ115721v1_alt\tLN:295964\n@SQ\tSN:chr24_KZ115722v1_alt\tLN:333400\n@SQ\tSN:chr25_KZ115723v1_alt\tLN:310450\n@SQ\tSN:chr25_KZ115724v1_alt\tLN:176737\n@SQ\tSN:chr25_KZ115725v1_alt\tLN:326351\n@SQ\tSN:chr25_KZ115726v1_alt\tLN:180535\n@SQ\tSN:chr25_KZ115727v1_alt\tLN:193675\n@SQ\tSN:chr25_KZ115728v1_alt\tLN:211235\n@SQ\tSN:chr25_KZ115729v1_alt\tLN:497404\n@SQ\tSN:chr25_KZ115730v1_alt\tLN:150913\n@SQ\tSN:chr25_KZ115731v1_alt\tLN:323404\n@SQ\tSN:chr25_KZ115732v1_alt\tLN:302861\n@SQ\tSN:chr25_KZ115733v1_alt\tLN:330407\n@SQ\tSN:chr25_KZ115734v1_alt\tLN:345587\n@SQ\tSN:chr25_KZ115735v1_alt\tLN:122028\n@SQ\tSN:chr25_KZ115736v1_alt\tLN:220171\n@SQ\tSN:chr25_KZ115737v1_alt\tLN:309344\n@SQ\tSN:chr25_KZ115738v1_alt\tLN:239395\n@SQ\tSN:chr25_KZ115739v1_alt\tLN:257270\n@SQ\tSN:chr25_KZ115740v1_alt\tLN:536750\n@SQ\tSN:chr25_KZ115741v1_alt\tLN:165730\n@SQ\tSN:chr25_KZ115742v1_alt\tLN:719945\n@SQ\tSN:chr25_KZ115743v1_alt\tLN:480383\n@SQ\tSN:chr25_KZ115744v1_alt\tLN:306851\n@SQ\tSN:chr25_KZ115745v1_alt\tLN:168877\n@SQ\tSN:chr1_KZ114834v1_alt\tLN:427963\n@SQ\tSN:chr1_KZ114835v1_alt\tLN:679277\n@SQ\tSN:chr1_KZ114836v1_alt\tLN:295604\n@SQ\tSN:chr1_KZ114837v1_alt\tLN:194895\n@SQ\tSN:chr1_KZ114838v1_alt\tLN:551405\n@SQ\tSN:chr1_KZ114839v1_alt\tLN:202106\n@SQ\tSN:chr1_KZ114840v1_alt\tLN:167474\n@SQ\tSN:chr1_KZ114841v1_alt\tLN:865375\n@SQ\tSN:chr1_KZ114842v1_alt\tLN:219598\n@SQ\tSN:chr1_KZ114843v1_alt\tLN:247059\n@SQ\tSN:chr1_KZ114844v1_alt\tLN:232235\n@SQ\tSN:chr1_KZ114845v1_alt\tLN:412051\n@SQ\tSN:chr1_KZ114846v1_alt\tLN:395719\n@SQ\tSN:chr1_KZ114847v1_alt\tLN:327970\n@SQ\tSN:chr2_KZ114848v1_alt\tLN:448072\n@SQ\tSN:chr2_KZ114849v1_alt\tLN:413644\n@SQ\tSN:chr3_KZ114850v1_alt\tLN:359689\n@SQ\tSN:chr3_KZ114851v1_alt\tLN:345944\n@SQ\tSN:chr3_KZ114852v1_alt\tLN:558611\n@SQ\tSN:chr3_KZ114853v1_alt\tLN:420613\n@SQ\tSN:chr3_KZ114854v1_alt\tLN:221257\n@SQ\tSN:chr4_KZ114855v1_alt\tLN:438223\n@SQ\tSN:chr4_KZ114856v1_alt\tLN:484449\n@SQ\tSN:chr4_KZ114857v1_alt\tLN:321797\n@SQ\tSN:chr4_KZ114858v1_alt\tLN:401335\n@SQ\tSN:chr5_KZ114859v1_alt\tLN:344256\n@SQ\tSN:chr5_KZ114860v1_alt\tLN:293484\n@SQ\tSN:chr5_KZ114861v1_alt\tLN:287537\n@SQ\tSN:chr5_KZ114862v1_alt\tLN:226421\n@SQ\tSN:chr5_KZ114863v1_alt\tLN:196955\n@SQ\tSN:chr5_KZ114864v1_alt\tLN:171956\n@SQ\tSN:chr5_KZ114865v1_alt\tLN:310867\n@SQ\tSN:chr5_KZ114866v1_alt\tLN:273549\n@SQ\tSN:chr5_KZ114867v1_alt\tLN:514903\n@SQ\tSN:chr5_KZ114868v1_alt\tLN:167372\n@SQ\tSN:chr5_KZ114869v1_alt\tLN:179776\n@SQ\tSN:chr5_KZ114870v1_alt\tLN:214049\n@SQ\tSN:chr5_KZ114871v1_alt\tLN:207401\n@SQ\tSN:chr5_KZ114872v1_alt\tLN:276114\n@SQ\tSN:chr5_KZ114873v1_alt\tLN:350058\n@SQ\tSN:chr6_KZ114874v1_alt\tLN:630243\n@SQ\tSN:chr6_KZ114875v1_alt\tLN:115960\n@SQ\tSN:chr6_KZ114877v1_alt\tLN:564668\n@SQ\tSN:chr6_KZ114878v1_alt\tLN:426041\n@SQ\tSN:chr6_KZ114876v1_alt\tLN:515543\n@SQ\tSN:chr6_KZ114879v1_alt\tLN:279806\n@SQ\tSN:chr6_KZ114880v1_alt\tLN:239690\n@SQ\tSN:chr6_KZ114881v1_alt\tLN:262693\n@SQ\tSN:chr6_KZ114882v1_alt\tLN:194385\n@SQ\tSN:chr6_KZ114883v1_alt\tLN:333677\n@SQ\tSN:chr6_KZ114884v1_alt\tLN:505004\n@SQ\tSN:chr6_KZ114885v1_alt\tLN:331967\n@SQ\tSN:chr6_KZ114886v1_alt\tLN:305465\n@SQ\tSN:chr6_KZ114887v1_alt\tLN:472316\n@SQ\tSN:chr7_KZ114888v1_alt\tLN:152980\n@SQ\tSN:chr7_KZ114889v1_alt\tLN:458046\n@SQ\tSN:chr7_KZ114890v1_alt\tLN:347497\n@SQ\tSN:chr7_KZ114891v1_alt\tLN:285188\n@SQ\tSN:chr7_KZ114892v1_alt\tLN:149621\n@SQ\tSN:chr7_KZ114893v1_alt\tLN:270129\n@SQ\tSN:chr7_KZ114894v1_alt\tLN:443717\n@SQ\tSN:chr8_KZ114895v1_alt\tLN:440426\n@SQ\tSN:chr8_KZ114896v1_alt\tLN:230740\n@SQ\tSN:chr8_KZ114897v1_alt\tLN:353474\n@SQ\tSN:chr8_KZ114898v1_alt\tLN:310722\n@SQ\tSN:chr8_KZ114899v1_alt\tLN:314978\n@SQ\tSN:chr8_KZ114900v1_alt\tLN:142881\n@SQ\tSN:chr9_KZ114901v1_alt\tLN:328231\n@SQ\tSN:chr9_KZ114902v1_alt\tLN:371605\n@SQ\tSN:chr9_KZ114903v1_alt\tLN:381002\n@SQ\tSN:chr9_KZ114904v1_alt\tLN:475844\n@SQ\tSN:chr9_KZ114905v1_alt\tLN:136745\n@SQ\tSN:chr9_KZ114906v1_alt\tLN:310897\n@SQ\tSN:chr9_KZ114907v1_alt\tLN:580942\n@SQ\tSN:chr9_KZ114908v1_alt\tLN:280043\n@SQ\tSN:chr9_KZ114909v1_alt\tLN:350556\n@SQ\tSN:chr9_KZ114910v1_alt\tLN:490283\n@SQ\tSN:chr10_KZ114911v1_alt\tLN:211400\n@SQ\tSN:chr10_KZ114912v1_alt\tLN:269797\n@SQ\tSN:chr10_KZ114913v1_alt\tLN:162578\n@SQ\tSN:chr10_KZ114914v1_alt\tLN:572329\n@SQ\tSN:chr10_KZ114915v1_alt\tLN:287446\n@SQ\tSN:chr10_KZ114916v1_alt\tLN:248020\n@SQ\tSN:chr10_KZ114917v1_alt\tLN:250405\n@SQ\tSN:chr10_KZ114918v1_alt\tLN:385835\n@SQ\tSN:chr11_KZ114919v1_alt\tLN:168622\n@SQ\tSN:chr11_KZ114920v1_alt\tLN:364969\n@SQ\tSN:chr11_KZ114921v1_alt\tLN:409876\n@SQ\tSN:chr11_KZ114922v1_alt\tLN:257729\n@SQ\tSN:chr11_KZ114923v1_alt\tLN:347088\n@SQ\tSN:chr11_KZ114924v1_alt\tLN:230115\n@SQ\tSN:chr11_KZ114925v1_alt\tLN:410172\n@SQ\tSN:chr12_KZ114926v1_alt\tLN:750006\n@SQ\tSN:chr12_KZ114927v1_alt\tLN:178522\n@SQ\tSN:chr12_KZ114928v1_alt\tLN:350808\n@SQ\tSN:chr12_KZ114929v1_alt\tLN:182584\n@SQ\tSN:chr13_KZ114930v1_alt\tLN:338818\n@SQ\tSN:chr13_KZ114931v1_alt\tLN:322765\n@SQ\tSN:chr13_KZ114932v1_alt\tLN:295554\n@SQ\tSN:chr13_KZ114933v1_alt\tLN:244373\n@SQ\tSN:chr13_KZ114934v1_alt\tLN:375908\n@SQ\tSN:chr13_KZ114935v1_alt\tLN:309330\n@SQ\tSN:chr14_KZ114936v1_alt\tLN:332510\n@SQ\tSN:chr14_KZ114937v1_alt\tLN:364098\n@SQ\tSN:chr14_KZ114938v1_alt\tLN:297326\n@SQ\tSN:chr14_KZ114939v1_alt\tLN:507217\n@SQ\tSN:chr14_KZ114940v1_alt\tLN:338397\n@SQ\tSN:chr14_KZ114941v1_alt\tLN:459127\n@SQ\tSN:chr14_KZ114942v1_alt\tLN:290732\n@SQ\tSN:chr14_KZ114943v1_alt\tLN:343595\n@SQ\tSN:chr14_KZ114944v1_alt\tLN:330942\n@SQ\tSN:chr15_KZ114945v1_alt\tLN:348482\n@SQ\tSN:chr15_KZ114946v1_alt\tLN:230937\n@SQ\tSN:chr15_KZ114947v1_alt\tLN:193294\n@SQ\tSN:chr15_KZ114948v1_alt\tLN:511324\n@SQ\tSN:chr16_KZ114949v1_alt\tLN:365630\n@SQ\tSN:chr16_KZ114950v1_alt\tLN:189124\n@SQ\tSN:chr16_KZ114951v1_alt\tLN:569531\n@SQ\tSN:chr17_KZ114952v1_alt\tLN:321232\n@SQ\tSN:chr17_KZ114953v1_alt\tLN:338614\n@SQ\tSN:chr17_KZ114954v1_alt\tLN:242686\n@SQ\tSN:chr17_KZ114955v1_alt\tLN:299846\n@SQ\tSN:chr17_KZ114956v1_alt\tLN:400652\n@SQ\tSN:chr17_KZ114957v1_alt\tLN:195601\n@SQ\tSN:chr18_KZ114958v1_alt\tLN:358367\n@SQ\tSN:chr18_KZ114959v1_alt\tLN:160458\n@SQ\tSN:chr18_KZ114960v1_alt\tLN:495649\n@SQ\tSN:chr18_KZ114961v1_alt\tLN:385799\n@SQ\tSN:chr18_KZ114962v1_alt\tLN:190462\n@SQ\tSN:chr18_KZ114963v1_alt\tLN:310446\n@SQ\tSN:chr18_KZ114964v1_alt\tLN:374960\n@SQ\tSN:chr18_KZ114965v1_alt\tLN:207088\n@SQ\tSN:chr18_KZ114966v1_alt\tLN:527795\n@SQ\tSN:chr18_KZ114967v1_alt\tLN:585253\n@SQ\tSN:chr20_KZ114968v1_alt\tLN:262180\n@SQ\tSN:chr20_KZ114969v1_alt\tLN:272282\n@SQ\tSN:chr20_KZ114970v1_alt\tLN:250473\n@SQ\tSN:chr21_KZ114971v1_alt\tLN:215340\n@SQ\tSN:chr21_KZ114972v1_alt\tLN:345283\n@SQ\tSN:chr21_KZ114973v1_alt\tLN:362555\n@SQ\tSN:chr21_KZ114974v1_alt\tLN:506090\n@SQ\tSN:chr22_KZ114975v1_alt\tLN:302473\n@SQ\tSN:chr22_KZ114976v1_alt\tLN:226904\n@SQ\tSN:chr22_KZ114977v1_alt\tLN:570218\n@SQ\tSN:chr22_KZ114978v1_alt\tLN:366993\n@SQ\tSN:chr22_KZ114979v1_alt\tLN:198670\n@SQ\tSN:chr22_KZ114980v1_alt\tLN:175545\n@SQ\tSN:chr22_KZ114981v1_alt\tLN:459411\n@SQ\tSN:chr22_KZ114982v1_alt\tLN:259787\n@SQ\tSN:chr23_KZ114983v1_alt\tLN:440239\n@SQ\tSN:chr23_KZ114984v1_alt\tLN:308760\n@SQ\tSN:chr23_KZ114985v1_alt\tLN:350026\n@SQ\tSN:chr23_KZ114986v1_alt\tLN:412562\n@SQ\tSN:chr23_KZ114987v1_alt\tLN:509809\n@SQ\tSN:chr24_KZ114988v1_alt\tLN:236927\n@SQ\tSN:chr24_KZ114989v1_alt\tLN:213656\n@SQ\tSN:chr24_KZ114990v1_alt\tLN:160616\n@SQ\tSN:chr24_KZ114991v1_alt\tLN:186906\n@SQ\tSN:chr24_KZ114992v1_alt\tLN:269715\n@SQ\tSN:chr24_KZ114993v1_alt\tLN:172551\n@SQ\tSN:chr25_KZ114994v1_alt\tLN:475156\n@SQ\tSN:chr25_KZ114995v1_alt\tLN:342335\n@SQ\tSN:chr25_KZ114996v1_alt\tLN:354810\n@SQ\tSN:chr1_KZ115746v1_alt\tLN:295456\n@SQ\tSN:chr1_KZ115747v1_alt\tLN:408621\n@SQ\tSN:chr5_KZ115748v1_alt\tLN:237423\n@SQ\tSN:chr5_KZ115749v1_alt\tLN:367913\n@SQ\tSN:chr5_KZ115750v1_alt\tLN:381777\n@SQ\tSN:chr6_KZ115751v1_alt\tLN:248907\n@SQ\tSN:chr6_KZ115752v1_alt\tLN:234350\n@SQ\tSN:chr6_KZ115753v1_alt\tLN:159867\n@SQ\tSN:chr6_KZ115754v1_alt\tLN:529647\n@SQ\tSN:chr6_KZ115755v1_alt\tLN:293798\n@SQ\tSN:chr6_KZ115756v1_alt\tLN:327950\n@SQ\tSN:chr9_KZ115757v1_alt\tLN:581366\n@SQ\tSN:chr11_KZ115758v1_alt\tLN:477473\n@SQ\tSN:chr11_KZ115759v1_alt\tLN:372242\n@SQ\tSN:chr14_KZ115760v1_alt\tLN:210780\n@SQ\tSN:chr6_KZ115761v1_alt\tLN:383034\n@SQ\tSN:chr11_KZ115762v1_alt\tLN:370664\n@SQ\tSN:chr14_KZ115763v1_alt\tLN:195606\n@SQ\tSN:chr1\tLN:59578282\n@SQ\tSN:chr10\tLN:45420867\n@SQ\tSN:chr11\tLN:45484837\n@SQ\tSN:chr12\tLN:49182954\n@SQ\tSN:chr13\tLN:52186027\n@SQ\tSN:chr14\tLN:52660232\n@SQ\tSN:chr15\tLN:48040578\n@SQ\tSN:chr16\tLN:55266484\n@SQ\tSN:chr17\tLN:53461100\n@SQ\tSN:chr18\tLN:51023478\n@SQ\tSN:chr19\tLN:48449771\n@SQ\tSN:chr2\tLN:59640629\n@SQ\tSN:chr20\tLN:55201332\n@SQ\tSN:chr21\tLN:45934066\n@SQ\tSN:chr22\tLN:39133080\n@SQ\tSN:chr23\tLN:46223584\n@SQ\tSN:chr24\tLN:42172926\n@SQ\tSN:chr25\tLN:37502051\n@SQ\tSN:chr3\tLN:62628489\n@SQ\tSN:chr4\tLN:78093715\n@SQ\tSN:chr5\tLN:72500376\n@SQ\tSN:chr6\tLN:60270059\n@SQ\tSN:chr7\tLN:74282399\n@SQ\tSN:chr8\tLN:54304671\n@SQ\tSN:chr9\tLN:56459846\n@SQ\tSN:chrUn_KN147552v2\tLN:24373\n@SQ\tSN:chrUn_KN147632v2\tLN:184438\n@SQ\tSN:chrUn_KN147636v1\tLN:203829\n@SQ\tSN:chrUn_KN147637v2\tLN:171924\n@SQ\tSN:chrUn_KN147642v2\tLN:204646\n@SQ\tSN:chrUn_KN147651v2\tLN:351968\n@SQ\tSN:chrUn_KN147652v2\tLN:252640\n@SQ\tSN:chrUn_KN148038v2\tLN:17585\n@SQ\tSN:chrUn_KN148828v2\tLN:13322\n@SQ\tSN:chrUn_KN148869v2\tLN:18523\n@SQ\tSN:chrUn_KN149680v1\tLN:38724\n@SQ\tSN:chrUn_KN149682v1\tLN:137468\n@SQ\tSN:chrUn_KN149683v1\tLN:152860\n@SQ\tSN:chrUn_KN149684v1\tLN:159057\n@SQ\tSN:chrUn_KN149685v1\tLN:164780\n@SQ\tSN:chrUn_KN149686v1\tLN:260365\n@SQ\tSN:chrUn_KN149687v1\tLN:165668\n@SQ\tSN:chrUn_KN149688v2\tLN:252035\n@SQ\tSN:chrUn_KN149689v2\tLN:201817\n@SQ\tSN:chrUn_KN149690v1\tLN:343018\n@SQ\tSN:chrUn_KN149691v1\tLN:233193\n@SQ\tSN:chrUn_KN149692v1\tLN:36911\n@SQ\tSN:chrUn_KN149693v1\tLN:49295\n@SQ\tSN:chrUn_KN149694v1\tLN:162759\n@SQ\tSN:chrUn_KN149695v1\tLN:190731\n@SQ\tSN:chrUn_KN149696v2\tLN:368252\n@SQ\tSN:chrUn_KN149697v1\tLN:40969\n@SQ\tSN:chrUn_KN149698v1\tLN:108577\n@SQ\tSN:chrUn_KN149700v1\tLN:40050\n@SQ\tSN:chrUn_KN149701v1\tLN:3760\n@SQ\tSN:chrUn_KN149702v1\tLN:100325\n@SQ\tSN:chrUn_KN149703v1\tLN:13902\n@SQ\tSN:chrUn_KN149705v1\tLN:27926\n@SQ\tSN:chrUn_KN149706v1\tLN:33279\n@SQ\tSN:chrUn_KN149707v2\tLN:7455\n@SQ\tSN:chrUn_KN149708v1\tLN:20567\n@SQ\tSN:chrUn_KN149709v1\tLN:27814\n@SQ\tSN:chrUn_KN149710v1\tLN:50974\n@SQ\tSN:chrUn_KN149711v1\tLN:11473\n@SQ\tSN:chrUn_KN149713v1\tLN:10094\n@SQ\tSN:chrUn_KN149714v1\tLN:74622\n@SQ\tSN:chrUn_KN149715v1\tLN:19020\n@SQ\tSN:chrUn_KN149716v1\tLN:42229\n@SQ\tSN:chrUn_KN149717v1\tLN:47589\n@SQ\tSN:chrUn_KN149718v1\tLN:65247\n@SQ\tSN:chrUn_KN149719v1\tLN:47531\n@SQ\tSN:chrUn_KN149720v1\tLN:10211\n@SQ\tSN:chrUn_KN149721v1\tLN:25462\n@SQ\tSN:chrUn_KN149722v1\tLN:13397\n@SQ\tSN:chrUn_KN149723v1\tLN:55784\n@SQ\tSN:chrUn_KN149724v1\tLN:11849\n@SQ\tSN:chrUn_KN149725v1\tLN:69829\n@SQ\tSN:chrUn_KN149727v1\tLN:24871\n@SQ\tSN:chrUn_KN149728v1\tLN:9442\n@SQ\tSN:chrUn_KN149729v1\tLN:5608\n@SQ\tSN:chrUn_KN149730v1\tLN:14804\n@SQ\tSN:chrUn_KN149732v1\tLN:16041\n@SQ\tSN:chrUn_KN149733v1\tLN:21637\n@SQ\tSN:chrUn_KN149735v1\tLN:5747\n@SQ\tSN:chrUn_KN149737v1\tLN:27700\n@SQ\tSN:chrUn_KN149738v1\tLN:10603\n@SQ\tSN:chrUn_KN149739v1\tLN:51610\n@SQ\tSN:chrUn_KN149740v1\tLN:1265\n@SQ\tSN:chrUn_KN149741v1\tLN:21941\n@SQ\tSN:chrUn_KN149742v1\tLN:2671\n@SQ\tSN:chrUn_KN149743v1\tLN:21023\n@SQ\tSN:chrUn_KN149745v1\tLN:8150\n@SQ\tSN:chrUn_KN149746v1\tLN:10900\n@SQ\tSN:chrUn_KN149747v1\tLN:16275\n@SQ\tSN:chrUn_KN149748v1\tLN:96570\n@SQ\tSN:chrUn_KN149749v1\tLN:40089\n@SQ\tSN:chrUn_KN149750v1\tLN:13928\n@SQ\tSN:chrUn_KN149751v1\tLN:15848\n@SQ\tSN:chrUn_KN149753v1\tLN:30249\n@SQ\tSN:chrUn_KN149754v1\tLN:40214\n@SQ\tSN:chrUn_KN149755v1\tLN:11941\n@SQ\tSN:chrUn_KN149756v1\tLN:11785\n@SQ\tSN:chrUn_KN149757v1\tLN:16145\n@SQ\tSN:chrUn_KN149758v1\tLN:9515\n@SQ\tSN:chrUn_KN149760v1\tLN:46605\n@SQ\tSN:chrUn_KN149761v1\tLN:14795\n@SQ\tSN:chrUn_KN149762v1\tLN:17936\n@SQ\tSN:chrUn_KN149763v1\tLN:19644\n@SQ\tSN:chrUn_KN149764v1\tLN:19831\n@SQ\tSN:chrUn_KN149765v1\tLN:29197\n@SQ\tSN:chrUn_KN149766v1\tLN:14664\n@SQ\tSN:chrUn_KN149767v1\tLN:30874\n@SQ\tSN:chrUn_KN149768v1\tLN:17671\n@SQ\tSN:chrUn_KN149769v1\tLN:53048\n@SQ\tSN:chrUn_KN149770v1\tLN:12046\n@SQ\tSN:chrUn_KN149771v1\tLN:14151\n@SQ\tSN:chrUn_KN149772v1\tLN:13273\n@SQ\tSN:chrUn_KN149774v1\tLN:12337\n@SQ\tSN:chrUn_KN149775v2\tLN:26074\n@SQ\tSN:chrUn_KN149777v1\tLN:1553\n@SQ\tSN:chrUn_KN149778v1\tLN:111598\n@SQ\tSN:chrUn_KN149779v1\tLN:21664\n@SQ\tSN:chrUn_KN149780v1\tLN:19718\n@SQ\tSN:chrUn_KN149782v1\tLN:36097\n@SQ\tSN:chrUn_KN149783v1\tLN:11892\n@SQ\tSN:chrUn_KN149784v1\tLN:73829\n@SQ\tSN:chrUn_KN149785v1\tLN:1577\n@SQ\tSN:chrUn_KN149786v1\tLN:1745\n@SQ\tSN:chrUn_KN149787v1\tLN:39794\n@SQ\tSN:chrUn_KN149788v1\tLN:8794\n@SQ\tSN:chrUn_KN149789v1\tLN:12990\n@SQ\tSN:chrUn_KN149790v1\tLN:115850\n@SQ\tSN:chrUn_KN149791v1\tLN:17273\n@SQ\tSN:chrUn_KN149792v1\tLN:11232\n@SQ\tSN:chrUn_KN149793v1\tLN:13298\n@SQ\tSN:chrUn_KN149794v1\tLN:25440\n@SQ\tSN:chrUn_KN149795v1\tLN:34615\n@SQ\tSN:chrUn_KN149796v1\tLN:25635\n@SQ\tSN:chrUn_KN149797v1\tLN:102101\n@SQ\tSN:chrUn_KN149798v1\tLN:1990\n@SQ\tSN:chrUn_KN149800v1\tLN:42049\n@SQ\tSN:chrUn_KN149801v1\tLN:4454\n@SQ\tSN:chrUn_KN149803v1\tLN:16018\n@SQ\tSN:chrUn_KN149804v1\tLN:10148\n@SQ\tSN:chrUn_KN149805v1\tLN:12432\n@SQ\tSN:chrUn_KN149806v1\tLN:15157\n@SQ\tSN:chrUn_KN149807v1\tLN:12512\n@SQ\tSN:chrUn_KN149809v1\tLN:2001\n@SQ\tSN:chrUn_KN149810v1\tLN:15043\n@SQ\tSN:chrUn_KN149811v1\tLN:8720\n@SQ\tSN:chrUn_KN149812v1\tLN:51419\n@SQ\tSN:chrUn_KN149813v1\tLN:59009\n@SQ\tSN:chrUn_KN149814v1\tLN:25878\n@SQ\tSN:chrUn_KN149815v1\tLN:33337\n@SQ\tSN:chrUn_KN149816v1\tLN:10128\n@SQ\tSN:chrUn_KN149817v1\tLN:11116\n@SQ\tSN:chrUn_KN149818v1\tLN:25942\n@SQ\tSN:chrUn_KN149819v1\tLN:10210\n@SQ\tSN:chrUn_KN149822v1\tLN:2460\n@SQ\tSN:chrUn_KN149823v1\tLN:14034\n@SQ\tSN:chrUn_KN149824v1\tLN:2357\n@SQ\tSN:chrUn_KN149825v1\tLN:22128\n@SQ\tSN:chrUn_KN149826v1\tLN:90482\n@SQ\tSN:chrUn_KN149827v1\tLN:13555\n@SQ\tSN:chrUn_KN149828v1\tLN:11414\n@SQ\tSN:chrUn_KN149829v1\tLN:27323\n@SQ\tSN:chrUn_KN149832v1\tLN:12483\n@SQ\tSN:chrUn_KN149834v1\tLN:17343\n@SQ\tSN:chrUn_KN149835v1\tLN:25861\n@SQ\tSN:chrUn_KN149836v1\tLN:34954\n@SQ\tSN:chrUn_KN149837v1\tLN:8007\n@SQ\tSN:chrUn_KN149838v1\tLN:29025\n@SQ\tSN:chrUn_KN149839v1\tLN:12998\n@SQ\tSN:chrUn_KN149840v1\tLN:46864\n@SQ\tSN:chrUn_KN149841v1\tLN:10085\n@SQ\tSN:chrUn_KN149843v1\tLN:33258\n@SQ\tSN:chrUn_KN149844v1\tLN:10201\n@SQ\tSN:chrUn_KN149846v1\tLN:28664\n@SQ\tSN:chrUn_KN149847v1\tLN:130903\n@SQ\tSN:chrUn_KN149848v1\tLN:10341\n@SQ\tSN:chrUn_KN149849v1\tLN:20421\n@SQ\tSN:chrUn_KN149850v1\tLN:33401\n@SQ\tSN:chrUn_KN149851v1\tLN:12094\n@SQ\tSN:chrUn_KN149852v1\tLN:30223\n@SQ\tSN:chrUn_KN149853v1\tLN:12817\n@SQ\tSN:chrUn_KN149854v1\tLN:6367\n@SQ\tSN:chrUn_KN149855v1\tLN:23165\n@SQ\tSN:chrUn_KN149856v1\tLN:35330\n@SQ\tSN:chrUn_KN149857v1\tLN:10132\n@SQ\tSN:chrUn_KN149859v1\tLN:53306\n@SQ\tSN:chrUn_KN149860v1\tLN:17408\n@SQ\tSN:chrUn_KN149861v1\tLN:14336\n@SQ\tSN:chrUn_KN149862v1\tLN:11987\n@SQ\tSN:chrUn_KN149863v1\tLN:11955\n@SQ\tSN:chrUn_KN149864v1\tLN:12929\n@SQ\tSN:chrUn_KN149865v1\tLN:49167\n@SQ\tSN:chrUn_KN149866v1\tLN:14752\n@SQ\tSN:chrUn_KN149867v1\tLN:1514\n@SQ\tSN:chrUn_KN149871v1\tLN:22553\n@SQ\tSN:chrUn_KN149872v1\tLN:12222\n@SQ\tSN:chrUn_KN149873v1\tLN:1146\n@SQ\tSN:chrUn_KN149874v1\tLN:5295\n@SQ\tSN:chrUn_KN149876v1\tLN:11298\n@SQ\tSN:chrUn_KN149878v1\tLN:7547\n@SQ\tSN:chrUn_KN149879v1\tLN:11893\n@SQ\tSN:chrUn_KN149880v1\tLN:64889\n@SQ\tSN:chrUn_KN149881v1\tLN:10736\n@SQ\tSN:chrUn_KN149882v1\tLN:7649\n@SQ\tSN:chrUn_KN149883v1\tLN:12434\n@SQ\tSN:chrUn_KN149884v1\tLN:51715\n@SQ\tSN:chrUn_KN149885v1\tLN:1347\n@SQ\tSN:chrUn_KN149887v1\tLN:11971\n@SQ\tSN:chrUn_KN149888v1\tLN:17117\n@SQ\tSN:chrUn_KN149889v1\tLN:10166\n@SQ\tSN:chrUn_KN149890v1\tLN:12029\n@SQ\tSN:chrUn_KN149892v1\tLN:24638\n@SQ\tSN:chrUn_KN149893v1\tLN:27995\n@SQ\tSN:chrUn_KN149895v1\tLN:92930\n@SQ\tSN:chrUn_KN149896v1\tLN:13102\n@SQ\tSN:chrUn_KN149897v1\tLN:14044\n@SQ\tSN:chrUn_KN149899v1\tLN:13632\n@SQ\tSN:chrUn_KN149900v1\tLN:11016\n@SQ\tSN:chrUn_KN149901v1\tLN:10512\n@SQ\tSN:chrUn_KN149903v1\tLN:11318\n@SQ\tSN:chrUn_KN149904v1\tLN:89156\n@SQ\tSN:chrUn_KN149905v1\tLN:14056\n@SQ\tSN:chrUn_KN149906v1\tLN:38987\n@SQ\tSN:chrUn_KN149907v1\tLN:9870\n@SQ\tSN:chrUn_KN149908v1\tLN:12800\n@SQ\tSN:chrUn_KN149909v1\tLN:40056\n@SQ\tSN:chrUn_KN149912v1\tLN:77979\n@SQ\tSN:chrUn_KN149913v1\tLN:16487\n@SQ\tSN:chrUn_KN149914v1\tLN:18241\n@SQ\tSN:chrUn_KN149915v1\tLN:10395\n@SQ\tSN:chrUn_KN149916v1\tLN:4293\n@SQ\tSN:chrUn_KN149917v1\tLN:3831\n@SQ\tSN:chrUn_KN149919v1\tLN:21073\n@SQ\tSN:chrUn_KN149921v1\tLN:28254\n@SQ\tSN:chrUn_KN149922v1\tLN:12529\n@SQ\tSN:chrUn_KN149923v1\tLN:36729\n@SQ\tSN:chrUn_KN149924v1\tLN:23395\n@SQ\tSN:chrUn_KN149925v1\tLN:29860\n@SQ\tSN:chrUn_KN149926v1\tLN:3688\n@SQ\tSN:chrUn_KN149927v1\tLN:11950\n@SQ\tSN:chrUn_KN149928v1\tLN:14297\n@SQ\tSN:chrUn_KN149931v1\tLN:6703\n@SQ\tSN:chrUn_KN149932v1\tLN:89521\n@SQ\tSN:chrUn_KN149933v1\tLN:13433\n@SQ\tSN:chrUn_KN149935v1\tLN:9230\n@SQ\tSN:chrUn_KN149936v1\tLN:16058\n@SQ\tSN:chrUn_KN149937v1\tLN:14110\n@SQ\tSN:chrUn_KN149938v1\tLN:12455\n@SQ\tSN:chrUn_KN149939v1\tLN:76611\n@SQ\tSN:chrUn_KN149940v1\tLN:11887\n@SQ\tSN:chrUn_KN149941v1\tLN:13607\n@SQ\tSN:chrUn_KN149943v1\tLN:29608\n@SQ\tSN:chrUn_KN149944v1\tLN:24909\n@SQ\tSN:chrUn_KN149946v1\tLN:33071\n@SQ\tSN:chrUn_KN149948v1\tLN:117499\n@SQ\tSN:chrUn_KN149949v1\tLN:64126\n@SQ\tSN:chrUn_KN149950v1\tLN:5952\n@SQ\tSN:chrUn_KN149951v1\tLN:5000\n@SQ\tSN:chrUn_KN149953v1\tLN:46218\n@SQ\tSN:chrUn_KN149955v1\tLN:19758\n@SQ\tSN:chrUn_KN149956v1\tLN:1889\n@SQ\tSN:chrUn_KN149957v1\tLN:1094\n@SQ\tSN:chrUn_KN149958v1\tLN:43073\n@SQ\tSN:chrUn_KN149959v1\tLN:59274\n@SQ\tSN:chrUn_KN149960v1\tLN:9235\n@SQ\tSN:chrUn_KN149961v1\tLN:20600\n@SQ\tSN:chrUn_KN149965v1\tLN:14790\n@SQ\tSN:chrUn_KN149967v1\tLN:8612\n@SQ\tSN:chrUn_KN149968v1\tLN:82990\n@SQ\tSN:chrUn_KN149969v1\tLN:13714\n@SQ\tSN:chrUn_KN149970v1\tLN:17511\n@SQ\tSN:chrUn_KN149971v1\tLN:11275\n@SQ\tSN:chrUn_KN149973v1\tLN:35555\n@SQ\tSN:chrUn_KN149974v1\tLN:19596\n@SQ\tSN:chrUn_KN149976v1\tLN:11858\n@SQ\tSN:chrUn_KN149977v2\tLN:11023\n@SQ\tSN:chrUn_KN149978v1\tLN:16801\n@SQ\tSN:chrUn_KN149979v1\tLN:22834\n@SQ\tSN:chrUn_KN149980v1\tLN:7980\n@SQ\tSN:chrUn_KN149981v1\tLN:12811\n@SQ\tSN:chrUn_KN149982v1\tLN:31814\n@SQ\tSN:chrUn_KN149983v1\tLN:17884\n@SQ\tSN:chrUn_KN149984v1\tLN:96477\n@SQ\tSN:chrUn_KN149988v1\tLN:9944\n@SQ\tSN:chrUn_KN149989v1\tLN:34480\n@SQ\tSN:chrUn_KN149990v1\tLN:57651\n@SQ\tSN:chrUn_KN149991v1\tLN:9871\n@SQ\tSN:chrUn_KN149992v1\tLN:57912\n@SQ\tSN:chrUn_KN149993v1\tLN:16921\n@SQ\tSN:chrUn_KN149995v1\tLN:12015\n@SQ\tSN:chrUn_KN149996v1\tLN:33528\n@SQ\tSN:chrUn_KN149997v1\tLN:6296\n@SQ\tSN:chrUn_KN149998v1\tLN:74724\n@SQ\tSN:chrUn_KN149999v1\tLN:14071\n@SQ\tSN:chrUn_KN150000v1\tLN:69737\n@SQ\tSN:chrUn_KN150002v1\tLN:17430\n@SQ\tSN:chrUn_KN150004v2\tLN:13059\n@SQ\tSN:chrUn_KN150005v1\tLN:34409\n@SQ\tSN:chrUn_KN150006v1\tLN:10518\n@SQ\tSN:chrUn_KN150007v1\tLN:13072\n@SQ\tSN:chrUn_KN150008v1\tLN:15572\n@SQ\tSN:chrUn_KN150009v1\tLN:17727\n@SQ\tSN:chrUn_KN150011v1\tLN:12995\n@SQ\tSN:chrUn_KN150012v1\tLN:11998\n@SQ\tSN:chrUn_KN150013v1\tLN:8488\n@SQ\tSN:chrUn_KN150014v1\tLN:13588\n@SQ\tSN:chrUn_KN150015v1\tLN:33441\n@SQ\tSN:chrUn_KN150016v1\tLN:21592\n@SQ\tSN:chrUn_KN150017v1\tLN:25636\n@SQ\tSN:chrUn_KN150018v1\tLN:1063\n@SQ\tSN:chrUn_KN150019v2\tLN:19834\n@SQ\tSN:chrUn_KN150020v1\tLN:11925\n@SQ\tSN:chrUn_KN150021v1\tLN:103967\n@SQ\tSN:chrUn_KN150022v1\tLN:76538\n@SQ\tSN:chrUn_KN150023v1\tLN:22153\n@SQ\tSN:chrUn_KN150024v1\tLN:1714\n@SQ\tSN:chrUn_KN150025v1\tLN:26343\n@SQ\tSN:chrUn_KN150028v1\tLN:19517\n@SQ\tSN:chrUn_KN150029v1\tLN:12415\n@SQ\tSN:chrUn_KN150030v1\tLN:57074\n@SQ\tSN:chrUn_KN150031v1\tLN:60899\n@SQ\tSN:chrUn_KN150032v1\tLN:29546\n@SQ\tSN:chrUn_KN150033v1\tLN:56448\n@SQ\tSN:chrUn_KN150034v1\tLN:1919\n@SQ\tSN:chrUn_KN150035v1\tLN:38086\n@SQ\tSN:chrUn_KN150037v1\tLN:2866\n@SQ\tSN:chrUn_KN150038v1\tLN:71326\n@SQ\tSN:chrUn_KN150039v1\tLN:3463\n@SQ\tSN:chrUn_KN150040v1\tLN:19896\n@SQ\tSN:chrUn_KN150041v2\tLN:66431\n@SQ\tSN:chrUn_KN150042v1\tLN:30789\n@SQ\tSN:chrUn_KN150043v1\tLN:31984\n@SQ\tSN:chrUn_KN150044v1\tLN:9097\n@SQ\tSN:chrUn_KN150045v2\tLN:10364\n@SQ\tSN:chrUn_KN150047v1\tLN:20749\n@SQ\tSN:chrUn_KN150048v1\tLN:128109\n@SQ\tSN:chrUn_KN150049v1\tLN:45008\n@SQ\tSN:chrUn_KN150051v1\tLN:1995\n@SQ\tSN:chrUn_KN150052v1\tLN:15943\n@SQ\tSN:chrUn_KN150054v1\tLN:16143\n@SQ\tSN:chrUn_KN150055v1\tLN:32561\n@SQ\tSN:chrUn_KN150056v1\tLN:29449\n@SQ\tSN:chrUn_KN150057v1\tLN:10736\n@SQ\tSN:chrUn_KN150058v1\tLN:21348\n@SQ\tSN:chrUn_KN150059v1\tLN:16588\n@SQ\tSN:chrUn_KN150060v1\tLN:80234\n@SQ\tSN:chrUn_KN150061v1\tLN:24048\n@SQ\tSN:chrUn_KN150062v1\tLN:35038\n@SQ\tSN:chrUn_KN150063v1\tLN:20846\n@SQ\tSN:chrUn_KN150064v1\tLN:14598\n@SQ\tSN:chrUn_KN150065v1\tLN:9859\n@SQ\tSN:chrUn_KN150066v1\tLN:29537\n@SQ\tSN:chrUn_KN150067v1\tLN:27325\n@SQ\tSN:chrUn_KN150068v1\tLN:62725\n@SQ\tSN:chrUn_KN150070v1\tLN:14070\n@SQ\tSN:chrUn_KN150071v1\tLN:14960\n@SQ\tSN:chrUn_KN150072v1\tLN:13309\n@SQ\tSN:chrUn_KN150073v1\tLN:14052\n@SQ\tSN:chrUn_KN150074v1\tLN:28653\n@SQ\tSN:chrUn_KN150076v1\tLN:14425\n@SQ\tSN:chrUn_KN150077v1\tLN:51360\n@SQ\tSN:chrUn_KN150078v1\tLN:12098\n@SQ\tSN:chrUn_KN150079v1\tLN:46800\n@SQ\tSN:chrUn_KN150080v1\tLN:37662\n@SQ\tSN:chrUn_KN150081v1\tLN:12836\n@SQ\tSN:chrUn_KN150082v1\tLN:8788\n@SQ\tSN:chrUn_KN150083v1\tLN:49514\n@SQ\tSN:chrUn_KN150084v1\tLN:24192\n@SQ\tSN:chrUn_KN150085v1\tLN:29177\n@SQ\tSN:chrUn_KN150086v1\tLN:1639\n@SQ\tSN:chrUn_KN150089v1\tLN:13104\n@SQ\tSN:chrUn_KN150090v1\tLN:12028\n@SQ\tSN:chrUn_KN150092v1\tLN:14544\n@SQ\tSN:chrUn_KN150093v1\tLN:14738\n@SQ\tSN:chrUn_KN150094v1\tLN:7824\n@SQ\tSN:chrUn_KN150095v1\tLN:9204\n@SQ\tSN:chrUn_KN150097v1\tLN:11690\n@SQ\tSN:chrUn_KN150098v1\tLN:68279\n@SQ\tSN:chrUn_KN150100v1\tLN:9237\n@SQ\tSN:chrUn_KN150102v1\tLN:34431\n@SQ\tSN:chrUn_KN150103v1\tLN:4090\n@SQ\tSN:chrUn_KN150104v1\tLN:53188\n@SQ\tSN:chrUn_KN150105v1\tLN:58062\n@SQ\tSN:chrUn_KN150106v1\tLN:56524\n@SQ\tSN:chrUn_KN150110v1\tLN:9804\n@SQ\tSN:chrUn_KN150111v1\tLN:29931\n@SQ\tSN:chrUn_KN150112v1\tLN:3423\n@SQ\tSN:chrUn_KN150113v1\tLN:19310\n@SQ\tSN:chrUn_KN150114v1\tLN:24178\n@SQ\tSN:chrUn_KN150115v1\tLN:18676\n@SQ\tSN:chrUn_KN150117v1\tLN:48543\n@SQ\tSN:chrUn_KN150118v1\tLN:54494\n@SQ\tSN:chrUn_KN150119v1\tLN:1143\n@SQ\tSN:chrUn_KN150120v1\tLN:27511\n@SQ\tSN:chrUn_KN150121v1\tLN:8447\n@SQ\tSN:chrUn_KN150122v1\tLN:67534\n@SQ\tSN:chrUn_KN150123v1\tLN:51978\n@SQ\tSN:chrUn_KN150125v1\tLN:83315\n@SQ\tSN:chrUn_KN150126v1\tLN:24847\n@SQ\tSN:chrUn_KN150127v1\tLN:33302\n@SQ\tSN:chrUn_KN150128v1\tLN:12262\n@SQ\tSN:chrUn_KN150130v1\tLN:9925\n@SQ\tSN:chrUn_KN150131v1\tLN:70868\n@SQ\tSN:chrUn_KN150132v1\tLN:13999\n@SQ\tSN:chrUn_KN150133v2\tLN:53456\n@SQ\tSN:chrUn_KN150134v1\tLN:29067\n@SQ\tSN:chrUn_KN150136v1\tLN:49373\n@SQ\tSN:chrUn_KN150137v1\tLN:36779\n@SQ\tSN:chrUn_KN150140v2\tLN:19733\n@SQ\tSN:chrUn_KN150141v1\tLN:17117\n@SQ\tSN:chrUn_KN150144v1\tLN:14974\n@SQ\tSN:chrUn_KN150145v1\tLN:9970\n@SQ\tSN:chrUn_KN150146v1\tLN:9714\n@SQ\tSN:chrUn_KN150147v1\tLN:7977\n@SQ\tSN:chrUn_KN150148v1\tLN:44589\n@SQ\tSN:chrUn_KN150150v1\tLN:9780\n@SQ\tSN:chrUn_KN150152v1\tLN:9348\n@SQ\tSN:chrUn_KN150154v1\tLN:21695\n@SQ\tSN:chrUn_KN150155v1\tLN:10282\n@SQ\tSN:chrUn_KN150156v1\tLN:33247\n@SQ\tSN:chrUn_KN150157v1\tLN:18756\n@SQ\tSN:chrUn_KN150158v1\tLN:106536\n@SQ\tSN:chrUn_KN150159v1\tLN:35229\n@SQ\tSN:chrUn_KN150160v1\tLN:17824\n@SQ\tSN:chrUn_KN150161v1\tLN:12647\n@SQ\tSN:chrUn_KN150162v1\tLN:10930\n@SQ\tSN:chrUn_KN150164v1\tLN:11300\n@SQ\tSN:chrUn_KN150165v1\tLN:32739\n@SQ\tSN:chrUn_KN150166v1\tLN:49457\n@SQ\tSN:chrUn_KN150167v1\tLN:13466\n@SQ\tSN:chrUn_KN150168v1\tLN:28382\n@SQ\tSN:chrUn_KN150170v1\tLN:55716\n@SQ\tSN:chrUn_KN150171v1\tLN:140649\n@SQ\tSN:chrUn_KN150172v1\tLN:40634\n@SQ\tSN:chrUn_KN150173v1\tLN:50946\n@SQ\tSN:chrUn_KN150174v1\tLN:13450\n@SQ\tSN:chrUn_KN150175v1\tLN:24612\n@SQ\tSN:chrUn_KN150176v1\tLN:69061\n@SQ\tSN:chrUn_KN150177v1\tLN:21670\n@SQ\tSN:chrUn_KN150179v1\tLN:47473\n@SQ\tSN:chrUn_KN150180v1\tLN:1872\n@SQ\tSN:chrUn_KN150181v1\tLN:32761\n@SQ\tSN:chrUn_KN150182v1\tLN:11735\n@SQ\tSN:chrUn_KN150183v1\tLN:22266\n@SQ\tSN:chrUn_KN150184v1\tLN:16312\n@SQ\tSN:chrUn_KN150185v1\tLN:8651\n@SQ\tSN:chrUn_KN150186v1\tLN:23923\n@SQ\tSN:chrUn_KN150187v1\tLN:19179\n@SQ\tSN:chrUn_KN150189v1\tLN:38868\n@SQ\tSN:chrUn_KN150190v1\tLN:11399\n@SQ\tSN:chrUn_KN150191v1\tLN:42303\n@SQ\tSN:chrUn_KN150193v1\tLN:12580\n@SQ\tSN:chrUn_KN150194v1\tLN:13629\n@SQ\tSN:chrUn_KN150195v1\tLN:18921\n@SQ\tSN:chrUn_KN150196v1\tLN:89077\n@SQ\tSN:chrUn_KN150197v1\tLN:14532\n@SQ\tSN:chrUn_KN150199v1\tLN:16564\n@SQ\tSN:chrUn_KN150200v1\tLN:31861\n@SQ\tSN:chrUn_KN150201v1\tLN:9480\n@SQ\tSN:chrUn_KN150202v1\tLN:15451\n@SQ\tSN:chrUn_KN150203v1\tLN:24004\n@SQ\tSN:chrUn_KN150204v1\tLN:95149\n@SQ\tSN:chrUn_KN150205v1\tLN:2620\n@SQ\tSN:chrUn_KN150206v1\tLN:2052\n@SQ\tSN:chrUn_KN150210v1\tLN:12550\n@SQ\tSN:chrUn_KN150211v1\tLN:16386\n@SQ\tSN:chrUn_KN150212v1\tLN:18932\n@SQ\tSN:chrUn_KN150213v1\tLN:16101\n@SQ\tSN:chrUn_KN150214v1\tLN:162877\n@SQ\tSN:chrUn_KN150215v1\tLN:1237\n@SQ\tSN:chrUn_KN150216v1\tLN:1020\n@SQ\tSN:chrUn_KN150217v1\tLN:13840\n@SQ\tSN:chrUn_KN150218v1\tLN:15354\n@SQ\tSN:chrUn_KN150219v1\tLN:16672\n@SQ\tSN:chrUn_KN150220v1\tLN:29625\n@SQ\tSN:chrUn_KN150221v1\tLN:28122\n@SQ\tSN:chrUn_KN150222v1\tLN:110669\n@SQ\tSN:chrUn_KN150224v1\tLN:24154\n@SQ\tSN:chrUn_KN150225v1\tLN:20429\n@SQ\tSN:chrUn_KN150226v1\tLN:25293\n@SQ\tSN:chrUn_KN150227v1\tLN:31979\n@SQ\tSN:chrUn_KN150228v1\tLN:17061\n@SQ\tSN:chrUn_KN150229v1\tLN:1251\n@SQ\tSN:chrUn_KN150230v1\tLN:149710\n@SQ\tSN:chrUn_KN150231v1\tLN:2322\n@SQ\tSN:chrUn_KN150232v1\tLN:53540\n@SQ\tSN:chrUn_KN150233v1\tLN:2246\n@SQ\tSN:chrUn_KN150234v1\tLN:18511\n@SQ\tSN:chrUn_KN150236v1\tLN:19315\n@SQ\tSN:chrUn_KN150237v1\tLN:1732\n@SQ\tSN:chrUn_KN150238v1\tLN:9450\n@SQ\tSN:chrUn_KN150240v1\tLN:31723\n@SQ\tSN:chrUn_KN150241v1\tLN:60821\n@SQ\tSN:chrUn_KN150242v1\tLN:20063\n@SQ\tSN:chrUn_KN150243v2\tLN:45964\n@SQ\tSN:chrUn_KN150244v1\tLN:42860\n@SQ\tSN:chrUn_KN150246v1\tLN:15365\n@SQ\tSN:chrUn_KN150248v1\tLN:18273\n@SQ\tSN:chrUn_KN150249v1\tLN:12261\n@SQ\tSN:chrUn_KN150250v1\tLN:13560\n@SQ\tSN:chrUn_KN150251v1\tLN:26988\n@SQ\tSN:chrUn_KN150252v1\tLN:43133\n@SQ\tSN:chrUn_KN150253v1\tLN:3149\n@SQ\tSN:chrUn_KN150254v1\tLN:12144\n@SQ\tSN:chrUn_KN150255v2\tLN:29368\n@SQ\tSN:chrUn_KN150257v1\tLN:12735\n@SQ\tSN:chrUn_KN150258v1\tLN:95885\n@SQ\tSN:chrUn_KN150259v1\tLN:50098\n@SQ\tSN:chrUn_KN150260v1\tLN:12318\n@SQ\tSN:chrUn_KN150263v1\tLN:31336\n@SQ\tSN:chrUn_KN150264v1\tLN:16955\n@SQ\tSN:chrUn_KN150265v1\tLN:51555\n@SQ\tSN:chrUn_KN150267v1\tLN:77778\n@SQ\tSN:chrUn_KN150268v1\tLN:15280\n@SQ\tSN:chrUn_KN150269v1\tLN:48062\n@SQ\tSN:chrUn_KN150270v1\tLN:22285\n@SQ\tSN:chrUn_KN150271v1\tLN:12637\n@SQ\tSN:chrUn_KN150272v1\tLN:34295\n@SQ\tSN:chrUn_KN150274v1\tLN:12247\n@SQ\tSN:chrUn_KN150275v1\tLN:13800\n@SQ\tSN:chrUn_KN150276v1\tLN:12942\n@SQ\tSN:chrUn_KN150278v1\tLN:30978\n@SQ\tSN:chrUn_KN150279v1\tLN:11402\n@SQ\tSN:chrUn_KN150280v1\tLN:10487\n@SQ\tSN:chrUn_KN150282v1\tLN:23758\n@SQ\tSN:chrUn_KN150283v1\tLN:13933\n@SQ\tSN:chrUn_KN150284v1\tLN:18131\n@SQ\tSN:chrUn_KN150285v1\tLN:25361\n@SQ\tSN:chrUn_KN150286v1\tLN:9068\n@SQ\tSN:chrUn_KN150287v1\tLN:11856\n@SQ\tSN:chrUn_KN150289v1\tLN:22206\n@SQ\tSN:chrUn_KN150290v1\tLN:18248\n@SQ\tSN:chrUn_KN150291v1\tLN:25796\n@SQ\tSN:chrUn_KN150292v1\tLN:9984\n@SQ\tSN:chrUn_KN150293v1\tLN:40764\n@SQ\tSN:chrUn_KN150296v1\tLN:10238\n@SQ\tSN:chrUn_KN150297v1\tLN:23472\n@SQ\tSN:chrUn_KN150299v1\tLN:23511\n@SQ\tSN:chrUn_KN150300v1\tLN:9489\n@SQ\tSN:chrUn_KN150301v1\tLN:18664\n@SQ\tSN:chrUn_KN150302v1\tLN:13538\n@SQ\tSN:chrUn_KN150303v1\tLN:39288\n@SQ\tSN:chrUn_KN150306v1\tLN:36728\n@SQ\tSN:chrUn_KN150307v1\tLN:9167\n@SQ\tSN:chrUn_KN150308v1\tLN:18907\n@SQ\tSN:chrUn_KN150309v1\tLN:20999\n@SQ\tSN:chrUn_KN150310v1\tLN:20509\n@SQ\tSN:chrUn_KN150311v1\tLN:15747\n@SQ\tSN:chrUn_KN150312v1\tLN:17282\n@SQ\tSN:chrUn_KN150313v1\tLN:20655\n@SQ\tSN:chrUn_KN150314v1\tLN:12455\n@SQ\tSN:chrUn_KN150315v1\tLN:20424\n@SQ\tSN:chrUn_KN150317v1\tLN:14866\n@SQ\tSN:chrUn_KN150318v1\tLN:2580\n@SQ\tSN:chrUn_KN150319v1\tLN:15807\n@SQ\tSN:chrUn_KN150320v1\tLN:1241\n@SQ\tSN:chrUn_KN150322v1\tLN:19644\n@SQ\tSN:chrUn_KN150323v1\tLN:18137\n@SQ\tSN:chrUn_KN150324v1\tLN:24032\n@SQ\tSN:chrUn_KN150325v1\tLN:19525\n@SQ\tSN:chrUn_KN150326v1\tLN:109565\n@SQ\tSN:chrUn_KN150327v1\tLN:19949\n@SQ\tSN:chrUn_KN150328v1\tLN:17410\n@SQ\tSN:chrUn_KN150329v1\tLN:13297\n@SQ\tSN:chrUn_KN150330v1\tLN:28440\n@SQ\tSN:chrUn_KN150331v1\tLN:44968\n@SQ\tSN:chrUn_KN150332v1\tLN:22862\n@SQ\tSN:chrUn_KN150333v1\tLN:12275\n@SQ\tSN:chrUn_KN150334v1\tLN:22542\n@SQ\tSN:chrUn_KN150335v1\tLN:44504\n@SQ\tSN:chrUn_KN150336v1\tLN:48672\n@SQ\tSN:chrUn_KN150337v1\tLN:20260\n@SQ\tSN:chrUn_KN150338v1\tLN:1142\n@SQ\tSN:chrUn_KN150340v1\tLN:28741\n@SQ\tSN:chrUn_KN150341v1\tLN:31147\n@SQ\tSN:chrUn_KN150342v1\tLN:82590\n@SQ\tSN:chrUn_KN150343v1\tLN:26928\n@SQ\tSN:chrUn_KN150344v1\tLN:19681\n@SQ\tSN:chrUn_KN150345v1\tLN:17012\n@SQ\tSN:chrUn_KN150347v1\tLN:51528\n@SQ\tSN:chrUn_KN150349v1\tLN:29114\n@SQ\tSN:chrUn_KN150350v1\tLN:9245\n@SQ\tSN:chrUn_KN150351v1\tLN:49608\n@SQ\tSN:chrUn_KN150352v2\tLN:25352\n@SQ\tSN:chrUn_KN150353v1\tLN:19631\n@SQ\tSN:chrUn_KN150354v1\tLN:1452\n@SQ\tSN:chrUn_KN150355v1\tLN:6731\n@SQ\tSN:chrUn_KN150357v1\tLN:27326\n@SQ\tSN:chrUn_KN150358v1\tLN:9951\n@SQ\tSN:chrUn_KN150360v1\tLN:15639\n@SQ\tSN:chrUn_KN150361v1\tLN:53624\n@SQ\tSN:chrUn_KN150362v1\tLN:17145\n@SQ\tSN:chrUn_KN150363v1\tLN:22766\n@SQ\tSN:chrUn_KN150364v1\tLN:15084\n@SQ\tSN:chrUn_KN150365v1\tLN:10769\n@SQ\tSN:chrUn_KN150366v1\tLN:10057\n@SQ\tSN:chrUn_KN150368v1\tLN:18491\n@SQ\tSN:chrUn_KN150369v1\tLN:11460\n@SQ\tSN:chrUn_KN150371v1\tLN:13836\n@SQ\tSN:chrUn_KN150372v1\tLN:29560\n@SQ\tSN:chrUn_KN150374v1\tLN:9775\n@SQ\tSN:chrUn_KN150375v1\tLN:111208\n@SQ\tSN:chrUn_KN150379v1\tLN:29907\n@SQ\tSN:chrUn_KN150380v1\tLN:12144\n@SQ\tSN:chrUn_KN150382v1\tLN:14074\n@SQ\tSN:chrUn_KN150383v1\tLN:7777\n@SQ\tSN:chrUn_KN150384v1\tLN:22969\n@SQ\tSN:chrUn_KN150385v1\tLN:37055\n@SQ\tSN:chrUn_KN150386v1\tLN:35900\n@SQ\tSN:chrUn_KN150387v1\tLN:15215\n@SQ\tSN:chrUn_KN150388v1\tLN:22284\n@SQ\tSN:chrUn_KN150389v1\tLN:10334\n@SQ\tSN:chrUn_KN150390v1\tLN:19066\n@SQ\tSN:chrUn_KN150392v1\tLN:12069\n@SQ\tSN:chrUn_KN150393v1\tLN:12073\n@SQ\tSN:chrUn_KN150394v1\tLN:17139\n@SQ\tSN:chrUn_KN150395v1\tLN:9792\n@SQ\tSN:chrUn_KN150396v1\tLN:8176\n@SQ\tSN:chrUn_KN150397v1\tLN:17295\n@SQ\tSN:chrUn_KN150398v1\tLN:39557\n@SQ\tSN:chrUn_KN150399v1\tLN:19362\n@SQ\tSN:chrUn_KN150400v1\tLN:34930\n@SQ\tSN:chrUn_KN150401v1\tLN:10081\n@SQ\tSN:chrUn_KN150403v1\tLN:34697\n@SQ\tSN:chrUn_KN150404v1\tLN:18160\n@SQ\tSN:chrUn_KN150405v1\tLN:76919\n@SQ\tSN:chrUn_KN150406v1\tLN:17215\n@SQ\tSN:chrUn_KN150407v1\tLN:31814\n@SQ\tSN:chrUn_KN150408v1\tLN:37191\n@SQ\tSN:chrUn_KN150411v1\tLN:20886\n@SQ\tSN:chrUn_KN150412v1\tLN:9605\n@SQ\tSN:chrUn_KN150413v1\tLN:15078\n@SQ\tSN:chrUn_KN150414v1\tLN:35871\n@SQ\tSN:chrUn_KN150416v1\tLN:33835\n@SQ\tSN:chrUn_KN150418v1\tLN:14930\n@SQ\tSN:chrUn_KN150419v1\tLN:14114\n@SQ\tSN:chrUn_KN150420v1\tLN:14290\n@SQ\tSN:chrUn_KN150421v1\tLN:14951\n@SQ\tSN:chrUn_KN150422v1\tLN:15053\n@SQ\tSN:chrUn_KN150425v1\tLN:110593\n@SQ\tSN:chrUn_KN150426v1\tLN:21499\n@SQ\tSN:chrUn_KN150428v1\tLN:29216\n@SQ\tSN:chrUn_KN150429v1\tLN:17683\n@SQ\tSN:chrUn_KN150430v1\tLN:16452\n@SQ\tSN:chrUn_KN150431v1\tLN:89659\n@SQ\tSN:chrUn_KN150432v1\tLN:91010\n@SQ\tSN:chrUn_KN150434v1\tLN:12053\n@SQ\tSN:chrUn_KN150436v1\tLN:17739\n@SQ\tSN:chrUn_KN150437v1\tLN:1262\n@SQ\tSN:chrUn_KN150439v1\tLN:10343\n@SQ\tSN:chrUn_KN150440v1\tLN:1193\n@SQ\tSN:chrUn_KN150441v1\tLN:12439\n@SQ\tSN:chrUn_KN150443v1\tLN:11834\n@SQ\tSN:chrUn_KN150444v1\tLN:11830\n@SQ\tSN:chrUn_KN150445v1\tLN:12072\n@SQ\tSN:chrUn_KN150446v1\tLN:12446\n@SQ\tSN:chrUn_KN150449v1\tLN:62607\n@SQ\tSN:chrUn_KN150450v1\tLN:25362\n@SQ\tSN:chrUn_KN150451v1\tLN:14920\n@SQ\tSN:chrUn_KN150452v1\tLN:8345\n@SQ\tSN:chrUn_KN150453v1\tLN:13591\n@SQ\tSN:chrUn_KN150454v1\tLN:18479\n@SQ\tSN:chrUn_KN150455v1\tLN:73536\n@SQ\tSN:chrUn_KN150458v1\tLN:17481\n@SQ\tSN:chrUn_KN150459v1\tLN:45603\n@SQ\tSN:chrUn_KN150462v1\tLN:24623\n@SQ\tSN:chrUn_KN150464v1\tLN:24865\n@SQ\tSN:chrUn_KN150465v1\tLN:1765\n@SQ\tSN:chrUn_KN150466v1\tLN:41319\n@SQ\tSN:chrUn_KN150467v1\tLN:11202\n@SQ\tSN:chrUn_KN150468v1\tLN:25381\n@SQ\tSN:chrUn_KN150469v1\tLN:14614\n@SQ\tSN:chrUn_KN150470v1\tLN:2027\n@SQ\tSN:chrUn_KN150471v1\tLN:76663\n@SQ\tSN:chrUn_KN150472v1\tLN:14586\n@SQ\tSN:chrUn_KN150473v1\tLN:1285\n@SQ\tSN:chrUn_KN150475v1\tLN:17517\n@SQ\tSN:chrUn_KN150476v1\tLN:59211\n@SQ\tSN:chrUn_KN150477v1\tLN:61693\n@SQ\tSN:chrUn_KN150478v1\tLN:25813\n@SQ\tSN:chrUn_KN150479v1\tLN:48186\n@SQ\tSN:chrUn_KN150481v1\tLN:1008\n@SQ\tSN:chrUn_KN150483v1\tLN:17332\n@SQ\tSN:chrUn_KN150484v1\tLN:14965\n@SQ\tSN:chrUn_KN150485v1\tLN:7348\n@SQ\tSN:chrUn_KN150486v1\tLN:8572\n@SQ\tSN:chrUn_KN150487v1\tLN:123701\n@SQ\tSN:chrUn_KN150488v1\tLN:17582\n@SQ\tSN:chrUn_KN150489v1\tLN:26739\n@SQ\tSN:chrUn_KN150490v1\tLN:23057\n@SQ\tSN:chrUn_KN150491v1\tLN:13001\n@SQ\tSN:chrUn_KN150492v2\tLN:30275\n@SQ\tSN:chrUn_KN150493v1\tLN:35575\n@SQ\tSN:chrUn_KN150494v1\tLN:10108\n@SQ\tSN:chrUn_KN150495v1\tLN:28160\n@SQ\tSN:chrUn_KN150499v1\tLN:11840\n@SQ\tSN:chrUn_KN150500v1\tLN:19866\n@SQ\tSN:chrUn_KN150501v1\tLN:22392\n@SQ\tSN:chrUn_KN150502v1\tLN:13027\n@SQ\tSN:chrUn_KN150503v1\tLN:1834\n@SQ\tSN:chrUn_KN150504v1\tLN:12094\n@SQ\tSN:chrUn_KN150505v1\tLN:39265\n@SQ\tSN:chrUn_KN150506v1\tLN:14319\n@SQ\tSN:chrUn_KN150508v1\tLN:26814\n@SQ\tSN:chrUn_KN150509v1\tLN:11846\n@SQ\tSN:chrUn_KN150510v1\tLN:13237\n@SQ\tSN:chrUn_KN150511v1\tLN:38183\n@SQ\tSN:chrUn_KN150513v1\tLN:10220\n@SQ\tSN:chrUn_KN150514v1\tLN:19391\n@SQ\tSN:chrUn_KN150515v1\tLN:1813\n@SQ\tSN:chrUn_KN150516v1\tLN:49339\n@SQ\tSN:chrUn_KN150517v1\tLN:16171\n@SQ\tSN:chrUn_KN150518v1\tLN:40394\n@SQ\tSN:chrUn_KN150519v1\tLN:11974\n@SQ\tSN:chrUn_KN150520v1\tLN:103159\n@SQ\tSN:chrUn_KN150521v1\tLN:20896\n@SQ\tSN:chrUn_KN150522v1\tLN:12046\n@SQ\tSN:chrUn_KN150523v1\tLN:19004\n@SQ\tSN:chrUn_KN150525v1\tLN:650\n@SQ\tSN:chrUn_KN150526v1\tLN:15513\n@SQ\tSN:chrUn_KN150527v1\tLN:20880\n@SQ\tSN:chrUn_KN150528v1\tLN:13138\n@SQ\tSN:chrUn_KN150529v1\tLN:81946\n@SQ\tSN:chrUn_KN150530v1\tLN:7299\n@SQ\tSN:chrUn_KN150532v1\tLN:21602\n@SQ\tSN:chrUn_KN150534v1\tLN:17661\n@SQ\tSN:chrUn_KN150535v1\tLN:2315\n@SQ\tSN:chrUn_KN150536v1\tLN:17908\n@SQ\tSN:chrUn_KN150537v1\tLN:27568\n@SQ\tSN:chrUn_KN150538v1\tLN:12119\n@SQ\tSN:chrUn_KN150540v1\tLN:15288\n@SQ\tSN:chrUn_KN150541v1\tLN:12323\n@SQ\tSN:chrUn_KN150542v1\tLN:12167\n@SQ\tSN:chrUn_KN150543v1\tLN:2343\n@SQ\tSN:chrUn_KN150544v1\tLN:1198\n@SQ\tSN:chrUn_KN150545v1\tLN:17546\n@SQ\tSN:chrUn_KN150546v1\tLN:10851\n@SQ\tSN:chrUn_KN150547v1\tLN:37420\n@SQ\tSN:chrUn_KN150548v1\tLN:46061\n@SQ\tSN:chrUn_KN150549v1\tLN:17599\n@SQ\tSN:chrUn_KN150550v1\tLN:14915\n@SQ\tSN:chrUn_KN150551v1\tLN:9435\n@SQ\tSN:chrUn_KN150552v1\tLN:74050\n@SQ\tSN:chrUn_KN150553v1\tLN:14032\n@SQ\tSN:chrUn_KN150554v1\tLN:9251\n@SQ\tSN:chrUn_KN150555v1\tLN:9941\n@SQ\tSN:chrUn_KN150556v1\tLN:9286\n@SQ\tSN:chrUn_KN150557v1\tLN:41459\n@SQ\tSN:chrUn_KN150558v1\tLN:12115\n@SQ\tSN:chrUn_KN150559v1\tLN:26580\n@SQ\tSN:chrUn_KN150560v1\tLN:2301\n@SQ\tSN:chrUn_KN150561v1\tLN:22238\n@SQ\tSN:chrUn_KN150562v1\tLN:22875\n@SQ\tSN:chrUn_KN150564v1\tLN:17709\n@SQ\tSN:chrUn_KN150565v1\tLN:20464\n@SQ\tSN:chrUn_KN150567v1\tLN:49566\n@SQ\tSN:chrUn_KN150568v1\tLN:108195\n@SQ\tSN:chrUn_KN150570v1\tLN:42279\n@SQ\tSN:chrUn_KN150571v1\tLN:16505\n@SQ\tSN:chrUn_KN150572v1\tLN:28871\n@SQ\tSN:chrUn_KN150573v1\tLN:26604\n@SQ\tSN:chrUn_KN150574v1\tLN:18499\n@SQ\tSN:chrUn_KN150575v1\tLN:11084\n@SQ\tSN:chrUn_KN150576v1\tLN:36129\n@SQ\tSN:chrUn_KN150577v1\tLN:13719\n@SQ\tSN:chrUn_KN150578v1\tLN:103698\n@SQ\tSN:chrUn_KN150579v1\tLN:23586\n@SQ\tSN:chrUn_KN150580v1\tLN:32349\n@SQ\tSN:chrUn_KN150581v1\tLN:12355\n@SQ\tSN:chrUn_KN150582v1\tLN:12396\n@SQ\tSN:chrUn_KN150583v1\tLN:1918\n@SQ\tSN:chrUn_KN150585v1\tLN:12430\n@SQ\tSN:chrUn_KN150586v1\tLN:17388\n@SQ\tSN:chrUn_KN150587v1\tLN:8461\n@SQ\tSN:chrUn_KN150588v1\tLN:14103\n@SQ\tSN:chrUn_KN150589v1\tLN:18957\n@SQ\tSN:chrUn_KN150591v1\tLN:8817\n@SQ\tSN:chrUn_KN150592v1\tLN:50000\n@SQ\tSN:chrUn_KN150593v1\tLN:14353\n@SQ\tSN:chrUn_KN150594v1\tLN:19382\n@SQ\tSN:chrUn_KN150595v1\tLN:12507\n@SQ\tSN:chrUn_KN150596v1\tLN:60847\n@SQ\tSN:chrUn_KN150598v1\tLN:12499\n@SQ\tSN:chrUn_KN150599v1\tLN:19019\n@SQ\tSN:chrUn_KN150601v1\tLN:11167\n@SQ\tSN:chrUn_KN150602v1\tLN:22730\n@SQ\tSN:chrUn_KN150603v1\tLN:98280\n@SQ\tSN:chrUn_KN150605v1\tLN:102574\n@SQ\tSN:chrUn_KN150606v1\tLN:51696\n@SQ\tSN:chrUn_KN150607v1\tLN:9531\n@SQ\tSN:chrUn_KN150608v1\tLN:149650\n@SQ\tSN:chrUn_KN150609v1\tLN:37413\n@SQ\tSN:chrUn_KN150610v1\tLN:10565\n@SQ\tSN:chrUn_KN150613v1\tLN:15739\n@SQ\tSN:chrUn_KN150614v1\tLN:9019\n@SQ\tSN:chrUn_KN150615v1\tLN:9878\n@SQ\tSN:chrUn_KN150616v1\tLN:88699\n@SQ\tSN:chrUn_KN150617v1\tLN:90208\n@SQ\tSN:chrUn_KN150619v1\tLN:41925\n@SQ\tSN:chrUn_KN150620v1\tLN:30729\n@SQ\tSN:chrUn_KN150621v1\tLN:1204\n@SQ\tSN:chrUn_KN150622v1\tLN:15811\n@SQ\tSN:chrUn_KN150623v1\tLN:1126\n@SQ\tSN:chrUn_KN150625v1\tLN:22486\n@SQ\tSN:chrUn_KN150626v1\tLN:32850\n@SQ\tSN:chrUn_KN150628v1\tLN:33906\n@SQ\tSN:chrUn_KN150629v1\tLN:19604\n@SQ\tSN:chrUn_KN150630v1\tLN:86421\n@SQ\tSN:chrUn_KN150631v1\tLN:36324\n@SQ\tSN:chrUn_KN150632v1\tLN:11627\n@SQ\tSN:chrUn_KN150633v1\tLN:19558\n@SQ\tSN:chrUn_KN150634v1\tLN:16020\n@SQ\tSN:chrUn_KN150635v1\tLN:27947\n@SQ\tSN:chrUn_KN150636v1\tLN:20513\n@SQ\tSN:chrUn_KN150639v1\tLN:27620\n@SQ\tSN:chrUn_KN150640v1\tLN:20890\n@SQ\tSN:chrUn_KN150641v1\tLN:14778\n@SQ\tSN:chrUn_KN150642v1\tLN:55536\n@SQ\tSN:chrUn_KN150643v1\tLN:28088\n@SQ\tSN:chrUn_KN150644v1\tLN:20534\n@SQ\tSN:chrUn_KN150645v1\tLN:22839\n@SQ\tSN:chrUn_KN150646v1\tLN:78076\n@SQ\tSN:chrUn_KN150647v1\tLN:14938\n@SQ\tSN:chrUn_KN150649v1\tLN:81249\n@SQ\tSN:chrUn_KN150650v1\tLN:3012\n@SQ\tSN:chrUn_KN150651v1\tLN:28018\n@SQ\tSN:chrUn_KN150652v1\tLN:18075\n@SQ\tSN:chrUn_KN150653v1\tLN:55997\n@SQ\tSN:chrUn_KN150654v1\tLN:18414\n@SQ\tSN:chrUn_KN150655v1\tLN:8089\n@SQ\tSN:chrUn_KN150656v2\tLN:29322\n@SQ\tSN:chrUn_KN150659v1\tLN:11827\n@SQ\tSN:chrUn_KN150661v1\tLN:26250\n@SQ\tSN:chrUn_KN150662v1\tLN:17820\n@SQ\tSN:chrUn_KN150663v1\tLN:88608\n@SQ\tSN:chrUn_KN150664v1\tLN:9590\n@SQ\tSN:chrUn_KN150665v1\tLN:11944\n@SQ\tSN:chrUn_KN150666v1\tLN:63484\n@SQ\tSN:chrUn_KN150667v1\tLN:54201\n@SQ\tSN:chrUn_KN150668v1\tLN:21856\n@SQ\tSN:chrUn_KN150669v1\tLN:15325\n@SQ\tSN:chrUn_KN150670v1\tLN:77993\n@SQ\tSN:chrUn_KN150671v1\tLN:13526\n@SQ\tSN:chrUn_KN150675v1\tLN:41858\n@SQ\tSN:chrUn_KN150676v1\tLN:51674\n@SQ\tSN:chrUn_KN150677v1\tLN:66956\n@SQ\tSN:chrUn_KN150678v1\tLN:7552\n@SQ\tSN:chrUn_KN150679v1\tLN:14065\n@SQ\tSN:chrUn_KN150680v1\tLN:13379\n@SQ\tSN:chrUn_KN150682v1\tLN:15190\n@SQ\tSN:chrUn_KN150683v1\tLN:16822\n@SQ\tSN:chrUn_KN150684v1\tLN:24053\n@SQ\tSN:chrUn_KN150685v1\tLN:13309\n@SQ\tSN:chrUn_KN150687v1\tLN:13294\n@SQ\tSN:chrUn_KN150689v1\tLN:19550\n@SQ\tSN:chrUn_KN150690v1\tLN:26145\n@SQ\tSN:chrUn_KN150691v1\tLN:184625\n@SQ\tSN:chrUn_KN150697v1\tLN:12709\n@SQ\tSN:chrUn_KN150698v1\tLN:31983\n@SQ\tSN:chrUn_KN150699v1\tLN:26100\n@SQ\tSN:chrUn_KN150700v2\tLN:71715\n@SQ\tSN:chrUn_KN150701v1\tLN:1133\n@SQ\tSN:chrUn_KN150703v1\tLN:48009\n@SQ\tSN:chrUn_KN150708v1\tLN:42677\n@SQ\tSN:chrUn_KN150709v1\tLN:65370\n@SQ\tSN:chrUn_KN150710v1\tLN:19629\n@SQ\tSN:chrUn_KN150711v1\tLN:11940\n@SQ\tSN:chrUn_KN150713v1\tLN:14579\n@SQ\tSN:chrUn_KZ115948v1\tLN:7895\n@SQ\tSN:chrUn_KZ115949v1\tLN:19487\n@SQ\tSN:chrUn_KZ115950v1\tLN:11151\n@SQ\tSN:chrUn_KZ115951v1\tLN:1460\n@SQ\tSN:chrUn_KZ115952v1\tLN:6745\n@SQ\tSN:chrUn_KZ115953v1\tLN:1282\n@SQ\tSN:chrUn_KZ115954v1\tLN:7681\n@SQ\tSN:chrUn_KZ115955v1\tLN:2649\n@SQ\tSN:chrUn_KZ115956v1\tLN:11017\n@SQ\tSN:chrUn_KZ115957v1\tLN:3033\n@SQ\tSN:chrUn_KZ115958v1\tLN:16150\n@SQ\tSN:chrUn_KZ115959v1\tLN:2076\n@SQ\tSN:chrUn_KZ115960v1\tLN:10408\n@SQ\tSN:chrUn_KZ115961v1\tLN:1814\n@SQ\tSN:chrUn_KZ115962v1\tLN:9328\n@SQ\tSN:chrUn_KZ115963v1\tLN:5511\n@SQ\tSN:chrUn_KZ115964v1\tLN:21985\n@SQ\tSN:chrUn_KZ115965v1\tLN:8631\n@SQ\tSN:chrUn_KZ115966v1\tLN:10700\n@SQ\tSN:chrUn_KZ115967v1\tLN:2223\n@SQ\tSN:chrUn_KZ115968v1\tLN:7463\n@SQ\tSN:chrUn_KZ115969v1\tLN:11096\n@SQ\tSN:chrUn_KZ115970v1\tLN:4964\n@SQ\tSN:chrUn_KZ115971v1\tLN:10999\n@SQ\tSN:chrUn_KZ115972v1\tLN:18193\n@SQ\tSN:chrUn_KZ115973v1\tLN:7329\n@SQ\tSN:chrUn_KZ115974v1\tLN:33679\n@SQ\tSN:chrUn_KZ115975v1\tLN:1668\n@SQ\tSN:chrUn_KZ115976v1\tLN:3381\n@SQ\tSN:chrUn_KZ115977v1\tLN:1917\n@SQ\tSN:chrUn_KZ115978v1\tLN:4867\n@SQ\tSN:chrUn_KZ115979v1\tLN:12653\n@SQ\tSN:chrUn_KZ115980v1\tLN:11444\n@SQ\tSN:chrUn_KZ115981v1\tLN:12102\n@SQ\tSN:chrUn_KZ115982v1\tLN:21678\n@SQ\tSN:chrUn_KZ115983v1\tLN:10690\n@SQ\tSN:chrUn_KZ115984v1\tLN:2298\n@SQ\tSN:chrUn_KZ115985v1\tLN:14091\n@SQ\tSN:chrUn_KZ115986v1\tLN:14146\n@SQ\tSN:chrUn_KZ115987v1\tLN:34728\n@SQ\tSN:chrUn_KZ115988v1\tLN:2311\n@SQ\tSN:chrUn_KZ115989v1\tLN:11382\n@SQ\tSN:chrUn_KZ115990v1\tLN:8014\n@SQ\tSN:chrUn_KZ115991v1\tLN:3745\n@SQ\tSN:chrUn_KZ115992v1\tLN:1250\n@SQ\tSN:chrUn_KZ115993v1\tLN:17707\n@SQ\tSN:chrUn_KZ115994v1\tLN:17825\n@SQ\tSN:chrUn_KZ115995v1\tLN:5114\n@SQ\tSN:chrUn_KZ115996v1\tLN:5023\n@SQ\tSN:chrUn_KZ115997v1\tLN:3918\n@SQ\tSN:chrUn_KZ115998v1\tLN:9069\n@SQ\tSN:chrUn_KZ115999v1\tLN:8942\n@SQ\tSN:chrUn_KZ116000v1\tLN:15093\n@SQ\tSN:chrUn_KZ116001v1\tLN:13723\n@SQ\tSN:chrUn_KZ116002v1\tLN:9522\n@SQ\tSN:chrUn_KZ116003v1\tLN:15105\n@SQ\tSN:chrUn_KZ116004v1\tLN:19050\n@SQ\tSN:chrUn_KZ116005v1\tLN:1920\n@SQ\tSN:chrUn_KZ116006v1\tLN:13138\n@SQ\tSN:chrUn_KZ116007v1\tLN:11049\n@SQ\tSN:chrUn_KZ116008v1\tLN:17226\n@SQ\tSN:chrUn_KZ116009v1\tLN:1395\n@SQ\tSN:chrUn_KZ116010v1\tLN:6942\n@SQ\tSN:chrUn_KZ116011v1\tLN:51615\n@SQ\tSN:chrUn_KZ116012v1\tLN:9499\n@SQ\tSN:chrUn_KZ116013v1\tLN:7022\n@SQ\tSN:chrUn_KZ116014v1\tLN:1536\n@SQ\tSN:chrUn_KZ116015v1\tLN:9998\n@SQ\tSN:chrUn_KZ116016v1\tLN:5168\n@SQ\tSN:chrUn_KZ116017v1\tLN:2865\n@SQ\tSN:chrUn_KZ116018v1\tLN:11006\n@SQ\tSN:chrUn_KZ116019v1\tLN:34606\n@SQ\tSN:chrUn_KZ116020v1\tLN:14934\n@SQ\tSN:chrUn_KZ116021v1\tLN:17216\n@SQ\tSN:chrUn_KZ116022v1\tLN:1919\n@SQ\tSN:chrUn_KZ116023v1\tLN:7875\n@SQ\tSN:chrUn_KZ116024v1\tLN:31767\n@SQ\tSN:chrUn_KZ116025v1\tLN:3864\n@SQ\tSN:chrUn_KZ116026v1\tLN:14318\n@SQ\tSN:chrUn_KZ116027v1\tLN:4074\n@SQ\tSN:chrUn_KZ116028v1\tLN:3289\n@SQ\tSN:chrUn_KZ116029v1\tLN:32560\n@SQ\tSN:chrUn_KZ116030v1\tLN:3552\n@SQ\tSN:chrUn_KZ116031v1\tLN:19707\n@SQ\tSN:chrUn_KZ116032v1\tLN:5873\n@SQ\tSN:chrUn_KZ116033v1\tLN:27103\n@SQ\tSN:chrUn_KZ116034v1\tLN:33615\n@SQ\tSN:chrUn_KZ116035v1\tLN:1766\n@SQ\tSN:chrUn_KZ116036v1\tLN:1919\n@SQ\tSN:chrUn_KZ116037v1\tLN:13248\n@SQ\tSN:chrUn_KZ116038v1\tLN:1428\n@SQ\tSN:chrUn_KZ116039v1\tLN:12461\n@SQ\tSN:chrUn_KZ116040v1\tLN:3054\n@SQ\tSN:chrUn_KZ116041v1\tLN:12997\n@SQ\tSN:chrUn_KZ116042v1\tLN:13126\n@SQ\tSN:chrUn_KZ116043v1\tLN:19339\n@SQ\tSN:chrUn_KZ116044v1\tLN:37221\n@SQ\tSN:chrUn_KZ116045v1\tLN:2029\n@SQ\tSN:chrUn_KZ116046v1\tLN:5807\n@SQ\tSN:chrUn_KZ116047v1\tLN:14251\n@SQ\tSN:chrUn_KZ116048v1\tLN:1356\n@SQ\tSN:chrUn_KZ116049v1\tLN:8498\n@SQ\tSN:chrUn_KZ116050v1\tLN:6653\n@SQ\tSN:chrUn_KZ116051v1\tLN:2418\n@SQ\tSN:chrUn_KZ116052v1\tLN:2026\n@SQ\tSN:chrUn_KZ116053v1\tLN:16466\n@SQ\tSN:chrUn_KZ116054v1\tLN:14656\n@SQ\tSN:chrUn_KZ116055v1\tLN:7229\n@SQ\tSN:chrUn_KZ116056v1\tLN:10581\n@SQ\tSN:chrUn_KZ116057v1\tLN:4882\n@SQ\tSN:chrUn_KZ116058v1\tLN:4138\n@SQ\tSN:chrUn_KZ116059v1\tLN:34033\n@SQ\tSN:chrUn_KZ116060v1\tLN:7854\n@SQ\tSN:chrUn_KZ116061v1\tLN:1669\n@SQ\tSN:chrUn_KZ116062v1\tLN:6923\n@SQ\tSN:chrUn_KZ116063v1\tLN:2601\n@SQ\tSN:chrUn_KZ116064v1\tLN:153879\n@SQ\tSN:chrUn_KZ116065v1\tLN:37354\n@SQ\tSN:chrUn_KZ116066v1\tLN:161442\n@SQ\tSN:chrUn_KZ116067v1\tLN:159186\n@SQ\tSN:chrM\tLN:16596\n@PG\tID:Bowtie\tVN:1.2.3\tCL:\"bowtie-1.2.3-linux-x86_64/bowtie-align-s --wrapper basic-0 sample_index sample.fastq -S -p 12\"\n"
    elif args.organism_name == "nematode":
        header = "@HD\tVN:1.0\tSO:unsorted\n@SQ\tSN:chrII\tLN:15279421\n@SQ\tSN:chrI\tLN:15072434\n@SQ\tSN:chrX\tLN:17718942\n@SQ\tSN:chrIII\tLN:13783801\n@SQ\tSN:chrIV\tLN:17493829\n@SQ\tSN:chrM\tLN:13794\n@SQ\tSN:chrV\tLN:20924180\n@PG\tID:Bowtie\tVN:1.2.3\tCL:\"bowtie-1.2.3-linux-x86_64/bowtie-align-s --wrapper basic-0 sample_index sample.fastq -S -p 12\"\n"
    elif args.organism_name == "fruitfly":
        header = "@HD\tVN:1.0\tSO:unsorted\n@SQ\tSN:chr2L\tLN:23513712\n@SQ\tSN:chr2R\tLN:25286936\n@SQ\tSN:chr3L\tLN:28110227\n@SQ\tSN:chr3R\tLN:32079331\n@SQ\tSN:chr4\tLN:1348131\n@SQ\tSN:chrM\tLN:19524\n@SQ\tSN:chrUn_DS485919v1\tLN:1021\n@SQ\tSN:chrUn_DS483755v1\tLN:6936\n@SQ\tSN:chrUn_DS485425v1\tLN:1143\n@SQ\tSN:chrUn_DS484861v1\tLN:1395\n@SQ\tSN:chrUn_DS484484v1\tLN:2020\n@SQ\tSN:chrUn_DS483705v1\tLN:27456\n@SQ\tSN:chrUn_DS485490v1\tLN:1127\n@SQ\tSN:chrUn_DS485998v1\tLN:1003\n@SQ\tSN:chrUn_DS483873v1\tLN:4222\n@SQ\tSN:chrUn_DS485608v1\tLN:1097\n@SQ\tSN:chrUn_DS485270v1\tLN:1185\n@SQ\tSN:chrUn_DS485979v1\tLN:1008\n@SQ\tSN:chrUn_DS485398v1\tLN:1148\n@SQ\tSN:chrUn_DS484139v1\tLN:2820\n@SQ\tSN:chrUn_DS483906v1\tLN:3924\n@SQ\tSN:chrUn_DS485760v1\tLN:1058\n@SQ\tSN:chrUn_DS484191v1\tLN:2665\n@SQ\tSN:chrUn_DS485340v1\tLN:1163\n@SQ\tSN:chrUn_DS484489v1\tLN:2008\n@SQ\tSN:chrUn_DS485495v1\tLN:1126\n@SQ\tSN:chrUn_DS484923v1\tLN:1343\n@SQ\tSN:chrUn_DS484663v1\tLN:1714\n@SQ\tSN:chrUn_DS485390v1\tLN:1152\n@SQ\tSN:chrUn_DS485130v1\tLN:1232\n@SQ\tSN:chrUn_DS485995v1\tLN:1004\n@SQ\tSN:chrUn_DS484448v1\tLN:2088\n@SQ\tSN:chrUn_DS484827v1\tLN:1432\n@SQ\tSN:chrUn_DS485467v1\tLN:1132\n@SQ\tSN:chrUn_DS485433v1\tLN:1140\n@SQ\tSN:chrUn_DS484944v1\tLN:1330\n@SQ\tSN:chrUn_DS485504v1\tLN:1123\n@SQ\tSN:chrUn_DS484938v1\tLN:1334\n@SQ\tSN:chrUn_DS485984v1\tLN:1006\n@SQ\tSN:chrUn_DS484921v1\tLN:1346\n@SQ\tSN:chrUn_DS485859v1\tLN:1036\n@SQ\tSN:chrUn_DS485086v1\tLN:1250\n@SQ\tSN:chrUn_DS484058v1\tLN:3073\n@SQ\tSN:chrUn_DS485294v1\tLN:1178\n@SQ\tSN:chrUn_DS484855v1\tLN:1404\n@SQ\tSN:chrUn_DS485356v1\tLN:1160\n@SQ\tSN:chrUn_DS485246v1\tLN:1193\n@SQ\tSN:chrUn_DS485386v1\tLN:1153\n@SQ\tSN:chrUn_DS484726v1\tLN:1571\n@SQ\tSN:chrUn_DS484366v1\tLN:2266\n@SQ\tSN:chrUn_DS486002v1\tLN:1001\n@SQ\tSN:chrUn_DS484770v1\tLN:1504\n@SQ\tSN:chrUn_DS485354v1\tLN:1160\n@SQ\tSN:chrUn_DS483728v1\tLN:12681\n@SQ\tSN:chrUn_DS485403v1\tLN:1148\n@SQ\tSN:chrUn_DS484964v1\tLN:1315\n@SQ\tSN:chrUn_DS483921v1\tLN:3806\n@SQ\tSN:chrUn_DS485181v1\tLN:1214\n@SQ\tSN:chrUn_DS485602v1\tLN:1099\n@SQ\tSN:chrUn_DS485783v1\tLN:1052\n@SQ\tSN:chrUn_DS485547v1\tLN:1112\n@SQ\tSN:chrUn_DS485280v1\tLN:1184\n@SQ\tSN:chrUn_DS483976v1\tLN:3463\n@SQ\tSN:chrUn_DS484972v1\tLN:1310\n@SQ\tSN:chrUn_DS484407v1\tLN:2176\n@SQ\tSN:chrUn_DS484446v1\tLN:2090\n@SQ\tSN:chrUn_DS485906v1\tLN:1025\n@SQ\tSN:chrUn_DS484769v1\tLN:1508\n@SQ\tSN:chrUn_DS484527v1\tLN:1956\n@SQ\tSN:chrUn_DS484933v1\tLN:1337\n@SQ\tSN:chrUn_DS483748v1\tLN:8346\n@SQ\tSN:chrUn_DS484460v1\tLN:2076\n@SQ\tSN:chrUn_DS483711v1\tLN:14687\n@SQ\tSN:chrUn_DS484039v1\tLN:3162\n@SQ\tSN:chrUn_DS484339v1\tLN:2330\n@SQ\tSN:chrUn_DS485457v1\tLN:1135\n@SQ\tSN:chrUn_DS485643v1\tLN:1086\n@SQ\tSN:chrUn_DS484689v1\tLN:1650\n@SQ\tSN:chrUn_DS485822v1\tLN:1045\n@SQ\tSN:chrUn_DS485678v1\tLN:1077\n@SQ\tSN:chrUn_DS485150v1\tLN:1226\n@SQ\tSN:chrUn_DS484746v1\tLN:1540\n@SQ\tSN:chrUn_DS485957v1\tLN:1013\n@SQ\tSN:chrUn_DS485541v1\tLN:1114\n@SQ\tSN:chrUn_DS485741v1\tLN:1063\n@SQ\tSN:chrUn_DS484490v1\tLN:2006\n@SQ\tSN:chrUn_DS484881v1\tLN:1380\n@SQ\tSN:chrUn_DS485539v1\tLN:1115\n@SQ\tSN:chrUn_DS485958v1\tLN:1013\n@SQ\tSN:chrUn_DS485748v1\tLN:1061\n@SQ\tSN:chrUn_DS484822v1\tLN:1436\n@SQ\tSN:chrUn_DS485421v1\tLN:1144\n@SQ\tSN:chrUn_DS485296v1\tLN:1178\n@SQ\tSN:chrUn_DS485337v1\tLN:1163\n@SQ\tSN:chrUn_DS483700v1\tLN:11430\n@SQ\tSN:chrUn_DS484511v1\tLN:1974\n@SQ\tSN:chrUn_DS485973v1\tLN:1010\n@SQ\tSN:chrUn_DS483719v1\tLN:12027\n@SQ\tSN:chrUn_DS484571v1\tLN:1893\n@SQ\tSN:chrUn_DS485733v1\tLN:1063\n@SQ\tSN:chrUn_CP007102v1\tLN:12714\n@SQ\tSN:chrUn_DS484052v1\tLN:3089\n@SQ\tSN:chrUn_DS485073v1\tLN:1259\n@SQ\tSN:chrUn_DS484257v1\tLN:2511\n@SQ\tSN:chrUn_DS485376v1\tLN:1155\n@SQ\tSN:chrUn_DS484485v1\tLN:2017\n@SQ\tSN:chrUn_DS485572v1\tLN:1107\n@SQ\tSN:chrUn_DS484816v1\tLN:1446\n@SQ\tSN:chrUn_DS485925v1\tLN:1020\n@SQ\tSN:chrUn_DS485239v1\tLN:1195\n@SQ\tSN:chrUn_DS485853v1\tLN:1038\n@SQ\tSN:chrUn_DS485443v1\tLN:1138\n@SQ\tSN:chrUn_DS485381v1\tLN:1154\n@SQ\tSN:chrUn_DS485339v1\tLN:1163\n@SQ\tSN:chrUn_DS484707v1\tLN:1614\n@SQ\tSN:chrUn_DS485675v1\tLN:1078\n@SQ\tSN:chrUn_DS485065v1\tLN:1262\n@SQ\tSN:chrUn_DS484546v1\tLN:1928\n@SQ\tSN:chrUn_DS485846v1\tLN:1040\n@SQ\tSN:chrUn_DS484667v1\tLN:1710\n@SQ\tSN:chrUn_DS484756v1\tLN:1525\n@SQ\tSN:chrUn_DS485558v1\tLN:1110\n@SQ\tSN:chrUn_DS485703v1\tLN:1071\n@SQ\tSN:chrUn_DS483977v1\tLN:3458\n@SQ\tSN:chrUn_DS485341v1\tLN:1162\n@SQ\tSN:chrUn_DS484226v1\tLN:2576\n@SQ\tSN:chrUn_DS485505v1\tLN:1123\n@SQ\tSN:chrUn_DS485451v1\tLN:1136\n@SQ\tSN:chrUn_DS484736v1\tLN:1552\n@SQ\tSN:chrUn_DS484304v1\tLN:2390\n@SQ\tSN:chrUn_DS485024v1\tLN:1278\n@SQ\tSN:chrUn_DS485808v1\tLN:1047\n@SQ\tSN:chrUn_DS485578v1\tLN:1105\n@SQ\tSN:chrUn_DS485029v1\tLN:1277\n@SQ\tSN:chrUn_DS485634v1\tLN:1088\n@SQ\tSN:chrUn_DS483877v1\tLN:4183\n@SQ\tSN:chrUn_DS483723v1\tLN:21074\n@SQ\tSN:chrUn_DS485038v1\tLN:1272\n@SQ\tSN:chrUn_DS485788v1\tLN:1051\n@SQ\tSN:chrUn_DS484496v1\tLN:1998\n@SQ\tSN:chrUn_DS484841v1\tLN:1416\n@SQ\tSN:chrUn_DS485123v1\tLN:1234\n@SQ\tSN:chrUn_DS485261v1\tLN:1189\n@SQ\tSN:chrUn_DS485673v1\tLN:1078\n@SQ\tSN:chrUn_DS483879v1\tLN:4163\n@SQ\tSN:chrUn_DS484716v1\tLN:1594\n@SQ\tSN:chrUn_DS485907v1\tLN:1025\n@SQ\tSN:chrUn_DS484100v1\tLN:2905\n@SQ\tSN:chrUn_DS486008v1\tLN:1001\n@SQ\tSN:chrUn_DS485747v1\tLN:1062\n@SQ\tSN:chrUn_DS485891v1\tLN:1029\n@SQ\tSN:chrUn_DS484329v1\tLN:2354\n@SQ\tSN:chrUn_DS484653v1\tLN:1732\n@SQ\tSN:chrUn_DS483692v1\tLN:11985\n@SQ\tSN:chrUn_DS485387v1\tLN:1152\n@SQ\tSN:chrUn_DS483938v1\tLN:3650\n@SQ\tSN:chrUn_DS484073v1\tLN:2999\n@SQ\tSN:chrUn_DS483957v1\tLN:3553\n@SQ\tSN:chrUn_DS484050v1\tLN:3100\n@SQ\tSN:chrUn_DS483694v1\tLN:11951\n@SQ\tSN:chrUn_DS485407v1\tLN:1147\n@SQ\tSN:chrUn_DS485357v1\tLN:1159\n@SQ\tSN:chrUn_DS484122v1\tLN:2849\n@SQ\tSN:chrUn_DS484548v1\tLN:1926\n@SQ\tSN:chrUn_DS485254v1\tLN:1190\n@SQ\tSN:chrUn_DS484988v1\tLN:1301\n@SQ\tSN:chrUn_DS485205v1\tLN:1206\n@SQ\tSN:chrUn_DS485793v1\tLN:1050\n@SQ\tSN:chrUn_DS485496v1\tLN:1126\n@SQ\tSN:chrUn_DS484904v1\tLN:1366\n@SQ\tSN:chrUn_DS483707v1\tLN:25840\n@SQ\tSN:chrUn_DS485365v1\tLN:1157\n@SQ\tSN:chrUn_DS485789v1\tLN:1051\n@SQ\tSN:chrUn_DS484842v1\tLN:1416\n@SQ\tSN:chrUn_DS484180v1\tLN:2697\n@SQ\tSN:chrUn_DS485333v1\tLN:1165\n@SQ\tSN:chrUn_DS485954v1\tLN:1014\n@SQ\tSN:chrUn_DS484202v1\tLN:2636\n@SQ\tSN:chrUn_DS485825v1\tLN:1044\n@SQ\tSN:chrUn_DS485285v1\tLN:1181\n@SQ\tSN:chrUn_DS485223v1\tLN:1200\n@SQ\tSN:chrUn_DS485313v1\tLN:1171\n@SQ\tSN:chrUn_DS484567v1\tLN:1900\n@SQ\tSN:chrUn_DS484040v1\tLN:3159\n@SQ\tSN:chrUn_DS484475v1\tLN:2043\n@SQ\tSN:chrUn_DS484168v1\tLN:2744\n@SQ\tSN:chrUn_DS485711v1\tLN:1070\n@SQ\tSN:chrUn_DS485475v1\tLN:1130\n@SQ\tSN:chrUn_DS484532v1\tLN:1945\n@SQ\tSN:chrUn_DS484751v1\tLN:1533\n@SQ\tSN:chrUn_DS484229v1\tLN:2575\n@SQ\tSN:chrUn_DS485870v1\tLN:1033\n@SQ\tSN:chrUn_DS484787v1\tLN:1475\n@SQ\tSN:chrUn_DS484277v1\tLN:2442\n@SQ\tSN:chrUn_DS485304v1\tLN:1175\n@SQ\tSN:chrUn_DS485794v1\tLN:1049\n@SQ\tSN:chrUn_DS485226v1\tLN:1199\n@SQ\tSN:chrUn_DS484470v1\tLN:2059\n@SQ\tSN:chrUn_DS484303v1\tLN:2390\n@SQ\tSN:chrUn_DS485506v1\tLN:1123\n@SQ\tSN:chrUn_DS485522v1\tLN:1118\n@SQ\tSN:chrUn_DS484505v1\tLN:1986\n@SQ\tSN:chrUn_DS485854v1\tLN:1038\n@SQ\tSN:chrUn_DS485342v1\tLN:1162\n@SQ\tSN:chrUn_DS484739v1\tLN:1549\n@SQ\tSN:chrUn_DS484452v1\tLN:2086\n@SQ\tSN:chrUn_DS484720v1\tLN:1586\n@SQ\tSN:chrUn_DS485722v1\tLN:1067\n@SQ\tSN:chrUn_DS484522v1\tLN:1962\n@SQ\tSN:chrUn_DS485781v1\tLN:1052\n@SQ\tSN:chrUn_DS485542v1\tLN:1114\n@SQ\tSN:chrUn_DS485821v1\tLN:1045\n@SQ\tSN:chrUn_DS484350v1\tLN:2304\n@SQ\tSN:chrUn_DS485623v1\tLN:1090\n@SQ\tSN:chrUn_DS485989v1\tLN:1005\n@SQ\tSN:chrUn_DS485743v1\tLN:1062\n@SQ\tSN:chrUn_DS485872v1\tLN:1033\n@SQ\tSN:chrUn_DS484190v1\tLN:2668\n@SQ\tSN:chrUn_DS485240v1\tLN:1195\n@SQ\tSN:chrUn_DS484844v1\tLN:1415\n@SQ\tSN:chrUn_DS483695v1\tLN:11743\n@SQ\tSN:chrUn_DS484798v1\tLN:1466\n@SQ\tSN:chrUn_DS484096v1\tLN:2916\n@SQ\tSN:chrUn_DS483799v1\tLN:5323\n@SQ\tSN:chrUn_DS484843v1\tLN:1416\n@SQ\tSN:chrUn_DS484659v1\tLN:1719\n@SQ\tSN:chrUn_DS485864v1\tLN:1035\n@SQ\tSN:chrUn_DS484825v1\tLN:1432\n@SQ\tSN:chrUn_DS485229v1\tLN:1198\n@SQ\tSN:chrUn_DS485773v1\tLN:1054\n@SQ\tSN:chrUn_DS485659v1\tLN:1082\n@SQ\tSN:chrUn_DS484993v1\tLN:1297\n@SQ\tSN:chrUn_DS484896v1\tLN:1374\n@SQ\tSN:chrUn_DS486005v1\tLN:1001\n@SQ\tSN:chrUn_DS485047v1\tLN:1270\n@SQ\tSN:chrUn_DS484069v1\tLN:3010\n@SQ\tSN:chrUn_DS485138v1\tLN:1229\n@SQ\tSN:chrUn_DS485929v1\tLN:1020\n@SQ\tSN:chrUn_DS485886v1\tLN:1030\n@SQ\tSN:chrUn_DS484493v1\tLN:2005\n@SQ\tSN:chrUn_DS485661v1\tLN:1081\n@SQ\tSN:chrUn_DS484866v1\tLN:1391\n@SQ\tSN:chrUn_DS484772v1\tLN:1502\n@SQ\tSN:chrUn_DS484727v1\tLN:1567\n@SQ\tSN:chrUn_DS485838v1\tLN:1042\n@SQ\tSN:chrUn_DS485701v1\tLN:1072\n@SQ\tSN:chrUn_DS483936v1\tLN:3681\n@SQ\tSN:chrUn_DS485581v1\tLN:1105\n@SQ\tSN:chrUn_DS485019v1\tLN:1280\n@SQ\tSN:chrUn_DS483940v1\tLN:3648\n@SQ\tSN:chrUn_DS485810v1\tLN:1047\n@SQ\tSN:chrUn_DS485982v1\tLN:1007\n@SQ\tSN:chrUn_DS485165v1\tLN:1222\n@SQ\tSN:chrUn_DS484404v1\tLN:2185\n@SQ\tSN:chrUn_DS483736v1\tLN:14006\n@SQ\tSN:chrUn_DS485654v1\tLN:1084\n@SQ\tSN:chrUn_DS485415v1\tLN:1146\n@SQ\tSN:chrUn_DS484275v1\tLN:2451\n@SQ\tSN:chrUn_DS485255v1\tLN:1190\n@SQ\tSN:chrUn_DS484383v1\tLN:2221\n@SQ\tSN:chrUn_DS485331v1\tLN:1165\n@SQ\tSN:chrUn_DS483901v1\tLN:3950\n@SQ\tSN:chrUn_DS484884v1\tLN:1378\n@SQ\tSN:chrUn_DS484515v1\tLN:1966\n@SQ\tSN:chrUn_DS485883v1\tLN:1030\n@SQ\tSN:chrUn_DS483703v1\tLN:11126\n@SQ\tSN:chrUn_DS485311v1\tLN:1173\n@SQ\tSN:chrUn_DS484897v1\tLN:1373\n@SQ\tSN:chrUn_DS483933v1\tLN:3708\n@SQ\tSN:chrUn_DS485740v1\tLN:1063\n@SQ\tSN:chrUn_DS485290v1\tLN:1179\n@SQ\tSN:chrUn_DS484481v1\tLN:2027\n@SQ\tSN:chrUn_DS485349v1\tLN:1161\n@SQ\tSN:chrUn_DS484454v1\tLN:2084\n@SQ\tSN:chrUn_DS483808v1\tLN:5060\n@SQ\tSN:chrUn_DS484976v1\tLN:1308\n@SQ\tSN:chrUn_DS484311v1\tLN:2383\n@SQ\tSN:chrUn_DS485089v1\tLN:1247\n@SQ\tSN:chrUn_DS485985v1\tLN:1006\n@SQ\tSN:chrUn_DS485753v1\tLN:1059\n@SQ\tSN:chrUn_DS484776v1\tLN:1490\n@SQ\tSN:chrUn_DS483864v1\tLN:4295\n@SQ\tSN:chrUn_DS485132v1\tLN:1231\n@SQ\tSN:chrUn_DS485209v1\tLN:1205\n@SQ\tSN:chrUn_DS485693v1\tLN:1074\n@SQ\tSN:chrUn_DS484210v1\tLN:2617\n@SQ\tSN:chrUn_DS484764v1\tLN:1518\n@SQ\tSN:chrUn_DS484999v1\tLN:1294\n@SQ\tSN:chrUn_DS484232v1\tLN:2570\n@SQ\tSN:chrUn_DS484262v1\tLN:2491\n@SQ\tSN:chrUn_DS484076v1\tLN:2991\n@SQ\tSN:chrUn_DS485437v1\tLN:1140\n@SQ\tSN:chrUn_DS485515v1\tLN:1120\n@SQ\tSN:chrUn_DS485199v1\tLN:1208\n@SQ\tSN:chrUn_DS485462v1\tLN:1134\n@SQ\tSN:chrUn_DS485501v1\tLN:1124\n@SQ\tSN:chrUn_DS484710v1\tLN:1610\n@SQ\tSN:chrUn_DS485153v1\tLN:1225\n@SQ\tSN:chrUn_DS484920v1\tLN:1347\n@SQ\tSN:chrUn_DS485163v1\tLN:1223\n@SQ\tSN:chrUn_DS485940v1\tLN:1018\n@SQ\tSN:chrUn_DS485650v1\tLN:1084\n@SQ\tSN:chrUn_DS483849v1\tLN:4400\n@SQ\tSN:chrUn_DS483972v1\tLN:3477\n@SQ\tSN:chrUn_DS485242v1\tLN:1194\n@SQ\tSN:chrUn_DS485056v1\tLN:1263\n@SQ\tSN:chrUn_DS485683v1\tLN:1076\n@SQ\tSN:chrUn_DS483682v1\tLN:12354\n@SQ\tSN:chrUn_DS484478v1\tLN:2033\n@SQ\tSN:chrUn_DS485325v1\tLN:1167\n@SQ\tSN:chrUn_DS484054v1\tLN:3080\n@SQ\tSN:chrUn_DS484771v1\tLN:1504\n@SQ\tSN:chrUn_DS485477v1\tLN:1130\n@SQ\tSN:chrUn_DS484170v1\tLN:2733\n@SQ\tSN:chrUn_DS484922v1\tLN:1344\n@SQ\tSN:chrUn_DS484160v1\tLN:2783\n@SQ\tSN:chrUn_DS485812v1\tLN:1047\n@SQ\tSN:chrUn_DS485438v1\tLN:1139\n@SQ\tSN:chrUn_DS485102v1\tLN:1240\n@SQ\tSN:chrUn_DS485082v1\tLN:1251\n@SQ\tSN:chrUn_DS483743v1\tLN:11569\n@SQ\tSN:chrUn_DS484282v1\tLN:2435\n@SQ\tSN:chrUn_DS485664v1\tLN:1081\n@SQ\tSN:chrUn_DS484369v1\tLN:2253\n@SQ\tSN:chrUn_DS485585v1\tLN:1103\n@SQ\tSN:chrUn_DS484948v1\tLN:1328\n@SQ\tSN:chrUn_DS484728v1\tLN:1566\n@SQ\tSN:chrUn_DS484313v1\tLN:2381\n@SQ\tSN:chrUn_DS485395v1\tLN:1150\n@SQ\tSN:chrUn_DS484443v1\tLN:2094\n@SQ\tSN:chrUn_DS483650v1\tLN:13906\n@SQ\tSN:chrUn_DS485498v1\tLN:1125\n@SQ\tSN:chrUn_DS485668v1\tLN:1080\n@SQ\tSN:chrUn_DS485751v1\tLN:1060\n@SQ\tSN:chrUn_DS484077v1\tLN:2984\n@SQ\tSN:chrUn_DS485900v1\tLN:1027\n@SQ\tSN:chrUn_DS485545v1\tLN:1114\n@SQ\tSN:chrUn_DS485076v1\tLN:1258\n@SQ\tSN:chrUn_DS484394v1\tLN:2200\n@SQ\tSN:chrUn_DS485064v1\tLN:1262\n@SQ\tSN:chrUn_DS484549v1\tLN:1926\n@SQ\tSN:chrUn_DS484738v1\tLN:1550\n@SQ\tSN:chrUn_DS484985v1\tLN:1303\n@SQ\tSN:chrUn_DS485324v1\tLN:1167\n@SQ\tSN:chrUn_DS485904v1\tLN:1025\n@SQ\tSN:chrUn_DS484979v1\tLN:1304\n@SQ\tSN:chrUn_DS485353v1\tLN:1160\n@SQ\tSN:chrUn_DS485688v1\tLN:1075\n@SQ\tSN:chrUn_DS484987v1\tLN:1302\n@SQ\tSN:chrUn_DS483680v1\tLN:12399\n@SQ\tSN:chrUn_DS485686v1\tLN:1075\n@SQ\tSN:chrUn_DS484456v1\tLN:2081\n@SQ\tSN:chrUn_DS485488v1\tLN:1127\n@SQ\tSN:chrUn_DS484479v1\tLN:2033\n@SQ\tSN:chrUn_DS484154v1\tLN:2791\n@SQ\tSN:chrUn_DS483845v1\tLN:4465\n@SQ\tSN:chrUn_DS484251v1\tLN:2521\n@SQ\tSN:chrUn_DS485442v1\tLN:1139\n@SQ\tSN:chrUn_DS484559v1\tLN:1905\n@SQ\tSN:chrUn_DS485062v1\tLN:1262\n@SQ\tSN:chrUn_DS484333v1\tLN:2344\n@SQ\tSN:chrUn_DS484207v1\tLN:2626\n@SQ\tSN:chrUn_DS485322v1\tLN:1168\n@SQ\tSN:chrUn_DS484309v1\tLN:2384\n@SQ\tSN:chrUn_DS485100v1\tLN:1241\n@SQ\tSN:chrUn_DS485526v1\tLN:1117\n@SQ\tSN:chrUn_DS483914v1\tLN:3864\n@SQ\tSN:chrUn_DS485362v1\tLN:1158\n@SQ\tSN:chrUn_DS484760v1\tLN:1521\n@SQ\tSN:chrUn_DS485893v1\tLN:1029\n@SQ\tSN:chrUn_DS484846v1\tLN:1412\n@SQ\tSN:chrUn_DS485249v1\tLN:1192\n@SQ\tSN:chrUn_DS484102v1\tLN:2903\n@SQ\tSN:chrUn_DS484380v1\tLN:2227\n@SQ\tSN:chrUn_DS485466v1\tLN:1133\n@SQ\tSN:chrUn_DS483805v1\tLN:5182\n@SQ\tSN:chrUn_DS485000v1\tLN:1293\n@SQ\tSN:chrUn_DS484243v1\tLN:2541\n@SQ\tSN:chrUn_DS483871v1\tLN:4225\n@SQ\tSN:chrUn_DS484436v1\tLN:2105\n@SQ\tSN:chrUn_DS484713v1\tLN:1608\n@SQ\tSN:chrUn_DS485863v1\tLN:1035\n@SQ\tSN:chrUn_DS485905v1\tLN:1025\n@SQ\tSN:chrUn_DS485055v1\tLN:1264\n@SQ\tSN:chrUn_DS483712v1\tLN:14199\n@SQ\tSN:chrUn_DS484152v1\tLN:2793\n@SQ\tSN:chrUn_DS485472v1\tLN:1131\n@SQ\tSN:chrUn_DS483678v1\tLN:12424\n@SQ\tSN:chrUn_DS484709v1\tLN:1611\n@SQ\tSN:chrUn_DS485026v1\tLN:1278\n@SQ\tSN:chrUn_DS484508v1\tLN:1976\n@SQ\tSN:chrUn_DS485842v1\tLN:1041\n@SQ\tSN:chrUn_DS485826v1\tLN:1044\n@SQ\tSN:chrUn_DS484578v1\tLN:1872\n@SQ\tSN:chrUn_DS485766v1\tLN:1056\n@SQ\tSN:chrUn_DS484654v1\tLN:1728\n@SQ\tSN:chrUn_DS485058v1\tLN:1263\n@SQ\tSN:chrUn_DS485828v1\tLN:1043\n@SQ\tSN:chrUn_DS484301v1\tLN:2394\n@SQ\tSN:chrUn_DS483740v1\tLN:12002\n@SQ\tSN:chrUn_DS484606v1\tLN:1826\n@SQ\tSN:chrUn_DS484220v1\tLN:2588\n@SQ\tSN:chrUn_DS484355v1\tLN:2291\n@SQ\tSN:chrUn_DS485682v1\tLN:1076\n@SQ\tSN:chrUn_DS485563v1\tLN:1109\n@SQ\tSN:chrUn_DS485059v1\tLN:1263\n@SQ\tSN:chrUn_DS486004v1\tLN:1001\n@SQ\tSN:chrUn_DS485173v1\tLN:1219\n@SQ\tSN:chrUn_DS483759v1\tLN:6860\n@SQ\tSN:chrUn_DS484111v1\tLN:2881\n@SQ\tSN:chrUn_DS483674v1\tLN:12632\n@SQ\tSN:chrUn_DS484895v1\tLN:1374\n@SQ\tSN:chrUn_DS484577v1\tLN:1882\n@SQ\tSN:chrUn_DS484400v1\tLN:2190\n@SQ\tSN:chrUn_DS484721v1\tLN:1581\n@SQ\tSN:chrUn_DS485529v1\tLN:1117\n@SQ\tSN:chrUn_DS484445v1\tLN:2092\n@SQ\tSN:chrUn_DS484991v1\tLN:1299\n@SQ\tSN:chrUn_DS484642v1\tLN:1754\n@SQ\tSN:chrUn_DS485868v1\tLN:1035\n@SQ\tSN:chrUn_DS485607v1\tLN:1097\n@SQ\tSN:chrUn_DS483876v1\tLN:4188\n@SQ\tSN:chrUn_DS485867v1\tLN:1035\n@SQ\tSN:chrUn_DS485509v1\tLN:1123\n@SQ\tSN:chrUn_DS484241v1\tLN:2547\n@SQ\tSN:chrUn_DS485605v1\tLN:1098\n@SQ\tSN:chrUn_DS484331v1\tLN:2352\n@SQ\tSN:chrUn_DS484106v1\tLN:2884\n@SQ\tSN:chrUn_DS485368v1\tLN:1157\n@SQ\tSN:chrUn_DS484276v1\tLN:2447\n@SQ\tSN:chrUn_DS485005v1\tLN:1289\n@SQ\tSN:chrUn_DS485469v1\tLN:1132\n@SQ\tSN:chrUn_DS485566v2\tLN:544\n@SQ\tSN:chrUn_DS483855v1\tLN:4377\n@SQ\tSN:chrUn_DS483662v1\tLN:13317\n@SQ\tSN:chrUn_DS485260v1\tLN:1189\n@SQ\tSN:chrUn_DS484469v1\tLN:2060\n@SQ\tSN:chrUn_DS484601v1\tLN:1832\n@SQ\tSN:chrUn_DS483681v1\tLN:12368\n@SQ\tSN:chrUn_DS484916v1\tLN:1352\n@SQ\tSN:chrUn_DS484385v1\tLN:2217\n@SQ\tSN:chrUn_DS485557v1\tLN:1110\n@SQ\tSN:chrUn_DS485997v1\tLN:1004\n@SQ\tSN:chrUn_DS484960v1\tLN:1316\n@SQ\tSN:chrUn_DS483726v1\tLN:14983\n@SQ\tSN:chrUn_DS485456v1\tLN:1135\n@SQ\tSN:chrUn_DS484246v1\tLN:2529\n@SQ\tSN:chrUn_DS485887v1\tLN:1029\n@SQ\tSN:chrUn_DS484396v1\tLN:2198\n@SQ\tSN:chrUn_DS485902v1\tLN:1026\n@SQ\tSN:chrUn_DS484629v1\tLN:1785\n@SQ\tSN:chrUn_DS484310v1\tLN:2383\n@SQ\tSN:chrUn_DS485117v1\tLN:1236\n@SQ\tSN:chrUn_DS485468v1\tLN:1132\n@SQ\tSN:chrUn_DS484263v1\tLN:2487\n@SQ\tSN:chrUn_DS485224v1\tLN:1200\n@SQ\tSN:chrUn_DS485156v1\tLN:1225\n@SQ\tSN:chrUn_DS484501v1\tLN:1990\n@SQ\tSN:chrUn_DS485991v1\tLN:1005\n@SQ\tSN:chrUn_DS485964v1\tLN:1012\n@SQ\tSN:chrUn_DS485361v1\tLN:1159\n@SQ\tSN:chrUn_DS484593v1\tLN:1849\n@SQ\tSN:chrUn_DS485681v1\tLN:1076\n@SQ\tSN:chrUn_DS484982v1\tLN:1304\n@SQ\tSN:chrUn_DS485136v1\tLN:1231\n@SQ\tSN:chrUn_DS483738v1\tLN:12856\n@SQ\tSN:chrUn_DS483783v1\tLN:5891\n@SQ\tSN:chrUn_DS485411v1\tLN:1146\n@SQ\tSN:chrUn_DS485729v1\tLN:1064\n@SQ\tSN:chrUn_DS485622v1\tLN:1090\n@SQ\tSN:chrUn_DS484796v1\tLN:1468\n@SQ\tSN:chrUn_DS485671v1\tLN:1079\n@SQ\tSN:chrUn_DS485684v1\tLN:1076\n@SQ\tSN:chrUn_DS485148v1\tLN:1227\n@SQ\tSN:chrUn_DS484188v1\tLN:2670\n@SQ\tSN:chrUn_DS484566v1\tLN:1900\n@SQ\tSN:chrUn_DS484646v1\tLN:1747\n@SQ\tSN:chrUn_DS485588v1\tLN:1103\n@SQ\tSN:chrUn_DS484498v1\tLN:1998\n@SQ\tSN:chrUn_DS485820v1\tLN:1045\n@SQ\tSN:chrUn_DS484048v1\tLN:3120\n@SQ\tSN:chrUn_DS485079v1\tLN:1253\n@SQ\tSN:chrUn_DS485420v1\tLN:1144\n@SQ\tSN:chrUn_DS483772v1\tLN:6076\n@SQ\tSN:chrUn_DS484281v1\tLN:2438\n@SQ\tSN:chrUn_DS484059v1\tLN:3073\n@SQ\tSN:chrUn_DS485969v1\tLN:1011\n@SQ\tSN:chrUn_DS485027v1\tLN:1277\n@SQ\tSN:chrUn_DS485133v1\tLN:1231\n@SQ\tSN:chrUn_DS485192v1\tLN:1210\n@SQ\tSN:chrUn_DS483693v1\tLN:11958\n@SQ\tSN:chrUn_DS484228v1\tLN:2575\n@SQ\tSN:chrUn_DS484239v1\tLN:2549\n@SQ\tSN:chrUn_DS484595v1\tLN:1843\n@SQ\tSN:chrUn_DS484274v1\tLN:2462\n@SQ\tSN:chrUn_DS485917v1\tLN:1022\n@SQ\tSN:chrUn_DS484320v1\tLN:2369\n@SQ\tSN:chrUn_DS484480v1\tLN:2030\n@SQ\tSN:chrUn_DS484579v1\tLN:1872\n@SQ\tSN:chrUn_DS485980v1\tLN:1008\n@SQ\tSN:chrUn_DS485531v1\tLN:1116\n@SQ\tSN:chrUn_DS484806v1\tLN:1458\n@SQ\tSN:chrUn_DS484782v1\tLN:1484\n@SQ\tSN:chrUn_DS484639v1\tLN:1761\n@SQ\tSN:chrUn_DS485494v1\tLN:1126\n@SQ\tSN:chrUn_DS484238v1\tLN:2555\n@SQ\tSN:chrUn_DS485965v1\tLN:1012\n@SQ\tSN:chrUn_DS484514v1\tLN:1966\n@SQ\tSN:chrUn_DS485092v1\tLN:1246\n@SQ\tSN:chrUn_DS485518v1\tLN:1119\n@SQ\tSN:chrUn_DS485453v1\tLN:1136\n@SQ\tSN:chrUn_DS484542v1\tLN:1933\n@SQ\tSN:chrUn_DS483970v1\tLN:3490\n@SQ\tSN:chrUn_DS484632v1\tLN:1775\n@SQ\tSN:chrUn_DS485401v1\tLN:1148\n@SQ\tSN:chrUn_DS484193v1\tLN:2647\n@SQ\tSN:chrUn_DS484487v1\tLN:2010\n@SQ\tSN:chrUn_DS484087v1\tLN:2937\n@SQ\tSN:chrUn_DS485517v1\tLN:1119\n@SQ\tSN:chrUn_DS485742v1\tLN:1062\n@SQ\tSN:chrUn_DS483919v1\tLN:3807\n@SQ\tSN:chrUn_DS484748v1\tLN:1538\n@SQ\tSN:chrUn_DS484312v1\tLN:2382\n@SQ\tSN:chrUn_DS485679v1\tLN:1077\n@SQ\tSN:chrUn_DS483797v1\tLN:5360\n@SQ\tSN:chrUn_DS485803v1\tLN:1048\n@SQ\tSN:chrUn_DS484315v1\tLN:2379\n@SQ\tSN:chrUn_DS485912v1\tLN:1022\n@SQ\tSN:chrUn_DS484027v1\tLN:3197\n@SQ\tSN:chrUn_DS485122v1\tLN:1234\n@SQ\tSN:chrUn_DS485847v1\tLN:1040\n@SQ\tSN:chrUn_DS484941v1\tLN:1333\n@SQ\tSN:chrUn_DS483734v1\tLN:15522\n@SQ\tSN:chrUn_DS484510v1\tLN:1975\n@SQ\tSN:chrUn_DS484028v1\tLN:3196\n@SQ\tSN:chrUn_DS484561v1\tLN:1903\n@SQ\tSN:chrUn_DS485802v1\tLN:1048\n@SQ\tSN:chrUn_DS484118v1\tLN:2858\n@SQ\tSN:chrUn_DS485915v1\tLN:1022\n@SQ\tSN:chrUn_DS485933v1\tLN:1019\n@SQ\tSN:chrUn_DS485371v1\tLN:1156\n@SQ\tSN:chrUn_DS484437v1\tLN:2103\n@SQ\tSN:chrUn_DS484155v1\tLN:2790\n@SQ\tSN:chrUn_DS485298v1\tLN:1178\n@SQ\tSN:chrUn_DS485007v1\tLN:1287\n@SQ\tSN:chrUn_DS484899v1\tLN:1369\n@SQ\tSN:chrUn_DS485544v1\tLN:1114\n@SQ\tSN:chrUn_DS485841v1\tLN:1041\n@SQ\tSN:chrUn_DS485614v1\tLN:1094\n@SQ\tSN:chrUn_DS484651v1\tLN:1734\n@SQ\tSN:chrUn_DS485968v1\tLN:1011\n@SQ\tSN:chrUn_DS484962v1\tLN:1315\n@SQ\tSN:chrUn_DS483840v1\tLN:4573\n@SQ\tSN:chrUn_DS483739v1\tLN:12459\n@SQ\tSN:chrUn_DS485903v1\tLN:1026\n@SQ\tSN:chrUn_DS485983v1\tLN:1006\n@SQ\tSN:chrUn_DS484984v1\tLN:1304\n@SQ\tSN:chrUn_DS485582v1\tLN:1105\n@SQ\tSN:chrUn_DS485880v1\tLN:1031\n@SQ\tSN:chrUn_DS485273v1\tLN:1185\n@SQ\tSN:chrUn_DS485583v1\tLN:1105\n@SQ\tSN:chrUn_DS485309v1\tLN:1173\n@SQ\tSN:chrUn_DS485428v1\tLN:1142\n@SQ\tSN:chrUn_DS484967v1\tLN:1311\n@SQ\tSN:chrUn_DS484910v1\tLN:1356\n@SQ\tSN:chrUn_DS484550v1\tLN:1924\n@SQ\tSN:chrUn_DS485666v1\tLN:1080\n@SQ\tSN:chrUn_DS483944v1\tLN:3622\n@SQ\tSN:chrUn_DS484894v1\tLN:1375\n@SQ\tSN:chrUn_DS483908v1\tLN:3913\n@SQ\tSN:chrUn_DS484244v1\tLN:2536\n@SQ\tSN:chrUn_DS485632v1\tLN:1088\n@SQ\tSN:chrUn_DS485291v1\tLN:1179\n@SQ\tSN:chrUn_DS484472v1\tLN:2046\n@SQ\tSN:chrUn_DS485045v1\tLN:1271\n@SQ\tSN:chrUn_DS483792v1\tLN:5465\n@SQ\tSN:chrUn_DS485986v1\tLN:1005\n@SQ\tSN:chrUn_DS485823v1\tLN:1044\n@SQ\tSN:chrUn_DS483848v1\tLN:4436\n@SQ\tSN:chrUn_DS484886v1\tLN:1377\n@SQ\tSN:chrUn_DS484025v1\tLN:3201\n@SQ\tSN:chrUn_DS483856v1\tLN:4370\n@SQ\tSN:chrUn_DS485543v1\tLN:1114\n@SQ\tSN:chrUn_DS485520v1\tLN:1118\n@SQ\tSN:chrUn_DS485725v1\tLN:1066\n@SQ\tSN:chrUn_DS485264v1\tLN:1186\n@SQ\tSN:chrUn_DS485497v1\tLN:1125\n@SQ\tSN:chrUn_DS485996v1\tLN:1004\n@SQ\tSN:chrUn_DS485025v1\tLN:1278\n@SQ\tSN:chrUn_DS485118v1\tLN:1235\n@SQ\tSN:chrUn_DS485220v1\tLN:1202\n@SQ\tSN:chrUn_DS485569v1\tLN:1108\n@SQ\tSN:chrUn_DS484919v1\tLN:1347\n@SQ\tSN:chrUn_DS484149v1\tLN:2795\n@SQ\tSN:chrUn_DS485127v1\tLN:1233\n@SQ\tSN:chrUn_DS485439v1\tLN:1139\n@SQ\tSN:chrUn_DS483673v1\tLN:12654\n@SQ\tSN:chrUn_DS484929v1\tLN:1339\n@SQ\tSN:chrUn_DS485441v1\tLN:1139\n@SQ\tSN:chrUn_DS483701v1\tLN:11220\n@SQ\tSN:chrUn_DS485796v1\tLN:1049\n@SQ\tSN:chrUn_DS485218v1\tLN:1203\n@SQ\tSN:chrUn_DS485712v1\tLN:1070\n@SQ\tSN:chrUn_DS483979v1\tLN:3434\n@SQ\tSN:chrUn_DS485087v1\tLN:1249\n@SQ\tSN:chrUn_DS484889v1\tLN:1377\n@SQ\tSN:chrUn_DS484291v1\tLN:2421\n@SQ\tSN:chrUn_DS485053v1\tLN:1266\n@SQ\tSN:chrUn_DS484093v1\tLN:2922\n@SQ\tSN:chrUn_DS485850v1\tLN:1039\n@SQ\tSN:chrUn_DS485243v1\tLN:1193\n@SQ\tSN:chrUn_DS485215v1\tLN:1203\n@SQ\tSN:chrUn_DS485370v1\tLN:1156\n@SQ\tSN:chrUn_DS483825v1\tLN:4815\n@SQ\tSN:chrUn_DS484658v1\tLN:1719\n@SQ\tSN:chrUn_DS483820v1\tLN:4888\n@SQ\tSN:chrUn_DS484851v1\tLN:1408\n@SQ\tSN:chrUn_DS483688v1\tLN:12095\n@SQ\tSN:chrUn_DS485233v1\tLN:1197\n@SQ\tSN:chrUn_DS483853v1\tLN:4381\n@SQ\tSN:chrUn_DS484847v1\tLN:1411\n@SQ\tSN:chrUn_DS485818v1\tLN:1045\n@SQ\tSN:chrUn_DS485383v1\tLN:1154\n@SQ\tSN:chrUn_DS484435v1\tLN:2105\n@SQ\tSN:chrUn_DS484565v1\tLN:1901\n@SQ\tSN:chrUn_DS485379v1\tLN:1154\n@SQ\tSN:chrUn_DS484403v1\tLN:2187\n@SQ\tSN:chrUn_DS483930v1\tLN:3716\n@SQ\tSN:chrUn_DS484370v1\tLN:2248\n@SQ\tSN:chrUn_DS485203v1\tLN:1208\n@SQ\tSN:chrUn_DS484635v1\tLN:1770\n@SQ\tSN:chrUn_DS484231v1\tLN:2574\n@SQ\tSN:chrUn_DS485392v1\tLN:1151\n@SQ\tSN:chrUn_DS484098v1\tLN:2911\n@SQ\tSN:chrUn_DS484678v1\tLN:1685\n@SQ\tSN:chrUn_DS485521v1\tLN:1118\n@SQ\tSN:chrUn_DS485251v1\tLN:1192\n@SQ\tSN:chrUn_DS483675v1\tLN:12536\n@SQ\tSN:chrUn_DS485775v1\tLN:1053\n@SQ\tSN:chrUn_DS484838v1\tLN:1422\n@SQ\tSN:chrUn_DS485263v1\tLN:1188\n@SQ\tSN:chrUn_DS484804v1\tLN:1461\n@SQ\tSN:chrUn_DS485571v1\tLN:1107\n@SQ\tSN:chrUn_DS484236v1\tLN:2556\n@SQ\tSN:chrUn_DS484954v1\tLN:1323\n@SQ\tSN:chrUn_DS484467v1\tLN:2060\n@SQ\tSN:chrUn_DS484148v1\tLN:2795\n@SQ\tSN:chrUn_DS484817v1\tLN:1445\n@SQ\tSN:chrUn_DS483741v1\tLN:11807\n@SQ\tSN:chrUn_DS485911v1\tLN:1023\n@SQ\tSN:chrUn_DS484157v1\tLN:2787\n@SQ\tSN:chrUn_DS484852v1\tLN:1407\n@SQ\tSN:chrUn_DS485636v1\tLN:1088\n@SQ\tSN:chrUn_DS484588v1\tLN:1863\n@SQ\tSN:chrUn_DS483769v1\tLN:6237\n@SQ\tSN:chrUn_DS484779v1\tLN:1487\n@SQ\tSN:chrUn_DS485326v1\tLN:1166\n@SQ\tSN:chrUn_DS485642v1\tLN:1087\n@SQ\tSN:chrUn_DS485184v1\tLN:1212\n@SQ\tSN:chrUn_DS485228v1\tLN:1198\n@SQ\tSN:chrUn_DS483663v1\tLN:13256\n@SQ\tSN:chrUn_DS483804v1\tLN:5189\n@SQ\tSN:chrUn_DS484169v1\tLN:2736\n@SQ\tSN:chrUn_DS485491v1\tLN:1126\n@SQ\tSN:chrUn_DS485657v1\tLN:1083\n@SQ\tSN:chrUn_DS484520v1\tLN:1962\n@SQ\tSN:chrUn_DS485780v1\tLN:1053\n@SQ\tSN:chrUn_DS484253v1\tLN:2520\n@SQ\tSN:chrUn_DS484591v1\tLN:1854\n@SQ\tSN:chrUn_DS484673v1\tLN:1696\n@SQ\tSN:chrUn_DS485528v1\tLN:1117\n@SQ\tSN:chrUn_DS485656v1\tLN:1083\n@SQ\tSN:chrUn_DS483659v1\tLN:13416\n@SQ\tSN:chrUn_DS485011v1\tLN:1285\n@SQ\tSN:chrUn_DS485737v1\tLN:1063\n@SQ\tSN:chrUn_DS485160v1\tLN:1224\n@SQ\tSN:chrUn_DS485208v1\tLN:1205\n@SQ\tSN:chrUn_DS485717v1\tLN:1069\n@SQ\tSN:chrUn_DS484882v1\tLN:1379\n@SQ\tSN:chrUn_DS483686v1\tLN:12148\n@SQ\tSN:chrUn_DS485876v1\tLN:1032\n@SQ\tSN:chrUn_DS484831v1\tLN:1429\n@SQ\tSN:chrUn_DS484205v1\tLN:2629\n@SQ\tSN:chrUn_DS485434v1\tLN:1140\n@SQ\tSN:chrUn_DS484003v1\tLN:3284\n@SQ\tSN:chrUn_DS485948v1\tLN:1015\n@SQ\tSN:chrUn_DS484340v1\tLN:2328\n@SQ\tSN:chrUn_DS483965v1\tLN:3503\n@SQ\tSN:chrUn_DS485068v1\tLN:1260\n@SQ\tSN:chrUn_DS485533v1\tLN:1116\n@SQ\tSN:chrUn_DS484774v1\tLN:1492\n@SQ\tSN:chrUn_DS485292v1\tLN:1179\n@SQ\tSN:chrUn_DS484156v1\tLN:2788\n@SQ\tSN:chrUn_DS485709v1\tLN:1070\n@SQ\tSN:chrUn_DS485947v1\tLN:1016\n@SQ\tSN:chrUn_DS484544v1\tLN:1929\n@SQ\tSN:chrUn_DS484524v1\tLN:1961\n@SQ\tSN:chrUn_DS485275v1\tLN:1185\n@SQ\tSN:chrUn_DS485527v1\tLN:1117\n@SQ\tSN:chrUn_DS484619v1\tLN:1800\n@SQ\tSN:chrUn_DS483801v1\tLN:5281\n@SQ\tSN:chrUn_DS484307v1\tLN:2385\n@SQ\tSN:chrUn_DS483687v1\tLN:12142\n@SQ\tSN:chrUn_DS484463v1\tLN:2064\n@SQ\tSN:chrUn_DS485939v1\tLN:1018\n@SQ\tSN:chrUn_DS485146v1\tLN:1227\n@SQ\tSN:chrUn_DS485174v1\tLN:1219\n@SQ\tSN:chrUn_DS485194v1\tLN:1209\n@SQ\tSN:chrUn_DS484283v1\tLN:2434\n@SQ\tSN:chrUn_DS485500v1\tLN:1124\n@SQ\tSN:chrUn_DS484183v1\tLN:2688\n@SQ\tSN:chrUn_DS484499v1\tLN:1995\n@SQ\tSN:chrUn_DS485338v1\tLN:1163\n@SQ\tSN:chrUn_DS485036v1\tLN:1274\n@SQ\tSN:chrUn_DS484553v1\tLN:1917\n@SQ\tSN:chrUn_DS485587v1\tLN:1103\n@SQ\tSN:chrUn_DS485265v1\tLN:1186\n@SQ\tSN:chrUn_DS484425v1\tLN:2124\n@SQ\tSN:chrUn_DS484802v1\tLN:1462\n@SQ\tSN:chrUn_DS485538v1\tLN:1115\n@SQ\tSN:chrUn_DS483872v1\tLN:4222\n@SQ\tSN:chrUn_DS485319v1\tLN:1169\n@SQ\tSN:chrUn_DS484752v1\tLN:1532\n@SQ\tSN:chrUn_DS485630v1\tLN:1089\n@SQ\tSN:chrUn_DS483915v1\tLN:3858\n@SQ\tSN:chrUn_DS485161v1\tLN:1224\n@SQ\tSN:chrUn_DS485482v1\tLN:1129\n@SQ\tSN:chrUn_DS484943v1\tLN:1332\n@SQ\tSN:chrUn_DS484722v1\tLN:1577\n@SQ\tSN:chrUn_DS485010v1\tLN:1286\n@SQ\tSN:chrUn_DS485952v1\tLN:1014\n@SQ\tSN:chrUn_DS484869v1\tLN:1391\n@SQ\tSN:chrUn_DS483749v1\tLN:8007\n@SQ\tSN:chrUn_DS484799v1\tLN:1464\n@SQ\tSN:chrUn_DS484998v1\tLN:1294\n@SQ\tSN:chrUn_DS484041v1\tLN:3157\n@SQ\tSN:chrUn_DS483841v1\tLN:4553\n@SQ\tSN:chrUn_DS485031v1\tLN:1275\n@SQ\tSN:chrUn_DS484254v1\tLN:2517\n@SQ\tSN:chrUn_DS484279v1\tLN:2438\n@SQ\tSN:chrUn_DS484503v1\tLN:1988\n@SQ\tSN:chrUn_DS483658v1\tLN:13455\n@SQ\tSN:chrUn_DS485397v1\tLN:1148\n@SQ\tSN:chrUn_DS485004v1\tLN:1290\n@SQ\tSN:chrUn_DS485046v1\tLN:1270\n@SQ\tSN:chrUn_DS485382v1\tLN:1154\n@SQ\tSN:chrUn_DS485728v1\tLN:1064\n@SQ\tSN:chrUn_DS485125v1\tLN:1234\n@SQ\tSN:chrUn_DS485200v1\tLN:1208\n@SQ\tSN:chrUn_DS484471v1\tLN:2050\n@SQ\tSN:chrUn_DS483750v1\tLN:7722\n@SQ\tSN:chrUn_DS485946v1\tLN:1016\n@SQ\tSN:chrUn_DS484874v1\tLN:1384\n@SQ\tSN:chrUn_DS485258v1\tLN:1189\n@SQ\tSN:chrUn_DS485833v1\tLN:1042\n@SQ\tSN:chrUn_DS485944v1\tLN:1016\n@SQ\tSN:chrUn_DS485714v1\tLN:1069\n@SQ\tSN:chrUn_DS483920v1\tLN:3806\n@SQ\tSN:chrUn_DS485464v1\tLN:1133\n@SQ\tSN:chrUn_DS484614v1\tLN:1806\n@SQ\tSN:chrUn_DS484153v1\tLN:2793\n@SQ\tSN:chrUn_DS485461v1\tLN:1134\n@SQ\tSN:chrUn_DS484828v1\tLN:1430\n@SQ\tSN:chrUn_DS484834v1\tLN:1424\n@SQ\tSN:chrUn_DS483913v1\tLN:3871\n@SQ\tSN:chrUn_DS483670v1\tLN:12827\n@SQ\tSN:chrUn_DS484427v1\tLN:2117\n@SQ\tSN:chrUn_DS485247v1\tLN:1193\n@SQ\tSN:chrUn_DS484083v1\tLN:2957\n@SQ\tSN:chrUn_DS485530v1\tLN:1117\n@SQ\tSN:chrUn_DS485020v1\tLN:1280\n@SQ\tSN:chrUn_DS485827v1\tLN:1043\n@SQ\tSN:chrUn_DS484047v1\tLN:3123\n@SQ\tSN:chrUn_DS485149v1\tLN:1226\n@SQ\tSN:chrUn_DS484287v1\tLN:2428\n@SQ\tSN:chrUn_DS485655v1\tLN:1083\n@SQ\tSN:chrUn_DS485757v1\tLN:1058\n@SQ\tSN:chrUn_DS484062v1\tLN:3058\n@SQ\tSN:chrUn_DS485932v1\tLN:1019\n@SQ\tSN:chrUn_DS484348v1\tLN:2308\n@SQ\tSN:chrUn_DS484686v1\tLN:1667\n@SQ\tSN:chrUn_DS485253v1\tLN:1191\n@SQ\tSN:chrUn_DS485953v1\tLN:1014\n@SQ\tSN:chrUn_DS484812v1\tLN:1451\n@SQ\tSN:chrUn_DS484449v1\tLN:2087\n@SQ\tSN:chrUn_DS485032v1\tLN:1275\n@SQ\tSN:chrUn_DS484438v1\tLN:2102\n@SQ\tSN:chrUn_DS485923v1\tLN:1021\n@SQ\tSN:chrUn_DS484314v1\tLN:2381\n@SQ\tSN:chrUn_DS485306v1\tLN:1174\n@SQ\tSN:chrUn_DS483975v1\tLN:3466\n@SQ\tSN:chrUn_DS485770v1\tLN:1055\n@SQ\tSN:chrUn_DS485204v1\tLN:1207\n@SQ\tSN:chrUn_DS484502v1\tLN:1990\n@SQ\tSN:chrUn_DS485667v1\tLN:1080\n@SQ\tSN:chrUn_DS483679v1\tLN:12424\n@SQ\tSN:chrUn_DS484080v1\tLN:2971\n@SQ\tSN:chrUn_DS484712v1\tLN:1610\n@SQ\tSN:chrUn_DS484742v1\tLN:1543\n@SQ\tSN:chrUn_DS483939v1\tLN:3649\n@SQ\tSN:chrUn_DS485535v1\tLN:1116\n@SQ\tSN:chrUn_DS484258v1\tLN:2510\n@SQ\tSN:chrUn_DS484285v1\tLN:2431\n@SQ\tSN:chrUn_DS484509v1\tLN:1976\n@SQ\tSN:chrUn_DS485211v1\tLN:1205\n@SQ\tSN:chrUn_DS483867v1\tLN:4272\n@SQ\tSN:chrUn_DS485066v1\tLN:1261\n@SQ\tSN:chrUn_DS484630v1\tLN:1776\n@SQ\tSN:chrUn_DS484271v1\tLN:2470\n@SQ\tSN:chrUn_DS484117v1\tLN:2860\n@SQ\tSN:chrUn_DS484042v1\tLN:3156\n@SQ\tSN:chrUn_DS483746v1\tLN:9341\n@SQ\tSN:chrUn_DS484932v1\tLN:1337\n@SQ\tSN:chrUn_DS485177v1\tLN:1218\n@SQ\tSN:chrUn_DS485540v1\tLN:1114\n@SQ\tSN:chrUn_DS484815v1\tLN:1446\n@SQ\tSN:chrUn_DS483989v1\tLN:3373\n@SQ\tSN:chrUn_DS483767v1\tLN:6396\n@SQ\tSN:chrUn_DS485621v1\tLN:1091\n@SQ\tSN:chrUn_DS483782v1\tLN:5915\n@SQ\tSN:chrUn_DS485774v1\tLN:1053\n@SQ\tSN:chrUn_DS483862v1\tLN:4310\n@SQ\tSN:chrUn_DS484513v1\tLN:1966\n@SQ\tSN:chrUn_DS484878v1\tLN:1381\n@SQ\tSN:chrUn_DS483737v1\tLN:13553\n@SQ\tSN:chrUn_DS483689v1\tLN:12034\n@SQ\tSN:chrUn_DS484671v1\tLN:1703\n@SQ\tSN:chrUn_DS484255v1\tLN:2516\n@SQ\tSN:chrUn_DS485481v1\tLN:1129\n@SQ\tSN:chrUn_DS484528v1\tLN:1947\n@SQ\tSN:chrUn_DS484797v1\tLN:1467\n@SQ\tSN:chrUn_DS485874v1\tLN:1033\n@SQ\tSN:chrUn_DS484286v1\tLN:2429\n@SQ\tSN:chrUn_DS484177v1\tLN:2703\n@SQ\tSN:chrUn_DS483816v1\tLN:4939\n@SQ\tSN:chrUn_DS484584v1\tLN:1869\n@SQ\tSN:chrUn_DS485574v1\tLN:1106\n@SQ\tSN:chrUn_DS485022v1\tLN:1279\n@SQ\tSN:chrUn_DS485750v1\tLN:1060\n@SQ\tSN:chrUn_DS483815v1\tLN:4967\n@SQ\tSN:chrUn_DS484389v1\tLN:2207\n@SQ\tSN:chrUn_DS484656v1\tLN:1724\n@SQ\tSN:chrUn_DS485567v1\tLN:1108\n@SQ\tSN:chrUn_DS484692v1\tLN:1643\n@SQ\tSN:chrUn_DS483858v1\tLN:4361\n@SQ\tSN:chrUn_DS484458v1\tLN:2079\n@SQ\tSN:chrUn_DS485628v1\tLN:1089\n@SQ\tSN:chrUn_DS483961v1\tLN:3527\n@SQ\tSN:chrUn_DS485966v1\tLN:1011\n@SQ\tSN:chrUn_DS484147v1\tLN:2796\n@SQ\tSN:chrUn_DS484378v1\tLN:2232\n@SQ\tSN:chrUn_DS485754v1\tLN:1059\n@SQ\tSN:chrUn_DS484017v1\tLN:3227\n@SQ\tSN:chrUn_DS485918v1\tLN:1021\n@SQ\tSN:chrUn_DS485314v1\tLN:1171\n@SQ\tSN:chrUn_DS485692v1\tLN:1074\n@SQ\tSN:chrUn_DS484300v1\tLN:2400\n@SQ\tSN:chrUn_DS483953v1\tLN:3557\n@SQ\tSN:chrUn_DS484138v1\tLN:2822\n@SQ\tSN:chrUn_DS485593v1\tLN:1101\n@SQ\tSN:chrUn_DS484342v1\tLN:2326\n@SQ\tSN:chrUn_DS484557v1\tLN:1907\n@SQ\tSN:chrUn_DS484685v1\tLN:1675\n@SQ\tSN:chrUn_DS484607v1\tLN:1819\n@SQ\tSN:chrUn_DS484189v1\tLN:2669\n@SQ\tSN:chrUn_DS485610v1\tLN:1096\n@SQ\tSN:chrUn_DS485151v1\tLN:1226\n@SQ\tSN:chrUn_DS484267v1\tLN:2476\n@SQ\tSN:chrUn_DS484020v1\tLN:3218\n@SQ\tSN:chrUn_DS485525v1\tLN:1117\n@SQ\tSN:chrUn_DS485429v1\tLN:1141\n@SQ\tSN:chrUn_DS485088v1\tLN:1248\n@SQ\tSN:chrUn_DS485190v1\tLN:1211\n@SQ\tSN:chrUn_DS485565v1\tLN:1109\n@SQ\tSN:chrUn_DS483870v1\tLN:4231\n@SQ\tSN:chrUn_DS484022v1\tLN:3209\n@SQ\tSN:chrUn_DS484836v1\tLN:1424\n@SQ\tSN:chrUn_DS484105v1\tLN:2889\n@SQ\tSN:chrUn_DS485889v1\tLN:1029\n@SQ\tSN:chrUn_DS484109v1\tLN:2882\n@SQ\tSN:chrUn_DS485882v1\tLN:1031\n@SQ\tSN:chrUn_DS483824v1\tLN:4820\n@SQ\tSN:chrUn_DS485426v1\tLN:1142\n@SQ\tSN:chrUn_DS485083v1\tLN:1251\n@SQ\tSN:chrUn_DS485851v1\tLN:1039\n@SQ\tSN:chrUn_DS483945v1\tLN:3622\n@SQ\tSN:chrUn_DS484534v1\tLN:1943\n@SQ\tSN:chrUn_DS484901v1\tLN:1368\n@SQ\tSN:chrUn_DS484789v1\tLN:1473\n@SQ\tSN:chrUn_DS483904v1\tLN:3932\n@SQ\tSN:chrUn_DS484264v1\tLN:2479\n@SQ\tSN:chrUn_DS484086v1\tLN:2943\n@SQ\tSN:chrUn_DS484089v1\tLN:2928\n@SQ\tSN:chrUn_DS485792v1\tLN:1050\n@SQ\tSN:chrUn_DS485085v1\tLN:1251\n@SQ\tSN:chrUn_DS483773v1\tLN:6062\n@SQ\tSN:chrUn_DS483837v1\tLN:4608\n@SQ\tSN:chrUn_DS485648v1\tLN:1086\n@SQ\tSN:chrUn_DS485105v1\tLN:1240\n@SQ\tSN:chrUn_DS485694v1\tLN:1074\n@SQ\tSN:chrUn_DS485389v1\tLN:1152\n@SQ\tSN:chrUn_DS484343v1\tLN:2325\n@SQ\tSN:chrUn_DS483702v1\tLN:11148\n@SQ\tSN:chrUn_DS485640v1\tLN:1087\n@SQ\tSN:chrUn_DS483868v1\tLN:4256\n@SQ\tSN:chrUn_DS485806v1\tLN:1048\n@SQ\tSN:chrUn_DS484434v1\tLN:2108\n@SQ\tSN:chrUn_DS484888v1\tLN:1377\n@SQ\tSN:chrUn_DS484693v1\tLN:1641\n@SQ\tSN:chrUn_DS485627v1\tLN:1090\n@SQ\tSN:chrUn_DS485245v1\tLN:1193\n@SQ\tSN:chrUn_DS485595v1\tLN:1101\n@SQ\tSN:chrUn_DS484064v1\tLN:3044\n@SQ\tSN:chrUn_DS485176v1\tLN:1219\n@SQ\tSN:chrUn_DS485252v1\tLN:1191\n@SQ\tSN:chrUn_DS485670v1\tLN:1079\n@SQ\tSN:chrUn_DS485152v1\tLN:1225\n@SQ\tSN:chrUn_DS484078v1\tLN:2982\n@SQ\tSN:chrUn_DS483814v1\tLN:4986\n@SQ\tSN:chrUn_DS484206v1\tLN:2628\n@SQ\tSN:chrUn_DS485071v1\tLN:1260\n@SQ\tSN:chrUn_DS484070v1\tLN:3009\n@SQ\tSN:chrUn_DS485584v1\tLN:1105\n@SQ\tSN:chrUn_DS483886v1\tLN:4081\n@SQ\tSN:chrUn_DS484773v1\tLN:1494\n@SQ\tSN:chrUn_DS484004v1\tLN:3277\n@SQ\tSN:chrUn_DS485393v1\tLN:1150\n@SQ\tSN:chrUn_DS484192v1\tLN:2664\n@SQ\tSN:chrUn_DS483891v1\tLN:4030\n@SQ\tSN:chrUn_DS484217v1\tLN:2603\n@SQ\tSN:chrUn_DS484055v1\tLN:3080\n@SQ\tSN:chrUn_DS484015v1\tLN:3234\n@SQ\tSN:chrUn_DS485848v1\tLN:1040\n@SQ\tSN:chrUn_DS485221v1\tLN:1201\n@SQ\tSN:chrUn_DS485227v1\tLN:1199\n@SQ\tSN:chrUn_DS485579v1\tLN:1105\n@SQ\tSN:chrUn_DS485400v1\tLN:1148\n@SQ\tSN:chrUn_DS485154v1\tLN:1225\n@SQ\tSN:chrUn_DS483956v1\tLN:3553\n@SQ\tSN:chrUn_DS483854v1\tLN:4378\n@SQ\tSN:chrUn_DS485410v1\tLN:1147\n@SQ\tSN:chrUn_DS484718v1\tLN:1586\n@SQ\tSN:chrUn_DS484412v1\tLN:2161\n@SQ\tSN:chrUn_DS484424v1\tLN:2124\n@SQ\tSN:chrUn_DS484213v1\tLN:2611\n@SQ\tSN:chrUn_DS485157v1\tLN:1225\n@SQ\tSN:chrUn_DS484940v1\tLN:1333\n@SQ\tSN:chrUn_DS484221v1\tLN:2584\n@SQ\tSN:chrUn_DS485746v1\tLN:1062\n@SQ\tSN:chrUn_DS484466v1\tLN:2062\n@SQ\tSN:chrUn_DS484306v1\tLN:2385\n@SQ\tSN:chrUn_DS485807v1\tLN:1048\n@SQ\tSN:chrUn_DS485591v1\tLN:1102\n@SQ\tSN:chrUn_DS484486v1\tLN:2014\n@SQ\tSN:chrUn_DS485030v1\tLN:1276\n@SQ\tSN:chrUn_DS484395v1\tLN:2198\n@SQ\tSN:chrUn_DS485216v1\tLN:1203\n@SQ\tSN:chrUn_DS483964v1\tLN:3519\n@SQ\tSN:chrUn_DS484750v1\tLN:1533\n@SQ\tSN:chrUn_DS484661v1\tLN:1716\n@SQ\tSN:chrUn_DS484621v1\tLN:1797\n@SQ\tSN:chrUn_DS484927v1\tLN:1340\n@SQ\tSN:chrUn_DS485330v1\tLN:1166\n@SQ\tSN:chrUn_DS485988v1\tLN:1005\n@SQ\tSN:chrUn_DS485832v1\tLN:1042\n@SQ\tSN:chrUn_DS484159v1\tLN:2784\n@SQ\tSN:chrUn_DS485041v1\tLN:1271\n@SQ\tSN:chrUn_DS484421v1\tLN:2129\n@SQ\tSN:chrUn_DS485091v1\tLN:1246\n@SQ\tSN:chrUn_DS485878v1\tLN:1032\n@SQ\tSN:chrUn_DS485140v1\tLN:1229\n@SQ\tSN:chrUn_DS485419v1\tLN:1144\n@SQ\tSN:chrUn_DS484887v1\tLN:1377\n@SQ\tSN:chrUn_DS485301v1\tLN:1177\n@SQ\tSN:chrUn_DS485002v1\tLN:1291\n@SQ\tSN:chrUn_DS484491v1\tLN:2006\n@SQ\tSN:chrUn_DS485589v1\tLN:1102\n@SQ\tSN:chrUn_DS485284v1\tLN:1182\n@SQ\tSN:chrUn_DS484525v1\tLN:1961\n@SQ\tSN:chrUn_DS484734v1\tLN:1555\n@SQ\tSN:chrUn_DS484212v1\tLN:2612\n@SQ\tSN:chrUn_DS483866v1\tLN:4273\n@SQ\tSN:chrUn_DS484107v1\tLN:2882\n@SQ\tSN:chrUn_DS484930v1\tLN:1339\n@SQ\tSN:chrUn_DS484321v1\tLN:2368\n@SQ\tSN:chrUn_DS485134v1\tLN:1231\n@SQ\tSN:chrUn_DS484044v1\tLN:3144\n@SQ\tSN:chrUn_DS484066v1\tLN:3025\n@SQ\tSN:chrUn_DS484151v1\tLN:2794\n@SQ\tSN:chrUn_DS484242v1\tLN:2541\n@SQ\tSN:chrUn_DS484602v1\tLN:1832\n@SQ\tSN:chrUn_DS484762v1\tLN:1520\n@SQ\tSN:chrUn_DS484408v1\tLN:2173\n@SQ\tSN:chrUn_DS485067v1\tLN:1261\n@SQ\tSN:chrUn_DS485297v1\tLN:1178\n@SQ\tSN:chrUn_DS484700v1\tLN:1625\n@SQ\tSN:chrUn_DS484116v1\tLN:2860\n@SQ\tSN:chrUn_DS484335v1\tLN:2342\n@SQ\tSN:chrUn_DS485169v1\tLN:1220\n@SQ\tSN:chrUn_DS485448v1\tLN:1137\n@SQ\tSN:chrUn_DS483822v1\tLN:4865\n@SQ\tSN:chrUn_DS484792v1\tLN:1471\n@SQ\tSN:chrUn_DS483768v1\tLN:6294\n@SQ\tSN:chrUn_DS483735v1\tLN:15068\n@SQ\tSN:chrUn_DS485653v1\tLN:1084\n@SQ\tSN:chrUn_DS484662v1\tLN:1715\n@SQ\tSN:chrUn_DS484097v1\tLN:2914\n@SQ\tSN:chrUn_DS484001v1\tLN:3299\n@SQ\tSN:chrUn_DS485609v1\tLN:1096\n@SQ\tSN:chrUn_DS485323v1\tLN:1167\n@SQ\tSN:chrUn_DS483649v1\tLN:13935\n@SQ\tSN:chrUn_DS484079v1\tLN:2982\n@SQ\tSN:chrUn_DS484065v1\tLN:3043\n@SQ\tSN:chrUn_DS485035v1\tLN:1274\n@SQ\tSN:chrUn_DS485897v1\tLN:1028\n@SQ\tSN:chrUn_DS485503v1\tLN:1123\n@SQ\tSN:chrUn_DS484521v1\tLN:1962\n@SQ\tSN:chrUn_DS484104v1\tLN:2893\n@SQ\tSN:chrUn_DS483863v1\tLN:4305\n@SQ\tSN:chrUn_DS484196v1\tLN:2644\n@SQ\tSN:chrUn_DS484318v1\tLN:2375\n@SQ\tSN:chrUn_DS485955v1\tLN:1014\n@SQ\tSN:chrUn_DS485624v1\tLN:1090\n@SQ\tSN:chrUn_DS484729v1\tLN:1560\n@SQ\tSN:chrUn_DS484573v1\tLN:1890\n@SQ\tSN:chrUn_DS484464v1\tLN:2063\n@SQ\tSN:chrUn_DS483994v1\tLN:3348\n@SQ\tSN:chrUn_DS484013v1\tLN:3252\n@SQ\tSN:chrUn_DS484714v1\tLN:1597\n@SQ\tSN:chrUn_DS484649v1\tLN:1738\n@SQ\tSN:chrUn_DS484543v1\tLN:1931\n@SQ\tSN:chrUn_DS484308v1\tLN:2385\n@SQ\tSN:chrUn_DS485155v1\tLN:1225\n@SQ\tSN:chrUn_DS485107v1\tLN:1239\n@SQ\tSN:chrUn_DS483899v1\tLN:3964\n@SQ\tSN:chrUn_DS485162v1\tLN:1223\n@SQ\tSN:chrUn_DS484108v1\tLN:2882\n@SQ\tSN:chrUn_DS485536v1\tLN:1116\n@SQ\tSN:chrUn_DS485198v1\tLN:1209\n@SQ\tSN:chrUn_DS484699v1\tLN:1629\n@SQ\tSN:chrUn_DS484091v1\tLN:2926\n@SQ\tSN:chrUn_DS485144v1\tLN:1227\n@SQ\tSN:chrUn_DS485256v1\tLN:1190\n@SQ\tSN:chrUn_DS484616v1\tLN:1802\n@SQ\tSN:chrUn_DS484862v1\tLN:1394\n@SQ\tSN:chrUn_DS484754v1\tLN:1527\n@SQ\tSN:chrUn_DS484617v1\tLN:1801\n@SQ\tSN:chrUn_DS484917v1\tLN:1351\n@SQ\tSN:chrUn_DS483646v1\tLN:14098\n@SQ\tSN:chrUn_DS485559v1\tLN:1110\n@SQ\tSN:chrUn_DS484120v1\tLN:2855\n@SQ\tSN:chrUn_DS483983v1\tLN:3396\n@SQ\tSN:chrUn_DS484853v1\tLN:1406\n@SQ\tSN:chrUn_DS484780v1\tLN:1487\n@SQ\tSN:chrUn_DS484145v1\tLN:2804\n@SQ\tSN:chrUn_DS484898v1\tLN:1371\n@SQ\tSN:chrUn_DS484926v1\tLN:1340\n@SQ\tSN:chrUn_DS484592v1\tLN:1851\n@SQ\tSN:chrUn_DS485230v1\tLN:1197\n@SQ\tSN:chrUn_DS484870v1\tLN:1386\n@SQ\tSN:chrUn_DS484581v1\tLN:1870\n@SQ\tSN:chrUn_DS485724v1\tLN:1067\n@SQ\tSN:chrUn_DS485695v2\tLN:564\n@SQ\tSN:chrUn_DS484123v1\tLN:2848\n@SQ\tSN:chrUn_DS483780v1\tLN:5968\n@SQ\tSN:chrUn_DS484007v1\tLN:3262\n@SQ\tSN:chrUn_DS484230v1\tLN:2575\n@SQ\tSN:chrUn_DS483819v1\tLN:4903\n@SQ\tSN:chrUn_DS483898v1\tLN:3970\n@SQ\tSN:chrUn_DS483762v1\tLN:6698\n@SQ\tSN:chrUn_DS483895v1\tLN:4006\n@SQ\tSN:chrUn_DS483929v1\tLN:3717\n@SQ\tSN:chrUn_DS484038v1\tLN:3171\n@SQ\tSN:chrUn_DS483844v1\tLN:4471\n@SQ\tSN:chrUn_DS483806v1\tLN:5098\n@SQ\tSN:chrUn_DS483812v1\tLN:4996\n@SQ\tSN:chrUn_DS483785v1\tLN:5772\n@SQ\tSN:chrUn_DS483943v1\tLN:3638\n@SQ\tSN:chrUn_DS483753v1\tLN:7123\n@SQ\tSN:chrUn_DS484045v1\tLN:3129\n@SQ\tSN:chrUn_DS484144v1\tLN:2811\n@SQ\tSN:chrUn_DS483925v1\tLN:3755\n@SQ\tSN:chrUn_DS483787v1\tLN:5698\n@SQ\tSN:chrUn_DS483865v1\tLN:4289\n@SQ\tSN:chrUn_DS484090v1\tLN:2927\n@SQ\tSN:chrUn_DS483757v1\tLN:6900\n@SQ\tSN:chrUn_DS484010v1\tLN:3259\n@SQ\tSN:chrUn_DS484247v1\tLN:2529\n@SQ\tSN:chrUn_DS483751v1\tLN:7314\n@SQ\tSN:chrUn_DS484280v1\tLN:2438\n@SQ\tSN:chrUn_DS484167v1\tLN:2745\n@SQ\tSN:chrUn_DS483918v1\tLN:3818\n@SQ\tSN:chrUn_DS484414v1\tLN:2157\n@SQ\tSN:chrUn_DS484134v1\tLN:2828\n@SQ\tSN:chrUn_DS483833v1\tLN:4701\n@SQ\tSN:chrUn_DS483878v1\tLN:4182\n@SQ\tSN:chrUn_DS484053v1\tLN:3085\n@SQ\tSN:chrUn_DS483859v1\tLN:4336\n@SQ\tSN:chrUn_DS483793v1\tLN:5463\n@SQ\tSN:chrUn_DS483774v1\tLN:6041\n@SQ\tSN:chrUn_DS483770v1\tLN:6193\n@SQ\tSN:chrUn_DS484225v1\tLN:2577\n@SQ\tSN:chrUn_DS483947v1\tLN:3603\n@SQ\tSN:chrUn_DS484006v1\tLN:3268\n@SQ\tSN:chrUn_DS483954v1\tLN:3554\n@SQ\tSN:chrUn_DS483982v1\tLN:3402\n@SQ\tSN:chrUn_DS484222v1\tLN:2583\n@SQ\tSN:chrUn_DS484092v1\tLN:2924\n@SQ\tSN:chrUn_DS483647v1\tLN:14028\n@SQ\tSN:chrUn_DS484095v1\tLN:2919\n@SQ\tSN:chrUn_DS483776v1\tLN:6000\n@SQ\tSN:chrUn_DS484209v1\tLN:2618\n@SQ\tSN:chrUn_DS483927v1\tLN:3737\n@SQ\tSN:chrUn_DS484234v1\tLN:2561\n@SQ\tSN:chrUn_DS483992v1\tLN:3365\n@SQ\tSN:chrUn_DS484036v1\tLN:3174\n@SQ\tSN:chrUn_DS483986v1\tLN:3386\n@SQ\tSN:chrUn_DS484031v1\tLN:3190\n@SQ\tSN:chrUn_DS483813v1\tLN:4994\n@SQ\tSN:chrUn_DS483881v1\tLN:4135\n@SQ\tSN:chrUn_DS484296v1\tLN:2417\n@SQ\tSN:chrUn_DS483949v1\tLN:3593\n@SQ\tSN:chrUn_DS484000v1\tLN:3302\n@SQ\tSN:chrUn_DS483941v1\tLN:3646\n@SQ\tSN:chrUn_DS483985v1\tLN:3389\n@SQ\tSN:chrUn_DS484375v1\tLN:2234\n@SQ\tSN:chrUn_DS483998v1\tLN:3313\n@SQ\tSN:chrUn_DS484068v1\tLN:3013\n@SQ\tSN:chrUn_DS484353v1\tLN:2295\n@SQ\tSN:chrUn_DS483810v1\tLN:5026\n@SQ\tSN:chrUn_DS484018v1\tLN:3223\n@SQ\tSN:chrUn_DS483817v1\tLN:4933\n@SQ\tSN:chrUn_DS483999v1\tLN:3308\n@SQ\tSN:chrUn_DS483724v1\tLN:13501\n@SQ\tSN:chrUn_DS484256v1\tLN:2511\n@SQ\tSN:chrUn_DS484391v1\tLN:2205\n@SQ\tSN:chrUn_DS484539v1\tLN:1936\n@SQ\tSN:chrUn_DS483937v1\tLN:3660\n@SQ\tSN:chrUn_DS483828v1\tLN:4785\n@SQ\tSN:chrUn_DS484113v1\tLN:2876\n@SQ\tSN:chrUn_DS483811v1\tLN:5000\n@SQ\tSN:chrUn_DS484432v1\tLN:2112\n@SQ\tSN:chrUn_DS483832v1\tLN:4705\n@SQ\tSN:chrUn_DS484386v1\tLN:2216\n@SQ\tSN:chrUn_DS483896v1\tLN:3991\n@SQ\tSN:chrUn_DS484294v1\tLN:2419\n@SQ\tSN:chrUn_DS484426v1\tLN:2119\n@SQ\tSN:chrUn_DS483800v1\tLN:5316\n@SQ\tSN:chrUn_DS483763v1\tLN:6546\n@SQ\tSN:chrUn_DS484289v1\tLN:2425\n@SQ\tSN:chrUn_DS484865v1\tLN:1391\n@SQ\tSN:chrUn_DS483839v1\tLN:4581\n@SQ\tSN:chrUn_DS483880v1\tLN:4150\n@SQ\tSN:chrUn_DS483951v1\tLN:3574\n@SQ\tSN:chrUn_DS483781v1\tLN:5952\n@SQ\tSN:chrUn_DS483798v1\tLN:5324\n@SQ\tSN:chrUn_DS483641v1\tLN:14503\n@SQ\tSN:chrUn_DS483861v1\tLN:4310\n@SQ\tSN:chrUn_DS484872v1\tLN:1385\n@SQ\tSN:chrUn_DS485098v1\tLN:1242\n@SQ\tSN:chrUn_DS484292v1\tLN:2421\n@SQ\tSN:chrUn_DS485935v1\tLN:1019\n@SQ\tSN:chrUn_DS483900v1\tLN:3960\n@SQ\tSN:chrUn_DS485601v1\tLN:1099\n@SQ\tSN:chrUn_DS484009v1\tLN:3259\n@SQ\tSN:chrUn_DS485385v1\tLN:1153\n@SQ\tSN:chrUn_DS485259v1\tLN:1189\n@SQ\tSN:chrUn_DS485182v1\tLN:1213\n@SQ\tSN:chrUn_DS483960v1\tLN:3527\n@SQ\tSN:chrUn_DS484735v1\tLN:1553\n@SQ\tSN:chrUn_DS484224v1\tLN:2577\n@SQ\tSN:chrUn_DS484363v1\tLN:2270\n@SQ\tSN:chrUn_DS483760v1\tLN:6825\n@SQ\tSN:chrUn_DS484652v1\tLN:1733\n@SQ\tSN:chrUn_DS485548v1\tLN:1112\n@SQ\tSN:chrUn_DS483910v1\tLN:3906\n@SQ\tSN:chrUn_DS485424v1\tLN:1143\n@SQ\tSN:chrUn_DS484848v1\tLN:1410\n@SQ\tSN:chrUn_DS484176v1\tLN:2708\n@SQ\tSN:chrUn_DS483807v1\tLN:5061\n@SQ\tSN:chrUn_DS483796v1\tLN:5383\n@SQ\tSN:chrUn_DS483754v1\tLN:7003\n@SQ\tSN:chrUn_DS483758v1\tLN:6860\n@SQ\tSN:chrUn_DS483846v1\tLN:4452\n@SQ\tSN:chrUn_DS484317v1\tLN:2378\n@SQ\tSN:chrUn_DS483744v1\tLN:9865\n@SQ\tSN:chrUn_DS483709v1\tLN:18299\n@SQ\tSN:chrUn_DS483874v1\tLN:4202\n@SQ\tSN:chrUn_DS483629v1\tLN:15417\n@SQ\tSN:chrUn_CP007071v1\tLN:19956\n@SQ\tSN:chrUn_CP007072v1\tLN:44411\n@SQ\tSN:chrUn_CP007073v1\tLN:13157\n@SQ\tSN:chrUn_CP007074v1\tLN:76224\n@SQ\tSN:chrUn_CP007075v1\tLN:11983\n@SQ\tSN:chrUn_CP007076v1\tLN:87365\n@SQ\tSN:chrUn_CP007077v1\tLN:36913\n@SQ\tSN:chrUn_CP007078v1\tLN:22604\n@SQ\tSN:chrUn_CP007079v1\tLN:23238\n@SQ\tSN:chrUn_CP007082v1\tLN:36482\n@SQ\tSN:chrUn_CP007083v1\tLN:25537\n@SQ\tSN:chrUn_CP007084v1\tLN:62570\n@SQ\tSN:chrUn_CP007085v1\tLN:45120\n@SQ\tSN:chrUn_CP007086v1\tLN:22882\n@SQ\tSN:chrUn_CP007087v1\tLN:46986\n@SQ\tSN:chrUn_CP007088v1\tLN:37106\n@SQ\tSN:chrUn_CP007089v1\tLN:16157\n@SQ\tSN:chrUn_CP007090v1\tLN:57785\n@SQ\tSN:chrUn_CP007091v1\tLN:20763\n@SQ\tSN:chrUn_CP007092v1\tLN:28305\n@SQ\tSN:chrUn_CP007093v1\tLN:25698\n@SQ\tSN:chrUn_CP007094v1\tLN:29583\n@SQ\tSN:chrUn_CP007095v1\tLN:25560\n@SQ\tSN:chrUn_CP007096v1\tLN:26115\n@SQ\tSN:chrUn_CP007080v1\tLN:86267\n@SQ\tSN:chrUn_CP007097v1\tLN:13455\n@SQ\tSN:chrUn_CP007098v1\tLN:43383\n@SQ\tSN:chrUn_CP007099v1\tLN:12632\n@SQ\tSN:chrUn_CP007100v1\tLN:10091\n@SQ\tSN:chrUn_CP007101v1\tLN:24503\n@SQ\tSN:chrUn_CP007081v1\tLN:88768\n@SQ\tSN:chrUn_CP007105v1\tLN:47411\n@SQ\tSN:chrUn_DS483562v1\tLN:50625\n@SQ\tSN:chrUn_CP007120v1\tLN:76973\n@SQ\tSN:chrX\tLN:23542271\n@SQ\tSN:chrX_DS484701v1_random\tLN:1625\n@SQ\tSN:chrX_DS484968v1_random\tLN:1311\n@SQ\tSN:chrX_DS484668v1_random\tLN:1709\n@SQ\tSN:chrX_DS484664v1_random\tLN:1713\n@SQ\tSN:chrX_DS484272v1_random\tLN:2464\n@SQ\tSN:chrX_DS485077v1_random\tLN:1258\n@SQ\tSN:chrX_DS484084v1_random\tLN:2956\n@SQ\tSN:chrX_DS484161v1_random\tLN:2781\n@SQ\tSN:chrX_DS484284v1_random\tLN:2432\n@SQ\tSN:chrX_DS484459v1_random\tLN:2078\n@SQ\tSN:chrX_DS484765v1_random\tLN:1516\n@SQ\tSN:chrX_DS484622v1_random\tLN:1793\n@SQ\tSN:chrX_DS484526v1_random\tLN:1956\n@SQ\tSN:chrX_DS485994v1_random\tLN:1004\n@SQ\tSN:chrX_DS485235v1_random\tLN:1195\n@SQ\tSN:chrX_DS484745v1_random\tLN:1541\n@SQ\tSN:chrX_DS484507v1_random\tLN:1978\n@SQ\tSN:chrX_DS484074v1_random\tLN:2999\n@SQ\tSN:chrX_DS485618v1_random\tLN:1092\n@SQ\tSN:chrX_DS485797v1_random\tLN:1049\n@SQ\tSN:chrX_DS484367v1_random\tLN:2259\n@SQ\tSN:chrX_DS484809v1_random\tLN:1453\n@SQ\tSN:chrX_DS484965v1_random\tLN:1312\n@SQ\tSN:chrX_DS484585v1_random\tLN:1869\n@SQ\tSN:chrX_DS485172v1_random\tLN:1220\n@SQ\tSN:chrX_DS484219v1_random\tLN:2591\n@SQ\tSN:chrX_DS484650v1_random\tLN:1737\n@SQ\tSN:chrX_DS484730v1_random\tLN:1560\n@SQ\tSN:chrX_DS484200v1_random\tLN:2639\n@SQ\tSN:chrX_DS484512v1_random\tLN:1970\n@SQ\tSN:chrX_DS484582v1_random\tLN:1870\n@SQ\tSN:chrX_DS484529v1_random\tLN:1947\n@SQ\tSN:chrX_DS484429v1_random\tLN:2113\n@SQ\tSN:chrX_DS484518v1_random\tLN:1964\n@SQ\tSN:chrX_DS484833v1_random\tLN:1424\n@SQ\tSN:chrX_DS484724v1_random\tLN:1575\n@SQ\tSN:chrX_DS485015v1_random\tLN:1283\n@SQ\tSN:chrX_DS484594v1_random\tLN:1843\n@SQ\tSN:chrX_DS485606v1_random\tLN:1097\n@SQ\tSN:chrX_DS484819v1_random\tLN:1441\n@SQ\tSN:chrX_DS484358v1_random\tLN:2286\n@SQ\tSN:chrX_DS484845v1_random\tLN:1412\n@SQ\tSN:chrX_DS484430v1_random\tLN:2113\n@SQ\tSN:chrX_DS484568v1_random\tLN:1899\n@SQ\tSN:chrX_DS485942v1_random\tLN:1018\n@SQ\tSN:chrX_DS484583v1_random\tLN:1869\n@SQ\tSN:chrX_DS484428v1_random\tLN:2114\n@SQ\tSN:chrX_DS485266v1_random\tLN:1186\n@SQ\tSN:chrX_DS484399v1_random\tLN:2192\n@SQ\tSN:chrX_DS485514v1_random\tLN:1121\n@SQ\tSN:chrX_DS484012v1_random\tLN:3254\n@SQ\tSN:chrX_DS484552v1_random\tLN:1920\n@SQ\tSN:chrX_DS485074v1_random\tLN:1258\n@SQ\tSN:chrX_DS484576v1_random\tLN:1888\n@SQ\tSN:chrX_DS484803v1_random\tLN:1461\n@SQ\tSN:chrX_DS485765v1_random\tLN:1056\n@SQ\tSN:chrX_DS484447v1_random\tLN:2089\n@SQ\tSN:chrX_DS485962v1_random\tLN:1012\n@SQ\tSN:chrX_DS485769v1_random\tLN:1055\n@SQ\tSN:chrX_DS484533v1_random\tLN:1944\n@SQ\tSN:chrX_DS484388v1_random\tLN:2209\n@SQ\tSN:chrX_DS484564v1_random\tLN:1902\n@SQ\tSN:chrX_DS484126v1_random\tLN:2841\n@SQ\tSN:chrX_DS484450v1_random\tLN:2087\n@SQ\tSN:chrX_DS484610v1_random\tLN:1813\n@SQ\tSN:chrX_DS485238v1_random\tLN:1195\n@SQ\tSN:chrX_DS484402v1_random\tLN:2189\n@SQ\tSN:chrX_DS484558v1_random\tLN:1906\n@SQ\tSN:chrX_DS484684v1_random\tLN:1678\n@SQ\tSN:chrX_DS484951v1_random\tLN:1327\n@SQ\tSN:chrX_DS484679v1_random\tLN:1683\n@SQ\tSN:chrX_DS484691v1_random\tLN:1643\n@SQ\tSN:chrX_DS484647v1_random\tLN:1743\n@SQ\tSN:chrX_DS485913v1_random\tLN:1022\n@SQ\tSN:chrX_DS484608v1_random\tLN:1818\n@SQ\tSN:chrX_DS484913v1_random\tLN:1355\n@SQ\tSN:chrX_DS485358v1_random\tLN:1159\n@SQ\tSN:chrX_DS485096v1_random\tLN:1244\n@SQ\tSN:chrX_DS485257v1_random\tLN:1189\n@SQ\tSN:chrX_DS484547v1_random\tLN:1927\n@SQ\tSN:chrX_DS484596v1_random\tLN:1843\n@SQ\tSN:chrX_DS484497v1_random\tLN:1998\n@SQ\tSN:chrX_DS485967v1_random\tLN:1011\n@SQ\tSN:chrX_DS484688v1_random\tLN:1657\n@SQ\tSN:chrX_DS485476v1_random\tLN:1130\n@SQ\tSN:chrX_DS485649v1_random\tLN:1084\n@SQ\tSN:chrX_DS484996v1_random\tLN:1295\n@SQ\tSN:chrX_DS485981v1_random\tLN:1007\n@SQ\tSN:chrX_DS484235v1_random\tLN:2557\n@SQ\tSN:chrX_DS484431v1_random\tLN:2113\n@SQ\tSN:chrX_DS484672v1_random\tLN:1703\n@SQ\tSN:chrX_DS484961v1_random\tLN:1315\n@SQ\tSN:chrX_DS483648v1_random\tLN:13940\n@SQ\tSN:chrX_DS484600v1_random\tLN:1841\n@SQ\tSN:chrX_DS485813v1_random\tLN:1047\n@SQ\tSN:chrX_DS485104v1_random\tLN:1240\n@SQ\tSN:chrX_DS484785v1_random\tLN:1478\n@SQ\tSN:chrX_DS484379v1_random\tLN:2228\n@SQ\tSN:chrX_DS485465v1_random\tLN:1133\n@SQ\tSN:chrX_DS485676v1_random\tLN:1078\n@SQ\tSN:chrX_DS485735v1_random\tLN:1063\n@SQ\tSN:chrX_DS484023v1_random\tLN:3206\n@SQ\tSN:chrX_DS484401v1_random\tLN:2189\n@SQ\tSN:chrX_DS484354v1_random\tLN:2293\n@SQ\tSN:chrX_DS484298v1_random\tLN:2412\n@SQ\tSN:chrX_DS484723v1_random\tLN:1577\n@SQ\tSN:chrX_DS485860v1_random\tLN:1036\n@SQ\tSN:chrX_DS484995v1_random\tLN:1296\n@SQ\tSN:chrX_DS484393v1_random\tLN:2201\n@SQ\tSN:chrX_DS484911v1_random\tLN:1355\n@SQ\tSN:chrX_DS485305v1_random\tLN:1174\n@SQ\tSN:chrX_DS484362v1_random\tLN:2273\n@SQ\tSN:chrX_DS484628v1_random\tLN:1785\n@SQ\tSN:chrX_DS484604v1_random\tLN:1829\n@SQ\tSN:chrX_DS484201v1_random\tLN:2637\n@SQ\tSN:chrX_DS484411v1_random\tLN:2161\n@SQ\tSN:chrX_DS485855v1_random\tLN:1037\n@SQ\tSN:chrX_DS484811v1_random\tLN:1452\n@SQ\tSN:chrX_DS484504v1_random\tLN:1986\n@SQ\tSN:chrX_DS484695v1_random\tLN:1637\n@SQ\tSN:chrX_DS484670v1_random\tLN:1704\n@SQ\tSN:chrX_DS484261v1_random\tLN:2500\n@SQ\tSN:chrX_DS485660v1_random\tLN:1082\n@SQ\tSN:chrX_DS485164v1_random\tLN:1223\n@SQ\tSN:chrX_DS484609v1_random\tLN:1818\n@SQ\tSN:chrX_DS485941v1_random\tLN:1018\n@SQ\tSN:chrX_DS484545v1_random\tLN:1928\n@SQ\tSN:chrX_DS484397v1_random\tLN:2196\n@SQ\tSN:chrX_DS484368v1_random\tLN:2259\n@SQ\tSN:chrX_DS484198v1_random\tLN:2641\n@SQ\tSN:chrX_DS485101v1_random\tLN:1241\n@SQ\tSN:chrX_DS485141v1_random\tLN:1228\n@SQ\tSN:chrX_DS484625v1_random\tLN:1787\n@SQ\tSN:chrX_DS484626v1_random\tLN:1786\n@SQ\tSN:chrX_DS485723v1_random\tLN:1067\n@SQ\tSN:chrX_DS484587v1_random\tLN:1865\n@SQ\tSN:chrX_DS485167v1_random\tLN:1221\n@SQ\tSN:chrX_DS485934v1_random\tLN:1019\n@SQ\tSN:chrX_DS484364v1_random\tLN:2269\n@SQ\tSN:chrX_DS485110v1_random\tLN:1238\n@SQ\tSN:chrX_DS484540v1_random\tLN:1935\n@SQ\tSN:chrX_DS484879v1_random\tLN:1381\n@SQ\tSN:chrX_DS484182v1_random\tLN:2689\n@SQ\tSN:chrX_DS484850v1_random\tLN:1408\n@SQ\tSN:chrX_DS485785v1_random\tLN:1051\n@SQ\tSN:chrX_DS484215v1_random\tLN:2605\n@SQ\tSN:chrX_DS484337v1_random\tLN:2335\n@SQ\tSN:chrX_DS485126v1_random\tLN:1233\n@SQ\tSN:chrX_DS484737v1_random\tLN:1550\n@SQ\tSN:chrX_DS485909v1_random\tLN:1023\n@SQ\tSN:chrX_DS484703v1_random\tLN:1622\n@SQ\tSN:chrX_DS484740v1_random\tLN:1546\n@SQ\tSN:chrX_DS484660v1_random\tLN:1716\n@SQ\tSN:chrX_DS484810v1_random\tLN:1452\n@SQ\tSN:chrX_DS485081v1_random\tLN:1252\n@SQ\tSN:chrX_DS484758v1_random\tLN:1525\n@SQ\tSN:chrX_DS484763v1_random\tLN:1519\n@SQ\tSN:chrX_DS484572v1_random\tLN:1891\n@SQ\tSN:chrX_DS484477v1_random\tLN:2035\n@SQ\tSN:chrX_DS485691v1_random\tLN:1074\n@SQ\tSN:chrX_DS485801v1_random\tLN:1048\n@SQ\tSN:chrX_DS485845v1_random\tLN:1040\n@SQ\tSN:chrX_DS484101v1_random\tLN:2904\n@SQ\tSN:chrX_DS485573v1_random\tLN:1107\n@SQ\tSN:chrX_DS484690v1_random\tLN:1645\n@SQ\tSN:chrX_DS484598v1_random\tLN:1842\n@SQ\tSN:chrX_DS484406v1_random\tLN:2177\n@SQ\tSN:chrX_DS484349v1_random\tLN:2307\n@SQ\tSN:chrX_DS485987v1_random\tLN:1005\n@SQ\tSN:chrX_DS484555v1_random\tLN:1916\n@SQ\tSN:chrX_DS485687v1_random\tLN:1075\n@SQ\tSN:chrX_DS485109v1_random\tLN:1238\n@SQ\tSN:chrX_DS484569v1_random\tLN:1895\n@SQ\tSN:chrX_DS484648v1_random\tLN:1741\n@SQ\tSN:chrX_DS484483v1_random\tLN:2021\n@SQ\tSN:chrX_DS485856v1_random\tLN:1037\n@SQ\tSN:chrX_DS484633v1_random\tLN:1775\n@SQ\tSN:chrX_DS484500v1_random\tLN:1993\n@SQ\tSN:chrX_DS484136v1_random\tLN:2823\n@SQ\tSN:chrX_DS484871v1_random\tLN:1386\n@SQ\tSN:chrX_DS484360v1_random\tLN:2283\n@SQ\tSN:chrX_DS485852v1_random\tLN:1038\n@SQ\tSN:chrX_DS484415v1_random\tLN:2147\n@SQ\tSN:chrX_DS484570v1_random\tLN:1895\n@SQ\tSN:chrX_DS484783v1_random\tLN:1482\n@SQ\tSN:chrX_DS484288v1_random\tLN:2425\n@SQ\tSN:chrX_DS484778v1_random\tLN:1488\n@SQ\tSN:chrX_DS484955v1_random\tLN:1323\n@SQ\tSN:chrX_DS484252v1_random\tLN:2520\n@SQ\tSN:chrX_DS484935v1_random\tLN:1336\n@SQ\tSN:chrX_DS485620v1_random\tLN:1091\n@SQ\tSN:chrX_DS485898v1_random\tLN:1028\n@SQ\tSN:chrX_DS485782v1_random\tLN:1052\n@SQ\tSN:chrX_DS484880v1_random\tLN:1380\n@SQ\tSN:chrX_DS484840v1_random\tLN:1419\n@SQ\tSN:chrX_DS484837v1_random\tLN:1423\n@SQ\tSN:chrX_DS484698v1_random\tLN:1630\n@SQ\tSN:chrX_DS484442v1_random\tLN:2096\n@SQ\tSN:chrX_DS485771v1_random\tLN:1055\n@SQ\tSN:chrX_DS484644v1_random\tLN:1747\n@SQ\tSN:chrX_DS485084v1_random\tLN:1251\n@SQ\tSN:chrX_DS484323v1_random\tLN:2363\n@SQ\tSN:chrX_DS484457v1_random\tLN:2079\n@SQ\tSN:chrX_DS484112v1_random\tLN:2877\n@SQ\tSN:chrX_DS484741v1_random\tLN:1544\n@SQ\tSN:chrX_DS484786v1_random\tLN:1476\n@SQ\tSN:chrX_DS485745v1_random\tLN:1062\n@SQ\tSN:chrX_DS484409v1_random\tLN:2166\n@SQ\tSN:chrX_DS484590v1_random\tLN:1856\n@SQ\tSN:chrX_DS484890v1_random\tLN:1376\n@SQ\tSN:chrX_DS485043v1_random\tLN:1271\n@SQ\tSN:chrX_DS484731v1_random\tLN:1558\n@SQ\tSN:chrX_DS484768v1_random\tLN:1509\n@SQ\tSN:chrX_DS484114v1_random\tLN:2871\n@SQ\tSN:chrX_DS484611v1_random\tLN:1813\n@SQ\tSN:chrX_DS484519v1_random\tLN:1963\n@SQ\tSN:chrX_DS485599v1_random\tLN:1100\n@SQ\tSN:chrX_DS485111v1_random\tLN:1238\n@SQ\tSN:chrX_DS485378v1_random\tLN:1155\n@SQ\tSN:chrX_DS483963v1_random\tLN:3523\n@SQ\tSN:chrX_DS484605v1_random\tLN:1829\n@SQ\tSN:chrX_DS485471v1_random\tLN:1131\n@SQ\tSN:chrX_DS484657v1_random\tLN:1724\n@SQ\tSN:chrX_DS484305v1_random\tLN:2389\n@SQ\tSN:chrX_DS485635v1_random\tLN:1088\n@SQ\tSN:chrX_DS485277v1_random\tLN:1184\n@SQ\tSN:chrX_DS484597v1_random\tLN:1843\n@SQ\tSN:chrX_DS484178v1_random\tLN:2698\n@SQ\tSN:chrX_DS485262v1_random\tLN:1189\n@SQ\tSN:chrX_DS485478v1_random\tLN:1129\n@SQ\tSN:chrX_DS484683v1_random\tLN:1679\n@SQ\tSN:chrX_DS485334v1_random\tLN:1164\n@SQ\tSN:chrX_DS485112v1_random\tLN:1238\n@SQ\tSN:chrX_DS484506v1_random\tLN:1980\n@SQ\tSN:chrX_DS485336v1_random\tLN:1163\n@SQ\tSN:chrX_DS483669v1_random\tLN:12848\n@SQ\tSN:chrX_DS483655v1_random\tLN:13549\n@SQ\tSN:chrX_DS485959v1_random\tLN:1013\n@SQ\tSN:chrX_DS485300v1_random\tLN:1178\n@SQ\tSN:chrX_DS485050v1_random\tLN:1268\n@SQ\tSN:chrX_DS484260v1_random\tLN:2505\n@SQ\tSN:chrX_DS484444v1_random\tLN:2094\n@SQ\tSN:chrX_DS484694v1_random\tLN:1637\n@SQ\tSN:chrX_DS484677v1_random\tLN:1687\n@SQ\tSN:chrX_DS484777v1_random\tLN:1489\n@SQ\tSN:chrX_DS485617v1_random\tLN:1093\n@SQ\tSN:chrX_DS484839v1_random\tLN:1421\n@SQ\tSN:chrX_DS485080v1_random\tLN:1253\n@SQ\tSN:chrX_DS484560v1_random\tLN:1904\n@SQ\tSN:chrX_DS484928v1_random\tLN:1340\n@SQ\tSN:chrX_DS484775v1_random\tLN:1492\n@SQ\tSN:chrX_DS484535v1_random\tLN:1939\n@SQ\tSN:chrX_DS484725v1_random\tLN:1573\n@SQ\tSN:chrX_DS484682v1_random\tLN:1680\n@SQ\tSN:chrX_DS484618v1_random\tLN:1800\n@SQ\tSN:chrX_DS484952v1_random\tLN:1326\n@SQ\tSN:chrX_DS484599v1_random\tLN:1841\n@SQ\tSN:chrX_DS484072v1_random\tLN:3002\n@SQ\tSN:chrX_DS484137v1_random\tLN:2822\n@SQ\tSN:chrX_DS485836v1_random\tLN:1042\n@SQ\tSN:chrX_DS484419v1_random\tLN:2132\n@SQ\tSN:chrX_DS484357v1_random\tLN:2287\n@SQ\tSN:chrX_DS485798v1_random\tLN:1049\n@SQ\tSN:chrX_DS484344v1_random\tLN:2322\n@SQ\tSN:chrX_DS484623v1_random\tLN:1792\n@SQ\tSN:chrX_DS485537v1_random\tLN:1115\n@SQ\tSN:chrX_DS484057v1_random\tLN:3076\n@SQ\tSN:chrX_DS485899v1_random\tLN:1027\n@SQ\tSN:chrX_DS484832v1_random\tLN:1425\n@SQ\tSN:chrX_DS485950v1_random\tLN:1015\n@SQ\tSN:chrX_DS483995v1_random\tLN:3347\n@SQ\tSN:chrX_DS485603v1_random\tLN:1098\n@SQ\tSN:chrX_DS484733v1_random\tLN:1556\n@SQ\tSN:chrX_DS484541v1_random\tLN:1933\n@SQ\tSN:chrX_DS484085v1_random\tLN:2945\n@SQ\tSN:chrX_DS484165v1_random\tLN:2751\n@SQ\tSN:chrX_DS485271v1_random\tLN:1185\n@SQ\tSN:chrX_DS485790v1_random\tLN:1051\n@SQ\tSN:chrX_DS484753v1_random\tLN:1529\n@SQ\tSN:chrX_DS484645v1_random\tLN:1747\n@SQ\tSN:chrX_DS484669v1_random\tLN:1708\n@SQ\tSN:chrX_DS484162v1_random\tLN:2765\n@SQ\tSN:chrX_DS484374v1_random\tLN:2237\n@SQ\tSN:chrX_DS485189v1_random\tLN:1211\n@SQ\tSN:chrX_DS484603v1_random\tLN:1830\n@SQ\tSN:chrX_DS485195v1_random\tLN:1209\n@SQ\tSN:chrX_DS484580v1_random\tLN:1871\n@SQ\tSN:chrX_DS485351v1_random\tLN:1161\n@SQ\tSN:chrX_DS484433v1_random\tLN:2109\n@SQ\tSN:chrX_DS485738v1_random\tLN:1063\n@SQ\tSN:chrX_DS484423v1_random\tLN:2126\n@SQ\tSN:chrX_DS485879v1_random\tLN:1031\n@SQ\tSN:chrX_DS484702v1_random\tLN:1623\n@SQ\tSN:chrX_DS484636v1_random\tLN:1769\n@SQ\tSN:chrX_DS485762v1_random\tLN:1057\n@SQ\tSN:chrX_DS485012v1_random\tLN:1284\n@SQ\tSN:chrX_DS484474v1_random\tLN:2044\n@SQ\tSN:chrX_DS485278v1_random\tLN:1184\n@SQ\tSN:chrX_DS484322v1_random\tLN:2366\n@SQ\tSN:chrX_DS484974v1_random\tLN:1309\n@SQ\tSN:chrX_DS484135v1_random\tLN:2825\n@SQ\tSN:chrX_DS484826v1_random\tLN:1432\n@SQ\tSN:chrX_DS485816v1_random\tLN:1046\n@SQ\tSN:chrX_DS483665v1_random\tLN:13234\n@SQ\tSN:chrX_DS484067v1_random\tLN:3024\n@SQ\tSN:chrX_DS485672v1_random\tLN:1078\n@SQ\tSN:chrX_DS484005v1_random\tLN:3275\n@SQ\tSN:chrX_DS483971v1_random\tLN:3478\n@SQ\tSN:chrX_DS485303v1_random\tLN:1175\n@SQ\tSN:chrX_DS484143v1_random\tLN:2814\n@SQ\tSN:chrX_DS484346v1_random\tLN:2317\n@SQ\tSN:chrX_DS485299v1_random\tLN:1178\n@SQ\tSN:chrX_DS484384v1_random\tLN:2220\n@SQ\tSN:chrX_DS484767v1_random\tLN:1510\n@SQ\tSN:chrX_DS485857v1_random\tLN:1037\n@SQ\tSN:chrX_DS485072v1_random\tLN:1260\n@SQ\tSN:chrX_DS484319v1_random\tLN:2372\n@SQ\tSN:chrX_DS485225v1_random\tLN:1200\n@SQ\tSN:chrX_DS485268v1_random\tLN:1186\n@SQ\tSN:chrX_DS484293v1_random\tLN:2420\n@SQ\tSN:chrX_DS484715v1_random\tLN:1595\n@SQ\tSN:chrX_DS485454v1_random\tLN:1135\n@SQ\tSN:chrX_DS484130v1_random\tLN:2834\n@SQ\tSN:chrX_DS484359v1_random\tLN:2284\n@SQ\tSN:chrX_DS483784v1_random\tLN:5832\n@SQ\tSN:chrX_DS485119v1_random\tLN:1235\n@SQ\tSN:chrX_DS484462v1_random\tLN:2068\n@SQ\tSN:chrX_DS485592v1_random\tLN:1102\n@SQ\tSN:chrX_DS485647v1_random\tLN:1086\n@SQ\tSN:chrX_DS484088v1_random\tLN:2937\n@SQ\tSN:chrX_DS485078v1_random\tLN:1257\n@SQ\tSN:chrX_DS483905v1_random\tLN:3926\n@SQ\tSN:chrX_DS484963v1_random\tLN:1315\n@SQ\tSN:chrX_DS483685v1_random\tLN:12187\n@SQ\tSN:chrX_DS484749v1_random\tLN:1534\n@SQ\tSN:chrX_DS484356v1_random\tLN:2289\n@SQ\tSN:chrX_DS485418v1_random\tLN:1145\n@SQ\tSN:chrX_DS484125v1_random\tLN:2844\n@SQ\tSN:chrX_DS484131v1_random\tLN:2833\n@SQ\tSN:chrX_DS484328v1_random\tLN:2355\n@SQ\tSN:chrX_DS483843v1_random\tLN:4515\n@SQ\tSN:chrX_DS484468v1_random\tLN:2060\n@SQ\tSN:chrX_DS485978v1_random\tLN:1008\n@SQ\tSN:chrX_DS485054v1_random\tLN:1265\n@SQ\tSN:chrX_DS483955v1_random\tLN:3553\n@SQ\tSN:chrX_DS483897v1_random\tLN:3984\n@SQ\tSN:chrX_DS484361v1_random\tLN:2282\n@SQ\tSN:chrX_DS485049v1_random\tLN:1269\n@SQ\tSN:chrX_DS484978v1_random\tLN:1306\n@SQ\tSN:chrX_DS484002v1_random\tLN:3290\n@SQ\tSN:chrX_DS485364v1_random\tLN:1158\n@SQ\tSN:chrX_DS484345v1_random\tLN:2318\n@SQ\tSN:chrX_DS485310v1_random\tLN:1173\n@SQ\tSN:chrX_DS485281v1_random\tLN:1184\n@SQ\tSN:chrX_DS485597v1_random\tLN:1100\n@SQ\tSN:chrX_DS485345v1_random\tLN:1161\n@SQ\tSN:chrX_DS484417v1_random\tLN:2139\n@SQ\tSN:chrX_DS483698v1_random\tLN:11522\n@SQ\tSN:chrX_DS484620v1_random\tLN:1798\n@SQ\tSN:chrX_DS485360v1_random\tLN:1159\n@SQ\tSN:chrX_DS485562v1_random\tLN:1109\n@SQ\tSN:chrX_DS485186v1_random\tLN:1212\n@SQ\tSN:chrX_DS485778v1_random\tLN:1053\n@SQ\tSN:chrX_DS485201v1_random\tLN:1208\n@SQ\tSN:chrX_DS485384v1_random\tLN:1153\n@SQ\tSN:chrX_DS485707v1_random\tLN:1071\n@SQ\tSN:chrX_DS483809v1_random\tLN:5057\n@SQ\tSN:chrX_DS484857v1_random\tLN:1402\n@SQ\tSN:chrX_DS484268v1_random\tLN:2475\n@SQ\tSN:chrX_DS484203v1_random\tLN:2635\n@SQ\tSN:chrX_DS484970v1_random\tLN:1310\n@SQ\tSN:chrX_DS483789v1_random\tLN:5555\n@SQ\tSN:chrX_DS484719v1_random\tLN:1586\n@SQ\tSN:chrX_DS484297v1_random\tLN:2413\n@SQ\tSN:chrX_DS484124v1_random\tLN:2846\n@SQ\tSN:chrX_DS485044v1_random\tLN:1271\n@SQ\tSN:chrX_DS484990v1_random\tLN:1301\n@SQ\tSN:chrX_DS484273v1_random\tLN:2463\n@SQ\tSN:chrX_DS485017v1_random\tLN:1281\n@SQ\tSN:chrX_DS484997v1_random\tLN:1294\n@SQ\tSN:chrX_DS483888v1_random\tLN:4072\n@SQ\tSN:chrX_DS485459v1_random\tLN:1134\n@SQ\tSN:chrX_DS485651v1_random\tLN:1084\n@SQ\tSN:chrX_DS484907v1_random\tLN:1361\n@SQ\tSN:chrX_DS485549v1_random\tLN:1112\n@SQ\tSN:chrX_DS484732v1_random\tLN:1556\n@SQ\tSN:chrX_DS484953v1_random\tLN:1326\n@SQ\tSN:chrX_DS483660v1_random\tLN:13394\n@SQ\tSN:chrX_DS484615v1_random\tLN:1803\n@SQ\tSN:chrX_DS484697v1_random\tLN:1636\n@SQ\tSN:chrX_DS484216v1_random\tLN:2603\n@SQ\tSN:chrX_DS485287v1_random\tLN:1181\n@SQ\tSN:chrX_DS484382v1_random\tLN:2223\n@SQ\tSN:chrX_DS484187v1_random\tLN:2671\n@SQ\tSN:chrX_DS485756v1_random\tLN:1058\n@SQ\tSN:chrX_DS484185v1_random\tLN:2686\n@SQ\tSN:chrX_DS485550v1_random\tLN:1112\n@SQ\tSN:chrX_DS483795v1_random\tLN:5387\n@SQ\tSN:chrX_DS484666v1_random\tLN:1710\n@SQ\tSN:chrX_DS483666v1_random\tLN:13108\n@SQ\tSN:chrX_DS484371v1_random\tLN:2247\n@SQ\tSN:chrX_DS483907v1_random\tLN:3921\n@SQ\tSN:chrX_DS484387v1_random\tLN:2210\n@SQ\tSN:chrX_DS484316v1_random\tLN:2379\n@SQ\tSN:chrX_DS483803v1_random\tLN:5232\n@SQ\tSN:chrX_DS483950v1_random\tLN:3582\n@SQ\tSN:chrX_DS483885v1_random\tLN:4085\n@SQ\tSN:chrX_DS483928v1_random\tLN:3730\n@SQ\tSN:chrX_DS484326v1_random\tLN:2357\n@SQ\tSN:chrX_DS483745v1_random\tLN:9368\n@SQ\tSN:chrX_DS483892v1_random\tLN:4013\n@SQ\tSN:chrX_DS484061v1_random\tLN:3059\n@SQ\tSN:chrX_DS484330v1_random\tLN:2353\n@SQ\tSN:chrX_DS484140v1_random\tLN:2819\n@SQ\tSN:chrX_DS484051v1_random\tLN:3100\n@SQ\tSN:chrX_DS483893v1_random\tLN:4012\n@SQ\tSN:chrX_DS484075v1_random\tLN:2996\n@SQ\tSN:chrX_DS483948v1_random\tLN:3602\n@SQ\tSN:chrX_DS484081v1_random\tLN:2964\n@SQ\tSN:chrX_DS484586v1_random\tLN:1868\n@SQ\tSN:chrX_DS484278v1_random\tLN:2439\n@SQ\tSN:chrX_DS484046v1_random\tLN:3123\n@SQ\tSN:chrX_DS484133v1_random\tLN:2829\n@SQ\tSN:chrX_DS483909v1_random\tLN:3913\n@SQ\tSN:chrX_DS484488v1_random\tLN:2009\n@SQ\tSN:chrX_DS483974v1_random\tLN:3473\n@SQ\tSN:chrX_DS483903v1_random\tLN:3941\n@SQ\tSN:chrX_DS484538v1_random\tLN:1936\n@SQ\tSN:chrX_DS483946v1_random\tLN:3603\n@SQ\tSN:chrX_DS484556v1_random\tLN:1916\n@SQ\tSN:chrX_DS483851v1_random\tLN:4395\n@SQ\tSN:chrX_DS483926v1_random\tLN:3745\n@SQ\tSN:chrX_DS484563v1_random\tLN:1903\n@SQ\tSN:chrX_DS483923v1_random\tLN:3775\n@SQ\tSN:chrX_DS484166v1_random\tLN:2750\n@SQ\tSN:chrX_DS484341v1_random\tLN:2328\n@SQ\tSN:chrX_DS484099v1_random\tLN:2910\n@SQ\tSN:chrX_DS484060v1_random\tLN:3065\n@SQ\tSN:chrX_DS484132v1_random\tLN:2830\n@SQ\tSN:chrX_DS483821v1_random\tLN:4879\n@SQ\tSN:chrX_DS483818v1_random\tLN:4917\n@SQ\tSN:chrX_DS484562v1_random\tLN:1903\n@SQ\tSN:chrX_DS483969v1_random\tLN:3498\n@SQ\tSN:chrX_DS484026v1_random\tLN:3201\n@SQ\tSN:chrX_CP007104v1_random\tLN:27447\n@SQ\tSN:chrX_CP007103v1_random\tLN:33320\n@SQ\tSN:chrY\tLN:3667352\n@SQ\tSN:chrY_DS485113v1_random\tLN:1237\n@SQ\tSN:chrY_DS485267v1_random\tLN:1186\n@SQ\tSN:chrY_DS484992v1_random\tLN:1297\n@SQ\tSN:chrY_DS485594v1_random\tLN:1101\n@SQ\tSN:chrY_DS484805v1_random\tLN:1459\n@SQ\tSN:chrY_DS484021v1_random\tLN:3213\n@SQ\tSN:chrY_DS484184v1_random\tLN:2688\n@SQ\tSN:chrY_DS485013v1_random\tLN:1284\n@SQ\tSN:chrY_DS485016v1_random\tLN:1282\n@SQ\tSN:chrY_DS484142v1_random\tLN:2815\n@SQ\tSN:chrY_DS484530v1_random\tLN:1947\n@SQ\tSN:chrY_DS485460v1_random\tLN:1134\n@SQ\tSN:chrY_DS486003v1_random\tLN:1001\n@SQ\tSN:chrY_DS485375v1_random\tLN:1155\n@SQ\tSN:chrY_DS484233v1_random\tLN:2565\n@SQ\tSN:chrY_DS484270v1_random\tLN:2473\n@SQ\tSN:chrY_DS485865v1_random\tLN:1035\n@SQ\tSN:chrY_DS484643v1_random\tLN:1751\n@SQ\tSN:chrY_DS484351v1_random\tLN:2303\n@SQ\tSN:chrY_DS484146v1_random\tLN:2799\n@SQ\tSN:chrY_DS483959v1_random\tLN:3537\n@SQ\tSN:chrY_DS485795v1_random\tLN:1049\n@SQ\tSN:chrY_DS484259v1_random\tLN:2508\n@SQ\tSN:chrY_DS483778v1_random\tLN:5984\n@SQ\tSN:chrY_DS484681v1_random\tLN:1683\n@SQ\tSN:chrY_DS485927v1_random\tLN:1020\n@SQ\tSN:chrY_DS484986v1_random\tLN:1303\n@SQ\tSN:chrY_DS484164v1_random\tLN:2762\n@SQ\tSN:chrY_DS485534v1_random\tLN:1116\n@SQ\tSN:chrY_DS484250v1_random\tLN:2521\n@SQ\tSN:chrY_DS485070v1_random\tLN:1260\n@SQ\tSN:chrY_DS485423v1_random\tLN:1144\n@SQ\tSN:chrY_DS485873v1_random\tLN:1033\n@SQ\tSN:chrY_DS485736v1_random\tLN:1063\n@SQ\tSN:chrY_DS485051v1_random\tLN:1268\n@SQ\tSN:chrY_DS483987v1_random\tLN:3375\n@SQ\tSN:chrY_DS485159v1_random\tLN:1224\n@SQ\tSN:chrY_DS484266v1_random\tLN:2477\n@SQ\tSN:chrY_DS485646v1_random\tLN:1086\n@SQ\tSN:chrY_DS484781v1_random\tLN:1485\n@SQ\tSN:chrY_DS485561v1_random\tLN:1109\n@SQ\tSN:chrY_DS484056v1_random\tLN:3077\n@SQ\tSN:chrY_DS485166v1_random\tLN:1222\n@SQ\tSN:chrY_DS485427v1_random\tLN:1142\n@SQ\tSN:chrY_DS485894v1_random\tLN:1029\n@SQ\tSN:chrY_DS484631v1_random\tLN:1775\n@SQ\tSN:chrY_DS485840v1_random\tLN:1041\n@SQ\tSN:chrY_DS485492v1_random\tLN:1126\n@SQ\tSN:chrY_DS485875v1_random\tLN:1032\n@SQ\tSN:chrY_DS484492v1_random\tLN:2005\n@SQ\tSN:chrY_DS485483v1_random\tLN:1129\n@SQ\tSN:chrY_DS485250v1_random\tLN:1192\n@SQ\tSN:chrY_DS485388v1_random\tLN:1152\n@SQ\tSN:chrY_DS484818v1_random\tLN:1443\n@SQ\tSN:chrY_DS485575v1_random\tLN:1106\n@SQ\tSN:chrY_DS485696v1_random\tLN:1073\n@SQ\tSN:chrY_DS484675v1_random\tLN:1690\n@SQ\tSN:chrY_DS484665v1_random\tLN:1712\n@SQ\tSN:chrY_DS483966v1_random\tLN:3502\n@SQ\tSN:chrY_DS485749v1_random\tLN:1060\n@SQ\tSN:chrY_DS485752v1_random\tLN:1059\n@SQ\tSN:chrY_DS484197v1_random\tLN:2642\n@SQ\tSN:chrY_DS485158v1_random\tLN:1224\n@SQ\tSN:chrY_DS484706v1_random\tLN:1619\n@SQ\tSN:chrY_DS484574v1_random\tLN:1890\n@SQ\tSN:chrY_DS484637v1_random\tLN:1766\n@SQ\tSN:chrY_DS485732v1_random\tLN:1064\n@SQ\tSN:chrY_DS485374v1_random\tLN:1155\n@SQ\tSN:chrY_DS485359v1_random\tLN:1159\n@SQ\tSN:chrY_DS485523v1_random\tLN:1118\n@SQ\tSN:chrY_DS485236v1_random\tLN:1195\n@SQ\tSN:chrY_DS485399v1_random\tLN:1148\n@SQ\tSN:chrY_DS484049v1_random\tLN:3102\n@SQ\tSN:chrY_DS485767v1_random\tLN:1056\n@SQ\tSN:chrY_DS484037v1_random\tLN:3173\n@SQ\tSN:chrY_DS485975v1_random\tLN:1010\n@SQ\tSN:chrY_DS485560v1_random\tLN:1110\n@SQ\tSN:chrY_DS484249v1_random\tLN:2522\n@SQ\tSN:chrY_DS485938v1_random\tLN:1019\n@SQ\tSN:chrY_DS485329v1_random\tLN:1166\n@SQ\tSN:chrY_DS484523v1_random\tLN:1961\n@SQ\tSN:chrY_DS485042v1_random\tLN:1271\n@SQ\tSN:chrY_DS485901v1_random\tLN:1027\n@SQ\tSN:chrY_DS484863v1_random\tLN:1393\n@SQ\tSN:chrY_DS485343v1_random\tLN:1162\n@SQ\tSN:chrY_DS485772v1_random\tLN:1054\n@SQ\tSN:chrY_DS484994v1_random\tLN:1297\n@SQ\tSN:chrY_DS485328v1_random\tLN:1166\n@SQ\tSN:chrY_DS484336v1_random\tLN:2342\n@SQ\tSN:chrY_DS485178v1_random\tLN:1218\n@SQ\tSN:chrY_DS485409v1_random\tLN:1147\n@SQ\tSN:chrY_DS485764v1_random\tLN:1056\n@SQ\tSN:chrY_DS484128v1_random\tLN:2836\n@SQ\tSN:chrY_DS485739v1_random\tLN:1063\n@SQ\tSN:chrY_DS485452v1_random\tLN:1136\n@SQ\tSN:chrY_DS484909v1_random\tLN:1356\n@SQ\tSN:chrY_DS485641v1_random\tLN:1087\n@SQ\tSN:chrY_DS484956v1_random\tLN:1322\n@SQ\tSN:chrY_DS485320v1_random\tLN:1169\n@SQ\tSN:chrY_DS485302v1_random\tLN:1176\n@SQ\tSN:chrY_DS485440v1_random\tLN:1139\n@SQ\tSN:chrY_DS485685v1_random\tLN:1075\n@SQ\tSN:chrY_DS483967v1_random\tLN:3499\n@SQ\tSN:chrY_DS484908v1_random\tLN:1360\n@SQ\tSN:chrY_DS484945v1_random\tLN:1330\n@SQ\tSN:chrY_DS485718v1_random\tLN:1068\n@SQ\tSN:chrY_DS485099v1_random\tLN:1241\n@SQ\tSN:chrY_DS485839v1_random\tLN:1042\n@SQ\tSN:chrY_DS484589v1_random\tLN:1863\n@SQ\tSN:chrY_DS485048v1_random\tLN:1270\n@SQ\tSN:chrY_DS485363v1_random\tLN:1158\n@SQ\tSN:chrY_DS484103v1_random\tLN:2899\n@SQ\tSN:chrY_DS485532v1_random\tLN:1116\n@SQ\tSN:chrY_DS484942v1_random\tLN:1333\n@SQ\tSN:chrY_DS484983v1_random\tLN:1304\n@SQ\tSN:chrY_DS484680v1_random\tLN:1683\n@SQ\tSN:chrY_DS484441v1_random\tLN:2096\n@SQ\tSN:chrY_DS485604v1_random\tLN:1098\n@SQ\tSN:chrY_DS485960v1_random\tLN:1012\n@SQ\tSN:chrY_DS485974v1_random\tLN:1010\n@SQ\tSN:chrY_DS484063v1_random\tLN:3046\n@SQ\tSN:chrY_DS485972v1_random\tLN:1010\n@SQ\tSN:chrY_DS484043v1_random\tLN:3154\n@SQ\tSN:chrY_DS485625v1_random\tLN:1090\n@SQ\tSN:chrY_DS485318v1_random\tLN:1170\n@SQ\tSN:chrY_DS485963v1_random\tLN:1012\n@SQ\tSN:chrY_DS485776v1_random\tLN:1053\n@SQ\tSN:chrY_DS485137v1_random\tLN:1230\n@SQ\tSN:chrY_DS485315v1_random\tLN:1171\n@SQ\tSN:chrY_DS484696v1_random\tLN:1637\n@SQ\tSN:chrY_DS483742v1_random\tLN:11763\n@SQ\tSN:chrY_DS483790v1_random\tLN:5520\n@SQ\tSN:chrY_DS484171v1_random\tLN:2728\n@SQ\tSN:chrY_DS485097v1_random\tLN:1243\n@SQ\tSN:chrY_DS484181v1_random\tLN:2694\n@SQ\tSN:chrY_CP007119v1_random\tLN:11498\n@SQ\tSN:chrY_DS485888v1_random\tLN:1029\n@SQ\tSN:chrY_DS484531v1_random\tLN:1946\n@SQ\tSN:chrY_DS485470v1_random\tLN:1132\n@SQ\tSN:chrY_DS485473v1_random\tLN:1131\n@SQ\tSN:chrY_DS485755v1_random\tLN:1058\n@SQ\tSN:chrY_DS485892v1_random\tLN:1029\n@SQ\tSN:chrY_DS485552v1_random\tLN:1111\n@SQ\tSN:chrY_DS485288v1_random\tLN:1181\n@SQ\tSN:chrY_DS485014v1_random\tLN:1283\n@SQ\tSN:chrY_DS484757v1_random\tLN:1525\n@SQ\tSN:chrY_DS484820v1_random\tLN:1440\n@SQ\tSN:chrY_DS485422v1_random\tLN:1144\n@SQ\tSN:chrY_DS484876v1_random\tLN:1382\n@SQ\tSN:chrY_DS485858v1_random\tLN:1037\n@SQ\tSN:chrY_DS485512v1_random\tLN:1122\n@SQ\tSN:chrY_DS485143v1_random\tLN:1227\n@SQ\tSN:chrY_DS484390v1_random\tLN:2206\n@SQ\tSN:chrY_DS485416v1_random\tLN:1146\n@SQ\tSN:chrY_DS484674v1_random\tLN:1690\n@SQ\tSN:chrY_DS484465v1_random\tLN:2063\n@SQ\tSN:chrY_DS485436v1_random\tLN:1140\n@SQ\tSN:chrY_DS485450v1_random\tLN:1136\n@SQ\tSN:chrY_DS484830v1_random\tLN:1429\n@SQ\tSN:chrY_DS483988v1_random\tLN:3374\n@SQ\tSN:chrY_DS484807v1_random\tLN:1456\n@SQ\tSN:chrY_DS485956v1_random\tLN:1014\n@SQ\tSN:chrY_DS485283v1_random\tLN:1182\n@SQ\tSN:chrY_DS485335v1_random\tLN:1163\n@SQ\tSN:chrY_DS485698v1_random\tLN:1072\n@SQ\tSN:chrY_DS484641v1_random\tLN:1756\n@SQ\tSN:chrY_DS485430v1_random\tLN:1141\n@SQ\tSN:chrY_DS485316v1_random\tLN:1171\n@SQ\tSN:chrY_DS484377v1_random\tLN:2232\n@SQ\tSN:chrY_DS485786v1_random\tLN:1051\n@SQ\tSN:chrY_DS484924v1_random\tLN:1341\n@SQ\tSN:chrY_DS485885v1_random\tLN:1030\n@SQ\tSN:chrY_DS485849v1_random\tLN:1039\n@SQ\tSN:chrY_DS485219v1_random\tLN:1202\n@SQ\tSN:chrY_DS484875v1_random\tLN:1383\n@SQ\tSN:chrY_DS484175v1_random\tLN:2709\n@SQ\tSN:chrY_DS485028v1_random\tLN:1277\n@SQ\tSN:chrY_DS483725v1_random\tLN:13079\n@SQ\tSN:chrY_DS483931v1_random\tLN:3713\n@SQ\tSN:chrY_DS483996v1_random\tLN:3341\n@SQ\tSN:chrY_DS483875v1_random\tLN:4197\n@SQ\tSN:chrY_DS483889v1_random\tLN:4059\n@SQ\tSN:chrY_DS484029v1_random\tLN:3195\n@SQ\tSN:chrY_DS484094v1_random\tLN:2922\n@SQ\tSN:chrY_DS483677v1_random\tLN:12513\n@SQ\tSN:chrY_DS483788v1_random\tLN:5564\n@SQ\tSN:chrY_DS483690v1_random\tLN:12001\n@SQ\tSN:chrY_CP007109v1_random\tLN:66439\n@SQ\tSN:chrY_CP007110v1_random\tLN:33316\n@SQ\tSN:chrY_CP007111v1_random\tLN:34521\n@SQ\tSN:chrY_CP007112v1_random\tLN:39041\n@SQ\tSN:chrY_CP007113v1_random\tLN:34359\n@SQ\tSN:chrY_CP007114v1_random\tLN:31460\n@SQ\tSN:chrY_CP007115v1_random\tLN:21921\n@SQ\tSN:chrY_CP007116v1_random\tLN:25805\n@SQ\tSN:chrY_CP007117v1_random\tLN:24380\n@SQ\tSN:chrY_CP007118v1_random\tLN:44104\n@SQ\tSN:chrY_CP007107v1_random\tLN:73091\n@SQ\tSN:chrY_CP007108v1_random\tLN:66731\n@PG\tID:Bowtie\tVN:1.2.3\tCL:\"bowtie-1.2.3-linux-x86_64/bowtie-align-s --wrapper basic-0 sample_index sample.fastq -S -p 12\"\n"
    elif args.organism_name == "hamster":
        header = "@HD\tVN:1.0\tSO:unsorted\n@SQ\tSN:KB708127.1\tLN:79790405\n@SQ\tSN:KB708128.1\tLN:60928133\n@SQ\tSN:KB708129.1\tLN:44330745\n@SQ\tSN:KB708130.1\tLN:37932696\n@SQ\tSN:KB708131.1\tLN:30845043\n@SQ\tSN:KB708132.1\tLN:30421869\n@SQ\tSN:KB708135.1\tLN:29822074\n@SQ\tSN:KB708134.1\tLN:29670104\n@SQ\tSN:KB708133.1\tLN:28733031\n@SQ\tSN:KB708136.1\tLN:26256861\n@SQ\tSN:KB708139.1\tLN:26018355\n@SQ\tSN:KB708138.1\tLN:25144588\n@SQ\tSN:KB708137.1\tLN:24937227\n@SQ\tSN:KB708141.1\tLN:24491037\n@SQ\tSN:KB708140.1\tLN:24332566\n@SQ\tSN:KB708142.1\tLN:24043102\n@SQ\tSN:KB708143.1\tLN:23545992\n@SQ\tSN:KB708146.1\tLN:23338012\n@SQ\tSN:KB708144.1\tLN:23119872\n@SQ\tSN:KB708145.1\tLN:22253760\n@SQ\tSN:KB708148.1\tLN:22071668\n@SQ\tSN:KB708149.1\tLN:21526299\n@SQ\tSN:KB708147.1\tLN:20666915\n@SQ\tSN:KB708150.1\tLN:20494602\n@SQ\tSN:KB708152.1\tLN:20268197\n@SQ\tSN:KB708156.1\tLN:19995379\n@SQ\tSN:KB708151.1\tLN:19910996\n@SQ\tSN:KB708155.1\tLN:19544038\n@SQ\tSN:KB708154.1\tLN:19452151\n@SQ\tSN:KB708153.1\tLN:19412169\n@SQ\tSN:KB708160.1\tLN:19385306\n@SQ\tSN:KB708157.1\tLN:19353835\n@SQ\tSN:KB708158.1\tLN:18220204\n@SQ\tSN:KB708162.1\tLN:18054249\n@SQ\tSN:KB708159.1\tLN:18013292\n@SQ\tSN:KB708161.1\tLN:17774785\n@SQ\tSN:KB708166.1\tLN:17264671\n@SQ\tSN:KB708163.1\tLN:16966535\n@SQ\tSN:KB708165.1\tLN:16574428\n@SQ\tSN:KB708164.1\tLN:16514833\n@SQ\tSN:KB708167.1\tLN:16010153\n@SQ\tSN:KB708168.1\tLN:15698363\n@SQ\tSN:KB708169.1\tLN:14687589\n@SQ\tSN:KB708173.1\tLN:14681865\n@SQ\tSN:KB708171.1\tLN:14538611\n@SQ\tSN:KB708170.1\tLN:14409287\n@SQ\tSN:KB708172.1\tLN:14115149\n@SQ\tSN:KB708176.1\tLN:13914209\n@SQ\tSN:KB708175.1\tLN:13762990\n@SQ\tSN:KB708178.1\tLN:13623367\n@SQ\tSN:KB708174.1\tLN:13057773\n@SQ\tSN:KB708186.1\tLN:13045859\n@SQ\tSN:KB708179.1\tLN:13024745\n@SQ\tSN:KB708185.1\tLN:12936534\n@SQ\tSN:KB708188.1\tLN:12802638\n@SQ\tSN:KB708181.1\tLN:12768202\n@SQ\tSN:KB708177.1\tLN:12753307\n@SQ\tSN:KB708192.1\tLN:12697732\n@SQ\tSN:KB708180.1\tLN:12409541\n@SQ\tSN:KB708183.1\tLN:12400418\n@SQ\tSN:KB708187.1\tLN:12223339\n@SQ\tSN:KB708184.1\tLN:12142327\n@SQ\tSN:KB708189.1\tLN:12073135\n@SQ\tSN:KB708195.1\tLN:12026347\n@SQ\tSN:KB708193.1\tLN:11978032\n@SQ\tSN:KB708190.1\tLN:11879098\n@SQ\tSN:KB708182.1\tLN:11875786\n@SQ\tSN:KB708191.1\tLN:11631182\n@SQ\tSN:KB708196.1\tLN:11545303\n@SQ\tSN:KB708198.1\tLN:11476413\n@SQ\tSN:KB708197.1\tLN:11359142\n@SQ\tSN:KB708206.1\tLN:11259275\n@SQ\tSN:KB708194.1\tLN:11249547\n@SQ\tSN:KB708208.1\tLN:11212859\n@SQ\tSN:KB708205.1\tLN:11014313\n@SQ\tSN:KB708202.1\tLN:10861382\n@SQ\tSN:KB708199.1\tLN:10803040\n@SQ\tSN:KB708200.1\tLN:10783063\n@SQ\tSN:KB708211.1\tLN:10749540\n@SQ\tSN:KB708203.1\tLN:10458145\n@SQ\tSN:KB708207.1\tLN:10403393\n@SQ\tSN:KB708201.1\tLN:10354366\n@SQ\tSN:KB708204.1\tLN:10228707\n@SQ\tSN:KB708212.1\tLN:10151807\n@SQ\tSN:KB708210.1\tLN:10075012\n@SQ\tSN:KB708209.1\tLN:9922814\n@SQ\tSN:KB708223.1\tLN:9852874\n@SQ\tSN:KB708213.1\tLN:9728819\n@SQ\tSN:KB708220.1\tLN:9671536\n@SQ\tSN:KB708215.1\tLN:9558460\n@SQ\tSN:KB708217.1\tLN:9542452\n@SQ\tSN:KB708218.1\tLN:9428644\n@SQ\tSN:KB708221.1\tLN:9356868\n@SQ\tSN:KB708226.1\tLN:9346862\n@SQ\tSN:KB708216.1\tLN:9330102\n@SQ\tSN:KB708214.1\tLN:9234670\n@SQ\tSN:KB708219.1\tLN:9159762\n@SQ\tSN:KB708222.1\tLN:8981744\n@SQ\tSN:KB708224.1\tLN:8746762\n@SQ\tSN:KB708227.1\tLN:8644782\n@SQ\tSN:KB708231.1\tLN:8601985\n@SQ\tSN:KB708237.1\tLN:8591704\n@SQ\tSN:KB708229.1\tLN:8573706\n@SQ\tSN:KB708233.1\tLN:8537925\n@SQ\tSN:KB708225.1\tLN:8492120\n@SQ\tSN:KB708235.1\tLN:8431132\n@SQ\tSN:KB708234.1\tLN:8393368\n@SQ\tSN:KB708240.1\tLN:8237167\n@SQ\tSN:KB708230.1\tLN:8218496\n@SQ\tSN:KB708232.1\tLN:8211293\n@SQ\tSN:KB708241.1\tLN:8120349\n@SQ\tSN:KB708239.1\tLN:8078759\n@SQ\tSN:KB708228.1\tLN:8054149\n@SQ\tSN:KB708238.1\tLN:8043434\n@SQ\tSN:KB708236.1\tLN:7717420\n@SQ\tSN:KB708248.1\tLN:7605019\n@SQ\tSN:KB708244.1\tLN:7469158\n@SQ\tSN:KB708245.1\tLN:7371250\n@SQ\tSN:KB708243.1\tLN:7341999\n@SQ\tSN:KB708242.1\tLN:7290106\n@SQ\tSN:KB708246.1\tLN:7134131\n@SQ\tSN:KB708250.1\tLN:6998506\n@SQ\tSN:KB708247.1\tLN:6870801\n@SQ\tSN:KB708249.1\tLN:6821335\n@SQ\tSN:KB708251.1\tLN:6474501\n@SQ\tSN:KB708252.1\tLN:6434747\n@SQ\tSN:KB708255.1\tLN:6423614\n@SQ\tSN:KB708256.1\tLN:6182709\n@SQ\tSN:KB708258.1\tLN:6096466\n@SQ\tSN:KB708253.1\tLN:6060195\n@SQ\tSN:KB708254.1\tLN:5944644\n@SQ\tSN:KB708257.1\tLN:5876941\n@SQ\tSN:KB708268.1\tLN:5874022\n@SQ\tSN:KB708262.1\tLN:5808961\n@SQ\tSN:KB708263.1\tLN:5732564\n@SQ\tSN:KB708261.1\tLN:5709260\n@SQ\tSN:KB708260.1\tLN:5660801\n@SQ\tSN:KB708267.1\tLN:5598688\n@SQ\tSN:KB708259.1\tLN:5594869\n@SQ\tSN:KB708264.1\tLN:5476900\n@SQ\tSN:KB708271.1\tLN:5360393\n@SQ\tSN:KB708266.1\tLN:5279663\n@SQ\tSN:KB708265.1\tLN:5218437\n@SQ\tSN:KB708269.1\tLN:5151517\n@SQ\tSN:KB708270.1\tLN:5087502\n@SQ\tSN:KB708280.1\tLN:5037192\n@SQ\tSN:KB708274.1\tLN:4895727\n@SQ\tSN:KB708273.1\tLN:4891347\n@SQ\tSN:KB708287.1\tLN:4844910\n@SQ\tSN:KB708272.1\tLN:4823536\n@SQ\tSN:KB708278.1\tLN:4786942\n@SQ\tSN:KB708275.1\tLN:4758655\n@SQ\tSN:KB708276.1\tLN:4742123\n@SQ\tSN:KB708277.1\tLN:4683292\n@SQ\tSN:KB708285.1\tLN:4538996\n@SQ\tSN:KB708279.1\tLN:4454769\n@SQ\tSN:KB708281.1\tLN:4339578\n@SQ\tSN:KB708288.1\tLN:4285334\n@SQ\tSN:KB708284.1\tLN:4249057\n@SQ\tSN:KB708290.1\tLN:4203244\n@SQ\tSN:KB708286.1\tLN:4179296\n@SQ\tSN:KB708282.1\tLN:4175447\n@SQ\tSN:KB708283.1\tLN:4168212\n@SQ\tSN:KB708303.1\tLN:4057723\n@SQ\tSN:KB708289.1\tLN:4015278\n@SQ\tSN:KB708291.1\tLN:3989979\n@SQ\tSN:KB708294.1\tLN:3973633\n@SQ\tSN:KB708293.1\tLN:3895050\n@SQ\tSN:KB708305.1\tLN:3871155\n@SQ\tSN:KB708292.1\tLN:3799537\n@SQ\tSN:KB708297.1\tLN:3731378\n@SQ\tSN:KB708298.1\tLN:3729730\n@SQ\tSN:KB708295.1\tLN:3667000\n@SQ\tSN:KB708296.1\tLN:3606901\n@SQ\tSN:KB708299.1\tLN:3534699\n@SQ\tSN:KB708301.1\tLN:3522752\n@SQ\tSN:KB708300.1\tLN:3521207\n@SQ\tSN:KB708302.1\tLN:3380474\n@SQ\tSN:KB708306.1\tLN:3363570\n@SQ\tSN:KB708312.1\tLN:3297488\n@SQ\tSN:KB708304.1\tLN:3274853\n@SQ\tSN:KB708309.1\tLN:3225409\n@SQ\tSN:KB708307.1\tLN:3155878\n@SQ\tSN:KB708310.1\tLN:3151410\n@SQ\tSN:KB708316.1\tLN:3147427\n@SQ\tSN:KB708308.1\tLN:3143235\n@SQ\tSN:KB708313.1\tLN:3110003\n@SQ\tSN:KB708311.1\tLN:3027426\n@SQ\tSN:KB708314.1\tLN:2917292\n@SQ\tSN:KB708318.1\tLN:2889929\n@SQ\tSN:KB708324.1\tLN:2808281\n@SQ\tSN:KB708322.1\tLN:2745234\n@SQ\tSN:KB708315.1\tLN:2726510\n@SQ\tSN:KB708326.1\tLN:2683826\n@SQ\tSN:KB708333.1\tLN:2649055\n@SQ\tSN:KB708329.1\tLN:2644817\n@SQ\tSN:KB708321.1\tLN:2637606\n@SQ\tSN:KB708317.1\tLN:2605861\n@SQ\tSN:KB708323.1\tLN:2590651\n@SQ\tSN:KB708320.1\tLN:2569479\n@SQ\tSN:KB708319.1\tLN:2548225\n@SQ\tSN:KB708325.1\tLN:2509250\n@SQ\tSN:KB708327.1\tLN:2494107\n@SQ\tSN:KB708330.1\tLN:2407494\n@SQ\tSN:KB708335.1\tLN:2389236\n@SQ\tSN:KB708328.1\tLN:2387246\n@SQ\tSN:KB708336.1\tLN:2329635\n@SQ\tSN:KB708334.1\tLN:2318271\n@SQ\tSN:KB708337.1\tLN:2231119\n@SQ\tSN:KB708331.1\tLN:2230254\n@SQ\tSN:KB708332.1\tLN:2228813\n@SQ\tSN:KB708340.1\tLN:2084661\n@SQ\tSN:KB708351.1\tLN:2066104\n@SQ\tSN:KB708339.1\tLN:2051779\n@SQ\tSN:KB708338.1\tLN:2033944\n@SQ\tSN:KB708341.1\tLN:1997539\n@SQ\tSN:KB708343.1\tLN:1982826\n@SQ\tSN:KB708342.1\tLN:1975406\n@SQ\tSN:KB708348.1\tLN:1938311\n@SQ\tSN:KB708346.1\tLN:1868164\n@SQ\tSN:KB708345.1\tLN:1841879\n@SQ\tSN:KB708357.1\tLN:1841128\n@SQ\tSN:KB708356.1\tLN:1825678\n@SQ\tSN:KB708350.1\tLN:1819326\n@SQ\tSN:KB708349.1\tLN:1816191\n@SQ\tSN:KB708347.1\tLN:1814582\n@SQ\tSN:KB708352.1\tLN:1810547\n@SQ\tSN:KB708344.1\tLN:1788005\n@SQ\tSN:KB708353.1\tLN:1722140\n@SQ\tSN:KB708354.1\tLN:1691671\n@SQ\tSN:KB708355.1\tLN:1633313\n@SQ\tSN:KB708358.1\tLN:1610936\n@SQ\tSN:KB708360.1\tLN:1578880\n@SQ\tSN:KB708364.1\tLN:1537270\n@SQ\tSN:KB708361.1\tLN:1501238\n@SQ\tSN:KB708362.1\tLN:1459171\n@SQ\tSN:KB708370.1\tLN:1452694\n@SQ\tSN:KB708359.1\tLN:1425900\n@SQ\tSN:KB708366.1\tLN:1425787\n@SQ\tSN:KB708363.1\tLN:1393813\n@SQ\tSN:KB708371.1\tLN:1368821\n@SQ\tSN:KB708365.1\tLN:1358691\n@SQ\tSN:KB708369.1\tLN:1331376\n@SQ\tSN:KB708377.1\tLN:1317208\n@SQ\tSN:KB708380.1\tLN:1284052\n@SQ\tSN:KB708367.1\tLN:1258670\n@SQ\tSN:KB708372.1\tLN:1255218\n@SQ\tSN:KB708376.1\tLN:1243532\n@SQ\tSN:KB708368.1\tLN:1231679\n@SQ\tSN:KB708381.1\tLN:1189481\n@SQ\tSN:KB708384.1\tLN:1174798\n@SQ\tSN:KB708374.1\tLN:1166470\n@SQ\tSN:KB708373.1\tLN:1155500\n@SQ\tSN:KB708378.1\tLN:1118329\n@SQ\tSN:KB708375.1\tLN:1113906\n@SQ\tSN:KB708387.1\tLN:1100842\n@SQ\tSN:KB708379.1\tLN:1053702\n@SQ\tSN:KB708382.1\tLN:1027779\n@SQ\tSN:KB708388.1\tLN:1027503\n@SQ\tSN:KB708383.1\tLN:1025701\n@SQ\tSN:KB708391.1\tLN:994833\n@SQ\tSN:KB708390.1\tLN:988837\n@SQ\tSN:KB708392.1\tLN:988022\n@SQ\tSN:KB708385.1\tLN:986218\n@SQ\tSN:KB708395.1\tLN:982945\n@SQ\tSN:KB708386.1\tLN:950998\n@SQ\tSN:KB708394.1\tLN:940476\n@SQ\tSN:KB708403.1\tLN:937532\n@SQ\tSN:KB708389.1\tLN:932407\n@SQ\tSN:KB708396.1\tLN:930488\n@SQ\tSN:KB708398.1\tLN:924071\n@SQ\tSN:KB708393.1\tLN:922104\n@SQ\tSN:KB708397.1\tLN:919001\n@SQ\tSN:KB708400.1\tLN:887639\n@SQ\tSN:KB708399.1\tLN:860427\n@SQ\tSN:KB708406.1\tLN:858530\n@SQ\tSN:KB708402.1\tLN:827755\n@SQ\tSN:KB708401.1\tLN:787705\n@SQ\tSN:KB708405.1\tLN:758406\n@SQ\tSN:KB708409.1\tLN:754500\n@SQ\tSN:KB708404.1\tLN:741722\n@SQ\tSN:KB708407.1\tLN:726269\n@SQ\tSN:KB708408.1\tLN:725278\n@SQ\tSN:KB708410.1\tLN:705444\n@SQ\tSN:KB708416.1\tLN:698616\n@SQ\tSN:KB708415.1\tLN:660632\n@SQ\tSN:KB708413.1\tLN:651638\n@SQ\tSN:KB708411.1\tLN:628835\n@SQ\tSN:KB708417.1\tLN:622140\n@SQ\tSN:KB708414.1\tLN:601790\n@SQ\tSN:KB708420.1\tLN:596620\n@SQ\tSN:KB708421.1\tLN:590785\n@SQ\tSN:KB708418.1\tLN:588960\n@SQ\tSN:KB708412.1\tLN:583693\n@SQ\tSN:KB708433.1\tLN:568337\n@SQ\tSN:KB708428.1\tLN:564748\n@SQ\tSN:KB708419.1\tLN:560568\n@SQ\tSN:KB708430.1\tLN:554014\n@SQ\tSN:KB708423.1\tLN:551432\n@SQ\tSN:KB708426.1\tLN:533162\n@SQ\tSN:KB708422.1\tLN:512765\n@SQ\tSN:KB708429.1\tLN:493236\n@SQ\tSN:KB708432.1\tLN:484406\n@SQ\tSN:KB708425.1\tLN:480516\n@SQ\tSN:KB708424.1\tLN:464612\n@SQ\tSN:KB708427.1\tLN:455089\n@SQ\tSN:KB708434.1\tLN:440682\n@SQ\tSN:KB708431.1\tLN:440114\n@SQ\tSN:KB708443.1\tLN:417123\n@SQ\tSN:KB708439.1\tLN:401743\n@SQ\tSN:KB708435.1\tLN:382471\n@SQ\tSN:KB708436.1\tLN:382149\n@SQ\tSN:KB708440.1\tLN:380352\n@SQ\tSN:KB708448.1\tLN:378799\n@SQ\tSN:KB708437.1\tLN:378390\n@SQ\tSN:KB708456.1\tLN:374052\n@SQ\tSN:KB708438.1\tLN:363965\n@SQ\tSN:KB708441.1\tLN:355944\n@SQ\tSN:KB708442.1\tLN:345565\n@SQ\tSN:KB708447.1\tLN:331159\n@SQ\tSN:KB708451.1\tLN:329151\n@SQ\tSN:KB708444.1\tLN:327708\n@SQ\tSN:KB708445.1\tLN:320758\n@SQ\tSN:KB708453.1\tLN:317817\n@SQ\tSN:KB708452.1\tLN:314453\n@SQ\tSN:KB708454.1\tLN:310376\n@SQ\tSN:KB708446.1\tLN:309039\n@SQ\tSN:KB708455.1\tLN:293896\n@SQ\tSN:KB708449.1\tLN:293195\n@SQ\tSN:KB708450.1\tLN:279927\n@SQ\tSN:KB708461.1\tLN:270757\n@SQ\tSN:KB708480.1\tLN:270163\n@SQ\tSN:KB708459.1\tLN:268448\n@SQ\tSN:KB708468.1\tLN:266725\n@SQ\tSN:KB708472.1\tLN:265729\n@SQ\tSN:KB708457.1\tLN:264167\n@SQ\tSN:KB708462.1\tLN:262331\n@SQ\tSN:KB708466.1\tLN:253901\n@SQ\tSN:KB708463.1\tLN:253632\n@SQ\tSN:KB708460.1\tLN:252734\n@SQ\tSN:KB708464.1\tLN:247862\n@SQ\tSN:KB708458.1\tLN:242609\n@SQ\tSN:KB708465.1\tLN:240013\n@SQ\tSN:KB708473.1\tLN:234126\n@SQ\tSN:KB708470.1\tLN:232211\n@SQ\tSN:KB708471.1\tLN:222922\n@SQ\tSN:KB708469.1\tLN:215312\n@SQ\tSN:KB708476.1\tLN:212480\n@SQ\tSN:KB708474.1\tLN:209284\n@SQ\tSN:KB708467.1\tLN:208430\n@SQ\tSN:KB708482.1\tLN:203410\n@SQ\tSN:KB708479.1\tLN:199525\n@SQ\tSN:KB708475.1\tLN:199378\n@SQ\tSN:KB708477.1\tLN:198337\n@SQ\tSN:KB708478.1\tLN:187300\n@SQ\tSN:KB708481.1\tLN:178569\n@SQ\tSN:KB708485.1\tLN:174830\n@SQ\tSN:KB708496.1\tLN:174718\n@SQ\tSN:KB708487.1\tLN:172979\n@SQ\tSN:KB708484.1\tLN:171933\n@SQ\tSN:KB708488.1\tLN:171783\n@SQ\tSN:KB708483.1\tLN:170880\n@SQ\tSN:KB708486.1\tLN:162914\n@SQ\tSN:KB708500.1\tLN:161995\n@SQ\tSN:KB708489.1\tLN:156556\n@SQ\tSN:KB708491.1\tLN:154612\n@SQ\tSN:KB708490.1\tLN:152513\n@SQ\tSN:KB708505.1\tLN:149850\n@SQ\tSN:KB708516.1\tLN:148560\n@SQ\tSN:KB708493.1\tLN:145194\n@SQ\tSN:KB708495.1\tLN:142778\n@SQ\tSN:KB708492.1\tLN:142141\n@SQ\tSN:KB708510.1\tLN:140950\n@SQ\tSN:KB708494.1\tLN:140691\n@SQ\tSN:KB708508.1\tLN:140207\n@SQ\tSN:KB708497.1\tLN:139919\n@SQ\tSN:KB708503.1\tLN:139513\n@SQ\tSN:KB708498.1\tLN:139473\n@SQ\tSN:KB708509.1\tLN:136489\n@SQ\tSN:KB708501.1\tLN:132465\n@SQ\tSN:KB708507.1\tLN:131587\n@SQ\tSN:KB708511.1\tLN:131231\n@SQ\tSN:KB708504.1\tLN:130602\n@SQ\tSN:KB708502.1\tLN:127674\n@SQ\tSN:KB708512.1\tLN:126970\n@SQ\tSN:KB708506.1\tLN:126245\n@SQ\tSN:KB708517.1\tLN:120339\n@SQ\tSN:KB708499.1\tLN:119360\n@SQ\tSN:KB708537.1\tLN:118869\n@SQ\tSN:KB708514.1\tLN:118603\n@SQ\tSN:KB708520.1\tLN:118169\n@SQ\tSN:KB708521.1\tLN:117396\n@SQ\tSN:KB708513.1\tLN:115126\n@SQ\tSN:KB708519.1\tLN:113642\n@SQ\tSN:KB708518.1\tLN:113250\n@SQ\tSN:KB708542.1\tLN:111457\n@SQ\tSN:KB708523.1\tLN:110849\n@SQ\tSN:KB708515.1\tLN:108903\n@SQ\tSN:KB708526.1\tLN:108648\n@SQ\tSN:KB708553.1\tLN:108531\n@SQ\tSN:KB708525.1\tLN:108280\n@SQ\tSN:KB708540.1\tLN:107904\n@SQ\tSN:KB708534.1\tLN:107245\n@SQ\tSN:KB708522.1\tLN:105857\n@SQ\tSN:KB708528.1\tLN:103729\n@SQ\tSN:KB708524.1\tLN:102975\n@SQ\tSN:KB708530.1\tLN:101786\n@SQ\tSN:KB708541.1\tLN:100923\n@SQ\tSN:KB708527.1\tLN:100254\n@SQ\tSN:KB708529.1\tLN:99812\n@SQ\tSN:KB708532.1\tLN:99354\n@SQ\tSN:KB708535.1\tLN:98659\n@SQ\tSN:KB708538.1\tLN:96995\n@SQ\tSN:KB708533.1\tLN:96698\n@SQ\tSN:KB708536.1\tLN:96091\n@SQ\tSN:KB708558.1\tLN:95396\n@SQ\tSN:KB708531.1\tLN:94863\n@SQ\tSN:KB708543.1\tLN:93673\n@SQ\tSN:KB708544.1\tLN:93401\n@SQ\tSN:KB708563.1\tLN:92646\n@SQ\tSN:KB708545.1\tLN:92593\n@SQ\tSN:KB708539.1\tLN:91562\n@SQ\tSN:KB708559.1\tLN:91248\n@SQ\tSN:KB708547.1\tLN:91008\n@SQ\tSN:KB708546.1\tLN:90823\n@SQ\tSN:KB708571.1\tLN:88781\n@SQ\tSN:KB708551.1\tLN:88165\n@SQ\tSN:KB708550.1\tLN:87639\n@SQ\tSN:KB708549.1\tLN:86584\n@SQ\tSN:KB708552.1\tLN:86383\n@SQ\tSN:KB708556.1\tLN:85381\n@SQ\tSN:KB708555.1\tLN:85305\n@SQ\tSN:KB708548.1\tLN:85224\n@SQ\tSN:KB708569.1\tLN:84425\n@SQ\tSN:KB708561.1\tLN:82703\n@SQ\tSN:KB708554.1\tLN:82166\n@SQ\tSN:KB708568.1\tLN:82008\n@SQ\tSN:KB708560.1\tLN:80417\n@SQ\tSN:KB708572.1\tLN:80034\n@SQ\tSN:KB708604.1\tLN:79099\n@SQ\tSN:KB708575.1\tLN:78331\n@SQ\tSN:KB708570.1\tLN:77983\n@SQ\tSN:KB708564.1\tLN:77916\n@SQ\tSN:KB708677.1\tLN:77799\n@SQ\tSN:KB708567.1\tLN:77701\n@SQ\tSN:KB708577.1\tLN:76846\n@SQ\tSN:KB708573.1\tLN:76619\n@SQ\tSN:KB708557.1\tLN:75967\n@SQ\tSN:KB708585.1\tLN:75740\n@SQ\tSN:KB708565.1\tLN:74523\n@SQ\tSN:KB708562.1\tLN:74454\n@SQ\tSN:KB708566.1\tLN:74183\n@SQ\tSN:KB708602.1\tLN:73283\n@SQ\tSN:KB708620.1\tLN:72991\n@SQ\tSN:KB708610.1\tLN:72945\n@SQ\tSN:KB708584.1\tLN:72577\n@SQ\tSN:KB708579.1\tLN:72412\n@SQ\tSN:KB708576.1\tLN:72085\n@SQ\tSN:KB708608.1\tLN:71953\n@SQ\tSN:KB708839.1\tLN:71609\n@SQ\tSN:KB708574.1\tLN:71487\n@SQ\tSN:KB708600.1\tLN:71194\n@SQ\tSN:KB708581.1\tLN:70639\n@SQ\tSN:KB708588.1\tLN:70174\n@SQ\tSN:KB708598.1\tLN:68209\n@SQ\tSN:KB708582.1\tLN:67743\n@SQ\tSN:KB708578.1\tLN:67638\n@SQ\tSN:KB708587.1\tLN:67489\n@SQ\tSN:KB708605.1\tLN:66879\n@SQ\tSN:KB708589.1\tLN:66396\n@SQ\tSN:KB708621.1\tLN:66358\n@SQ\tSN:KB708596.1\tLN:66339\n@SQ\tSN:KB708593.1\tLN:64627\n@SQ\tSN:KB708591.1\tLN:64293\n@SQ\tSN:KB708603.1\tLN:63731\n@SQ\tSN:KB708599.1\tLN:63638\n@SQ\tSN:KB708611.1\tLN:63319\n@SQ\tSN:KB708597.1\tLN:62328\n@SQ\tSN:KB708601.1\tLN:62222\n@SQ\tSN:KB708628.1\tLN:61857\n@SQ\tSN:KB708592.1\tLN:61782\n@SQ\tSN:KB708580.1\tLN:61638\n@SQ\tSN:KB708637.1\tLN:61579\n@SQ\tSN:KB708624.1\tLN:61498\n@SQ\tSN:KB708607.1\tLN:61076\n@SQ\tSN:KB708586.1\tLN:60952\n@SQ\tSN:KB708640.1\tLN:60566\n@SQ\tSN:KB708615.1\tLN:60360\n@SQ\tSN:KB708583.1\tLN:60146\n@SQ\tSN:KB708606.1\tLN:59597\n@SQ\tSN:KB708614.1\tLN:59595\n@SQ\tSN:KB708616.1\tLN:59249\n@SQ\tSN:KB708682.1\tLN:59114\n@SQ\tSN:KB708654.1\tLN:59079\n@SQ\tSN:KB708595.1\tLN:58891\n@SQ\tSN:KB708639.1\tLN:58757\n@SQ\tSN:KB708590.1\tLN:58561\n@SQ\tSN:KB708625.1\tLN:58477\n@SQ\tSN:KB708613.1\tLN:58043\n@SQ\tSN:KB708618.1\tLN:57882\n@SQ\tSN:KB708594.1\tLN:57783\n@SQ\tSN:KB708617.1\tLN:57486\n@SQ\tSN:KB708612.1\tLN:57426\n@SQ\tSN:KB708663.1\tLN:57232\n@SQ\tSN:KB708819.1\tLN:57039\n@SQ\tSN:KB708609.1\tLN:57002\n@SQ\tSN:KB708622.1\tLN:56918\n@SQ\tSN:KB708684.1\tLN:56728\n@SQ\tSN:KB708626.1\tLN:56378\n@SQ\tSN:KB708655.1\tLN:56100\n@SQ\tSN:KB708651.1\tLN:55995\n@SQ\tSN:KB708653.1\tLN:55985\n@SQ\tSN:KB708661.1\tLN:55821\n@SQ\tSN:KB708650.1\tLN:55342\n@SQ\tSN:KB708627.1\tLN:55124\n@SQ\tSN:KB708662.1\tLN:54774\n@SQ\tSN:KB708629.1\tLN:54743\n@SQ\tSN:KB708635.1\tLN:54665\n@SQ\tSN:KB708630.1\tLN:54344\n@SQ\tSN:KB708631.1\tLN:54337\n@SQ\tSN:KB708710.1\tLN:54300\n@SQ\tSN:KB708685.1\tLN:54266\n@SQ\tSN:APMT01204937.1\tLN:54189\n@SQ\tSN:KB708686.1\tLN:54183\n@SQ\tSN:KB708633.1\tLN:54098\n@SQ\tSN:KB708638.1\tLN:53872\n@SQ\tSN:KB708642.1\tLN:53825\n@SQ\tSN:KB708623.1\tLN:53527\n@SQ\tSN:KB708648.1\tLN:53416\n@SQ\tSN:KB708707.1\tLN:53152\n@SQ\tSN:KB708678.1\tLN:53141\n@SQ\tSN:KB708619.1\tLN:53066\n@SQ\tSN:KB708725.1\tLN:52972\n@SQ\tSN:KB708645.1\tLN:52955\n@SQ\tSN:KB708644.1\tLN:52870\n@SQ\tSN:KB708646.1\tLN:52859\n@SQ\tSN:KB708701.1\tLN:52857\n@SQ\tSN:KB708737.1\tLN:52692\n@SQ\tSN:KB708688.1\tLN:52654\n@SQ\tSN:KB708643.1\tLN:52640\n@SQ\tSN:KB708660.1\tLN:52327\n@SQ\tSN:KB708698.1\tLN:52216\n@SQ\tSN:KB708649.1\tLN:52202\n@SQ\tSN:KB708680.1\tLN:52195\n@SQ\tSN:KB708656.1\tLN:52091\n@SQ\tSN:KB708683.1\tLN:52039\n@SQ\tSN:KB708636.1\tLN:51924\n@SQ\tSN:KB708657.1\tLN:51822\n@SQ\tSN:KB708641.1\tLN:51724\n@SQ\tSN:KB708689.1\tLN:51666\n@SQ\tSN:KB708659.1\tLN:51609\n@SQ\tSN:KB708676.1\tLN:51553\n@SQ\tSN:KB708632.1\tLN:51535\n@SQ\tSN:KB708665.1\tLN:51488\n@SQ\tSN:KB708668.1\tLN:51189\n@SQ\tSN:KB708658.1\tLN:51162\n@SQ\tSN:KB708695.1\tLN:51029\n@SQ\tSN:KB708778.1\tLN:51005\n@SQ\tSN:KB708673.1\tLN:50993\n@SQ\tSN:KB708694.1\tLN:50960\n@SQ\tSN:APMT01205340.1\tLN:50804\n@SQ\tSN:KB708664.1\tLN:50733\n@SQ\tSN:KB708666.1\tLN:50701\n@SQ\tSN:KB708691.1\tLN:50620\n@SQ\tSN:KB708652.1\tLN:50408\n@SQ\tSN:KB708738.1\tLN:50345\n@SQ\tSN:KB708670.1\tLN:50266\n@SQ\tSN:KB708687.1\tLN:50261\n@SQ\tSN:KB708681.1\tLN:50241\n@SQ\tSN:KB708876.1\tLN:50196\n@SQ\tSN:KB708674.1\tLN:50153\n@SQ\tSN:KB708699.1\tLN:50092\n@SQ\tSN:KB708708.1\tLN:49941\n@SQ\tSN:KB708675.1\tLN:49888\n@SQ\tSN:KB708647.1\tLN:49618\n@SQ\tSN:KB708669.1\tLN:49609\n@SQ\tSN:KB708690.1\tLN:49608\n@SQ\tSN:KB708692.1\tLN:49565\n@SQ\tSN:KB708697.1\tLN:49515\n@SQ\tSN:KB708805.1\tLN:49459\n@SQ\tSN:KB708672.1\tLN:49342\n@SQ\tSN:KB708693.1\tLN:49312\n@SQ\tSN:KB708696.1\tLN:49205\n@SQ\tSN:KB708634.1\tLN:49197\n@SQ\tSN:KB708715.1\tLN:49153\n@SQ\tSN:KB708713.1\tLN:49027\n@SQ\tSN:KB708920.1\tLN:48926\n@SQ\tSN:KB708702.1\tLN:48882\n@SQ\tSN:KB708705.1\tLN:48740\n@SQ\tSN:KB708703.1\tLN:48645\n@SQ\tSN:KB708671.1\tLN:48555\n@SQ\tSN:KB708706.1\tLN:48336\n@SQ\tSN:KB708704.1\tLN:48304\n@SQ\tSN:KB708712.1\tLN:48304\n@SQ\tSN:KB708709.1\tLN:48160\n@SQ\tSN:KB708714.1\tLN:48117\n@SQ\tSN:KB708720.1\tLN:48095\n@SQ\tSN:KB708739.1\tLN:47983\n@SQ\tSN:KB708727.1\tLN:47945\n@SQ\tSN:KB708717.1\tLN:47917\n@SQ\tSN:KB708711.1\tLN:47709\n@SQ\tSN:KB708791.1\tLN:47695\n@SQ\tSN:KB708750.1\tLN:47531\n@SQ\tSN:KB708716.1\tLN:47394\n@SQ\tSN:KB708722.1\tLN:47372\n@SQ\tSN:KB708726.1\tLN:47188\n@SQ\tSN:KB708723.1\tLN:47186\n@SQ\tSN:KB708773.1\tLN:47152\n@SQ\tSN:KB708728.1\tLN:47146\n@SQ\tSN:KB708729.1\tLN:47047\n@SQ\tSN:KB708755.1\tLN:46888\n@SQ\tSN:KB708924.1\tLN:46854\n@SQ\tSN:KB708731.1\tLN:46853\n@SQ\tSN:KB708812.1\tLN:46820\n@SQ\tSN:KB708735.1\tLN:46659\n@SQ\tSN:KB708679.1\tLN:46654\n@SQ\tSN:KB708721.1\tLN:46610\n@SQ\tSN:KB708730.1\tLN:46589\n@SQ\tSN:KB708754.1\tLN:46577\n@SQ\tSN:KB708769.1\tLN:46428\n@SQ\tSN:KB708667.1\tLN:46373\n@SQ\tSN:KB708742.1\tLN:46368\n@SQ\tSN:APMT01205917.1\tLN:46343\n@SQ\tSN:KB708763.1\tLN:46326\n@SQ\tSN:KB708743.1\tLN:46298\n@SQ\tSN:KB708740.1\tLN:46262\n@SQ\tSN:KB708764.1\tLN:46252\n@SQ\tSN:KB708741.1\tLN:46231\n@SQ\tSN:KB708768.1\tLN:46197\n@SQ\tSN:KB708744.1\tLN:46177\n@SQ\tSN:KB708718.1\tLN:46151\n@SQ\tSN:KB708733.1\tLN:46125\n@SQ\tSN:KB708752.1\tLN:46065\n@SQ\tSN:KB708758.1\tLN:46064\n@SQ\tSN:KB708772.1\tLN:46060\n@SQ\tSN:KB708777.1\tLN:46058\n@SQ\tSN:KB708746.1\tLN:46040\n@SQ\tSN:KB708749.1\tLN:46011\n@SQ\tSN:KB708760.1\tLN:45998\n@SQ\tSN:KB708700.1\tLN:45994\n@SQ\tSN:KB708719.1\tLN:45989\n@SQ\tSN:KB708767.1\tLN:45964\n@SQ\tSN:KB708783.1\tLN:45946\n@SQ\tSN:KB708748.1\tLN:45894\n@SQ\tSN:KB708782.1\tLN:45847\n@SQ\tSN:KB708766.1\tLN:45843\n@SQ\tSN:KB708745.1\tLN:45826\n@SQ\tSN:KB708751.1\tLN:45781\n@SQ\tSN:KB708747.1\tLN:45711\n@SQ\tSN:KB708753.1\tLN:45663\n@SQ\tSN:KB708787.1\tLN:45651\n@SQ\tSN:KB708757.1\tLN:45593\n@SQ\tSN:KB708759.1\tLN:45572\n@SQ\tSN:KB708762.1\tLN:45470\n@SQ\tSN:KB708761.1\tLN:45363\n@SQ\tSN:KB708810.1\tLN:45289\n@SQ\tSN:KB708765.1\tLN:45284\n@SQ\tSN:KB708841.1\tLN:45144\n@SQ\tSN:KB708801.1\tLN:45109\n@SQ\tSN:KB708774.1\tLN:45053\n@SQ\tSN:KB708770.1\tLN:45020\n@SQ\tSN:KB708807.1\tLN:45010\n@SQ\tSN:KB708834.1\tLN:44965\n@SQ\tSN:KB708771.1\tLN:44873\n@SQ\tSN:KB708796.1\tLN:44803\n@SQ\tSN:KB708790.1\tLN:44760\n@SQ\tSN:KB708970.1\tLN:44606\n@SQ\tSN:KB708840.1\tLN:44573\n@SQ\tSN:KB708814.1\tLN:44559\n@SQ\tSN:KB708803.1\tLN:44534\n@SQ\tSN:KB708724.1\tLN:44532\n@SQ\tSN:KB708756.1\tLN:44502\n@SQ\tSN:KB708775.1\tLN:44389\n@SQ\tSN:KB708800.1\tLN:44365\n@SQ\tSN:KB708830.1\tLN:44345\n@SQ\tSN:KB708781.1\tLN:44197\n@SQ\tSN:KB708784.1\tLN:44153\n@SQ\tSN:KB708786.1\tLN:44144\n@SQ\tSN:KB708828.1\tLN:44141\n@SQ\tSN:KB708899.1\tLN:44138\n@SQ\tSN:APMT01206202.1\tLN:44114\n@SQ\tSN:KB708809.1\tLN:44113\n@SQ\tSN:KB708788.1\tLN:44070\n@SQ\tSN:KB708785.1\tLN:44030\n@SQ\tSN:KB708776.1\tLN:43970\n@SQ\tSN:KB708832.1\tLN:43932\n@SQ\tSN:KB708795.1\tLN:43925\n@SQ\tSN:KB708793.1\tLN:43901\n@SQ\tSN:KB708734.1\tLN:43865\n@SQ\tSN:KB708799.1\tLN:43861\n@SQ\tSN:KB708797.1\tLN:43815\n@SQ\tSN:KB708779.1\tLN:43723\n@SQ\tSN:KB708804.1\tLN:43614\n@SQ\tSN:KB708856.1\tLN:43613\n@SQ\tSN:KB708806.1\tLN:43506\n@SQ\tSN:KB708813.1\tLN:43458\n@SQ\tSN:KB708789.1\tLN:43450\n@SQ\tSN:KB708811.1\tLN:43444\n@SQ\tSN:KB708802.1\tLN:43400\n@SQ\tSN:KB708798.1\tLN:43388\n@SQ\tSN:KB708865.1\tLN:43333\n@SQ\tSN:KB708831.1\tLN:43322\n@SQ\tSN:KB708816.1\tLN:43320\n@SQ\tSN:KB708843.1\tLN:43320\n@SQ\tSN:KB708866.1\tLN:43242\n@SQ\tSN:KB708822.1\tLN:43220\n@SQ\tSN:KB708808.1\tLN:43173\n@SQ\tSN:KB708815.1\tLN:43136\n@SQ\tSN:KB708823.1\tLN:43124\n@SQ\tSN:KB708820.1\tLN:43075\n@SQ\tSN:KB708821.1\tLN:43042\n@SQ\tSN:KB708838.1\tLN:43019\n@SQ\tSN:KB708792.1\tLN:42915\n@SQ\tSN:KB708827.1\tLN:42914\n@SQ\tSN:KB708826.1\tLN:42912\n@SQ\tSN:KB708853.1\tLN:42845\n@SQ\tSN:KB708854.1\tLN:42797\n@SQ\tSN:KB708857.1\tLN:42741\n@SQ\tSN:KB708890.1\tLN:42723\n@SQ\tSN:KB708818.1\tLN:42719\n@SQ\tSN:KB708833.1\tLN:42699\n@SQ\tSN:KB708794.1\tLN:42624\n@SQ\tSN:KB708835.1\tLN:42607\n@SQ\tSN:KB708817.1\tLN:42556\n@SQ\tSN:KB708868.1\tLN:42551\n@SQ\tSN:KB708825.1\tLN:42543\n@SQ\tSN:KB708837.1\tLN:42516\n@SQ\tSN:KB708736.1\tLN:42513\n@SQ\tSN:KB708844.1\tLN:42435\n@SQ\tSN:APMT01206517.1\tLN:42376\n@SQ\tSN:KB708862.1\tLN:42303\n@SQ\tSN:KB708780.1\tLN:42275\n@SQ\tSN:KB708846.1\tLN:42262\n@SQ\tSN:KB708847.1\tLN:42251\n@SQ\tSN:APMT01206525.1\tLN:42228\n@SQ\tSN:APMT01206526.1\tLN:42214\n@SQ\tSN:KB708852.1\tLN:42210\n@SQ\tSN:KB708845.1\tLN:42169\n@SQ\tSN:KB708848.1\tLN:42074\n@SQ\tSN:KB708842.1\tLN:42038\n@SQ\tSN:KB708860.1\tLN:41978\n@SQ\tSN:KB708849.1\tLN:41923\n@SQ\tSN:APMT01206572.1\tLN:41922\n@SQ\tSN:KB708858.1\tLN:41906\n@SQ\tSN:KB708850.1\tLN:41897\n@SQ\tSN:APMT01206571.1\tLN:41892\n@SQ\tSN:KB708891.1\tLN:41889\n@SQ\tSN:KB708859.1\tLN:41879\n@SQ\tSN:KB708855.1\tLN:41842\n@SQ\tSN:KB708861.1\tLN:41817\n@SQ\tSN:KB708870.1\tLN:41726\n@SQ\tSN:KB708824.1\tLN:41691\n@SQ\tSN:KB708889.1\tLN:41685\n@SQ\tSN:KB708863.1\tLN:41590\n@SQ\tSN:KB708864.1\tLN:41539\n@SQ\tSN:KB708873.1\tLN:41487\n@SQ\tSN:KB708869.1\tLN:41386\n@SQ\tSN:KB708867.1\tLN:41384\n@SQ\tSN:KB708829.1\tLN:41259\n@SQ\tSN:KB708872.1\tLN:41244\n@SQ\tSN:KB708871.1\tLN:41077\n@SQ\tSN:KB708879.1\tLN:40990\n@SQ\tSN:KB708875.1\tLN:40974\n@SQ\tSN:KB708878.1\tLN:40921\n@SQ\tSN:KB708880.1\tLN:40889\n@SQ\tSN:KB708877.1\tLN:40888\n@SQ\tSN:KB708885.1\tLN:40822\n@SQ\tSN:KB708887.1\tLN:40804\n@SQ\tSN:KB708883.1\tLN:40801\n@SQ\tSN:KB708886.1\tLN:40787\n@SQ\tSN:APMT01206693.1\tLN:40705\n@SQ\tSN:APMT01206694.1\tLN:40705\n@SQ\tSN:KB708892.1\tLN:40636\n@SQ\tSN:KB708893.1\tLN:40635\n@SQ\tSN:KB708894.1\tLN:40627\n@SQ\tSN:KB708882.1\tLN:40605\n@SQ\tSN:KB708895.1\tLN:40602\n@SQ\tSN:KB708851.1\tLN:40572\n@SQ\tSN:KB708884.1\tLN:40561\n@SQ\tSN:KB708896.1\tLN:40524\n@SQ\tSN:KB708912.1\tLN:40511\n@SQ\tSN:APMT01206722.1\tLN:40504\n@SQ\tSN:KB708897.1\tLN:40497\n@SQ\tSN:KB708898.1\tLN:40474\n@SQ\tSN:KB708901.1\tLN:40467\n@SQ\tSN:KB708904.1\tLN:40336\n@SQ\tSN:KB708905.1\tLN:40193\n@SQ\tSN:KB708900.1\tLN:40191\n@SQ\tSN:KB708836.1\tLN:40059\n@SQ\tSN:APMT01206761.1\tLN:39732\n@SQ\tSN:KB708888.1\tLN:39507\n@SQ\tSN:KB708881.1\tLN:39476\n@SQ\tSN:KB708874.1\tLN:39285\n@SQ\tSN:KB708906.1\tLN:39078\n@SQ\tSN:KB708907.1\tLN:38859\n@SQ\tSN:APMT01206777.1\tLN:38757\n@SQ\tSN:APMT01206778.1\tLN:38757\n@SQ\tSN:KB708908.1\tLN:38056\n@SQ\tSN:KB708916.1\tLN:37915\n@SQ\tSN:KB708903.1\tLN:37783\n@SQ\tSN:KB708915.1\tLN:37554\n@SQ\tSN:KB708913.1\tLN:37383\n@SQ\tSN:KB708910.1\tLN:37226\n@SQ\tSN:KB708909.1\tLN:37139\n@SQ\tSN:KB708911.1\tLN:36894\n@SQ\tSN:KB708732.1\tLN:36768\n@SQ\tSN:KB708902.1\tLN:36373\n@SQ\tSN:APMT01206878.1\tLN:36239\n@SQ\tSN:APMT01206903.1\tLN:35850\n@SQ\tSN:APMT01206902.1\tLN:35844\n@SQ\tSN:KB708922.1\tLN:35753\n@SQ\tSN:KB708919.1\tLN:35607\n@SQ\tSN:APMT01206912.1\tLN:35396\n@SQ\tSN:APMT01206913.1\tLN:35396\n@SQ\tSN:KB708914.1\tLN:35277\n@SQ\tSN:APMT01206928.1\tLN:35183\n@SQ\tSN:KB708918.1\tLN:34553\n@SQ\tSN:APMT01206968.1\tLN:34492\n@SQ\tSN:KB708925.1\tLN:34456\n@SQ\tSN:KB708931.1\tLN:34447\n@SQ\tSN:APMT01206969.1\tLN:34286\n@SQ\tSN:APMT01206970.1\tLN:34144\n@SQ\tSN:APMT01206971.1\tLN:34095\n@SQ\tSN:KB708923.1\tLN:33882\n@SQ\tSN:KB708929.1\tLN:33481\n@SQ\tSN:APMT01206972.1\tLN:33472\n@SQ\tSN:KB708917.1\tLN:33356\n@SQ\tSN:KB708945.1\tLN:33211\n@SQ\tSN:APMT01206992.1\tLN:33178\n@SQ\tSN:APMT01206993.1\tLN:33099\n@SQ\tSN:KB708930.1\tLN:33039\n@SQ\tSN:KB708921.1\tLN:32990\n@SQ\tSN:APMT01207017.1\tLN:32743\n@SQ\tSN:APMT01207042.1\tLN:32649\n@SQ\tSN:KB708932.1\tLN:32409\n@SQ\tSN:KB709063.1\tLN:32265\n@SQ\tSN:KB708956.1\tLN:32191\n@SQ\tSN:APMT01207054.1\tLN:32180\n@SQ\tSN:KB708953.1\tLN:31980\n@SQ\tSN:KB708928.1\tLN:31975\n@SQ\tSN:APMT01207071.1\tLN:31953\n@SQ\tSN:KB708936.1\tLN:31811\n@SQ\tSN:KB708940.1\tLN:31702\n@SQ\tSN:KB708933.1\tLN:31498\n@SQ\tSN:KB708971.1\tLN:31404\n@SQ\tSN:KB708938.1\tLN:31359\n@SQ\tSN:KB708927.1\tLN:31310\n@SQ\tSN:KB708978.1\tLN:31004\n@SQ\tSN:APMT01207134.1\tLN:30897\n@SQ\tSN:APMT01207186.1\tLN:30872\n@SQ\tSN:APMT01207135.1\tLN:30756\n@SQ\tSN:APMT01207136.1\tLN:30756\n@SQ\tSN:KB708946.1\tLN:30715\n@SQ\tSN:APMT01207146.1\tLN:30660\n@SQ\tSN:KB708939.1\tLN:30613\n@SQ\tSN:APMT01207147.1\tLN:30613\n@SQ\tSN:KB708941.1\tLN:30463\n@SQ\tSN:APMT01207169.1\tLN:30292\n@SQ\tSN:KB708951.1\tLN:30135\n@SQ\tSN:APMT01207188.1\tLN:29882\n@SQ\tSN:APMT01207187.1\tLN:29879\n@SQ\tSN:APMT01207190.1\tLN:29828\n@SQ\tSN:APMT01207189.1\tLN:29816\n@SQ\tSN:KB708943.1\tLN:29787\n@SQ\tSN:KB708979.1\tLN:29753\n@SQ\tSN:APMT01207198.1\tLN:29711\n@SQ\tSN:KB708985.1\tLN:29694\n@SQ\tSN:APMT01207199.1\tLN:29604\n@SQ\tSN:KB708934.1\tLN:29599\n@SQ\tSN:APMT01207200.1\tLN:29596\n@SQ\tSN:KB708950.1\tLN:29454\n@SQ\tSN:APMT01207212.1\tLN:29417\n@SQ\tSN:APMT01207213.1\tLN:29413\n@SQ\tSN:KB708994.1\tLN:29394\n@SQ\tSN:APMT01207214.1\tLN:29384\n@SQ\tSN:APMT01207258.1\tLN:28948\n@SQ\tSN:KB708949.1\tLN:28756\n@SQ\tSN:KB708967.1\tLN:28735\n@SQ\tSN:APMT01207259.1\tLN:28718\n@SQ\tSN:APMT01207261.1\tLN:28568\n@SQ\tSN:APMT01207260.1\tLN:28544\n@SQ\tSN:APMT01207263.1\tLN:28513\n@SQ\tSN:KB708962.1\tLN:28505\n@SQ\tSN:KB708937.1\tLN:28501\n@SQ\tSN:KB709002.1\tLN:28493\n@SQ\tSN:APMT01207262.1\tLN:28484\n@SQ\tSN:APMT01207278.1\tLN:28440\n@SQ\tSN:APMT01207272.1\tLN:28423\n@SQ\tSN:APMT01207279.1\tLN:28421\n@SQ\tSN:APMT01207280.1\tLN:28375\n@SQ\tSN:KB708926.1\tLN:28366\n@SQ\tSN:APMT01207281.1\tLN:28358\n@SQ\tSN:KB708964.1\tLN:28328\n@SQ\tSN:APMT01207292.1\tLN:28317\n@SQ\tSN:APMT01207293.1\tLN:28317\n@SQ\tSN:APMT01207294.1\tLN:28289\n@SQ\tSN:KB708948.1\tLN:28119\n@SQ\tSN:APMT01207295.1\tLN:28115\n@SQ\tSN:APMT01207296.1\tLN:28093\n@SQ\tSN:APMT01207304.1\tLN:28076\n@SQ\tSN:APMT01207305.1\tLN:28076\n@SQ\tSN:APMT01207306.1\tLN:28062\n@SQ\tSN:KB709110.1\tLN:28058\n@SQ\tSN:KB708942.1\tLN:27992\n@SQ\tSN:KB708947.1\tLN:27932\n@SQ\tSN:KB708955.1\tLN:27926\n@SQ\tSN:APMT01207307.1\tLN:27922\n@SQ\tSN:APMT01207308.1\tLN:27771\n@SQ\tSN:APMT01207318.1\tLN:27711\n@SQ\tSN:APMT01207329.1\tLN:27634\n@SQ\tSN:APMT01207340.1\tLN:27629\n@SQ\tSN:APMT01207341.1\tLN:27611\n@SQ\tSN:APMT01207343.1\tLN:27586\n@SQ\tSN:APMT01207342.1\tLN:27559\n@SQ\tSN:KB708974.1\tLN:27537\n@SQ\tSN:KB708972.1\tLN:27511\n@SQ\tSN:APMT01207350.1\tLN:27495\n@SQ\tSN:APMT01207351.1\tLN:27495\n@SQ\tSN:APMT01207352.1\tLN:27490\n@SQ\tSN:APMT01207353.1\tLN:27490\n@SQ\tSN:APMT01207354.1\tLN:27388\n@SQ\tSN:APMT01207355.1\tLN:27372\n@SQ\tSN:APMT01207356.1\tLN:27372\n@SQ\tSN:APMT01207363.1\tLN:27319\n@SQ\tSN:KB708965.1\tLN:27295\n@SQ\tSN:APMT01207364.1\tLN:27270\n@SQ\tSN:APMT01207374.1\tLN:27216\n@SQ\tSN:APMT01207375.1\tLN:27154\n@SQ\tSN:KB708954.1\tLN:27075\n@SQ\tSN:APMT01207398.1\tLN:27000\n@SQ\tSN:KB708958.1\tLN:26957\n@SQ\tSN:KB708961.1\tLN:26945\n@SQ\tSN:APMT01207399.1\tLN:26885\n@SQ\tSN:APMT01207400.1\tLN:26837\n@SQ\tSN:APMT01207401.1\tLN:26831\n@SQ\tSN:APMT01207424.1\tLN:26762\n@SQ\tSN:APMT01207425.1\tLN:26577\n@SQ\tSN:APMT01207435.1\tLN:26559\n@SQ\tSN:KB708935.1\tLN:26520\n@SQ\tSN:APMT01207436.1\tLN:26368\n@SQ\tSN:KB708973.1\tLN:26353\n@SQ\tSN:APMT01207447.1\tLN:26351\n@SQ\tSN:APMT01207437.1\tLN:26308\n@SQ\tSN:APMT01207456.1\tLN:26186\n@SQ\tSN:APMT01207457.1\tLN:26186\n@SQ\tSN:APMT01207448.1\tLN:26156\n@SQ\tSN:KB709028.1\tLN:26137\n@SQ\tSN:APMT01207460.1\tLN:26136\n@SQ\tSN:KB709087.1\tLN:26130\n@SQ\tSN:APMT01207459.1\tLN:26111\n@SQ\tSN:APMT01207458.1\tLN:26110\n@SQ\tSN:KB710235.1\tLN:26093\n@SQ\tSN:KB709005.1\tLN:26090\n@SQ\tSN:APMT01207462.1\tLN:26009\n@SQ\tSN:APMT01207463.1\tLN:26008\n@SQ\tSN:APMT01207461.1\tLN:25964\n@SQ\tSN:KB709030.1\tLN:25859\n@SQ\tSN:KB708963.1\tLN:25747\n@SQ\tSN:APMT01207486.1\tLN:25717\n@SQ\tSN:APMT01207487.1\tLN:25717\n@SQ\tSN:APMT01207488.1\tLN:25714\n@SQ\tSN:APMT01207512.1\tLN:25589\n@SQ\tSN:APMT01207511.1\tLN:25579\n@SQ\tSN:KB709216.1\tLN:25578\n@SQ\tSN:APMT01207530.1\tLN:25497\n@SQ\tSN:APMT01207531.1\tLN:25497\n@SQ\tSN:KB708969.1\tLN:25299\n@SQ\tSN:KB708976.1\tLN:25297\n@SQ\tSN:KB708986.1\tLN:25288\n@SQ\tSN:KB709018.1\tLN:25147\n@SQ\tSN:KB708959.1\tLN:25128\n@SQ\tSN:KB708966.1\tLN:25108\n@SQ\tSN:KB709142.1\tLN:25101\n@SQ\tSN:KB708983.1\tLN:25092\n@SQ\tSN:APMT01207540.1\tLN:25058\n@SQ\tSN:APMT01207547.1\tLN:25023\n@SQ\tSN:APMT01207548.1\tLN:24999\n@SQ\tSN:KB709000.1\tLN:24984\n@SQ\tSN:KB708991.1\tLN:24945\n@SQ\tSN:APMT01207549.1\tLN:24925\n@SQ\tSN:KB708975.1\tLN:24911\n@SQ\tSN:APMT01207550.1\tLN:24863\n@SQ\tSN:APMT01207551.1\tLN:24862\n@SQ\tSN:KB708957.1\tLN:24809\n@SQ\tSN:APMT01207562.1\tLN:24787\n@SQ\tSN:KB708960.1\tLN:24721\n@SQ\tSN:KB708987.1\tLN:24712\n@SQ\tSN:APMT01207585.1\tLN:24627\n@SQ\tSN:KB709011.1\tLN:24624\n@SQ\tSN:KB708968.1\tLN:24580\n@SQ\tSN:KB709003.1\tLN:24506\n@SQ\tSN:APMT01207613.1\tLN:24499\n@SQ\tSN:APMT01207603.1\tLN:24496\n@SQ\tSN:APMT01207629.1\tLN:24466\n@SQ\tSN:APMT01207630.1\tLN:24466\n@SQ\tSN:APMT01207631.1\tLN:24459\n@SQ\tSN:KB708982.1\tLN:24368\n@SQ\tSN:KB708995.1\tLN:24358\n@SQ\tSN:APMT01207632.1\tLN:24353\n@SQ\tSN:APMT01207633.1\tLN:24319\n@SQ\tSN:APMT01207635.1\tLN:24210\n@SQ\tSN:APMT01207634.1\tLN:24208\n@SQ\tSN:KB708997.1\tLN:24196\n@SQ\tSN:APMT01207636.1\tLN:24171\n@SQ\tSN:APMT01207649.1\tLN:24164\n@SQ\tSN:APMT01207650.1\tLN:24083\n@SQ\tSN:KB708990.1\tLN:24063\n@SQ\tSN:APMT01207651.1\tLN:24036\n@SQ\tSN:KB709017.1\tLN:23950\n@SQ\tSN:APMT01207653.1\tLN:23920\n@SQ\tSN:APMT01207652.1\tLN:23888\n@SQ\tSN:APMT01207654.1\tLN:23848\n@SQ\tSN:KB708981.1\tLN:23829\n@SQ\tSN:APMT01207677.1\tLN:23731\n@SQ\tSN:KB708944.1\tLN:23675\n@SQ\tSN:APMT01207699.1\tLN:23641\n@SQ\tSN:KB709013.1\tLN:23583\n@SQ\tSN:KB708993.1\tLN:23577\n@SQ\tSN:APMT01207700.1\tLN:23560\n@SQ\tSN:APMT01207701.1\tLN:23554\n@SQ\tSN:APMT01207702.1\tLN:23554\n@SQ\tSN:KB709042.1\tLN:23509\n@SQ\tSN:APMT01207710.1\tLN:23475\n@SQ\tSN:APMT01207712.1\tLN:23444\n@SQ\tSN:APMT01207713.1\tLN:23426\n@SQ\tSN:KB709022.1\tLN:23423\n@SQ\tSN:APMT01207711.1\tLN:23417\n@SQ\tSN:KB708977.1\tLN:23344\n@SQ\tSN:APMT01207740.1\tLN:23265\n@SQ\tSN:APMT01207741.1\tLN:23245\n@SQ\tSN:KB709123.1\tLN:23149\n@SQ\tSN:APMT01207750.1\tLN:23136\n@SQ\tSN:APMT01207751.1\tLN:23136\n@SQ\tSN:APMT01207752.1\tLN:23061\n@SQ\tSN:APMT01207761.1\tLN:22972\n@SQ\tSN:APMT01207773.1\tLN:22962\n@SQ\tSN:APMT01207774.1\tLN:22867\n@SQ\tSN:APMT01207775.1\tLN:22841\n@SQ\tSN:KB709031.1\tLN:22825\n@SQ\tSN:KB709043.1\tLN:22806\n@SQ\tSN:KB708996.1\tLN:22803\n@SQ\tSN:KB709508.1\tLN:22783\n@SQ\tSN:KB709039.1\tLN:22719\n@SQ\tSN:APMT01207776.1\tLN:22704\n@SQ\tSN:APMT01207777.1\tLN:22686\n@SQ\tSN:APMT01207784.1\tLN:22664\n@SQ\tSN:KB709219.1\tLN:22664\n@SQ\tSN:APMT01207786.1\tLN:22661\n@SQ\tSN:APMT01207785.1\tLN:22658\n@SQ\tSN:KB709051.1\tLN:22648\n@SQ\tSN:KB708980.1\tLN:22557\n@SQ\tSN:KB709009.1\tLN:22517\n@SQ\tSN:APMT01207813.1\tLN:22481\n@SQ\tSN:KB709026.1\tLN:22448\n@SQ\tSN:APMT01207838.1\tLN:22432\n@SQ\tSN:APMT01207839.1\tLN:22432\n@SQ\tSN:APMT01207840.1\tLN:22422\n@SQ\tSN:KB709050.1\tLN:22400\n@SQ\tSN:APMT01207841.1\tLN:22393\n@SQ\tSN:KB709029.1\tLN:22345\n@SQ\tSN:KB708984.1\tLN:22323\n@SQ\tSN:KB709060.1\tLN:22311\n@SQ\tSN:APMT01207861.1\tLN:22297\n@SQ\tSN:KB709679.1\tLN:22250\n@SQ\tSN:APMT01207864.1\tLN:22247\n@SQ\tSN:KB709004.1\tLN:22172\n@SQ\tSN:APMT01207874.1\tLN:22163\n@SQ\tSN:APMT01207865.1\tLN:22147\n@SQ\tSN:KB709014.1\tLN:22140\n@SQ\tSN:APMT01207873.1\tLN:22110\n@SQ\tSN:KB709033.1\tLN:22099\n@SQ\tSN:APMT01207908.1\tLN:22086\n@SQ\tSN:KB709012.1\tLN:22079\n@SQ\tSN:APMT01207906.1\tLN:22065\n@SQ\tSN:APMT01207896.1\tLN:22033\n@SQ\tSN:APMT01207905.1\tLN:22016\n@SQ\tSN:APMT01207907.1\tLN:22016\n@SQ\tSN:APMT01207919.1\tLN:21998\n@SQ\tSN:APMT01207920.1\tLN:21995\n@SQ\tSN:APMT01207921.1\tLN:21995\n@SQ\tSN:APMT01207922.1\tLN:21983\n@SQ\tSN:APMT01207930.1\tLN:21946\n@SQ\tSN:KB709096.1\tLN:21929\n@SQ\tSN:APMT01207943.1\tLN:21903\n@SQ\tSN:APMT01207956.1\tLN:21896\n@SQ\tSN:APMT01207942.1\tLN:21885\n@SQ\tSN:APMT01207954.1\tLN:21878\n@SQ\tSN:APMT01207955.1\tLN:21878\n@SQ\tSN:KB710163.1\tLN:21809\n@SQ\tSN:APMT01207970.1\tLN:21805\n@SQ\tSN:APMT01207957.1\tLN:21803\n@SQ\tSN:KB708952.1\tLN:21795\n@SQ\tSN:KB709023.1\tLN:21793\n@SQ\tSN:APMT01207990.1\tLN:21753\n@SQ\tSN:APMT01208001.1\tLN:21730\n@SQ\tSN:KB709034.1\tLN:21717\n@SQ\tSN:APMT01208002.1\tLN:21640\n@SQ\tSN:APMT01208003.1\tLN:21630\n@SQ\tSN:KB709032.1\tLN:21597\n@SQ\tSN:KB709006.1\tLN:21564\n@SQ\tSN:APMT01208004.1\tLN:21561\n@SQ\tSN:KB709037.1\tLN:21510\n@SQ\tSN:KB708989.1\tLN:21498\n@SQ\tSN:KB709025.1\tLN:21448\n@SQ\tSN:KB709053.1\tLN:21447\n@SQ\tSN:APMT01208050.1\tLN:21435\n@SQ\tSN:KB709038.1\tLN:21433\n@SQ\tSN:KB709089.1\tLN:21431\n@SQ\tSN:APMT01208051.1\tLN:21429\n@SQ\tSN:APMT01208057.1\tLN:21409\n@SQ\tSN:APMT01208058.1\tLN:21409\n@SQ\tSN:APMT01208059.1\tLN:21397\n@SQ\tSN:APMT01208060.1\tLN:21394\n@SQ\tSN:APMT01208063.1\tLN:21358\n@SQ\tSN:APMT01208064.1\tLN:21358\n@SQ\tSN:APMT01208066.1\tLN:21337\n@SQ\tSN:APMT01208067.1\tLN:21337\n@SQ\tSN:KB709019.1\tLN:21336\n@SQ\tSN:APMT01208068.1\tLN:21325\n@SQ\tSN:APMT01208061.1\tLN:21322\n@SQ\tSN:KB709007.1\tLN:21303\n@SQ\tSN:APMT01208070.1\tLN:21292\n@SQ\tSN:APMT01208062.1\tLN:21290\n@SQ\tSN:APMT01208069.1\tLN:21290\n@SQ\tSN:APMT01208065.1\tLN:21287\n@SQ\tSN:APMT01208072.1\tLN:21272\n@SQ\tSN:KB708988.1\tLN:21258\n@SQ\tSN:APMT01208073.1\tLN:21256\n@SQ\tSN:APMT01208079.1\tLN:21248\n@SQ\tSN:KB709077.1\tLN:21181\n@SQ\tSN:APMT01208071.1\tLN:21178\n@SQ\tSN:APMT01208080.1\tLN:21168\n@SQ\tSN:APMT01208081.1\tLN:21164\n@SQ\tSN:APMT01208082.1\tLN:21164\n@SQ\tSN:APMT01208083.1\tLN:21133\n@SQ\tSN:APMT01208084.1\tLN:21118\n@SQ\tSN:APMT01208103.1\tLN:21047\n@SQ\tSN:APMT01208085.1\tLN:21038\n@SQ\tSN:APMT01208111.1\tLN:21031\n@SQ\tSN:KB709001.1\tLN:20995\n@SQ\tSN:APMT01208118.1\tLN:20988\n@SQ\tSN:APMT01208119.1\tLN:20972\n@SQ\tSN:APMT01208121.1\tLN:20968\n@SQ\tSN:APMT01208122.1\tLN:20964\n@SQ\tSN:KB709045.1\tLN:20959\n@SQ\tSN:APMT01208120.1\tLN:20919\n@SQ\tSN:APMT01208131.1\tLN:20875\n@SQ\tSN:KB709021.1\tLN:20869\n@SQ\tSN:APMT01208138.1\tLN:20851\n@SQ\tSN:APMT01208139.1\tLN:20851\n@SQ\tSN:APMT01208137.1\tLN:20843\n@SQ\tSN:APMT01208140.1\tLN:20831\n@SQ\tSN:KB709065.1\tLN:20831\n@SQ\tSN:KB709027.1\tLN:20798\n@SQ\tSN:APMT01208146.1\tLN:20794\n@SQ\tSN:APMT01208147.1\tLN:20790\n@SQ\tSN:KB709036.1\tLN:20763\n@SQ\tSN:APMT01208157.1\tLN:20759\n@SQ\tSN:APMT01208156.1\tLN:20713\n@SQ\tSN:KB709062.1\tLN:20711\n@SQ\tSN:KB709020.1\tLN:20697\n@SQ\tSN:APMT01208159.1\tLN:20693\n@SQ\tSN:APMT01208158.1\tLN:20683\n@SQ\tSN:APMT01208166.1\tLN:20622\n@SQ\tSN:APMT01208176.1\tLN:20612\n@SQ\tSN:APMT01208160.1\tLN:20607\n@SQ\tSN:APMT01208177.1\tLN:20596\n@SQ\tSN:APMT01208175.1\tLN:20565\n@SQ\tSN:APMT01208186.1\tLN:20486\n@SQ\tSN:KB709016.1\tLN:20478\n@SQ\tSN:APMT01208178.1\tLN:20476\n@SQ\tSN:APMT01208185.1\tLN:20443\n@SQ\tSN:APMT01208196.1\tLN:20380\n@SQ\tSN:APMT01208203.1\tLN:20351\n@SQ\tSN:APMT01208217.1\tLN:20343\n@SQ\tSN:APMT01208216.1\tLN:20342\n@SQ\tSN:KB708992.1\tLN:20225\n@SQ\tSN:APMT01208225.1\tLN:20209\n@SQ\tSN:APMT01208245.1\tLN:20196\n@SQ\tSN:APMT01208238.1\tLN:20189\n@SQ\tSN:APMT01208244.1\tLN:20180\n@SQ\tSN:APMT01208246.1\tLN:20160\n@SQ\tSN:KB709048.1\tLN:20130\n@SQ\tSN:APMT01208248.1\tLN:20093\n@SQ\tSN:APMT01208247.1\tLN:20069\n@SQ\tSN:APMT01208256.1\tLN:20060\n@SQ\tSN:KB709093.1\tLN:20045\n@SQ\tSN:APMT01208249.1\tLN:20035\n@SQ\tSN:KB709084.1\tLN:20003\n@SQ\tSN:APMT01208276.1\tLN:19992\n@SQ\tSN:APMT01208277.1\tLN:19992\n@SQ\tSN:KB709181.1\tLN:19987\n@SQ\tSN:APMT01208278.1\tLN:19986\n@SQ\tSN:APMT01208279.1\tLN:19974\n@SQ\tSN:APMT01208280.1\tLN:19927\n@SQ\tSN:APMT01208282.1\tLN:19911\n@SQ\tSN:APMT01208283.1\tLN:19911\n@SQ\tSN:APMT01208281.1\tLN:19903\n@SQ\tSN:APMT01208284.1\tLN:19887\n@SQ\tSN:KB709122.1\tLN:19869\n@SQ\tSN:APMT01208285.1\tLN:19862\n@SQ\tSN:APMT01208286.1\tLN:19862\n@SQ\tSN:KB709174.1\tLN:19857\n@SQ\tSN:KB709182.1\tLN:19850\n@SQ\tSN:APMT01208295.1\tLN:19846\n@SQ\tSN:APMT01208296.1\tLN:19845\n@SQ\tSN:KB709061.1\tLN:19828\n@SQ\tSN:APMT01208297.1\tLN:19826\n@SQ\tSN:KB709072.1\tLN:19826\n@SQ\tSN:APMT01208299.1\tLN:19825\n@SQ\tSN:KB709121.1\tLN:19773\n@SQ\tSN:APMT01208298.1\tLN:19770\n@SQ\tSN:APMT01208319.1\tLN:19755\n@SQ\tSN:KB709047.1\tLN:19737\n@SQ\tSN:KB709058.1\tLN:19732\n@SQ\tSN:KB709209.1\tLN:19718\n@SQ\tSN:APMT01208312.1\tLN:19707\n@SQ\tSN:KB709085.1\tLN:19682\n@SQ\tSN:APMT01208321.1\tLN:19676\n@SQ\tSN:APMT01208323.1\tLN:19655\n@SQ\tSN:APMT01208322.1\tLN:19654\n@SQ\tSN:APMT01208324.1\tLN:19631\n@SQ\tSN:KB709146.1\tLN:19628\n@SQ\tSN:APMT01208325.1\tLN:19621\n@SQ\tSN:APMT01208326.1\tLN:19604\n@SQ\tSN:APMT01208327.1\tLN:19603\n@SQ\tSN:APMT01208328.1\tLN:19603\n@SQ\tSN:APMT01208330.1\tLN:19592\n@SQ\tSN:APMT01208332.1\tLN:19584\n@SQ\tSN:APMT01208331.1\tLN:19579\n@SQ\tSN:KB709073.1\tLN:19574\n@SQ\tSN:APMT01208320.1\tLN:19571\n@SQ\tSN:APMT01208329.1\tLN:19539\n@SQ\tSN:KB709846.1\tLN:19526\n@SQ\tSN:APMT01208368.1\tLN:19523\n@SQ\tSN:APMT01208369.1\tLN:19523\n@SQ\tSN:APMT01208371.1\tLN:19520\n@SQ\tSN:KB709064.1\tLN:19507\n@SQ\tSN:APMT01208360.1\tLN:19501\n@SQ\tSN:APMT01208372.1\tLN:19501\n@SQ\tSN:APMT01208373.1\tLN:19499\n@SQ\tSN:APMT01208374.1\tLN:19498\n@SQ\tSN:KB709080.1\tLN:19488\n@SQ\tSN:KB709148.1\tLN:19486\n@SQ\tSN:APMT01208370.1\tLN:19481\n@SQ\tSN:KB709046.1\tLN:19476\n@SQ\tSN:APMT01208375.1\tLN:19469\n@SQ\tSN:APMT01208376.1\tLN:19469\n@SQ\tSN:APMT01208388.1\tLN:19450\n@SQ\tSN:APMT01208397.1\tLN:19411\n@SQ\tSN:APMT01208398.1\tLN:19402\n@SQ\tSN:KB709086.1\tLN:19397\n@SQ\tSN:APMT01208396.1\tLN:19395\n@SQ\tSN:APMT01208399.1\tLN:19389\n@SQ\tSN:APMT01208401.1\tLN:19388\n@SQ\tSN:APMT01208402.1\tLN:19388\n@SQ\tSN:KB709066.1\tLN:19372\n@SQ\tSN:KB709091.1\tLN:19357\n@SQ\tSN:APMT01208421.1\tLN:19347\n@SQ\tSN:APMT01208404.1\tLN:19338\n@SQ\tSN:APMT01208400.1\tLN:19335\n@SQ\tSN:APMT01208403.1\tLN:19287\n@SQ\tSN:APMT01208422.1\tLN:19283\n@SQ\tSN:APMT01208423.1\tLN:19281\n@SQ\tSN:APMT01208437.1\tLN:19279\n@SQ\tSN:KB709059.1\tLN:19275\n@SQ\tSN:KB709024.1\tLN:19240\n@SQ\tSN:APMT01208438.1\tLN:19231\n@SQ\tSN:APMT01208439.1\tLN:19216\n@SQ\tSN:KB709162.1\tLN:19203\n@SQ\tSN:APMT01208440.1\tLN:19198\n@SQ\tSN:APMT01208441.1\tLN:19175\n@SQ\tSN:APMT01208442.1\tLN:19172\n@SQ\tSN:APMT01208467.1\tLN:19128\n@SQ\tSN:KB709069.1\tLN:19126\n@SQ\tSN:APMT01208469.1\tLN:19110\n@SQ\tSN:APMT01208468.1\tLN:19108\n@SQ\tSN:KB709070.1\tLN:19086\n@SQ\tSN:APMT01208474.1\tLN:19084\n@SQ\tSN:APMT01208475.1\tLN:19079\n@SQ\tSN:APMT01208476.1\tLN:19050\n@SQ\tSN:APMT01208477.1\tLN:19048\n@SQ\tSN:APMT01208470.1\tLN:19043\n@SQ\tSN:APMT01208471.1\tLN:19041\n@SQ\tSN:APMT01208478.1\tLN:19038\n@SQ\tSN:APMT01208479.1\tLN:19037\n@SQ\tSN:APMT01208472.1\tLN:19031\n@SQ\tSN:APMT01208473.1\tLN:19026\n@SQ\tSN:APMT01208480.1\tLN:19014\n@SQ\tSN:KB709098.1\tLN:18940\n@SQ\tSN:APMT01208492.1\tLN:18932\n@SQ\tSN:APMT01208493.1\tLN:18932\n@SQ\tSN:APMT01208494.1\tLN:18928\n@SQ\tSN:APMT01208495.1\tLN:18909\n@SQ\tSN:APMT01208497.1\tLN:18904\n@SQ\tSN:KB709015.1\tLN:18884\n@SQ\tSN:APMT01208500.1\tLN:18880\n@SQ\tSN:APMT01208496.1\tLN:18879\n@SQ\tSN:APMT01208501.1\tLN:18872\n@SQ\tSN:APMT01208498.1\tLN:18870\n@SQ\tSN:APMT01208502.1\tLN:18868\n@SQ\tSN:APMT01208503.1\tLN:18861\n@SQ\tSN:APMT01208504.1\tLN:18861\n@SQ\tSN:APMT01208505.1\tLN:18860\n@SQ\tSN:APMT01208511.1\tLN:18832\n@SQ\tSN:APMT01208513.1\tLN:18828\n@SQ\tSN:KB709113.1\tLN:18828\n@SQ\tSN:APMT01208499.1\tLN:18822\n@SQ\tSN:KB709753.1\tLN:18818\n@SQ\tSN:APMT01208525.1\tLN:18800\n@SQ\tSN:APMT01208512.1\tLN:18769\n@SQ\tSN:APMT01208531.1\tLN:18724\n@SQ\tSN:APMT01208532.1\tLN:18718\n@SQ\tSN:KB709052.1\tLN:18709\n@SQ\tSN:APMT01208538.1\tLN:18702\n@SQ\tSN:KB709054.1\tLN:18689\n@SQ\tSN:APMT01208546.1\tLN:18686\n@SQ\tSN:APMT01208530.1\tLN:18674\n@SQ\tSN:APMT01208547.1\tLN:18666\n@SQ\tSN:APMT01208563.1\tLN:18661\n@SQ\tSN:KB709126.1\tLN:18657\n@SQ\tSN:APMT01208564.1\tLN:18654\n@SQ\tSN:KB709095.1\tLN:18647\n@SQ\tSN:KB709068.1\tLN:18635\n@SQ\tSN:APMT01208562.1\tLN:18621\n@SQ\tSN:APMT01208577.1\tLN:18593\n@SQ\tSN:APMT01208576.1\tLN:18592\n@SQ\tSN:KB709079.1\tLN:18588\n@SQ\tSN:KB709083.1\tLN:18578\n@SQ\tSN:APMT01208584.1\tLN:18561\n@SQ\tSN:KB709082.1\tLN:18556\n@SQ\tSN:KB709056.1\tLN:18552\n@SQ\tSN:APMT01208566.1\tLN:18545\n@SQ\tSN:APMT01208585.1\tLN:18533\n@SQ\tSN:KB709140.1\tLN:18527\n@SQ\tSN:APMT01208565.1\tLN:18523\n@SQ\tSN:APMT01208598.1\tLN:18519\n@SQ\tSN:KB709150.1\tLN:18512\n@SQ\tSN:APMT01208605.1\tLN:18503\n@SQ\tSN:APMT01208618.1\tLN:18436\n@SQ\tSN:KB709191.1\tLN:18436\n@SQ\tSN:KB709010.1\tLN:18369\n@SQ\tSN:APMT01208627.1\tLN:18362\n@SQ\tSN:APMT01208628.1\tLN:18357\n@SQ\tSN:APMT01208629.1\tLN:18357\n@SQ\tSN:KB709090.1\tLN:18329\n@SQ\tSN:APMT01208641.1\tLN:18312\n@SQ\tSN:APMT01208642.1\tLN:18305\n@SQ\tSN:APMT01208643.1\tLN:18293\n@SQ\tSN:APMT01208644.1\tLN:18289\n@SQ\tSN:APMT01208652.1\tLN:18272\n@SQ\tSN:KB709088.1\tLN:18237\n@SQ\tSN:APMT01208653.1\tLN:18235\n@SQ\tSN:KB709076.1\tLN:18226\n@SQ\tSN:APMT01208661.1\tLN:18200\n@SQ\tSN:APMT01208662.1\tLN:18184\n@SQ\tSN:APMT01208671.1\tLN:18172\n@SQ\tSN:APMT01208678.1\tLN:18133\n@SQ\tSN:APMT01208679.1\tLN:18126\n@SQ\tSN:APMT01208672.1\tLN:18117\n@SQ\tSN:APMT01208670.1\tLN:18116\n@SQ\tSN:KB709252.1\tLN:18106\n@SQ\tSN:KB709201.1\tLN:18105\n@SQ\tSN:KB709131.1\tLN:18104\n@SQ\tSN:KB709099.1\tLN:18103\n@SQ\tSN:APMT01208680.1\tLN:18097\n@SQ\tSN:KB709115.1\tLN:18091\n@SQ\tSN:KB709094.1\tLN:18088\n@SQ\tSN:APMT01208682.1\tLN:18087\n@SQ\tSN:APMT01208684.1\tLN:18078\n@SQ\tSN:APMT01208685.1\tLN:18078\n@SQ\tSN:APMT01208697.1\tLN:18044\n@SQ\tSN:APMT01208681.1\tLN:18032\n@SQ\tSN:APMT01208692.1\tLN:18031\n@SQ\tSN:KB709008.1\tLN:18030\n@SQ\tSN:APMT01208683.1\tLN:18028\n@SQ\tSN:KB709120.1\tLN:18021\n@SQ\tSN:APMT01208705.1\tLN:18011\n@SQ\tSN:APMT01208710.1\tLN:17980\n@SQ\tSN:KB709114.1\tLN:17971\n@SQ\tSN:APMT01208711.1\tLN:17968\n@SQ\tSN:APMT01208704.1\tLN:17965\n@SQ\tSN:APMT01208713.1\tLN:17944\n@SQ\tSN:APMT01208712.1\tLN:17939\n@SQ\tSN:KB709097.1\tLN:17923\n@SQ\tSN:APMT01208714.1\tLN:17909\n@SQ\tSN:APMT01208715.1\tLN:17908\n@SQ\tSN:APMT01208717.1\tLN:17906\n@SQ\tSN:APMT01208716.1\tLN:17905\n@SQ\tSN:APMT01208718.1\tLN:17894\n@SQ\tSN:APMT01208719.1\tLN:17892\n@SQ\tSN:APMT01208730.1\tLN:17872\n@SQ\tSN:APMT01208736.1\tLN:17863\n@SQ\tSN:KB709105.1\tLN:17861\n@SQ\tSN:KB709255.1\tLN:17853\n@SQ\tSN:APMT01208738.1\tLN:17846\n@SQ\tSN:APMT01208739.1\tLN:17846\n@SQ\tSN:KB709241.1\tLN:17844\n@SQ\tSN:KB709111.1\tLN:17834\n@SQ\tSN:KB709215.1\tLN:17830\n@SQ\tSN:KB709049.1\tLN:17810\n@SQ\tSN:KB709196.1\tLN:17810\n@SQ\tSN:APMT01208773.1\tLN:17804\n@SQ\tSN:KB709092.1\tLN:17792\n@SQ\tSN:APMT01208737.1\tLN:17791\n@SQ\tSN:KB709200.1\tLN:17786\n@SQ\tSN:KB709118.1\tLN:17760\n@SQ\tSN:KB709127.1\tLN:17757\n@SQ\tSN:APMT01208774.1\tLN:17756\n@SQ\tSN:APMT01208790.1\tLN:17745\n@SQ\tSN:APMT01208791.1\tLN:17745\n@SQ\tSN:APMT01208792.1\tLN:17743\n@SQ\tSN:APMT01208793.1\tLN:17735\n@SQ\tSN:KB709075.1\tLN:17732\n@SQ\tSN:APMT01208796.1\tLN:17699\n@SQ\tSN:APMT01208797.1\tLN:17693\n@SQ\tSN:APMT01208798.1\tLN:17686\n@SQ\tSN:APMT01208799.1\tLN:17673\n@SQ\tSN:KB709211.1\tLN:17668\n@SQ\tSN:APMT01208794.1\tLN:17653\n@SQ\tSN:APMT01208800.1\tLN:17647\n@SQ\tSN:APMT01208795.1\tLN:17642\n@SQ\tSN:APMT01208801.1\tLN:17632\n@SQ\tSN:APMT01208802.1\tLN:17622\n@SQ\tSN:KB709128.1\tLN:17606\n@SQ\tSN:APMT01208810.1\tLN:17592\n@SQ\tSN:KB709055.1\tLN:17563\n@SQ\tSN:KB709176.1\tLN:17523\n@SQ\tSN:APMT01208824.1\tLN:17513\n@SQ\tSN:KB709163.1\tLN:17513\n@SQ\tSN:KB709078.1\tLN:17511\n@SQ\tSN:APMT01208823.1\tLN:17498\n@SQ\tSN:KB709119.1\tLN:17490\n@SQ\tSN:KB710491.1\tLN:17486\n@SQ\tSN:APMT01208825.1\tLN:17481\n@SQ\tSN:KB709040.1\tLN:17470\n@SQ\tSN:KB709100.1\tLN:17462\n@SQ\tSN:APMT01208850.1\tLN:17454\n@SQ\tSN:APMT01208851.1\tLN:17454\n@SQ\tSN:KB709107.1\tLN:17449\n@SQ\tSN:APMT01208826.1\tLN:17422\n@SQ\tSN:KB709198.1\tLN:17419\n@SQ\tSN:KB709412.1\tLN:17414\n@SQ\tSN:APMT01208854.1\tLN:17408\n@SQ\tSN:APMT01208855.1\tLN:17403\n@SQ\tSN:APMT01208856.1\tLN:17401\n@SQ\tSN:APMT01208842.1\tLN:17400\n@SQ\tSN:APMT01208870.1\tLN:17383\n@SQ\tSN:APMT01208871.1\tLN:17382\n@SQ\tSN:APMT01208852.1\tLN:17373\n@SQ\tSN:APMT01208853.1\tLN:17370\n@SQ\tSN:KB708998.1\tLN:17344\n@SQ\tSN:APMT01208873.1\tLN:17341\n@SQ\tSN:APMT01208874.1\tLN:17341\n@SQ\tSN:APMT01208875.1\tLN:17328\n@SQ\tSN:APMT01208876.1\tLN:17328\n@SQ\tSN:KB709141.1\tLN:17324\n@SQ\tSN:APMT01208872.1\tLN:17315\n@SQ\tSN:APMT01208877.1\tLN:17313\n@SQ\tSN:APMT01208882.1\tLN:17286\n@SQ\tSN:KB709130.1\tLN:17285\n@SQ\tSN:KB709116.1\tLN:17284\n@SQ\tSN:APMT01208881.1\tLN:17276\n@SQ\tSN:KB709129.1\tLN:17272\n@SQ\tSN:KB709135.1\tLN:17265\n@SQ\tSN:KB709124.1\tLN:17261\n@SQ\tSN:KB709139.1\tLN:17260\n@SQ\tSN:KB709145.1\tLN:17250\n@SQ\tSN:KB709283.1\tLN:17247\n@SQ\tSN:APMT01208883.1\tLN:17244\n@SQ\tSN:APMT01208901.1\tLN:17210\n@SQ\tSN:APMT01208902.1\tLN:17210\n@SQ\tSN:APMT01208903.1\tLN:17207\n@SQ\tSN:APMT01208911.1\tLN:17179\n@SQ\tSN:APMT01208912.1\tLN:17179\n@SQ\tSN:KB709159.1\tLN:17144\n@SQ\tSN:APMT01208923.1\tLN:17141\n@SQ\tSN:APMT01208937.1\tLN:17140\n@SQ\tSN:APMT01208910.1\tLN:17130\n@SQ\tSN:APMT01208944.1\tLN:17127\n@SQ\tSN:KB709237.1\tLN:17125\n@SQ\tSN:APMT01208945.1\tLN:17123\n@SQ\tSN:KB709247.1\tLN:17117\n@SQ\tSN:APMT01208957.1\tLN:17101\n@SQ\tSN:APMT01208958.1\tLN:17101\n@SQ\tSN:APMT01208959.1\tLN:17090\n@SQ\tSN:APMT01208960.1\tLN:17070\n@SQ\tSN:KB709187.1\tLN:17066\n@SQ\tSN:APMT01208938.1\tLN:17062\n@SQ\tSN:APMT01208976.1\tLN:17028\n@SQ\tSN:KB709109.1\tLN:17002\n@SQ\tSN:APMT01208981.1\tLN:17001\n@SQ\tSN:APMT01208975.1\tLN:16997\n@SQ\tSN:APMT01208982.1\tLN:16994\n@SQ\tSN:KB709311.1\tLN:16986\n@SQ\tSN:APMT01208989.1\tLN:16966\n@SQ\tSN:APMT01208990.1\tLN:16964\n@SQ\tSN:APMT01208991.1\tLN:16945\n@SQ\tSN:KB709074.1\tLN:16937\n@SQ\tSN:APMT01208980.1\tLN:16936\n@SQ\tSN:APMT01208999.1\tLN:16927\n@SQ\tSN:KB709133.1\tLN:16909\n@SQ\tSN:KB709147.1\tLN:16885\n@SQ\tSN:APMT01209012.1\tLN:16883\n@SQ\tSN:KB709035.1\tLN:16866\n@SQ\tSN:APMT01209032.1\tLN:16826\n@SQ\tSN:APMT01209024.1\tLN:16820\n@SQ\tSN:APMT01209023.1\tLN:16813\n@SQ\tSN:KB709167.1\tLN:16802\n@SQ\tSN:APMT01209033.1\tLN:16771\n@SQ\tSN:APMT01209034.1\tLN:16763\n@SQ\tSN:APMT01209025.1\tLN:16759\n@SQ\tSN:APMT01209035.1\tLN:16757\n@SQ\tSN:KB709234.1\tLN:16715\n@SQ\tSN:APMT01209069.1\tLN:16706\n@SQ\tSN:APMT01209070.1\tLN:16706\n@SQ\tSN:APMT01209071.1\tLN:16703\n@SQ\tSN:APMT01209072.1\tLN:16697\n@SQ\tSN:KB709057.1\tLN:16696\n@SQ\tSN:APMT01209068.1\tLN:16690\n@SQ\tSN:KB709951.1\tLN:16677\n@SQ\tSN:KB709044.1\tLN:16658\n@SQ\tSN:KB709218.1\tLN:16649\n@SQ\tSN:APMT01209097.1\tLN:16638\n@SQ\tSN:APMT01209073.1\tLN:16634\n@SQ\tSN:APMT01209098.1\tLN:16631\n@SQ\tSN:APMT01209099.1\tLN:16631\n@SQ\tSN:APMT01209100.1\tLN:16626\n@SQ\tSN:APMT01209080.1\tLN:16625\n@SQ\tSN:APMT01209079.1\tLN:16623\n@SQ\tSN:APMT01209101.1\tLN:16619\n@SQ\tSN:APMT01209108.1\tLN:16575\n@SQ\tSN:APMT01209109.1\tLN:16573\n@SQ\tSN:KB710880.1\tLN:16570\n@SQ\tSN:APMT01209102.1\tLN:16556\n@SQ\tSN:KB709277.1\tLN:16530\n@SQ\tSN:APMT01209129.1\tLN:16514\n@SQ\tSN:APMT01209130.1\tLN:16511\n@SQ\tSN:APMT01209116.1\tLN:16504\n@SQ\tSN:APMT01209132.1\tLN:16499\n@SQ\tSN:KB709144.1\tLN:16498\n@SQ\tSN:APMT01209131.1\tLN:16498\n@SQ\tSN:APMT01209133.1\tLN:16496\n@SQ\tSN:APMT01209134.1\tLN:16485\n@SQ\tSN:KB709192.1\tLN:16483\n@SQ\tSN:KB709177.1\tLN:16479\n@SQ\tSN:APMT01209141.1\tLN:16459\n@SQ\tSN:APMT01209146.1\tLN:16454\n@SQ\tSN:KB709103.1\tLN:16451\n@SQ\tSN:APMT01209135.1\tLN:16425\n@SQ\tSN:KB710148.1\tLN:16425\n@SQ\tSN:KB709250.1\tLN:16420\n@SQ\tSN:APMT01209142.1\tLN:16414\n@SQ\tSN:APMT01209147.1\tLN:16409\n@SQ\tSN:APMT01209149.1\tLN:16409\n@SQ\tSN:KB709183.1\tLN:16399\n@SQ\tSN:KB709149.1\tLN:16389\n@SQ\tSN:KB709155.1\tLN:16384\n@SQ\tSN:APMT01209156.1\tLN:16379\n@SQ\tSN:APMT01209186.1\tLN:16355\n@SQ\tSN:APMT01209148.1\tLN:16353\n@SQ\tSN:KB709134.1\tLN:16347\n@SQ\tSN:KB709154.1\tLN:16341\n@SQ\tSN:APMT01209155.1\tLN:16325\n@SQ\tSN:APMT01209170.1\tLN:16321\n@SQ\tSN:KB709156.1\tLN:16304\n@SQ\tSN:APMT01209171.1\tLN:16304\n@SQ\tSN:KB709171.1\tLN:16298\n@SQ\tSN:KB709160.1\tLN:16296\n@SQ\tSN:APMT01209185.1\tLN:16292\n@SQ\tSN:KB709136.1\tLN:16280\n@SQ\tSN:KB709289.1\tLN:16271\n@SQ\tSN:APMT01209194.1\tLN:16270\n@SQ\tSN:APMT01209195.1\tLN:16270\n@SQ\tSN:MT\tLN:16264\n@SQ\tSN:KB709228.1\tLN:16245\n@SQ\tSN:KB709071.1\tLN:16236\n@SQ\tSN:APMT01209203.1\tLN:16213\n@SQ\tSN:APMT01209204.1\tLN:16213\n@SQ\tSN:KB709208.1\tLN:16205\n@SQ\tSN:APMT01209215.1\tLN:16193\n@SQ\tSN:KB709870.1\tLN:16193\n@SQ\tSN:KB709179.1\tLN:16176\n@SQ\tSN:APMT01209226.1\tLN:16171\n@SQ\tSN:APMT01209227.1\tLN:16171\n@SQ\tSN:APMT01209225.1\tLN:16170\n@SQ\tSN:KB709197.1\tLN:16163\n@SQ\tSN:KB709132.1\tLN:16110\n@SQ\tSN:APMT01209240.1\tLN:16108\n@SQ\tSN:APMT01209241.1\tLN:16096\n@SQ\tSN:KB709232.1\tLN:16088\n@SQ\tSN:APMT01209234.1\tLN:16079\n@SQ\tSN:APMT01209242.1\tLN:16068\n@SQ\tSN:APMT01209261.1\tLN:16057\n@SQ\tSN:APMT01209262.1\tLN:16053\n@SQ\tSN:KB709715.1\tLN:16031\n@SQ\tSN:KB709161.1\tLN:16025\n@SQ\tSN:APMT01209289.1\tLN:16015\n@SQ\tSN:KB709164.1\tLN:16006\n@SQ\tSN:APMT01209290.1\tLN:16005\n@SQ\tSN:APMT01209291.1\tLN:16005\n@SQ\tSN:APMT01209292.1\tLN:15996\n@SQ\tSN:APMT01209293.1\tLN:15993\n@SQ\tSN:KB709185.1\tLN:15981\n@SQ\tSN:KB709170.1\tLN:15977\n@SQ\tSN:KB709175.1\tLN:15972\n@SQ\tSN:APMT01209296.1\tLN:15967\n@SQ\tSN:KB709264.1\tLN:15966\n@SQ\tSN:APMT01209297.1\tLN:15965\n@SQ\tSN:APMT01209298.1\tLN:15965\n@SQ\tSN:KB709266.1\tLN:15965\n@SQ\tSN:APMT01209300.1\tLN:15954\n@SQ\tSN:APMT01209301.1\tLN:15953\n@SQ\tSN:APMT01209302.1\tLN:15953\n@SQ\tSN:KB709661.1\tLN:15950\n@SQ\tSN:APMT01209322.1\tLN:15937\n@SQ\tSN:KB709172.1\tLN:15936\n@SQ\tSN:KB709416.1\tLN:15934\n@SQ\tSN:APMT01209303.1\tLN:15921\n@SQ\tSN:APMT01209305.1\tLN:15920\n@SQ\tSN:APMT01209304.1\tLN:15918\n@SQ\tSN:APMT01209334.1\tLN:15893\n@SQ\tSN:APMT01209299.1\tLN:15883\n@SQ\tSN:APMT01209331.1\tLN:15846\n@SQ\tSN:APMT01209333.1\tLN:15846\n@SQ\tSN:APMT01209335.1\tLN:15840\n@SQ\tSN:APMT01209323.1\tLN:15839\n@SQ\tSN:KB709180.1\tLN:15835\n@SQ\tSN:APMT01209321.1\tLN:15830\n@SQ\tSN:KB709117.1\tLN:15824\n@SQ\tSN:KB709212.1\tLN:15810\n@SQ\tSN:APMT01209345.1\tLN:15808\n@SQ\tSN:KB709296.1\tLN:15795\n@SQ\tSN:APMT01209346.1\tLN:15793\n@SQ\tSN:APMT01209347.1\tLN:15793\n@SQ\tSN:APMT01209348.1\tLN:15788\n@SQ\tSN:APMT01209349.1\tLN:15782\n@SQ\tSN:APMT01209350.1\tLN:15775\n@SQ\tSN:APMT01209395.1\tLN:15763\n@SQ\tSN:APMT01209351.1\tLN:15755\n@SQ\tSN:APMT01209363.1\tLN:15743\n@SQ\tSN:KB709231.1\tLN:15741\n@SQ\tSN:KB709157.1\tLN:15740\n@SQ\tSN:APMT01209364.1\tLN:15740\n@SQ\tSN:KB709165.1\tLN:15738\n@SQ\tSN:APMT01209332.1\tLN:15736\n@SQ\tSN:KB709186.1\tLN:15712\n@SQ\tSN:APMT01209381.1\tLN:15710\n@SQ\tSN:KB709184.1\tLN:15704\n@SQ\tSN:KB709168.1\tLN:15691\n@SQ\tSN:APMT01209389.1\tLN:15683\n@SQ\tSN:APMT01209387.1\tLN:15682\n@SQ\tSN:APMT01209386.1\tLN:15672\n@SQ\tSN:APMT01209396.1\tLN:15665\n@SQ\tSN:KB708999.1\tLN:15664\n@SQ\tSN:KB709257.1\tLN:15647\n@SQ\tSN:APMT01209400.1\tLN:15645\n@SQ\tSN:APMT01209402.1\tLN:15639\n@SQ\tSN:APMT01209380.1\tLN:15637\n@SQ\tSN:APMT01209401.1\tLN:15636\n@SQ\tSN:APMT01209403.1\tLN:15633\n@SQ\tSN:APMT01209388.1\tLN:15625\n@SQ\tSN:APMT01209415.1\tLN:15618\n@SQ\tSN:APMT01209416.1\tLN:15618\n@SQ\tSN:KB709153.1\tLN:15611\n@SQ\tSN:APMT01209421.1\tLN:15609\n@SQ\tSN:KB709194.1\tLN:15594\n@SQ\tSN:APMT01209465.1\tLN:15561\n@SQ\tSN:KB709151.1\tLN:15559\n@SQ\tSN:KB709101.1\tLN:15550\n@SQ\tSN:APMT01209477.1\tLN:15536\n@SQ\tSN:APMT01209455.1\tLN:15533\n@SQ\tSN:KB709272.1\tLN:15527\n@SQ\tSN:APMT01209484.1\tLN:15525\n@SQ\tSN:APMT01209485.1\tLN:15524\n@SQ\tSN:APMT01209502.1\tLN:15489\n@SQ\tSN:KB709207.1\tLN:15485\n@SQ\tSN:KB709199.1\tLN:15477\n@SQ\tSN:APMT01209516.1\tLN:15466\n@SQ\tSN:APMT01209515.1\tLN:15461\n@SQ\tSN:APMT01209517.1\tLN:15460\n@SQ\tSN:APMT01209518.1\tLN:15456\n@SQ\tSN:KB709203.1\tLN:15447\n@SQ\tSN:KB709041.1\tLN:15445\n@SQ\tSN:APMT01209520.1\tLN:15445\n@SQ\tSN:APMT01209521.1\tLN:15443\n@SQ\tSN:APMT01209527.1\tLN:15433\n@SQ\tSN:APMT01209514.1\tLN:15419\n@SQ\tSN:KB709190.1\tLN:15412\n@SQ\tSN:KB709307.1\tLN:15410\n@SQ\tSN:APMT01209519.1\tLN:15402\n@SQ\tSN:APMT01209547.1\tLN:15389\n@SQ\tSN:KB709553.1\tLN:15379\n@SQ\tSN:APMT01209549.1\tLN:15373\n@SQ\tSN:APMT01209560.1\tLN:15367\n@SQ\tSN:APMT01209561.1\tLN:15360\n@SQ\tSN:KB709235.1\tLN:15353\n@SQ\tSN:APMT01209548.1\tLN:15344\n@SQ\tSN:APMT01209546.1\tLN:15332\n@SQ\tSN:APMT01209554.1\tLN:15313\n@SQ\tSN:APMT01209562.1\tLN:15309\n@SQ\tSN:APMT01209577.1\tLN:15294\n@SQ\tSN:APMT01209588.1\tLN:15281\n@SQ\tSN:APMT01209589.1\tLN:15281\n@SQ\tSN:KB709271.1\tLN:15272\n@SQ\tSN:KB709152.1\tLN:15270\n@SQ\tSN:KB709239.1\tLN:15263\n@SQ\tSN:APMT01209571.1\tLN:15262\n@SQ\tSN:APMT01209576.1\tLN:15262\n@SQ\tSN:APMT01209590.1\tLN:15257\n@SQ\tSN:APMT01209591.1\tLN:15248\n@SQ\tSN:KB709544.1\tLN:15247\n@SQ\tSN:KB709102.1\tLN:15242\n@SQ\tSN:APMT01209596.1\tLN:15239\n@SQ\tSN:APMT01209601.1\tLN:15234\n@SQ\tSN:APMT01209602.1\tLN:15232\n@SQ\tSN:KB709229.1\tLN:15231\n@SQ\tSN:APMT01209603.1\tLN:15217\n@SQ\tSN:KB709304.1\tLN:15212\n@SQ\tSN:KB709342.1\tLN:15207\n@SQ\tSN:APMT01209611.1\tLN:15205\n@SQ\tSN:APMT01209609.1\tLN:15204\n@SQ\tSN:APMT01209608.1\tLN:15202\n@SQ\tSN:APMT01209615.1\tLN:15199\n@SQ\tSN:APMT01209616.1\tLN:15195\n@SQ\tSN:APMT01209617.1\tLN:15195\n@SQ\tSN:KB709210.1\tLN:15192\n@SQ\tSN:APMT01209610.1\tLN:15174\n@SQ\tSN:KB709204.1\tLN:15147\n@SQ\tSN:APMT01209636.1\tLN:15145\n@SQ\tSN:APMT01209645.1\tLN:15137\n@SQ\tSN:KB709225.1\tLN:15127\n@SQ\tSN:APMT01209658.1\tLN:15120\n@SQ\tSN:APMT01209635.1\tLN:15118\n@SQ\tSN:APMT01209659.1\tLN:15117\n@SQ\tSN:APMT01209660.1\tLN:15117\n@SQ\tSN:APMT01209661.1\tLN:15115\n@SQ\tSN:KB709220.1\tLN:15114\n@SQ\tSN:APMT01209607.1\tLN:15096\n@SQ\tSN:KB709361.1\tLN:15096\n@SQ\tSN:APMT01209668.1\tLN:15072\n@SQ\tSN:APMT01209669.1\tLN:15072\n@SQ\tSN:KB709202.1\tLN:15066\n@SQ\tSN:KB709138.1\tLN:15062\n@SQ\tSN:KB709224.1\tLN:15050\n@SQ\tSN:APMT01209685.1\tLN:15049\n@SQ\tSN:APMT01209691.1\tLN:15036\n@SQ\tSN:APMT01209692.1\tLN:15031\n@SQ\tSN:APMT01209693.1\tLN:15031\n@SQ\tSN:KB709251.1\tLN:15023\n@SQ\tSN:APMT01209695.1\tLN:15019\n@SQ\tSN:APMT01209701.1\tLN:15016\n@SQ\tSN:APMT01209702.1\tLN:15012\n@SQ\tSN:APMT01209714.1\tLN:14992\n@SQ\tSN:KB709260.1\tLN:14989\n@SQ\tSN:APMT01209715.1\tLN:14988\n@SQ\tSN:KB709485.1\tLN:14983\n@SQ\tSN:APMT01209719.1\tLN:14981\n@SQ\tSN:KB709193.1\tLN:14980\n@SQ\tSN:APMT01209708.1\tLN:14974\n@SQ\tSN:APMT01209694.1\tLN:14967\n@SQ\tSN:APMT01209721.1\tLN:14966\n@SQ\tSN:KB709384.1\tLN:14966\n@SQ\tSN:APMT01209733.1\tLN:14942\n@SQ\tSN:APMT01209734.1\tLN:14941\n@SQ\tSN:APMT01209732.1\tLN:14932\n@SQ\tSN:KB709388.1\tLN:14931\n@SQ\tSN:KB709275.1\tLN:14916\n@SQ\tSN:KB709236.1\tLN:14912\n@SQ\tSN:KB709143.1\tLN:14908\n@SQ\tSN:KB709233.1\tLN:14908\n@SQ\tSN:APMT01209720.1\tLN:14907\n@SQ\tSN:APMT01209722.1\tLN:14904\n@SQ\tSN:APMT01209737.1\tLN:14902\n@SQ\tSN:APMT01209744.1\tLN:14898\n@SQ\tSN:KB709344.1\tLN:14891\n@SQ\tSN:KB709386.1\tLN:14891\n@SQ\tSN:APMT01209745.1\tLN:14888\n@SQ\tSN:APMT01209735.1\tLN:14887\n@SQ\tSN:KB709245.1\tLN:14881\n@SQ\tSN:KB709242.1\tLN:14876\n@SQ\tSN:KB709583.1\tLN:14871\n@SQ\tSN:APMT01209736.1\tLN:14869\n@SQ\tSN:KB709495.1\tLN:14864\n@SQ\tSN:APMT01209746.1\tLN:14863\n@SQ\tSN:KB709223.1\tLN:14828\n@SQ\tSN:APMT01209764.1\tLN:14822\n@SQ\tSN:APMT01209754.1\tLN:14819\n@SQ\tSN:KB709104.1\tLN:14817\n@SQ\tSN:APMT01209771.1\tLN:14817\n@SQ\tSN:APMT01209765.1\tLN:14809\n@SQ\tSN:APMT01209753.1\tLN:14805\n@SQ\tSN:APMT01209783.1\tLN:14800\n@SQ\tSN:KB709336.1\tLN:14793\n@SQ\tSN:KB709081.1\tLN:14785\n@SQ\tSN:KB709261.1\tLN:14772\n@SQ\tSN:APMT01209782.1\tLN:14758\n@SQ\tSN:APMT01209801.1\tLN:14753\n@SQ\tSN:APMT01209772.1\tLN:14752\n@SQ\tSN:KB709459.1\tLN:14746\n@SQ\tSN:APMT01209807.1\tLN:14741\n@SQ\tSN:KB709347.1\tLN:14739\n@SQ\tSN:KB709442.1\tLN:14718\n@SQ\tSN:KB709243.1\tLN:14715\n@SQ\tSN:APMT01209825.1\tLN:14713\n@SQ\tSN:KB709329.1\tLN:14710\n@SQ\tSN:APMT01209834.1\tLN:14689\n@SQ\tSN:APMT01209835.1\tLN:14689\n@SQ\tSN:APMT01209836.1\tLN:14688\n@SQ\tSN:APMT01209839.1\tLN:14679\n@SQ\tSN:APMT01209840.1\tLN:14678\n@SQ\tSN:APMT01209838.1\tLN:14674\n@SQ\tSN:APMT01209837.1\tLN:14671\n@SQ\tSN:APMT01209814.1\tLN:14664\n@SQ\tSN:APMT01209800.1\tLN:14659\n@SQ\tSN:KB710154.1\tLN:14650\n@SQ\tSN:KB709254.1\tLN:14640\n@SQ\tSN:APMT01209855.1\tLN:14623\n@SQ\tSN:KB709067.1\tLN:14617\n@SQ\tSN:KB709301.1\tLN:14603\n@SQ\tSN:KB709206.1\tLN:14601\n@SQ\tSN:KB709106.1\tLN:14587\n@SQ\tSN:KB709323.1\tLN:14578\n@SQ\tSN:APMT01209854.1\tLN:14574\n@SQ\tSN:APMT01209864.1\tLN:14560\n@SQ\tSN:APMT01209869.1\tLN:14560\n@SQ\tSN:APMT01209870.1\tLN:14560\n@SQ\tSN:APMT01209876.1\tLN:14550\n@SQ\tSN:KB709335.1\tLN:14550\n@SQ\tSN:APMT01209863.1\tLN:14538\n@SQ\tSN:APMT01209883.1\tLN:14533\n@SQ\tSN:APMT01209884.1\tLN:14529\n@SQ\tSN:KB709373.1\tLN:14515\n@SQ\tSN:APMT01209893.1\tLN:14512\n@SQ\tSN:KB709444.1\tLN:14512\n@SQ\tSN:APMT01209894.1\tLN:14503\n@SQ\tSN:APMT01209908.1\tLN:14499\n@SQ\tSN:KB710454.1\tLN:14494\n@SQ\tSN:APMT01209913.1\tLN:14492\n@SQ\tSN:APMT01209914.1\tLN:14492\n@SQ\tSN:APMT01209877.1\tLN:14487\n@SQ\tSN:APMT01209885.1\tLN:14467\n@SQ\tSN:APMT01209892.1\tLN:14467\n@SQ\tSN:APMT01209920.1\tLN:14458\n@SQ\tSN:KB709262.1\tLN:14452\n@SQ\tSN:APMT01209922.1\tLN:14442\n@SQ\tSN:KB709259.1\tLN:14440\n@SQ\tSN:KB709269.1\tLN:14439\n@SQ\tSN:KB709173.1\tLN:14433\n@SQ\tSN:APMT01209923.1\tLN:14432\n@SQ\tSN:APMT01209925.1\tLN:14431\n@SQ\tSN:APMT01209926.1\tLN:14431\n@SQ\tSN:APMT01209927.1\tLN:14430\n@SQ\tSN:KB709256.1\tLN:14428\n@SQ\tSN:KB709425.1\tLN:14425\n@SQ\tSN:APMT01209919.1\tLN:14417\n@SQ\tSN:APMT01209928.1\tLN:14412\n@SQ\tSN:APMT01209929.1\tLN:14411\n@SQ\tSN:APMT01209931.1\tLN:14410\n@SQ\tSN:APMT01209921.1\tLN:14405\n@SQ\tSN:APMT01209935.1\tLN:14401\n@SQ\tSN:APMT01209936.1\tLN:14401\n@SQ\tSN:KB709364.1\tLN:14398\n@SQ\tSN:APMT01209951.1\tLN:14396\n@SQ\tSN:APMT01209947.1\tLN:14393\n@SQ\tSN:APMT01209952.1\tLN:14391\n@SQ\tSN:APMT01209953.1\tLN:14391\n@SQ\tSN:APMT01209957.1\tLN:14386\n@SQ\tSN:APMT01209958.1\tLN:14386\n@SQ\tSN:APMT01209924.1\tLN:14379\n@SQ\tSN:APMT01209959.1\tLN:14375\n@SQ\tSN:KB709330.1\tLN:14369\n@SQ\tSN:APMT01209960.1\tLN:14365\n@SQ\tSN:APMT01209961.1\tLN:14360\n@SQ\tSN:APMT01209930.1\tLN:14349\n@SQ\tSN:KB709268.1\tLN:14326\n@SQ\tSN:APMT01209971.1\tLN:14322\n@SQ\tSN:KB709249.1\tLN:14321\n@SQ\tSN:APMT01209988.1\tLN:14312\n@SQ\tSN:APMT01209989.1\tLN:14302\n@SQ\tSN:KB709280.1\tLN:14300\n@SQ\tSN:APMT01209987.1\tLN:14285\n@SQ\tSN:APMT01209995.1\tLN:14284\n@SQ\tSN:APMT01209972.1\tLN:14281\n@SQ\tSN:APMT01210035.1\tLN:14280\n@SQ\tSN:APMT01210003.1\tLN:14272\n@SQ\tSN:APMT01210002.1\tLN:14270\n@SQ\tSN:APMT01210004.1\tLN:14250\n@SQ\tSN:KB709420.1\tLN:14247\n@SQ\tSN:APMT01210006.1\tLN:14243\n@SQ\tSN:APMT01209990.1\tLN:14241\n@SQ\tSN:APMT01210005.1\tLN:14231\n@SQ\tSN:APMT01209996.1\tLN:14227\n@SQ\tSN:APMT01210011.1\tLN:14225\n@SQ\tSN:APMT01210017.1\tLN:14222\n@SQ\tSN:APMT01210018.1\tLN:14221\n@SQ\tSN:APMT01210019.1\tLN:14214\n@SQ\tSN:KB709430.1\tLN:14212\n@SQ\tSN:APMT01210020.1\tLN:14211\n@SQ\tSN:APMT01210022.1\tLN:14205\n@SQ\tSN:APMT01210021.1\tLN:14199\n@SQ\tSN:APMT01210030.1\tLN:14188\n@SQ\tSN:KB709379.1\tLN:14170\n@SQ\tSN:APMT01210043.1\tLN:14164\n@SQ\tSN:KB709294.1\tLN:14164\n@SQ\tSN:KB710103.1\tLN:14157\n@SQ\tSN:KB709214.1\tLN:14154\n@SQ\tSN:APMT01210044.1\tLN:14153\n@SQ\tSN:APMT01210050.1\tLN:14150\n@SQ\tSN:APMT01210051.1\tLN:14150\n@SQ\tSN:KB709665.1\tLN:14141\n@SQ\tSN:APMT01210058.1\tLN:14131\n@SQ\tSN:KB709285.1\tLN:14126\n@SQ\tSN:APMT01210036.1\tLN:14120\n@SQ\tSN:KB709213.1\tLN:14119\n@SQ\tSN:APMT01210060.1\tLN:14114\n@SQ\tSN:KB709368.1\tLN:14114\n@SQ\tSN:KB709284.1\tLN:14112\n@SQ\tSN:APMT01210063.1\tLN:14104\n@SQ\tSN:KB709510.1\tLN:14104\n@SQ\tSN:APMT01210064.1\tLN:14093\n@SQ\tSN:APMT01210052.1\tLN:14089\n@SQ\tSN:KB709306.1\tLN:14089\n@SQ\tSN:APMT01210065.1\tLN:14077\n@SQ\tSN:KB709286.1\tLN:14076\n@SQ\tSN:APMT01210067.1\tLN:14071\n@SQ\tSN:APMT01210068.1\tLN:14071\n@SQ\tSN:KB709278.1\tLN:14070\n@SQ\tSN:APMT01210069.1\tLN:14067\n@SQ\tSN:APMT01210070.1\tLN:14067\n@SQ\tSN:APMT01210066.1\tLN:14056\n@SQ\tSN:APMT01210071.1\tLN:14050\n@SQ\tSN:APMT01210072.1\tLN:14050\n@SQ\tSN:KB709331.1\tLN:14049\n@SQ\tSN:APMT01210059.1\tLN:14041\n@SQ\tSN:APMT01210081.1\tLN:14035\n@SQ\tSN:APMT01210073.1\tLN:14029\n@SQ\tSN:KB709293.1\tLN:14029\n@SQ\tSN:APMT01210082.1\tLN:14015\n@SQ\tSN:APMT01210083.1\tLN:14015\n@SQ\tSN:APMT01210084.1\tLN:14015\n@SQ\tSN:KB709282.1\tLN:14014\n@SQ\tSN:APMT01210088.1\tLN:14006\n@SQ\tSN:APMT01210089.1\tLN:14003\n@SQ\tSN:KB709112.1\tLN:13996\n@SQ\tSN:APMT01210074.1\tLN:13990\n@SQ\tSN:APMT01210095.1\tLN:13989\n@SQ\tSN:APMT01210096.1\tLN:13976\n@SQ\tSN:KB709321.1\tLN:13973\n@SQ\tSN:KB709298.1\tLN:13951\n@SQ\tSN:KB709365.1\tLN:13951\n@SQ\tSN:APMT01210099.1\tLN:13948\n@SQ\tSN:KB709418.1\tLN:13934\n@SQ\tSN:APMT01210098.1\tLN:13932\n@SQ\tSN:KB709462.1\tLN:13926\n@SQ\tSN:APMT01210118.1\tLN:13918\n@SQ\tSN:APMT01210097.1\tLN:13914\n@SQ\tSN:APMT01210119.1\tLN:13912\n@SQ\tSN:APMT01210120.1\tLN:13905\n@SQ\tSN:APMT01210121.1\tLN:13905\n@SQ\tSN:APMT01210122.1\tLN:13901\n@SQ\tSN:APMT01210100.1\tLN:13892\n@SQ\tSN:APMT01210124.1\tLN:13892\n@SQ\tSN:APMT01210125.1\tLN:13888\n@SQ\tSN:APMT01210136.1\tLN:13864\n@SQ\tSN:KB709415.1\tLN:13854\n@SQ\tSN:APMT01210123.1\tLN:13851\n@SQ\tSN:KB709381.1\tLN:13845\n@SQ\tSN:APMT01210153.1\tLN:13833\n@SQ\tSN:APMT01210154.1\tLN:13831\n@SQ\tSN:APMT01210155.1\tLN:13822\n@SQ\tSN:APMT01210156.1\tLN:13822\n@SQ\tSN:APMT01210157.1\tLN:13822\n@SQ\tSN:KB709287.1\tLN:13819\n@SQ\tSN:APMT01210135.1\tLN:13808\n@SQ\tSN:APMT01210176.1\tLN:13804\n@SQ\tSN:APMT01210147.1\tLN:13801\n@SQ\tSN:APMT01210185.1\tLN:13801\n@SQ\tSN:KB709985.1\tLN:13798\n@SQ\tSN:KB709240.1\tLN:13794\n@SQ\tSN:APMT01210177.1\tLN:13793\n@SQ\tSN:APMT01210187.1\tLN:13792\n@SQ\tSN:APMT01210186.1\tLN:13791\n@SQ\tSN:APMT01210178.1\tLN:13790\n@SQ\tSN:KB709334.1\tLN:13786\n@SQ\tSN:APMT01210158.1\tLN:13771\n@SQ\tSN:APMT01210191.1\tLN:13765\n@SQ\tSN:KB709297.1\tLN:13763\n@SQ\tSN:APMT01210208.1\tLN:13752\n@SQ\tSN:APMT01210209.1\tLN:13752\n@SQ\tSN:APMT01210202.1\tLN:13751\n@SQ\tSN:APMT01210210.1\tLN:13744\n@SQ\tSN:APMT01210215.1\tLN:13729\n@SQ\tSN:KB709533.1\tLN:13709\n@SQ\tSN:APMT01210229.1\tLN:13700\n@SQ\tSN:APMT01210211.1\tLN:13695\n@SQ\tSN:APMT01210231.1\tLN:13688\n@SQ\tSN:KB709108.1\tLN:13676\n@SQ\tSN:APMT01210248.1\tLN:13671\n@SQ\tSN:APMT01210249.1\tLN:13671\n@SQ\tSN:APMT01210251.1\tLN:13666\n@SQ\tSN:APMT01210252.1\tLN:13664\n@SQ\tSN:APMT01210230.1\tLN:13659\n@SQ\tSN:APMT01210253.1\tLN:13645\n@SQ\tSN:APMT01210270.1\tLN:13637\n@SQ\tSN:APMT01210271.1\tLN:13636\n@SQ\tSN:APMT01210280.1\tLN:13623\n@SQ\tSN:KB709313.1\tLN:13618\n@SQ\tSN:APMT01210287.1\tLN:13615\n@SQ\tSN:KB709682.1\tLN:13609\n@SQ\tSN:KB709319.1\tLN:13606\n@SQ\tSN:KB709291.1\tLN:13605\n@SQ\tSN:APMT01210296.1\tLN:13603\n@SQ\tSN:KB709369.1\tLN:13597\n@SQ\tSN:APMT01210250.1\tLN:13595\n@SQ\tSN:KB709348.1\tLN:13595\n@SQ\tSN:APMT01210257.1\tLN:13589\n@SQ\tSN:APMT01210279.1\tLN:13586\n@SQ\tSN:APMT01210298.1\tLN:13583\n@SQ\tSN:KB709328.1\tLN:13574\n@SQ\tSN:KB709326.1\tLN:13572\n@SQ\tSN:KB709351.1\tLN:13565\n@SQ\tSN:KB709359.1\tLN:13552\n@SQ\tSN:KB709308.1\tLN:13545\n@SQ\tSN:APMT01210297.1\tLN:13543\n@SQ\tSN:KB709610.1\tLN:13542\n@SQ\tSN:KB709303.1\tLN:13534\n@SQ\tSN:APMT01210320.1\tLN:13533\n@SQ\tSN:APMT01210327.1\tLN:13529\n@SQ\tSN:APMT01210325.1\tLN:13525\n@SQ\tSN:APMT01210326.1\tLN:13525\n@SQ\tSN:KB709333.1\tLN:13515\n@SQ\tSN:KB709318.1\tLN:13513\n@SQ\tSN:APMT01210336.1\tLN:13513\n@SQ\tSN:APMT01210328.1\tLN:13501\n@SQ\tSN:KB709545.1\tLN:13494\n@SQ\tSN:KB709253.1\tLN:13493\n@SQ\tSN:KB709350.1\tLN:13481\n@SQ\tSN:APMT01210351.1\tLN:13480\n@SQ\tSN:APMT01210367.1\tLN:13478\n@SQ\tSN:APMT01210368.1\tLN:13465\n@SQ\tSN:KB709299.1\tLN:13463\n@SQ\tSN:APMT01210356.1\tLN:13460\n@SQ\tSN:KB709521.1\tLN:13456\n@SQ\tSN:KB709320.1\tLN:13453\n@SQ\tSN:APMT01210369.1\tLN:13453\n@SQ\tSN:KB709325.1\tLN:13450\n@SQ\tSN:APMT01210315.1\tLN:13450\n@SQ\tSN:APMT01210350.1\tLN:13438\n@SQ\tSN:APMT01210374.1\tLN:13438\n@SQ\tSN:APMT01210375.1\tLN:13438\n@SQ\tSN:KB709479.1\tLN:13436\n@SQ\tSN:APMT01210380.1\tLN:13431\n@SQ\tSN:KB709310.1\tLN:13430\n@SQ\tSN:APMT01210386.1\tLN:13424\n@SQ\tSN:APMT01210398.1\tLN:13413\n@SQ\tSN:APMT01210329.1\tLN:13409\n@SQ\tSN:APMT01210399.1\tLN:13398\n@SQ\tSN:KB709439.1\tLN:13398\n@SQ\tSN:APMT01210400.1\tLN:13395\n@SQ\tSN:APMT01210401.1\tLN:13387\n@SQ\tSN:APMT01210402.1\tLN:13387\n@SQ\tSN:APMT01210403.1\tLN:13384\n@SQ\tSN:KB709292.1\tLN:13381\n@SQ\tSN:APMT01210410.1\tLN:13377\n@SQ\tSN:APMT01210420.1\tLN:13371\n@SQ\tSN:APMT01210421.1\tLN:13371\n@SQ\tSN:APMT01210422.1\tLN:13368\n@SQ\tSN:APMT01210438.1\tLN:13362\n@SQ\tSN:APMT01210439.1\tLN:13362\n@SQ\tSN:KB710905.1\tLN:13361\n@SQ\tSN:KB709382.1\tLN:13358\n@SQ\tSN:APMT01210445.1\tLN:13354\n@SQ\tSN:APMT01210449.1\tLN:13346\n@SQ\tSN:APMT01210456.1\tLN:13346\n@SQ\tSN:KB709288.1\tLN:13341\n@SQ\tSN:APMT01210457.1\tLN:13341\n@SQ\tSN:KB709188.1\tLN:13334\n@SQ\tSN:KB709341.1\tLN:13311\n@SQ\tSN:KB709317.1\tLN:13304\n@SQ\tSN:APMT01210473.1\tLN:13285\n@SQ\tSN:APMT01210474.1\tLN:13276\n@SQ\tSN:KB709339.1\tLN:13266\n@SQ\tSN:APMT01210515.1\tLN:13258\n@SQ\tSN:KB709409.1\tLN:13258\n@SQ\tSN:APMT01210483.1\tLN:13257\n@SQ\tSN:APMT01210484.1\tLN:13255\n@SQ\tSN:APMT01210471.1\tLN:13254\n@SQ\tSN:APMT01210485.1\tLN:13243\n@SQ\tSN:KB709405.1\tLN:13243\n@SQ\tSN:APMT01210486.1\tLN:13240\n@SQ\tSN:APMT01210472.1\tLN:13234\n@SQ\tSN:KB709367.1\tLN:13232\n@SQ\tSN:KB709279.1\tLN:13229\n@SQ\tSN:APMT01210496.1\tLN:13219\n@SQ\tSN:APMT01210482.1\tLN:13210\n@SQ\tSN:APMT01210502.1\tLN:13209\n@SQ\tSN:KB709511.1\tLN:13209\n@SQ\tSN:KB709217.1\tLN:13208\n@SQ\tSN:APMT01210506.1\tLN:13200\n@SQ\tSN:APMT01210507.1\tLN:13200\n@SQ\tSN:KB709169.1\tLN:13199\n@SQ\tSN:APMT01210508.1\tLN:13196\n@SQ\tSN:KB709668.1\tLN:13185\n@SQ\tSN:APMT01210514.1\tLN:13180\n@SQ\tSN:APMT01210516.1\tLN:13170\n@SQ\tSN:KB709354.1\tLN:13165\n@SQ\tSN:APMT01210495.1\tLN:13160\n@SQ\tSN:APMT01210501.1\tLN:13156\n@SQ\tSN:KB709352.1\tLN:13153\n@SQ\tSN:KB709397.1\tLN:13147\n@SQ\tSN:KB709403.1\tLN:13141\n@SQ\tSN:APMT01210521.1\tLN:13132\n@SQ\tSN:APMT01210523.1\tLN:13125\n@SQ\tSN:APMT01210530.1\tLN:13115\n@SQ\tSN:APMT01210520.1\tLN:13111\n@SQ\tSN:APMT01210531.1\tLN:13108\n@SQ\tSN:KB709205.1\tLN:13105\n@SQ\tSN:APMT01210545.1\tLN:13105\n@SQ\tSN:KB709499.1\tLN:13093\n@SQ\tSN:APMT01210552.1\tLN:13088\n@SQ\tSN:APMT01210553.1\tLN:13088\n@SQ\tSN:APMT01210549.1\tLN:13086\n@SQ\tSN:APMT01210560.1\tLN:13084\n@SQ\tSN:APMT01210561.1\tLN:13084\n@SQ\tSN:APMT01210574.1\tLN:13069\n@SQ\tSN:APMT01210575.1\tLN:13069\n@SQ\tSN:APMT01210522.1\tLN:13068\n@SQ\tSN:APMT01210573.1\tLN:13063\n@SQ\tSN:KB709267.1\tLN:13062\n@SQ\tSN:APMT01210585.1\tLN:13027\n@SQ\tSN:APMT01210584.1\tLN:13026\n@SQ\tSN:KB709400.1\tLN:13026\n@SQ\tSN:APMT01210562.1\tLN:13023\n@SQ\tSN:APMT01210572.1\tLN:13022\n@SQ\tSN:APMT01210592.1\tLN:13013\n@SQ\tSN:KB709374.1\tLN:13013\n@SQ\tSN:APMT01210606.1\tLN:13002\n@SQ\tSN:KB709332.1\tLN:12997\n@SQ\tSN:APMT01210580.1\tLN:12992\n@SQ\tSN:APMT01210618.1\tLN:12992\n@SQ\tSN:APMT01210586.1\tLN:12989\n@SQ\tSN:KB709456.1\tLN:12976\n@SQ\tSN:APMT01210619.1\tLN:12975\n@SQ\tSN:APMT01210634.1\tLN:12969\n@SQ\tSN:KB709941.1\tLN:12967\n@SQ\tSN:APMT01210633.1\tLN:12963\n@SQ\tSN:KB709383.1\tLN:12955\n@SQ\tSN:KB709402.1\tLN:12954\n@SQ\tSN:APMT01210605.1\tLN:12944\n@SQ\tSN:APMT01210645.1\tLN:12942\n@SQ\tSN:APMT01210646.1\tLN:12942\n@SQ\tSN:APMT01210640.1\tLN:12941\n@SQ\tSN:KB709390.1\tLN:12941\n@SQ\tSN:APMT01210647.1\tLN:12939\n@SQ\tSN:APMT01210654.1\tLN:12933\n@SQ\tSN:APMT01210656.1\tLN:12925\n@SQ\tSN:APMT01210632.1\tLN:12920\n@SQ\tSN:KB709683.1\tLN:12914\n@SQ\tSN:KB709455.1\tLN:12912\n@SQ\tSN:APMT01210677.1\tLN:12907\n@SQ\tSN:APMT01210678.1\tLN:12895\n@SQ\tSN:APMT01210679.1\tLN:12895\n@SQ\tSN:KB709675.1\tLN:12894\n@SQ\tSN:APMT01210680.1\tLN:12891\n@SQ\tSN:APMT01210688.1\tLN:12883\n@SQ\tSN:APMT01210655.1\tLN:12873\n@SQ\tSN:KB709427.1\tLN:12870\n@SQ\tSN:KB710100.1\tLN:12868\n@SQ\tSN:APMT01210662.1\tLN:12863\n@SQ\tSN:APMT01210689.1\tLN:12863\n@SQ\tSN:APMT01210663.1\tLN:12861\n@SQ\tSN:KB709238.1\tLN:12851\n@SQ\tSN:KB709295.1\tLN:12849\n@SQ\tSN:KB709463.1\tLN:12831\n@SQ\tSN:KB709377.1\tLN:12830\n@SQ\tSN:KB709340.1\tLN:12829\n@SQ\tSN:APMT01210716.1\tLN:12828\n@SQ\tSN:APMT01210703.1\tLN:12827\n@SQ\tSN:KB709378.1\tLN:12817\n@SQ\tSN:APMT01210722.1\tLN:12816\n@SQ\tSN:APMT01210728.1\tLN:12810\n@SQ\tSN:APMT01210729.1\tLN:12810\n@SQ\tSN:APMT01210691.1\tLN:12803\n@SQ\tSN:APMT01210692.1\tLN:12792\n@SQ\tSN:APMT01210744.1\tLN:12792\n@SQ\tSN:KB709394.1\tLN:12786\n@SQ\tSN:APMT01210690.1\tLN:12784\n@SQ\tSN:KB709438.1\tLN:12756\n@SQ\tSN:APMT01210761.1\tLN:12755\n@SQ\tSN:APMT01210763.1\tLN:12751\n@SQ\tSN:APMT01210764.1\tLN:12751\n@SQ\tSN:APMT01210760.1\tLN:12744\n@SQ\tSN:APMT01210765.1\tLN:12743\n@SQ\tSN:KB709246.1\tLN:12731\n@SQ\tSN:KB709467.1\tLN:12721\n@SQ\tSN:APMT01210774.1\tLN:12719\n@SQ\tSN:APMT01210775.1\tLN:12718\n@SQ\tSN:KB709356.1\tLN:12696\n@SQ\tSN:APMT01210791.1\tLN:12692\n@SQ\tSN:APMT01210794.1\tLN:12684\n@SQ\tSN:APMT01210795.1\tLN:12681\n@SQ\tSN:KB710037.1\tLN:12681\n@SQ\tSN:APMT01210802.1\tLN:12676\n@SQ\tSN:APMT01210762.1\tLN:12669\n@SQ\tSN:APMT01210816.1\tLN:12668\n@SQ\tSN:KB709435.1\tLN:12657\n@SQ\tSN:KB709375.1\tLN:12655\n@SQ\tSN:KB709387.1\tLN:12655\n@SQ\tSN:APMT01210818.1\tLN:12655\n@SQ\tSN:APMT01210819.1\tLN:12651\n@SQ\tSN:APMT01210793.1\tLN:12648\n@SQ\tSN:APMT01210821.1\tLN:12644\n@SQ\tSN:APMT01210820.1\tLN:12639\n@SQ\tSN:APMT01210830.1\tLN:12638\n@SQ\tSN:APMT01210800.1\tLN:12628\n@SQ\tSN:APMT01210792.1\tLN:12625\n@SQ\tSN:APMT01210842.1\tLN:12624\n@SQ\tSN:APMT01210833.1\tLN:12623\n@SQ\tSN:APMT01210841.1\tLN:12623\n@SQ\tSN:APMT01210801.1\tLN:12622\n@SQ\tSN:APMT01210829.1\tLN:12618\n@SQ\tSN:APMT01210844.1\tLN:12609\n@SQ\tSN:APMT01210846.1\tLN:12606\n@SQ\tSN:APMT01210817.1\tLN:12603\n@SQ\tSN:APMT01210847.1\tLN:12602\n@SQ\tSN:APMT01210849.1\tLN:12600\n@SQ\tSN:APMT01210850.1\tLN:12600\n@SQ\tSN:APMT01210851.1\tLN:12595\n@SQ\tSN:APMT01210852.1\tLN:12595\n@SQ\tSN:APMT01210853.1\tLN:12590\n@SQ\tSN:APMT01210848.1\tLN:12589\n@SQ\tSN:KB709471.1\tLN:12588\n@SQ\tSN:APMT01210843.1\tLN:12587\n@SQ\tSN:APMT01210845.1\tLN:12583\n@SQ\tSN:APMT01210854.1\tLN:12583\n@SQ\tSN:APMT01210856.1\tLN:12579\n@SQ\tSN:KB709807.1\tLN:12578\n@SQ\tSN:KB709270.1\tLN:12560\n@SQ\tSN:KB709437.1\tLN:12556\n@SQ\tSN:KB709550.1\tLN:12556\n@SQ\tSN:APMT01210869.1\tLN:12555\n@SQ\tSN:APMT01210870.1\tLN:12555\n@SQ\tSN:KB709414.1\tLN:12547\n@SQ\tSN:APMT01210871.1\tLN:12547\n@SQ\tSN:APMT01210880.1\tLN:12538\n@SQ\tSN:APMT01210888.1\tLN:12534\n@SQ\tSN:APMT01210889.1\tLN:12534\n@SQ\tSN:APMT01210890.1\tLN:12534\n@SQ\tSN:APMT01210855.1\tLN:12532\n@SQ\tSN:KB709588.1\tLN:12529\n@SQ\tSN:APMT01210892.1\tLN:12528\n@SQ\tSN:APMT01210893.1\tLN:12524\n@SQ\tSN:APMT01210895.1\tLN:12516\n@SQ\tSN:APMT01210894.1\tLN:12515\n@SQ\tSN:APMT01210891.1\tLN:12514\n@SQ\tSN:APMT01210864.1\tLN:12511\n@SQ\tSN:APMT01210902.1\tLN:12502\n@SQ\tSN:APMT01210905.1\tLN:12500\n@SQ\tSN:APMT01210908.1\tLN:12491\n@SQ\tSN:APMT01210933.1\tLN:12490\n@SQ\tSN:APMT01210925.1\tLN:12485\n@SQ\tSN:APMT01210881.1\tLN:12480\n@SQ\tSN:APMT01210907.1\tLN:12480\n@SQ\tSN:APMT01210915.1\tLN:12475\n@SQ\tSN:APMT01210917.1\tLN:12467\n@SQ\tSN:APMT01210914.1\tLN:12460\n@SQ\tSN:APMT01210918.1\tLN:12460\n@SQ\tSN:KB709360.1\tLN:12459\n@SQ\tSN:APMT01210924.1\tLN:12458\n@SQ\tSN:APMT01210927.1\tLN:12456\n@SQ\tSN:APMT01210906.1\tLN:12454\n@SQ\tSN:APMT01210928.1\tLN:12454\n@SQ\tSN:APMT01210929.1\tLN:12452\n@SQ\tSN:KB709404.1\tLN:12445\n@SQ\tSN:APMT01210879.1\tLN:12441\n@SQ\tSN:KB709407.1\tLN:12439\n@SQ\tSN:KB709601.1\tLN:12437\n@SQ\tSN:APMT01210934.1\tLN:12432\n@SQ\tSN:KB709195.1\tLN:12427\n@SQ\tSN:APMT01210926.1\tLN:12427\n@SQ\tSN:APMT01210946.1\tLN:12426\n@SQ\tSN:APMT01210945.1\tLN:12422\n@SQ\tSN:KB709445.1\tLN:12419\n@SQ\tSN:APMT01210947.1\tLN:12411\n@SQ\tSN:KB709721.1\tLN:12410\n@SQ\tSN:APMT01210916.1\tLN:12409\n@SQ\tSN:KB709450.1\tLN:12404\n@SQ\tSN:KB709431.1\tLN:12402\n@SQ\tSN:APMT01210952.1\tLN:12399\n@SQ\tSN:APMT01210953.1\tLN:12399\n@SQ\tSN:KB709371.1\tLN:12398\n@SQ\tSN:APMT01210964.1\tLN:12384\n@SQ\tSN:APMT01210970.1\tLN:12381\n@SQ\tSN:KB709443.1\tLN:12380\n@SQ\tSN:APMT01210971.1\tLN:12379\n@SQ\tSN:APMT01210972.1\tLN:12377\n@SQ\tSN:APMT01210973.1\tLN:12377\n@SQ\tSN:APMT01210977.1\tLN:12360\n@SQ\tSN:KB709189.1\tLN:12353\n@SQ\tSN:APMT01210978.1\tLN:12350\n@SQ\tSN:KB709401.1\tLN:12348\n@SQ\tSN:APMT01210979.1\tLN:12346\n@SQ\tSN:APMT01211006.1\tLN:12346\n@SQ\tSN:KB709428.1\tLN:12345\n@SQ\tSN:KB709801.1\tLN:12342\n@SQ\tSN:APMT01210987.1\tLN:12340\n@SQ\tSN:KB709263.1\tLN:12339\n@SQ\tSN:APMT01210994.1\tLN:12329\n@SQ\tSN:KB709413.1\tLN:12325\n@SQ\tSN:KB709434.1\tLN:12325\n@SQ\tSN:KB709429.1\tLN:12322\n@SQ\tSN:APMT01210969.1\tLN:12322\n@SQ\tSN:APMT01210986.1\tLN:12316\n@SQ\tSN:APMT01211004.1\tLN:12316\n@SQ\tSN:APMT01211005.1\tLN:12316\n@SQ\tSN:KB709441.1\tLN:12311\n@SQ\tSN:KB709469.1\tLN:12304\n@SQ\tSN:KB709592.1\tLN:12304\n@SQ\tSN:APMT01211009.1\tLN:12303\n@SQ\tSN:APMT01211010.1\tLN:12300\n@SQ\tSN:APMT01211011.1\tLN:12300\n@SQ\tSN:APMT01211017.1\tLN:12295\n@SQ\tSN:KB709380.1\tLN:12293\n@SQ\tSN:APMT01211007.1\tLN:12291\n@SQ\tSN:APMT01211003.1\tLN:12287\n@SQ\tSN:APMT01211030.1\tLN:12283\n@SQ\tSN:APMT01211031.1\tLN:12281\n@SQ\tSN:APMT01211032.1\tLN:12281\n@SQ\tSN:APMT01211034.1\tLN:12280\n@SQ\tSN:APMT01211035.1\tLN:12280\n@SQ\tSN:APMT01211036.1\tLN:12279\n@SQ\tSN:APMT01211002.1\tLN:12276\n@SQ\tSN:APMT01210993.1\tLN:12272\n@SQ\tSN:APMT01211033.1\tLN:12271\n@SQ\tSN:KB709393.1\tLN:12270\n@SQ\tSN:APMT01211043.1\tLN:12260\n@SQ\tSN:APMT01211045.1\tLN:12250\n@SQ\tSN:KB709440.1\tLN:12250\n@SQ\tSN:KB709421.1\tLN:12249\n@SQ\tSN:APMT01211046.1\tLN:12249\n@SQ\tSN:APMT01211023.1\tLN:12248\n@SQ\tSN:APMT01211044.1\tLN:12248\n@SQ\tSN:APMT01211047.1\tLN:12248\n@SQ\tSN:APMT01211048.1\tLN:12248\n@SQ\tSN:APMT01211008.1\tLN:12246\n@SQ\tSN:APMT01211049.1\tLN:12246\n@SQ\tSN:APMT01211050.1\tLN:12246\n@SQ\tSN:APMT01211051.1\tLN:12244\n@SQ\tSN:APMT01211016.1\tLN:12240\n@SQ\tSN:APMT01211069.1\tLN:12233\n@SQ\tSN:APMT01211024.1\tLN:12232\n@SQ\tSN:APMT01211052.1\tLN:12231\n@SQ\tSN:KB709398.1\tLN:12215\n@SQ\tSN:APMT01211042.1\tLN:12215\n@SQ\tSN:KB709494.1\tLN:12211\n@SQ\tSN:APMT01211068.1\tLN:12206\n@SQ\tSN:APMT01211070.1\tLN:12200\n@SQ\tSN:KB709423.1\tLN:12199\n@SQ\tSN:APMT01211071.1\tLN:12199\n@SQ\tSN:APMT01211056.1\tLN:12184\n@SQ\tSN:KB709424.1\tLN:12178\n@SQ\tSN:APMT01211082.1\tLN:12174\n@SQ\tSN:APMT01211090.1\tLN:12161\n@SQ\tSN:APMT01211095.1\tLN:12158\n@SQ\tSN:KB709498.1\tLN:12153\n@SQ\tSN:APMT01211096.1\tLN:12151\n@SQ\tSN:APMT01211097.1\tLN:12150\n@SQ\tSN:KB709448.1\tLN:12149\n@SQ\tSN:APMT01211100.1\tLN:12145\n@SQ\tSN:APMT01211105.1\tLN:12143\n@SQ\tSN:APMT01211106.1\tLN:12143\n@SQ\tSN:KB709472.1\tLN:12138\n@SQ\tSN:KB709166.1\tLN:12130\n@SQ\tSN:APMT01211081.1\tLN:12124\n@SQ\tSN:APMT01211116.1\tLN:12112\n@SQ\tSN:APMT01211137.1\tLN:12097\n@SQ\tSN:APMT01211138.1\tLN:12091\n@SQ\tSN:APMT01211140.1\tLN:12089\n@SQ\tSN:APMT01211141.1\tLN:12087\n@SQ\tSN:APMT01211142.1\tLN:12087\n@SQ\tSN:KB709453.1\tLN:12082\n@SQ\tSN:KB709411.1\tLN:12081\n@SQ\tSN:APMT01211148.1\tLN:12069\n@SQ\tSN:APMT01211149.1\tLN:12069\n@SQ\tSN:APMT01211150.1\tLN:12068\n@SQ\tSN:APMT01211109.1\tLN:12064\n@SQ\tSN:KB710568.1\tLN:12048\n@SQ\tSN:APMT01211160.1\tLN:12046\n@SQ\tSN:APMT01211161.1\tLN:12046\n@SQ\tSN:APMT01211162.1\tLN:12046\n@SQ\tSN:APMT01211139.1\tLN:12038\n@SQ\tSN:APMT01211158.1\tLN:12030\n@SQ\tSN:KB709178.1\tLN:12023\n@SQ\tSN:APMT01211146.1\tLN:12022\n@SQ\tSN:APMT01211147.1\tLN:12020\n@SQ\tSN:APMT01211169.1\tLN:12017\n@SQ\tSN:APMT01211178.1\tLN:11999\n@SQ\tSN:KB709493.1\tLN:11997\n@SQ\tSN:APMT01211170.1\tLN:11996\n@SQ\tSN:APMT01211159.1\tLN:11994\n@SQ\tSN:APMT01211188.1\tLN:11991\n@SQ\tSN:APMT01211193.1\tLN:11985\n@SQ\tSN:APMT01211196.1\tLN:11983\n@SQ\tSN:APMT01211197.1\tLN:11976\n@SQ\tSN:APMT01211198.1\tLN:11976\n@SQ\tSN:KB710174.1\tLN:11974\n@SQ\tSN:APMT01211199.1\tLN:11972\n@SQ\tSN:APMT01211201.1\tLN:11968\n@SQ\tSN:APMT01211202.1\tLN:11967\n@SQ\tSN:KB709433.1\tLN:11965\n@SQ\tSN:KB709466.1\tLN:11965\n@SQ\tSN:KB709460.1\tLN:11948\n@SQ\tSN:APMT01211168.1\tLN:11946\n@SQ\tSN:KB710073.1\tLN:11943\n@SQ\tSN:KB709474.1\tLN:11941\n@SQ\tSN:KB709477.1\tLN:11932\n@SQ\tSN:KB709385.1\tLN:11928\n@SQ\tSN:KB709464.1\tLN:11927\n@SQ\tSN:APMT01211167.1\tLN:11925\n@SQ\tSN:APMT01211225.1\tLN:11924\n@SQ\tSN:APMT01211226.1\tLN:11924\n@SQ\tSN:APMT01211233.1\tLN:11918\n@SQ\tSN:APMT01211234.1\tLN:11918\n@SQ\tSN:APMT01211200.1\tLN:11912\n@SQ\tSN:APMT01211235.1\tLN:11909\n@SQ\tSN:APMT01211236.1\tLN:11907\n@SQ\tSN:KB709571.1\tLN:11905\n@SQ\tSN:KB709644.1\tLN:11903\n@SQ\tSN:KB709735.1\tLN:11899\n@SQ\tSN:APMT01211238.1\tLN:11897\n@SQ\tSN:APMT01211224.1\tLN:11895\n@SQ\tSN:APMT01211220.1\tLN:11894\n@SQ\tSN:KB710279.1\tLN:11884\n@SQ\tSN:KB709520.1\tLN:11877\n@SQ\tSN:APMT01211247.1\tLN:11874\n@SQ\tSN:APMT01211248.1\tLN:11868\n@SQ\tSN:KB709541.1\tLN:11866\n@SQ\tSN:APMT01211261.1\tLN:11858\n@SQ\tSN:APMT01211237.1\tLN:11857\n@SQ\tSN:APMT01211263.1\tLN:11855\n@SQ\tSN:APMT01211264.1\tLN:11855\n@SQ\tSN:APMT01211260.1\tLN:11854\n@SQ\tSN:APMT01211265.1\tLN:11851\n@SQ\tSN:APMT01211254.1\tLN:11850\n@SQ\tSN:APMT01211262.1\tLN:11845\n@SQ\tSN:KB709566.1\tLN:11842\n@SQ\tSN:KB709488.1\tLN:11839\n@SQ\tSN:APMT01211275.1\tLN:11831\n@SQ\tSN:APMT01211279.1\tLN:11830\n@SQ\tSN:APMT01211280.1\tLN:11827\n@SQ\tSN:APMT01211282.1\tLN:11823\n@SQ\tSN:KB709481.1\tLN:11821\n@SQ\tSN:APMT01211286.1\tLN:11812\n@SQ\tSN:APMT01211294.1\tLN:11811\n@SQ\tSN:APMT01211299.1\tLN:11808\n@SQ\tSN:APMT01211281.1\tLN:11805\n@SQ\tSN:APMT01211255.1\tLN:11803\n@SQ\tSN:KB709221.1\tLN:11802\n@SQ\tSN:KB709554.1\tLN:11800\n@SQ\tSN:APMT01211304.1\tLN:11797\n@SQ\tSN:APMT01211306.1\tLN:11797\n@SQ\tSN:KB709543.1\tLN:11792\n@SQ\tSN:APMT01211314.1\tLN:11787\n@SQ\tSN:APMT01211315.1\tLN:11787\n@SQ\tSN:APMT01211316.1\tLN:11781\n@SQ\tSN:KB709613.1\tLN:11781\n@SQ\tSN:APMT01211317.1\tLN:11775\n@SQ\tSN:KB709587.1\tLN:11774\n@SQ\tSN:APMT01211322.1\tLN:11770\n@SQ\tSN:APMT01211330.1\tLN:11769\n@SQ\tSN:KB709500.1\tLN:11769\n@SQ\tSN:APMT01211337.1\tLN:11760\n@SQ\tSN:APMT01211338.1\tLN:11759\n@SQ\tSN:APMT01211274.1\tLN:11755\n@SQ\tSN:APMT01211293.1\tLN:11754\n@SQ\tSN:APMT01211305.1\tLN:11753\n@SQ\tSN:APMT01211345.1\tLN:11744\n@SQ\tSN:KB709449.1\tLN:11743\n@SQ\tSN:APMT01211321.1\tLN:11740\n@SQ\tSN:KB710139.1\tLN:11738\n@SQ\tSN:KB709483.1\tLN:11731\n@SQ\tSN:APMT01211331.1\tLN:11725\n@SQ\tSN:KB709595.1\tLN:11723\n@SQ\tSN:APMT01211368.1\tLN:11721\n@SQ\tSN:APMT01211379.1\tLN:11714\n@SQ\tSN:APMT01211344.1\tLN:11712\n@SQ\tSN:KB709276.1\tLN:11701\n@SQ\tSN:KB709230.1\tLN:11700\n@SQ\tSN:KB709678.1\tLN:11695\n@SQ\tSN:KB709480.1\tLN:11693\n@SQ\tSN:KB709642.1\tLN:11693\n@SQ\tSN:KB709470.1\tLN:11689\n@SQ\tSN:APMT01211401.1\tLN:11684\n@SQ\tSN:KB709482.1\tLN:11680\n@SQ\tSN:KB709685.1\tLN:11675\n@SQ\tSN:APMT01211375.1\tLN:11670\n@SQ\tSN:APMT01211423.1\tLN:11669\n@SQ\tSN:APMT01211425.1\tLN:11665\n@SQ\tSN:APMT01211426.1\tLN:11665\n@SQ\tSN:APMT01211427.1\tLN:11665\n@SQ\tSN:KB709572.1\tLN:11661\n@SQ\tSN:KB709501.1\tLN:11654\n@SQ\tSN:APMT01211429.1\tLN:11653\n@SQ\tSN:APMT01211430.1\tLN:11653\n@SQ\tSN:APMT01211431.1\tLN:11648\n@SQ\tSN:KB709505.1\tLN:11644\n@SQ\tSN:APMT01211432.1\tLN:11643\n@SQ\tSN:APMT01211407.1\tLN:11637\n@SQ\tSN:KB709486.1\tLN:11636\n@SQ\tSN:KB709760.1\tLN:11634\n@SQ\tSN:APMT01211391.1\tLN:11616\n@SQ\tSN:APMT01211428.1\tLN:11615\n@SQ\tSN:APMT01211424.1\tLN:11614\n@SQ\tSN:KB709489.1\tLN:11610\n@SQ\tSN:APMT01211390.1\tLN:11610\n@SQ\tSN:KB709524.1\tLN:11609\n@SQ\tSN:KB709504.1\tLN:11605\n@SQ\tSN:KB709663.1\tLN:11602\n@SQ\tSN:APMT01211435.1\tLN:11600\n@SQ\tSN:APMT01211406.1\tLN:11596\n@SQ\tSN:APMT01211454.1\tLN:11595\n@SQ\tSN:APMT01211455.1\tLN:11595\n@SQ\tSN:APMT01211457.1\tLN:11593\n@SQ\tSN:APMT01211456.1\tLN:11588\n@SQ\tSN:APMT01211467.1\tLN:11583\n@SQ\tSN:APMT01211473.1\tLN:11575\n@SQ\tSN:APMT01211474.1\tLN:11573\n@SQ\tSN:APMT01211475.1\tLN:11573\n@SQ\tSN:KB709327.1\tLN:11568\n@SQ\tSN:KB714598.1\tLN:11568\n@SQ\tSN:KB709507.1\tLN:11566\n@SQ\tSN:APMT01211478.1\tLN:11565\n@SQ\tSN:APMT01211488.1\tLN:11551\n@SQ\tSN:APMT01211479.1\tLN:11546\n@SQ\tSN:KB709458.1\tLN:11543\n@SQ\tSN:APMT01211499.1\tLN:11543\n@SQ\tSN:APMT01211500.1\tLN:11543\n@SQ\tSN:KB709767.1\tLN:11542\n@SQ\tSN:APMT01211501.1\tLN:11539\n@SQ\tSN:APMT01211502.1\tLN:11539\n@SQ\tSN:KB709376.1\tLN:11538\n@SQ\tSN:APMT01211505.1\tLN:11533\n@SQ\tSN:APMT01211507.1\tLN:11523\n@SQ\tSN:KB709475.1\tLN:11514\n@SQ\tSN:APMT01211508.1\tLN:11514\n@SQ\tSN:KB709137.1\tLN:11510\n@SQ\tSN:APMT01211480.1\tLN:11509\n@SQ\tSN:APMT01211516.1\tLN:11507\n@SQ\tSN:KB709629.1\tLN:11507\n@SQ\tSN:APMT01211481.1\tLN:11501\n@SQ\tSN:APMT01211487.1\tLN:11499\n@SQ\tSN:APMT01211517.1\tLN:11499\n@SQ\tSN:APMT01211518.1\tLN:11499\n@SQ\tSN:KB709222.1\tLN:11494\n@SQ\tSN:APMT01211519.1\tLN:11492\n@SQ\tSN:APMT01211526.1\tLN:11492\n@SQ\tSN:APMT01211527.1\tLN:11491\n@SQ\tSN:KB709497.1\tLN:11490\n@SQ\tSN:APMT01211503.1\tLN:11488\n@SQ\tSN:APMT01211504.1\tLN:11475\n@SQ\tSN:KB710338.1\tLN:11475\n@SQ\tSN:KB709609.1\tLN:11474\n@SQ\tSN:KB709396.1\tLN:11473\n@SQ\tSN:KB709797.1\tLN:11473\n@SQ\tSN:APMT01211506.1\tLN:11466\n@SQ\tSN:APMT01211544.1\tLN:11466\n@SQ\tSN:APMT01211567.1\tLN:11458\n@SQ\tSN:KB709584.1\tLN:11458\n@SQ\tSN:APMT01211436.1\tLN:11455\n@SQ\tSN:APMT01211568.1\tLN:11448\n@SQ\tSN:KB709370.1\tLN:11444\n@SQ\tSN:APMT01211576.1\tLN:11441\n@SQ\tSN:APMT01211577.1\tLN:11440\n@SQ\tSN:APMT01211540.1\tLN:11434\n@SQ\tSN:KB709410.1\tLN:11433\n@SQ\tSN:APMT01211534.1\tLN:11433\n@SQ\tSN:KB709281.1\tLN:11425\n@SQ\tSN:KB709512.1\tLN:11422\n@SQ\tSN:KB709492.1\tLN:11418\n@SQ\tSN:APMT01211588.1\tLN:11417\n@SQ\tSN:APMT01211593.1\tLN:11413\n@SQ\tSN:APMT01211578.1\tLN:11412\n@SQ\tSN:APMT01211553.1\tLN:11410\n@SQ\tSN:KB709515.1\tLN:11408\n@SQ\tSN:APMT01211587.1\tLN:11403\n@SQ\tSN:KB709916.1\tLN:11402\n@SQ\tSN:APMT01211598.1\tLN:11398\n@SQ\tSN:KB709614.1\tLN:11398\n@SQ\tSN:KB709358.1\tLN:11397\n@SQ\tSN:APMT01211597.1\tLN:11397\n@SQ\tSN:APMT01211569.1\tLN:11396\n@SQ\tSN:APMT01211599.1\tLN:11395\n@SQ\tSN:APMT01211600.1\tLN:11395\n@SQ\tSN:APMT01211573.1\tLN:11394\n@SQ\tSN:KB709436.1\tLN:11391\n@SQ\tSN:KB709539.1\tLN:11391\n@SQ\tSN:KB709606.1\tLN:11390\n@SQ\tSN:APMT01211602.1\tLN:11387\n@SQ\tSN:KB709531.1\tLN:11384\n@SQ\tSN:APMT01211575.1\tLN:11381\n@SQ\tSN:APMT01211603.1\tLN:11380\n@SQ\tSN:APMT01211604.1\tLN:11380\n@SQ\tSN:APMT01211585.1\tLN:11374\n@SQ\tSN:APMT01211605.1\tLN:11374\n@SQ\tSN:APMT01211574.1\tLN:11373\n@SQ\tSN:APMT01211586.1\tLN:11363\n@SQ\tSN:APMT01211620.1\tLN:11358\n@SQ\tSN:APMT01211625.1\tLN:11352\n@SQ\tSN:KB709519.1\tLN:11346\n@SQ\tSN:KB709514.1\tLN:11344\n@SQ\tSN:APMT01211612.1\tLN:11342\n@SQ\tSN:APMT01211642.1\tLN:11336\n@SQ\tSN:APMT01211631.1\tLN:11335\n@SQ\tSN:APMT01211619.1\tLN:11331\n@SQ\tSN:APMT01211630.1\tLN:11331\n@SQ\tSN:APMT01211633.1\tLN:11330\n@SQ\tSN:APMT01211601.1\tLN:11328\n@SQ\tSN:KB709654.1\tLN:11325\n@SQ\tSN:APMT01211596.1\tLN:11324\n@SQ\tSN:APMT01211624.1\tLN:11324\n@SQ\tSN:APMT01211634.1\tLN:11315\n@SQ\tSN:APMT01211626.1\tLN:11307\n@SQ\tSN:APMT01211638.1\tLN:11306\n@SQ\tSN:APMT01211632.1\tLN:11303\n@SQ\tSN:APMT01211639.1\tLN:11299\n@SQ\tSN:APMT01211640.1\tLN:11299\n@SQ\tSN:KB709226.1\tLN:11294\n@SQ\tSN:APMT01211643.1\tLN:11294\n@SQ\tSN:APMT01211641.1\tLN:11293\n@SQ\tSN:KB709227.1\tLN:11290\n@SQ\tSN:APMT01211644.1\tLN:11287\n@SQ\tSN:APMT01211648.1\tLN:11280\n@SQ\tSN:APMT01211613.1\tLN:11267\n@SQ\tSN:APMT01211635.1\tLN:11267\n@SQ\tSN:KB709934.1\tLN:11263\n@SQ\tSN:KB709454.1\tLN:11260\n@SQ\tSN:APMT01211649.1\tLN:11257\n@SQ\tSN:APMT01211652.1\tLN:11255\n@SQ\tSN:APMT01211654.1\tLN:11250\n@SQ\tSN:APMT01211659.1\tLN:11247\n@SQ\tSN:APMT01211651.1\tLN:11243\n@SQ\tSN:APMT01211661.1\tLN:11241\n@SQ\tSN:KB709708.1\tLN:11241\n@SQ\tSN:APMT01211660.1\tLN:11239\n@SQ\tSN:APMT01211674.1\tLN:11234\n@SQ\tSN:APMT01211675.1\tLN:11230\n@SQ\tSN:APMT01211676.1\tLN:11230\n@SQ\tSN:APMT01211677.1\tLN:11230\n@SQ\tSN:KB711170.1\tLN:11228\n@SQ\tSN:APMT01211678.1\tLN:11223\n@SQ\tSN:KB709535.1\tLN:11222\n@SQ\tSN:APMT01211679.1\tLN:11216\n@SQ\tSN:APMT01211685.1\tLN:11213\n@SQ\tSN:APMT01211686.1\tLN:11213\n@SQ\tSN:APMT01211687.1\tLN:11210\n@SQ\tSN:APMT01211650.1\tLN:11208\n@SQ\tSN:APMT01211688.1\tLN:11207\n@SQ\tSN:APMT01211662.1\tLN:11202\n@SQ\tSN:KB709578.1\tLN:11202\n@SQ\tSN:KB709792.1\tLN:11196\n@SQ\tSN:KB709615.1\tLN:11194\n@SQ\tSN:KB709337.1\tLN:11192\n@SQ\tSN:APMT01211658.1\tLN:11192\n@SQ\tSN:KB709465.1\tLN:11185\n@SQ\tSN:KB709549.1\tLN:11176\n@SQ\tSN:KB709690.1\tLN:11173\n@SQ\tSN:APMT01211708.1\tLN:11171\n@SQ\tSN:APMT01211709.1\tLN:11171\n@SQ\tSN:APMT01211710.1\tLN:11169\n@SQ\tSN:KB709530.1\tLN:11163\n@SQ\tSN:KB709780.1\tLN:11160\n@SQ\tSN:KB709345.1\tLN:11156\n@SQ\tSN:APMT01211653.1\tLN:11153\n@SQ\tSN:APMT01211726.1\tLN:11149\n@SQ\tSN:APMT01211727.1\tLN:11147\n@SQ\tSN:APMT01211711.1\tLN:11143\n@SQ\tSN:KB709491.1\tLN:11138\n@SQ\tSN:KB709516.1\tLN:11138\n@SQ\tSN:APMT01211741.1\tLN:11128\n@SQ\tSN:APMT01211736.1\tLN:11127\n@SQ\tSN:APMT01211731.1\tLN:11125\n@SQ\tSN:KB709125.1\tLN:11124\n@SQ\tSN:KB709534.1\tLN:11118\n@SQ\tSN:KB709861.1\tLN:11115\n@SQ\tSN:KB709542.1\tLN:11098\n@SQ\tSN:KB709560.1\tLN:11097\n@SQ\tSN:APMT01211762.1\tLN:11096\n@SQ\tSN:APMT01211763.1\tLN:11095\n@SQ\tSN:APMT01211764.1\tLN:11089\n@SQ\tSN:KB709818.1\tLN:11089\n@SQ\tSN:KB709518.1\tLN:11087\n@SQ\tSN:KB709555.1\tLN:11086\n@SQ\tSN:APMT01211768.1\tLN:11086\n@SQ\tSN:KB709660.1\tLN:11083\n@SQ\tSN:APMT01211740.1\tLN:11079\n@SQ\tSN:APMT01211765.1\tLN:11079\n@SQ\tSN:KB709540.1\tLN:11077\n@SQ\tSN:APMT01211766.1\tLN:11077\n@SQ\tSN:APMT01211735.1\tLN:11075\n@SQ\tSN:APMT01211769.1\tLN:11072\n@SQ\tSN:APMT01211737.1\tLN:11070\n@SQ\tSN:APMT01211749.1\tLN:11070\n@SQ\tSN:APMT01211770.1\tLN:11070\n@SQ\tSN:APMT01211771.1\tLN:11068\n@SQ\tSN:APMT01211772.1\tLN:11067\n@SQ\tSN:APMT01211773.1\tLN:11066\n@SQ\tSN:APMT01211774.1\tLN:11065\n@SQ\tSN:KB709716.1\tLN:11065\n@SQ\tSN:KB710155.1\tLN:11058\n@SQ\tSN:KB709659.1\tLN:11050\n@SQ\tSN:APMT01211781.1\tLN:11036\n@SQ\tSN:APMT01211782.1\tLN:11033\n@SQ\tSN:KB709395.1\tLN:11029\n@SQ\tSN:KB709559.1\tLN:11024\n@SQ\tSN:APMT01211787.1\tLN:11024\n@SQ\tSN:KB709639.1\tLN:11021\n@SQ\tSN:APMT01211792.1\tLN:11020\n@SQ\tSN:APMT01211767.1\tLN:11018\n@SQ\tSN:APMT01211775.1\tLN:11016\n@SQ\tSN:APMT01211799.1\tLN:11015\n@SQ\tSN:APMT01211800.1\tLN:11011\n@SQ\tSN:KB709784.1\tLN:11009\n@SQ\tSN:KB709564.1\tLN:11006\n@SQ\tSN:APMT01211809.1\tLN:11004\n@SQ\tSN:APMT01211810.1\tLN:11001\n@SQ\tSN:KB709547.1\tLN:10999\n@SQ\tSN:KB709551.1\tLN:10995\n@SQ\tSN:APMT01211812.1\tLN:10995\n@SQ\tSN:KB709769.1\tLN:10995\n@SQ\tSN:APMT01211814.1\tLN:10987\n@SQ\tSN:APMT01211815.1\tLN:10986\n@SQ\tSN:APMT01211816.1\tLN:10986\n@SQ\tSN:APMT01211817.1\tLN:10983\n@SQ\tSN:APMT01211822.1\tLN:10982\n@SQ\tSN:APMT01211813.1\tLN:10981\n@SQ\tSN:KB709741.1\tLN:10981\n@SQ\tSN:KB709503.1\tLN:10980\n@SQ\tSN:APMT01211818.1\tLN:10980\n@SQ\tSN:KB709526.1\tLN:10979\n@SQ\tSN:KB709538.1\tLN:10973\n@SQ\tSN:KB709739.1\tLN:10973\n@SQ\tSN:KB709562.1\tLN:10968\n@SQ\tSN:APMT01211830.1\tLN:10967\n@SQ\tSN:APMT01211831.1\tLN:10967\n@SQ\tSN:APMT01211833.1\tLN:10967\n@SQ\tSN:KB709447.1\tLN:10966\n@SQ\tSN:KB709556.1\tLN:10965\n@SQ\tSN:APMT01211834.1\tLN:10965\n@SQ\tSN:KB709705.1\tLN:10952\n@SQ\tSN:KB709869.1\tLN:10949\n@SQ\tSN:KB709563.1\tLN:10948\n@SQ\tSN:KB709552.1\tLN:10946\n@SQ\tSN:KB709789.1\tLN:10944\n@SQ\tSN:APMT01211842.1\tLN:10942\n@SQ\tSN:APMT01211843.1\tLN:10942\n@SQ\tSN:KB709274.1\tLN:10938\n@SQ\tSN:KB710067.1\tLN:10929\n@SQ\tSN:APMT01211847.1\tLN:10927\n@SQ\tSN:APMT01211849.1\tLN:10924\n@SQ\tSN:APMT01211811.1\tLN:10917\n@SQ\tSN:APMT01211860.1\tLN:10916\n@SQ\tSN:APMT01211861.1\tLN:10916\n@SQ\tSN:KB709408.1\tLN:10909\n@SQ\tSN:APMT01211872.1\tLN:10909\n@SQ\tSN:APMT01211832.1\tLN:10908\n@SQ\tSN:APMT01211865.1\tLN:10904\n@SQ\tSN:KB709399.1\tLN:10903\n@SQ\tSN:APMT01211870.1\tLN:10898\n@SQ\tSN:APMT01211877.1\tLN:10887\n@SQ\tSN:APMT01211848.1\tLN:10886\n@SQ\tSN:APMT01211879.1\tLN:10880\n@SQ\tSN:APMT01211878.1\tLN:10876\n@SQ\tSN:APMT01211887.1\tLN:10868\n@SQ\tSN:KB709905.1\tLN:10868\n@SQ\tSN:APMT01211866.1\tLN:10867\n@SQ\tSN:KB710887.1\tLN:10859\n@SQ\tSN:KB709594.1\tLN:10851\n@SQ\tSN:APMT01211899.1\tLN:10848\n@SQ\tSN:KB709626.1\tLN:10847\n@SQ\tSN:APMT01211900.1\tLN:10842\n@SQ\tSN:KB709689.1\tLN:10837\n@SQ\tSN:APMT01211913.1\tLN:10834\n@SQ\tSN:APMT01211837.1\tLN:10830\n@SQ\tSN:APMT01211871.1\tLN:10830\n@SQ\tSN:APMT01211914.1\tLN:10829\n@SQ\tSN:APMT01211919.1\tLN:10825\n@SQ\tSN:APMT01211920.1\tLN:10825\n@SQ\tSN:APMT01211859.1\tLN:10824\n@SQ\tSN:KB709590.1\tLN:10823\n@SQ\tSN:APMT01211901.1\tLN:10821\n@SQ\tSN:APMT01211927.1\tLN:10820\n@SQ\tSN:APMT01211933.1\tLN:10815\n@SQ\tSN:APMT01211934.1\tLN:10814\n@SQ\tSN:KB709581.1\tLN:10812\n@SQ\tSN:APMT01211950.1\tLN:10800\n@SQ\tSN:APMT01211938.1\tLN:10790\n@SQ\tSN:APMT01211957.1\tLN:10786\n@SQ\tSN:KB709664.1\tLN:10785\n@SQ\tSN:KB709733.1\tLN:10785\n@SQ\tSN:KB709349.1\tLN:10781\n@SQ\tSN:APMT01211960.1\tLN:10778\n@SQ\tSN:APMT01211961.1\tLN:10778\n@SQ\tSN:KB709862.1\tLN:10777\n@SQ\tSN:APMT01211962.1\tLN:10776\n@SQ\tSN:KB709625.1\tLN:10773\n@SQ\tSN:APMT01211956.1\tLN:10772\n@SQ\tSN:APMT01211963.1\tLN:10768\n@SQ\tSN:KB709300.1\tLN:10764\n@SQ\tSN:APMT01211942.1\tLN:10764\n@SQ\tSN:KB709677.1\tLN:10764\n@SQ\tSN:APMT01211949.1\tLN:10759\n@SQ\tSN:APMT01211972.1\tLN:10757\n@SQ\tSN:APMT01211935.1\tLN:10756\n@SQ\tSN:APMT01211970.1\tLN:10755\n@SQ\tSN:APMT01211980.1\tLN:10755\n@SQ\tSN:KB709742.1\tLN:10747\n@SQ\tSN:KB709701.1\tLN:10739\n@SQ\tSN:APMT01211958.1\tLN:10733\n@SQ\tSN:KB709476.1\tLN:10732\n@SQ\tSN:APMT01211959.1\tLN:10731\n@SQ\tSN:APMT01211982.1\tLN:10730\n@SQ\tSN:APMT01211996.1\tLN:10730\n@SQ\tSN:APMT01212005.1\tLN:10722\n@SQ\tSN:APMT01212006.1\tLN:10721\n@SQ\tSN:APMT01212007.1\tLN:10718\n@SQ\tSN:APMT01212010.1\tLN:10711\n@SQ\tSN:APMT01212004.1\tLN:10709\n@SQ\tSN:APMT01212013.1\tLN:10709\n@SQ\tSN:KB709265.1\tLN:10708\n@SQ\tSN:APMT01212014.1\tLN:10708\n@SQ\tSN:KB709752.1\tLN:10708\n@SQ\tSN:KB709525.1\tLN:10707\n@SQ\tSN:APMT01211964.1\tLN:10706\n@SQ\tSN:KB709658.1\tLN:10705\n@SQ\tSN:KB709573.1\tLN:10702\n@SQ\tSN:APMT01212016.1\tLN:10699\n@SQ\tSN:APMT01211981.1\tLN:10698\n@SQ\tSN:APMT01212036.1\tLN:10688\n@SQ\tSN:KB710040.1\tLN:10688\n@SQ\tSN:APMT01211971.1\tLN:10687\n@SQ\tSN:APMT01212042.1\tLN:10684\n@SQ\tSN:KB709599.1\tLN:10680\n@SQ\tSN:KB709574.1\tLN:10679\n@SQ\tSN:APMT01212037.1\tLN:10678\n@SQ\tSN:KB709608.1\tLN:10671\n@SQ\tSN:APMT01212055.1\tLN:10667\n@SQ\tSN:APMT01212056.1\tLN:10667\n@SQ\tSN:APMT01212057.1\tLN:10667\n@SQ\tSN:APMT01212015.1\tLN:10666\n@SQ\tSN:APMT01212058.1\tLN:10666\n@SQ\tSN:APMT01212059.1\tLN:10666\n@SQ\tSN:APMT01212065.1\tLN:10665\n@SQ\tSN:APMT01212066.1\tLN:10664\n@SQ\tSN:APMT01212054.1\tLN:10662\n@SQ\tSN:APMT01212069.1\tLN:10653\n@SQ\tSN:APMT01212070.1\tLN:10651\n@SQ\tSN:KB709696.1\tLN:10651\n@SQ\tSN:APMT01212071.1\tLN:10649\n@SQ\tSN:KB709808.1\tLN:10649\n@SQ\tSN:APMT01212083.1\tLN:10644\n@SQ\tSN:APMT01212024.1\tLN:10638\n@SQ\tSN:APMT01212090.1\tLN:10634\n@SQ\tSN:APMT01212092.1\tLN:10634\n@SQ\tSN:APMT01212035.1\tLN:10633\n@SQ\tSN:APMT01212094.1\tLN:10632\n@SQ\tSN:APMT01212107.1\tLN:10626\n@SQ\tSN:KB709621.1\tLN:10624\n@SQ\tSN:APMT01212043.1\tLN:10617\n@SQ\tSN:KB710596.1\tLN:10616\n@SQ\tSN:APMT01212114.1\tLN:10615\n@SQ\tSN:APMT01212117.1\tLN:10611\n@SQ\tSN:APMT01212118.1\tLN:10611\n@SQ\tSN:KB709617.1\tLN:10610\n@SQ\tSN:KB709593.1\tLN:10609\n@SQ\tSN:APMT01212119.1\tLN:10608\n@SQ\tSN:APMT01212093.1\tLN:10607\n@SQ\tSN:APMT01212120.1\tLN:10607\n@SQ\tSN:APMT01212140.1\tLN:10600\n@SQ\tSN:APMT01212141.1\tLN:10600\n@SQ\tSN:KB709258.1\tLN:10599\n@SQ\tSN:APMT01212146.1\tLN:10597\n@SQ\tSN:APMT01212147.1\tLN:10597\n@SQ\tSN:APMT01212148.1\tLN:10595\n@SQ\tSN:KB709778.1\tLN:10593\n@SQ\tSN:APMT01212109.1\tLN:10592\n@SQ\tSN:APMT01212108.1\tLN:10580\n@SQ\tSN:APMT01212091.1\tLN:10578\n@SQ\tSN:APMT01212157.1\tLN:10573\n@SQ\tSN:KB709726.1\tLN:10573\n@SQ\tSN:APMT01212156.1\tLN:10572\n@SQ\tSN:APMT01212158.1\tLN:10572\n@SQ\tSN:KB709432.1\tLN:10569\n@SQ\tSN:KB709619.1\tLN:10568\n@SQ\tSN:APMT01212164.1\tLN:10565\n@SQ\tSN:KB709725.1\tLN:10565\n@SQ\tSN:KB709964.1\tLN:10561\n@SQ\tSN:APMT01212171.1\tLN:10556\n@SQ\tSN:APMT01212172.1\tLN:10556\n@SQ\tSN:KB709338.1\tLN:10551\n@SQ\tSN:KB709936.1\tLN:10551\n@SQ\tSN:APMT01212173.1\tLN:10550\n@SQ\tSN:APMT01212149.1\tLN:10548\n@SQ\tSN:KB709790.1\tLN:10547\n@SQ\tSN:KB709692.1\tLN:10543\n@SQ\tSN:KB710010.1\tLN:10542\n@SQ\tSN:APMT01212180.1\tLN:10540\n@SQ\tSN:APMT01212184.1\tLN:10537\n@SQ\tSN:KB709782.1\tLN:10535\n@SQ\tSN:APMT01212187.1\tLN:10534\n@SQ\tSN:APMT01212190.1\tLN:10530\n@SQ\tSN:KB709624.1\tLN:10528\n@SQ\tSN:APMT01212191.1\tLN:10522\n@SQ\tSN:APMT01212166.1\tLN:10520\n@SQ\tSN:APMT01212167.1\tLN:10520\n@SQ\tSN:APMT01212192.1\tLN:10517\n@SQ\tSN:KB709645.1\tLN:10517\n@SQ\tSN:KB709611.1\tLN:10516\n@SQ\tSN:APMT01212165.1\tLN:10514\n@SQ\tSN:APMT01212229.1\tLN:10511\n@SQ\tSN:APMT01212203.1\tLN:10505\n@SQ\tSN:APMT01212202.1\tLN:10504\n@SQ\tSN:APMT01212208.1\tLN:10501\n@SQ\tSN:APMT01212210.1\tLN:10495\n@SQ\tSN:APMT01212211.1\tLN:10494\n@SQ\tSN:APMT01212214.1\tLN:10491\n@SQ\tSN:APMT01212215.1\tLN:10490\n@SQ\tSN:KB709772.1\tLN:10488\n@SQ\tSN:KB709312.1\tLN:10484\n@SQ\tSN:KB709697.1\tLN:10483\n@SQ\tSN:APMT01212193.1\tLN:10482\n@SQ\tSN:APMT01212201.1\tLN:10474\n@SQ\tSN:APMT01212230.1\tLN:10472\n@SQ\tSN:KB709727.1\tLN:10470\n@SQ\tSN:APMT01212235.1\tLN:10469\n@SQ\tSN:APMT01212234.1\tLN:10468\n@SQ\tSN:APMT01212239.1\tLN:10459\n@SQ\tSN:APMT01212209.1\tLN:10452\n@SQ\tSN:APMT01212243.1\tLN:10451\n@SQ\tSN:APMT01212212.1\tLN:10449\n@SQ\tSN:APMT01212252.1\tLN:10448\n@SQ\tSN:KB709669.1\tLN:10440\n@SQ\tSN:KB709643.1\tLN:10439\n@SQ\tSN:APMT01212256.1\tLN:10437\n@SQ\tSN:KB709748.1\tLN:10434\n@SQ\tSN:APMT01212242.1\tLN:10433\n@SQ\tSN:APMT01212253.1\tLN:10432\n@SQ\tSN:APMT01212255.1\tLN:10432\n@SQ\tSN:KB709908.1\tLN:10432\n@SQ\tSN:APMT01212241.1\tLN:10427\n@SQ\tSN:KB709641.1\tLN:10421\n@SQ\tSN:APMT01212254.1\tLN:10420\n@SQ\tSN:APMT01212266.1\tLN:10417\n@SQ\tSN:APMT01212244.1\tLN:10415\n@SQ\tSN:KB709457.1\tLN:10412\n@SQ\tSN:APMT01212263.1\tLN:10410\n@SQ\tSN:APMT01212267.1\tLN:10409\n@SQ\tSN:KB709570.1\tLN:10408\n@SQ\tSN:APMT01212258.1\tLN:10406\n@SQ\tSN:KB709623.1\tLN:10405\n@SQ\tSN:APMT01212240.1\tLN:10403\n@SQ\tSN:APMT01212271.1\tLN:10395\n@SQ\tSN:KB709316.1\tLN:10391\n@SQ\tSN:APMT01212251.1\tLN:10390\n@SQ\tSN:KB709630.1\tLN:10386\n@SQ\tSN:APMT01212245.1\tLN:10380\n@SQ\tSN:APMT01212287.1\tLN:10380\n@SQ\tSN:APMT01212288.1\tLN:10377\n@SQ\tSN:KB709631.1\tLN:10373\n@SQ\tSN:APMT01212213.1\tLN:10373\n@SQ\tSN:APMT01212289.1\tLN:10372\n@SQ\tSN:KB709315.1\tLN:10369\n@SQ\tSN:APMT01212257.1\tLN:10366\n@SQ\tSN:KB709673.1\tLN:10362\n@SQ\tSN:KB709863.1\tLN:10360\n@SQ\tSN:APMT01212290.1\tLN:10356\n@SQ\tSN:APMT01212292.1\tLN:10347\n@SQ\tSN:KB709569.1\tLN:10336\n@SQ\tSN:KB710152.1\tLN:10334\n@SQ\tSN:APMT01212310.1\tLN:10332\n@SQ\tSN:APMT01212312.1\tLN:10329\n@SQ\tSN:APMT01212311.1\tLN:10326\n@SQ\tSN:KB709730.1\tLN:10325\n@SQ\tSN:APMT01212313.1\tLN:10318\n@SQ\tSN:APMT01212309.1\tLN:10316\n@SQ\tSN:APMT01212318.1\tLN:10316\n@SQ\tSN:APMT01212319.1\tLN:10316\n@SQ\tSN:APMT01212294.1\tLN:10315\n@SQ\tSN:APMT01212320.1\tLN:10313\n@SQ\tSN:APMT01212293.1\tLN:10311\n@SQ\tSN:KB709490.1\tLN:10309\n@SQ\tSN:APMT01212322.1\tLN:10308\n@SQ\tSN:APMT01212291.1\tLN:10305\n@SQ\tSN:APMT01212340.1\tLN:10300\n@SQ\tSN:KB709646.1\tLN:10299\n@SQ\tSN:APMT01212321.1\tLN:10297\n@SQ\tSN:KB709346.1\tLN:10292\n@SQ\tSN:KB709638.1\tLN:10289\n@SQ\tSN:KB709628.1\tLN:10287\n@SQ\tSN:APMT01212363.1\tLN:10287\n@SQ\tSN:APMT01212364.1\tLN:10287\n@SQ\tSN:APMT01212365.1\tLN:10284\n@SQ\tSN:APMT01212378.1\tLN:10282\n@SQ\tSN:APMT01212380.1\tLN:10281\n@SQ\tSN:APMT01212381.1\tLN:10281\n@SQ\tSN:APMT01212308.1\tLN:10274\n@SQ\tSN:KB709640.1\tLN:10272\n@SQ\tSN:KB709711.1\tLN:10270\n@SQ\tSN:APMT01212379.1\tLN:10262\n@SQ\tSN:APMT01212393.1\tLN:10258\n@SQ\tSN:APMT01212394.1\tLN:10258\n@SQ\tSN:KB709734.1\tLN:10257\n@SQ\tSN:KB709809.1\tLN:10255\n@SQ\tSN:APMT01212386.1\tLN:10254\n@SQ\tSN:APMT01212403.1\tLN:10254\n@SQ\tSN:APMT01212404.1\tLN:10253\n@SQ\tSN:APMT01212405.1\tLN:10253\n@SQ\tSN:KB711239.1\tLN:10253\n@SQ\tSN:APMT01212407.1\tLN:10249\n@SQ\tSN:KB710038.1\tLN:10244\n@SQ\tSN:APMT01212415.1\tLN:10243\n@SQ\tSN:KB709616.1\tLN:10241\n@SQ\tSN:APMT01212414.1\tLN:10235\n@SQ\tSN:KB709874.1\tLN:10234\n@SQ\tSN:KB712341.1\tLN:10232\n@SQ\tSN:APMT01212426.1\tLN:10226\n@SQ\tSN:KB709695.1\tLN:10226\n@SQ\tSN:KB709523.1\tLN:10225\n@SQ\tSN:APMT01212382.1\tLN:10224\n@SQ\tSN:KB709777.1\tLN:10217\n@SQ\tSN:APMT01212438.1\tLN:10216\n@SQ\tSN:APMT01212406.1\tLN:10215\n@SQ\tSN:KB709585.1\tLN:10212\n@SQ\tSN:APMT01212445.1\tLN:10212\n@SQ\tSN:APMT01212446.1\tLN:10212\n@SQ\tSN:APMT01212383.1\tLN:10210\n@SQ\tSN:KB709698.1\tLN:10210\n@SQ\tSN:KB710004.1\tLN:10210\n@SQ\tSN:KB709750.1\tLN:10209\n@SQ\tSN:KB709607.1\tLN:10204\n@SQ\tSN:APMT01212451.1\tLN:10204\n@SQ\tSN:KB710910.1\tLN:10202\n@SQ\tSN:KB709817.1\tLN:10198\n@SQ\tSN:KB709788.1\tLN:10194\n@SQ\tSN:APMT01212408.1\tLN:10191\n@SQ\tSN:KB709648.1\tLN:10188\n@SQ\tSN:KB709674.1\tLN:10175\n@SQ\tSN:APMT01212536.1\tLN:10175\n@SQ\tSN:APMT01212475.1\tLN:10174\n@SQ\tSN:APMT01212476.1\tLN:10173\n@SQ\tSN:APMT01212477.1\tLN:10167\n@SQ\tSN:APMT01212478.1\tLN:10164\n@SQ\tSN:APMT01212480.1\tLN:10162\n@SQ\tSN:APMT01212469.1\tLN:10147\n@SQ\tSN:APMT01212492.1\tLN:10141\n@SQ\tSN:APMT01212495.1\tLN:10136\n@SQ\tSN:APMT01212496.1\tLN:10135\n@SQ\tSN:APMT01212497.1\tLN:10133\n@SQ\tSN:KB709822.1\tLN:10133\n@SQ\tSN:APMT01212498.1\tLN:10132\n@SQ\tSN:APMT01212499.1\tLN:10132\n@SQ\tSN:KB709680.1\tLN:10130\n@SQ\tSN:KB709676.1\tLN:10129\n@SQ\tSN:APMT01212488.1\tLN:10127\n@SQ\tSN:APMT01212505.1\tLN:10127\n@SQ\tSN:KB709768.1\tLN:10126\n@SQ\tSN:KB709724.1\tLN:10125\n@SQ\tSN:APMT01212487.1\tLN:10124\n@SQ\tSN:KB711037.1\tLN:10123\n@SQ\tSN:APMT01212512.1\tLN:10121\n@SQ\tSN:APMT01212648.1\tLN:10119\n@SQ\tSN:KB709836.1\tLN:10115\n@SQ\tSN:APMT01212523.1\tLN:10112\n@SQ\tSN:KB709579.1\tLN:10111\n@SQ\tSN:APMT01212524.1\tLN:10111\n@SQ\tSN:KB709667.1\tLN:10110\n@SQ\tSN:KB710656.1\tLN:10110\n@SQ\tSN:APMT01212532.1\tLN:10109\n@SQ\tSN:APMT01212479.1\tLN:10108\n@SQ\tSN:APMT01212525.1\tLN:10108\n@SQ\tSN:APMT01212493.1\tLN:10100\n@SQ\tSN:APMT01212511.1\tLN:10100\n@SQ\tSN:APMT01212549.1\tLN:10092\n@SQ\tSN:KB709703.1\tLN:10092\n@SQ\tSN:APMT01212494.1\tLN:10090\n@SQ\tSN:KB709723.1\tLN:10090\n@SQ\tSN:APMT01212551.1\tLN:10086\n@SQ\tSN:APMT01212550.1\tLN:10085\n@SQ\tSN:KB709577.1\tLN:10081\n@SQ\tSN:KB709707.1\tLN:10075\n@SQ\tSN:KB709868.1\tLN:10074\n@SQ\tSN:KB709710.1\tLN:10068\n@SQ\tSN:APMT01212555.1\tLN:10067\n@SQ\tSN:APMT01212535.1\tLN:10065\n@SQ\tSN:KB709273.1\tLN:10058\n@SQ\tSN:KB709714.1\tLN:10056\n@SQ\tSN:APMT01212558.1\tLN:10053\n@SQ\tSN:APMT01212533.1\tLN:10050\n@SQ\tSN:APMT01212564.1\tLN:10050\n@SQ\tSN:APMT01212556.1\tLN:10049\n@SQ\tSN:APMT01212565.1\tLN:10046\n@SQ\tSN:KB709322.1\tLN:10039\n@SQ\tSN:APMT01212566.1\tLN:10039\n@SQ\tSN:APMT01212534.1\tLN:10036\n@SQ\tSN:KB709779.1\tLN:10034\n@SQ\tSN:KB709686.1\tLN:10028\n@SQ\tSN:APMT01212579.1\tLN:10027\n@SQ\tSN:APMT01212580.1\tLN:10027\n@SQ\tSN:APMT01212581.1\tLN:10027\n@SQ\tSN:APMT01212586.1\tLN:10025\n@SQ\tSN:APMT01212587.1\tLN:10024\n@SQ\tSN:KB709565.1\tLN:10022\n@SQ\tSN:KB709622.1\tLN:10022\n@SQ\tSN:KB710071.1\tLN:10019\n@SQ\tSN:APMT01212559.1\tLN:10013\n@SQ\tSN:APMT01212597.1\tLN:10003\n@SQ\tSN:KB709580.1\tLN:9998\n@SQ\tSN:APMT01212602.1\tLN:9996\n@SQ\tSN:KB709597.1\tLN:9995\n@SQ\tSN:APMT01212563.1\tLN:9995\n@SQ\tSN:APMT01212601.1\tLN:9981\n@SQ\tSN:KB709718.1\tLN:9979\n@SQ\tSN:KB709651.1\tLN:9978\n@SQ\tSN:KB709662.1\tLN:9978\n@SQ\tSN:APMT01212684.1\tLN:9978\n@SQ\tSN:KB709691.1\tLN:9973\n@SQ\tSN:APMT01212625.1\tLN:9963\n@SQ\tSN:APMT01212557.1\tLN:9961\n@SQ\tSN:APMT01212627.1\tLN:9961\n@SQ\tSN:APMT01212628.1\tLN:9961\n@SQ\tSN:APMT01212612.1\tLN:9960\n@SQ\tSN:APMT01212629.1\tLN:9960\n@SQ\tSN:KB710102.1\tLN:9958\n@SQ\tSN:APMT01212594.1\tLN:9955\n@SQ\tSN:APMT01212632.1\tLN:9955\n@SQ\tSN:APMT01212626.1\tLN:9953\n@SQ\tSN:APMT01212635.1\tLN:9952\n@SQ\tSN:APMT01212595.1\tLN:9951\n@SQ\tSN:APMT01212596.1\tLN:9950\n@SQ\tSN:KB709653.1\tLN:9947\n@SQ\tSN:APMT01212643.1\tLN:9945\n@SQ\tSN:KB709975.1\tLN:9945\n@SQ\tSN:KB709729.1\tLN:9944\n@SQ\tSN:APMT01212646.1\tLN:9939\n@SQ\tSN:APMT01212647.1\tLN:9939\n@SQ\tSN:KB710260.1\tLN:9936\n@SQ\tSN:KB710209.1\tLN:9933\n@SQ\tSN:APMT01212653.1\tLN:9928\n@SQ\tSN:APMT01212658.1\tLN:9925\n@SQ\tSN:KB709832.1\tLN:9924\n@SQ\tSN:APMT01212645.1\tLN:9922\n@SQ\tSN:APMT01212617.1\tLN:9921\n@SQ\tSN:APMT01212623.1\tLN:9919\n@SQ\tSN:KB709764.1\tLN:9917\n@SQ\tSN:APMT01212677.1\tLN:9916\n@SQ\tSN:APMT01212662.1\tLN:9914\n@SQ\tSN:KB709666.1\tLN:9912\n@SQ\tSN:KB709833.1\tLN:9912\n@SQ\tSN:APMT01212682.1\tLN:9909\n@SQ\tSN:KB709885.1\tLN:9906\n@SQ\tSN:APMT01212683.1\tLN:9905\n@SQ\tSN:APMT01212642.1\tLN:9904\n@SQ\tSN:APMT01212624.1\tLN:9903\n@SQ\tSN:KB709693.1\tLN:9897\n@SQ\tSN:APMT01212692.1\tLN:9894\n@SQ\tSN:KB709700.1\tLN:9884\n@SQ\tSN:APMT01212709.1\tLN:9884\n@SQ\tSN:APMT01212644.1\tLN:9883\n@SQ\tSN:KB709776.1\tLN:9882\n@SQ\tSN:APMT01212719.1\tLN:9877\n@SQ\tSN:APMT01212710.1\tLN:9875\n@SQ\tSN:APMT01212731.1\tLN:9865\n@SQ\tSN:APMT01212733.1\tLN:9864\n@SQ\tSN:APMT01212693.1\tLN:9863\n@SQ\tSN:APMT01212670.1\tLN:9859\n@SQ\tSN:APMT01212744.1\tLN:9854\n@SQ\tSN:KB709712.1\tLN:9852\n@SQ\tSN:APMT01212718.1\tLN:9852\n@SQ\tSN:APMT01212750.1\tLN:9852\n@SQ\tSN:APMT01212732.1\tLN:9851\n@SQ\tSN:APMT01212745.1\tLN:9850\n@SQ\tSN:KB709754.1\tLN:9850\n@SQ\tSN:KB709717.1\tLN:9847\n@SQ\tSN:APMT01212757.1\tLN:9832\n@SQ\tSN:KB709684.1\tLN:9831\n@SQ\tSN:APMT01212758.1\tLN:9831\n@SQ\tSN:KB709787.1\tLN:9831\n@SQ\tSN:APMT01212756.1\tLN:9830\n@SQ\tSN:KB709738.1\tLN:9826\n@SQ\tSN:APMT01212746.1\tLN:9817\n@SQ\tSN:KB709302.1\tLN:9815\n@SQ\tSN:APMT01212767.1\tLN:9815\n@SQ\tSN:KB709670.1\tLN:9813\n@SQ\tSN:APMT01212768.1\tLN:9811\n@SQ\tSN:APMT01212770.1\tLN:9809\n@SQ\tSN:KB709363.1\tLN:9808\n@SQ\tSN:KB709761.1\tLN:9808\n@SQ\tSN:KB709509.1\tLN:9798\n@SQ\tSN:APMT01212780.1\tLN:9796\n@SQ\tSN:KB709889.1\tLN:9795\n@SQ\tSN:KB709745.1\tLN:9794\n@SQ\tSN:APMT01212781.1\tLN:9793\n@SQ\tSN:APMT01212782.1\tLN:9791\n@SQ\tSN:APMT01212791.1\tLN:9783\n@SQ\tSN:APMT01212792.1\tLN:9783\n@SQ\tSN:APMT01212793.1\tLN:9781\n@SQ\tSN:APMT01212751.1\tLN:9780\n@SQ\tSN:APMT01212794.1\tLN:9779\n@SQ\tSN:KB709736.1\tLN:9778\n@SQ\tSN:KB709655.1\tLN:9773\n@SQ\tSN:KB710142.1\tLN:9769\n@SQ\tSN:APMT01212811.1\tLN:9766\n@SQ\tSN:APMT01212812.1\tLN:9766\n@SQ\tSN:KB709952.1\tLN:9765\n@SQ\tSN:APMT01212813.1\tLN:9762\n@SQ\tSN:APMT01212818.1\tLN:9757\n@SQ\tSN:APMT01212769.1\tLN:9753\n@SQ\tSN:APMT01212820.1\tLN:9753\n@SQ\tSN:APMT01212827.1\tLN:9749\n@SQ\tSN:APMT01212832.1\tLN:9749\n@SQ\tSN:APMT01212805.1\tLN:9745\n@SQ\tSN:APMT01212833.1\tLN:9745\n@SQ\tSN:APMT01212834.1\tLN:9744\n@SQ\tSN:APMT01212819.1\tLN:9741\n@SQ\tSN:KB709722.1\tLN:9740\n@SQ\tSN:KB709604.1\tLN:9737\n@SQ\tSN:APMT01212841.1\tLN:9730\n@SQ\tSN:APMT01212849.1\tLN:9730\n@SQ\tSN:KB709770.1\tLN:9730\n@SQ\tSN:KB709627.1\tLN:9729\n@SQ\tSN:KB709758.1\tLN:9727\n@SQ\tSN:APMT01212850.1\tLN:9726\n@SQ\tSN:APMT01212851.1\tLN:9726\n@SQ\tSN:APMT01212852.1\tLN:9724\n@SQ\tSN:APMT01212857.1\tLN:9723\n@SQ\tSN:APMT01212779.1\tLN:9720\n@SQ\tSN:APMT01212859.1\tLN:9720\n@SQ\tSN:KB709744.1\tLN:9718\n@SQ\tSN:APMT01212860.1\tLN:9716\n@SQ\tSN:APMT01212867.1\tLN:9713\n@SQ\tSN:APMT01212868.1\tLN:9711\n@SQ\tSN:APMT01212869.1\tLN:9708\n@SQ\tSN:APMT01212858.1\tLN:9707\n@SQ\tSN:APMT01212810.1\tLN:9706\n@SQ\tSN:APMT01212866.1\tLN:9705\n@SQ\tSN:KB714019.1\tLN:9704\n@SQ\tSN:APMT01212882.1\tLN:9699\n@SQ\tSN:APMT01212884.1\tLN:9694\n@SQ\tSN:APMT01212886.1\tLN:9691\n@SQ\tSN:APMT01212883.1\tLN:9682\n@SQ\tSN:APMT01212892.1\tLN:9681\n@SQ\tSN:APMT01212878.1\tLN:9680\n@SQ\tSN:KB710052.1\tLN:9680\n@SQ\tSN:APMT01212893.1\tLN:9679\n@SQ\tSN:APMT01212898.1\tLN:9675\n@SQ\tSN:APMT01212899.1\tLN:9675\n@SQ\tSN:KB709452.1\tLN:9669\n@SQ\tSN:KB709873.1\tLN:9669\n@SQ\tSN:APMT01212906.1\tLN:9668\n@SQ\tSN:APMT01212907.1\tLN:9665\n@SQ\tSN:APMT01212928.1\tLN:9662\n@SQ\tSN:APMT01212929.1\tLN:9662\n@SQ\tSN:KB709759.1\tLN:9657\n@SQ\tSN:APMT01212938.1\tLN:9653\n@SQ\tSN:APMT01212939.1\tLN:9652\n@SQ\tSN:KB709688.1\tLN:9648\n@SQ\tSN:KB709749.1\tLN:9648\n@SQ\tSN:KB709709.1\tLN:9646\n@SQ\tSN:KB709747.1\tLN:9644\n@SQ\tSN:APMT01212885.1\tLN:9642\n@SQ\tSN:KB709757.1\tLN:9640\n@SQ\tSN:KB709633.1\tLN:9639\n@SQ\tSN:APMT01212943.1\tLN:9639\n@SQ\tSN:KB709357.1\tLN:9638\n@SQ\tSN:KB709391.1\tLN:9632\n@SQ\tSN:APMT01212950.1\tLN:9632\n@SQ\tSN:APMT01212905.1\tLN:9622\n@SQ\tSN:KB709827.1\tLN:9622\n@SQ\tSN:APMT01212944.1\tLN:9621\n@SQ\tSN:APMT01212957.1\tLN:9619\n@SQ\tSN:APMT01212962.1\tLN:9619\n@SQ\tSN:APMT01212963.1\tLN:9619\n@SQ\tSN:KB709756.1\tLN:9615\n@SQ\tSN:APMT01212952.1\tLN:9615\n@SQ\tSN:APMT01212964.1\tLN:9615\n@SQ\tSN:APMT01212966.1\tLN:9612\n@SQ\tSN:KB709496.1\tLN:9608\n@SQ\tSN:APMT01212967.1\tLN:9607\n@SQ\tSN:KB709755.1\tLN:9604\n@SQ\tSN:APMT01212969.1\tLN:9601\n@SQ\tSN:APMT01212970.1\tLN:9600\n@SQ\tSN:APMT01212971.1\tLN:9600\n@SQ\tSN:APMT01212972.1\tLN:9597\n@SQ\tSN:APMT01212951.1\tLN:9592\n@SQ\tSN:KB709826.1\tLN:9590\n@SQ\tSN:KB709842.1\tLN:9590\n@SQ\tSN:APMT01212965.1\tLN:9589\n@SQ\tSN:APMT01212975.1\tLN:9588\n@SQ\tSN:KB709309.1\tLN:9580\n@SQ\tSN:KB709324.1\tLN:9579\n@SQ\tSN:APMT01212976.1\tLN:9579\n@SQ\tSN:APMT01212978.1\tLN:9576\n@SQ\tSN:APMT01212949.1\tLN:9574\n@SQ\tSN:APMT01212979.1\tLN:9574\n@SQ\tSN:KB709785.1\tLN:9569\n@SQ\tSN:APMT01212984.1\tLN:9568\n@SQ\tSN:APMT01212989.1\tLN:9565\n@SQ\tSN:APMT01212993.1\tLN:9564\n@SQ\tSN:APMT01212994.1\tLN:9563\n@SQ\tSN:APMT01212968.1\tLN:9561\n@SQ\tSN:APMT01212995.1\tLN:9560\n@SQ\tSN:APMT01212956.1\tLN:9559\n@SQ\tSN:KB710131.1\tLN:9557\n@SQ\tSN:KB709672.1\tLN:9556\n@SQ\tSN:APMT01212996.1\tLN:9552\n@SQ\tSN:KB709687.1\tLN:9550\n@SQ\tSN:APMT01212997.1\tLN:9549\n@SQ\tSN:APMT01213001.1\tLN:9547\n@SQ\tSN:APMT01213002.1\tLN:9547\n@SQ\tSN:KB709857.1\tLN:9539\n@SQ\tSN:APMT01213007.1\tLN:9537\n@SQ\tSN:KB709417.1\tLN:9531\n@SQ\tSN:APMT01213013.1\tLN:9527\n@SQ\tSN:KB710813.1\tLN:9527\n@SQ\tSN:KB709422.1\tLN:9526\n@SQ\tSN:APMT01212977.1\tLN:9523\n@SQ\tSN:APMT01212980.1\tLN:9514\n@SQ\tSN:APMT01213027.1\tLN:9514\n@SQ\tSN:APMT01213030.1\tLN:9511\n@SQ\tSN:APMT01213032.1\tLN:9503\n@SQ\tSN:APMT01213033.1\tLN:9503\n@SQ\tSN:KB709487.1\tLN:9501\n@SQ\tSN:KB709986.1\tLN:9501\n@SQ\tSN:APMT01213043.1\tLN:9499\n@SQ\tSN:APMT01213034.1\tLN:9498\n@SQ\tSN:KB709942.1\tLN:9498\n@SQ\tSN:APMT01213029.1\tLN:9497\n@SQ\tSN:APMT01213035.1\tLN:9492\n@SQ\tSN:APMT01213036.1\tLN:9492\n@SQ\tSN:KB709970.1\tLN:9490\n@SQ\tSN:APMT01213008.1\tLN:9488\n@SQ\tSN:KB709850.1\tLN:9488\n@SQ\tSN:APMT01213041.1\tLN:9485\n@SQ\tSN:KB709728.1\tLN:9484\n@SQ\tSN:APMT01213048.1\tLN:9481\n@SQ\tSN:APMT01213049.1\tLN:9478\n@SQ\tSN:KB709781.1\tLN:9474\n@SQ\tSN:KB709649.1\tLN:9470\n@SQ\tSN:APMT01213052.1\tLN:9469\n@SQ\tSN:APMT01213042.1\tLN:9468\n@SQ\tSN:APMT01213026.1\tLN:9467\n@SQ\tSN:APMT01213066.1\tLN:9466\n@SQ\tSN:KB711460.1\tLN:9466\n@SQ\tSN:KB710120.1\tLN:9465\n@SQ\tSN:KB709897.1\tLN:9464\n@SQ\tSN:APMT01213067.1\tLN:9463\n@SQ\tSN:APMT01213028.1\tLN:9462\n@SQ\tSN:APMT01213031.1\tLN:9461\n@SQ\tSN:APMT01213050.1\tLN:9458\n@SQ\tSN:KB709290.1\tLN:9455\n@SQ\tSN:KB710499.1\tLN:9451\n@SQ\tSN:APMT01213081.1\tLN:9447\n@SQ\tSN:KB709406.1\tLN:9446\n@SQ\tSN:KB710773.1\tLN:9442\n@SQ\tSN:KB709965.1\tLN:9436\n@SQ\tSN:KB709314.1\tLN:9427\n@SQ\tSN:APMT01213061.1\tLN:9421\n@SQ\tSN:APMT01213051.1\tLN:9418\n@SQ\tSN:KB709657.1\tLN:9414\n@SQ\tSN:APMT01213118.1\tLN:9413\n@SQ\tSN:KB709762.1\tLN:9410\n@SQ\tSN:APMT01213119.1\tLN:9410\n@SQ\tSN:APMT01213120.1\tLN:9410\n@SQ\tSN:APMT01213121.1\tLN:9409\n@SQ\tSN:APMT01213122.1\tLN:9407\n@SQ\tSN:KB709548.1\tLN:9403\n@SQ\tSN:KB709973.1\tLN:9399\n@SQ\tSN:APMT01213131.1\tLN:9394\n@SQ\tSN:APMT01213082.1\tLN:9392\n@SQ\tSN:KB710119.1\tLN:9389\n@SQ\tSN:APMT01213140.1\tLN:9387\n@SQ\tSN:KB709802.1\tLN:9386\n@SQ\tSN:KB709958.1\tLN:9380\n@SQ\tSN:APMT01213157.1\tLN:9379\n@SQ\tSN:APMT01213158.1\tLN:9379\n@SQ\tSN:KB710072.1\tLN:9379\n@SQ\tSN:APMT01213159.1\tLN:9378\n@SQ\tSN:KB709828.1\tLN:9377\n@SQ\tSN:KB709532.1\tLN:9376\n@SQ\tSN:APMT01213161.1\tLN:9376\n@SQ\tSN:APMT01213139.1\tLN:9375\n@SQ\tSN:APMT01213153.1\tLN:9375\n@SQ\tSN:APMT01213163.1\tLN:9375\n@SQ\tSN:KB709796.1\tLN:9370\n@SQ\tSN:APMT01213165.1\tLN:9369\n@SQ\tSN:APMT01213166.1\tLN:9369\n@SQ\tSN:APMT01213167.1\tLN:9369\n@SQ\tSN:APMT01213169.1\tLN:9367\n@SQ\tSN:APMT01213114.1\tLN:9366\n@SQ\tSN:KB709804.1\tLN:9365\n@SQ\tSN:APMT01213170.1\tLN:9364\n@SQ\tSN:APMT01213171.1\tLN:9359\n@SQ\tSN:KB709819.1\tLN:9359\n@SQ\tSN:KB709799.1\tLN:9358\n@SQ\tSN:KB709814.1\tLN:9355\n@SQ\tSN:KB709244.1\tLN:9349\n@SQ\tSN:APMT01213176.1\tLN:9348\n@SQ\tSN:APMT01213168.1\tLN:9345\n@SQ\tSN:APMT01213177.1\tLN:9345\n@SQ\tSN:APMT01213178.1\tLN:9342\n@SQ\tSN:KB709811.1\tLN:9342\n@SQ\tSN:KB709810.1\tLN:9338\n@SQ\tSN:APMT01213222.1\tLN:9335\n@SQ\tSN:KB709823.1\tLN:9334\n@SQ\tSN:KB709478.1\tLN:9329\n@SQ\tSN:APMT01213185.1\tLN:9329\n@SQ\tSN:APMT01213186.1\tLN:9329\n@SQ\tSN:APMT01213191.1\tLN:9325\n@SQ\tSN:APMT01213200.1\tLN:9319\n@SQ\tSN:APMT01213162.1\tLN:9315\n@SQ\tSN:APMT01213206.1\tLN:9314\n@SQ\tSN:KB709737.1\tLN:9313\n@SQ\tSN:APMT01213160.1\tLN:9313\n@SQ\tSN:APMT01213164.1\tLN:9311\n@SQ\tSN:APMT01213205.1\tLN:9310\n@SQ\tSN:KB709830.1\tLN:9310\n@SQ\tSN:KB709558.1\tLN:9305\n@SQ\tSN:APMT01213223.1\tLN:9298\n@SQ\tSN:APMT01213212.1\tLN:9296\n@SQ\tSN:KB709473.1\tLN:9292\n@SQ\tSN:KB709816.1\tLN:9283\n@SQ\tSN:APMT01213244.1\tLN:9282\n@SQ\tSN:APMT01213242.1\tLN:9280\n@SQ\tSN:APMT01213246.1\tLN:9279\n@SQ\tSN:APMT01213179.1\tLN:9278\n@SQ\tSN:APMT01213245.1\tLN:9278\n@SQ\tSN:APMT01213180.1\tLN:9276\n@SQ\tSN:APMT01213192.1\tLN:9272\n@SQ\tSN:KB709546.1\tLN:9271\n@SQ\tSN:KB709783.1\tLN:9265\n@SQ\tSN:APMT01213241.1\tLN:9265\n@SQ\tSN:APMT01213248.1\tLN:9264\n@SQ\tSN:APMT01213264.1\tLN:9263\n@SQ\tSN:KB710289.1\tLN:9261\n@SQ\tSN:APMT01213211.1\tLN:9260\n@SQ\tSN:APMT01213268.1\tLN:9251\n@SQ\tSN:APMT01213210.1\tLN:9250\n@SQ\tSN:APMT01213273.1\tLN:9249\n@SQ\tSN:APMT01213274.1\tLN:9249\n@SQ\tSN:APMT01213275.1\tLN:9247\n@SQ\tSN:KB709392.1\tLN:9244\n@SQ\tSN:KB709694.1\tLN:9242\n@SQ\tSN:APMT01213280.1\tLN:9242\n@SQ\tSN:APMT01213284.1\tLN:9240\n@SQ\tSN:APMT01213289.1\tLN:9238\n@SQ\tSN:APMT01213227.1\tLN:9237\n@SQ\tSN:APMT01213234.1\tLN:9237\n@SQ\tSN:APMT01213267.1\tLN:9237\n@SQ\tSN:APMT01213295.1\tLN:9232\n@SQ\tSN:APMT01213293.1\tLN:9226\n@SQ\tSN:APMT01213294.1\tLN:9222\n@SQ\tSN:APMT01213243.1\tLN:9220\n@SQ\tSN:APMT01213247.1\tLN:9218\n@SQ\tSN:APMT01213290.1\tLN:9218\n@SQ\tSN:APMT01213296.1\tLN:9217\n@SQ\tSN:KB709765.1\tLN:9212\n@SQ\tSN:APMT01213265.1\tLN:9209\n@SQ\tSN:APMT01213317.1\tLN:9205\n@SQ\tSN:KB709650.1\tLN:9203\n@SQ\tSN:APMT01213266.1\tLN:9200\n@SQ\tSN:APMT01213327.1\tLN:9198\n@SQ\tSN:KB709950.1\tLN:9195\n@SQ\tSN:APMT01213333.1\tLN:9192\n@SQ\tSN:KB709389.1\tLN:9187\n@SQ\tSN:APMT01213334.1\tLN:9187\n@SQ\tSN:APMT01213332.1\tLN:9185\n@SQ\tSN:KB709834.1\tLN:9182\n@SQ\tSN:KB709824.1\tLN:9179\n@SQ\tSN:KB709954.1\tLN:9171\n@SQ\tSN:KB709805.1\tLN:9170\n@SQ\tSN:APMT01213343.1\tLN:9167\n@SQ\tSN:KB710507.1\tLN:9165\n@SQ\tSN:KB709865.1\tLN:9164\n@SQ\tSN:APMT01213351.1\tLN:9163\n@SQ\tSN:KB709911.1\tLN:9161\n@SQ\tSN:APMT01213352.1\tLN:9160\n@SQ\tSN:APMT01213353.1\tLN:9160\n@SQ\tSN:KB709837.1\tLN:9158\n@SQ\tSN:APMT01213355.1\tLN:9157\n@SQ\tSN:KB709813.1\tLN:9155\n@SQ\tSN:APMT01213356.1\tLN:9155\n@SQ\tSN:KB710029.1\tLN:9155\n@SQ\tSN:APMT01213357.1\tLN:9153\n@SQ\tSN:APMT01213389.1\tLN:9152\n@SQ\tSN:APMT01213301.1\tLN:9150\n@SQ\tSN:KB709831.1\tLN:9148\n@SQ\tSN:APMT01213367.1\tLN:9148\n@SQ\tSN:APMT01213366.1\tLN:9145\n@SQ\tSN:APMT01213370.1\tLN:9145\n@SQ\tSN:APMT01213374.1\tLN:9142\n@SQ\tSN:APMT01213383.1\tLN:9138\n@SQ\tSN:APMT01213384.1\tLN:9137\n@SQ\tSN:KB710356.1\tLN:9136\n@SQ\tSN:APMT01213385.1\tLN:9134\n@SQ\tSN:APMT01213396.1\tLN:9130\n@SQ\tSN:APMT01213397.1\tLN:9130\n@SQ\tSN:APMT01213393.1\tLN:9129\n@SQ\tSN:KB709537.1\tLN:9128\n@SQ\tSN:KB709746.1\tLN:9122\n@SQ\tSN:APMT01213308.1\tLN:9122\n@SQ\tSN:APMT01213406.1\tLN:9122\n@SQ\tSN:KB709794.1\tLN:9121\n@SQ\tSN:APMT01213368.1\tLN:9121\n@SQ\tSN:APMT01213405.1\tLN:9120\n@SQ\tSN:KB709536.1\tLN:9109\n@SQ\tSN:KB709605.1\tLN:9108\n@SQ\tSN:APMT01213430.1\tLN:9104\n@SQ\tSN:APMT01213431.1\tLN:9104\n@SQ\tSN:APMT01213369.1\tLN:9103\n@SQ\tSN:APMT01213437.1\tLN:9103\n@SQ\tSN:KB709839.1\tLN:9102\n@SQ\tSN:KB709468.1\tLN:9099\n@SQ\tSN:KB710050.1\tLN:9099\n@SQ\tSN:APMT01213442.1\tLN:9095\n@SQ\tSN:APMT01213354.1\tLN:9094\n@SQ\tSN:APMT01213447.1\tLN:9088\n@SQ\tSN:KB709502.1\tLN:9087\n@SQ\tSN:APMT01213448.1\tLN:9086\n@SQ\tSN:APMT01213420.1\tLN:9084\n@SQ\tSN:KB709732.1\tLN:9079\n@SQ\tSN:KB709681.1\tLN:9078\n@SQ\tSN:KB709825.1\tLN:9078\n@SQ\tSN:KB709795.1\tLN:9073\n@SQ\tSN:APMT01213459.1\tLN:9073\n@SQ\tSN:KB709871.1\tLN:9073\n@SQ\tSN:KB709840.1\tLN:9072\n@SQ\tSN:APMT01213460.1\tLN:9071\n@SQ\tSN:APMT01213461.1\tLN:9071\n@SQ\tSN:KB709867.1\tLN:9071\n@SQ\tSN:KB709766.1\tLN:9065\n@SQ\tSN:APMT01213464.1\tLN:9063\n@SQ\tSN:APMT01213465.1\tLN:9062\n@SQ\tSN:KB709848.1\tLN:9061\n@SQ\tSN:APMT01213468.1\tLN:9061\n@SQ\tSN:APMT01213470.1\tLN:9059\n@SQ\tSN:APMT01213407.1\tLN:9057\n@SQ\tSN:APMT01213471.1\tLN:9051\n@SQ\tSN:KB709362.1\tLN:9045\n@SQ\tSN:APMT01213469.1\tLN:9044\n@SQ\tSN:KB709843.1\tLN:9043\n@SQ\tSN:APMT01213481.1\tLN:9041\n@SQ\tSN:KB709838.1\tLN:9033\n@SQ\tSN:APMT01213487.1\tLN:9032\n@SQ\tSN:APMT01213449.1\tLN:9031\n@SQ\tSN:KB709451.1\tLN:9029\n@SQ\tSN:KB710091.1\tLN:9028\n@SQ\tSN:KB709763.1\tLN:9027\n@SQ\tSN:KB709859.1\tLN:9027\n@SQ\tSN:APMT01213488.1\tLN:9027\n@SQ\tSN:APMT01213450.1\tLN:9022\n@SQ\tSN:APMT01213493.1\tLN:9022\n@SQ\tSN:APMT01213512.1\tLN:9017\n@SQ\tSN:APMT01213517.1\tLN:9015\n@SQ\tSN:APMT01213472.1\tLN:9014\n@SQ\tSN:KB709883.1\tLN:9014\n@SQ\tSN:APMT01213462.1\tLN:9009\n@SQ\tSN:KB709713.1\tLN:9005\n@SQ\tSN:APMT01213463.1\tLN:9004\n@SQ\tSN:APMT01213531.1\tLN:9002\n@SQ\tSN:APMT01213532.1\tLN:9002\n@SQ\tSN:KB709844.1\tLN:8997\n@SQ\tSN:APMT01213540.1\tLN:8996\n@SQ\tSN:APMT01213541.1\tLN:8996\n@SQ\tSN:APMT01213542.1\tLN:8996\n@SQ\tSN:APMT01213545.1\tLN:8996\n@SQ\tSN:APMT01213482.1\tLN:8995\n@SQ\tSN:APMT01213547.1\tLN:8993\n@SQ\tSN:KB710149.1\tLN:8991\n@SQ\tSN:KB709851.1\tLN:8988\n@SQ\tSN:KB709647.1\tLN:8984\n@SQ\tSN:APMT01213548.1\tLN:8984\n@SQ\tSN:KB709940.1\tLN:8984\n@SQ\tSN:KB710064.1\tLN:8983\n@SQ\tSN:KB709855.1\tLN:8982\n@SQ\tSN:KB710054.1\tLN:8982\n@SQ\tSN:APMT01213554.1\tLN:8981\n@SQ\tSN:APMT01213555.1\tLN:8981\n@SQ\tSN:APMT01213556.1\tLN:8980\n@SQ\tSN:KB709890.1\tLN:8979\n@SQ\tSN:APMT01213557.1\tLN:8976\n@SQ\tSN:APMT01213559.1\tLN:8975\n@SQ\tSN:APMT01213563.1\tLN:8972\n@SQ\tSN:APMT01213526.1\tLN:8971\n@SQ\tSN:APMT01213509.1\tLN:8970\n@SQ\tSN:KB709878.1\tLN:8969\n@SQ\tSN:APMT01213525.1\tLN:8967\n@SQ\tSN:APMT01213574.1\tLN:8967\n@SQ\tSN:APMT01213572.1\tLN:8965\n@SQ\tSN:APMT01213575.1\tLN:8964\n@SQ\tSN:APMT01213576.1\tLN:8963\n@SQ\tSN:KB709854.1\tLN:8961\n@SQ\tSN:APMT01213582.1\tLN:8958\n@SQ\tSN:KB709875.1\tLN:8954\n@SQ\tSN:APMT01213586.1\tLN:8951\n@SQ\tSN:APMT01213596.1\tLN:8950\n@SQ\tSN:APMT01213597.1\tLN:8950\n@SQ\tSN:APMT01213605.1\tLN:8947\n@SQ\tSN:APMT01213602.1\tLN:8946\n@SQ\tSN:KB709522.1\tLN:8945\n@SQ\tSN:APMT01213533.1\tLN:8942\n@SQ\tSN:KB709821.1\tLN:8940\n@SQ\tSN:APMT01213606.1\tLN:8940\n@SQ\tSN:APMT01213607.1\tLN:8939\n@SQ\tSN:KB709882.1\tLN:8937\n@SQ\tSN:APMT01213498.1\tLN:8936\n@SQ\tSN:APMT01213546.1\tLN:8935\n@SQ\tSN:APMT01213610.1\tLN:8933\n@SQ\tSN:KB709751.1\tLN:8931\n@SQ\tSN:APMT01213583.1\tLN:8930\n@SQ\tSN:APMT01213608.1\tLN:8929\n@SQ\tSN:APMT01213616.1\tLN:8929\n@SQ\tSN:APMT01213617.1\tLN:8929\n@SQ\tSN:APMT01213618.1\tLN:8929\n@SQ\tSN:KB710483.1\tLN:8929\n@SQ\tSN:APMT01213624.1\tLN:8916\n@SQ\tSN:APMT01213558.1\tLN:8914\n@SQ\tSN:KB710133.1\tLN:8914\n@SQ\tSN:APMT01213609.1\tLN:8912\n@SQ\tSN:APMT01213628.1\tLN:8910\n@SQ\tSN:KB710112.1\tLN:8910\n@SQ\tSN:KB709812.1\tLN:8907\n@SQ\tSN:KB709786.1\tLN:8905\n@SQ\tSN:APMT01213629.1\tLN:8903\n@SQ\tSN:APMT01213630.1\tLN:8902\n@SQ\tSN:APMT01213573.1\tLN:8900\n@SQ\tSN:APMT01213632.1\tLN:8896\n@SQ\tSN:APMT01213634.1\tLN:8892\n@SQ\tSN:APMT01213635.1\tLN:8891\n@SQ\tSN:KB709898.1\tLN:8891\n@SQ\tSN:KB709895.1\tLN:8890\n@SQ\tSN:KB710157.1\tLN:8885\n@SQ\tSN:APMT01213648.1\tLN:8883\n@SQ\tSN:APMT01213650.1\tLN:8883\n@SQ\tSN:APMT01213649.1\tLN:8882\n@SQ\tSN:APMT01213651.1\tLN:8881\n@SQ\tSN:APMT01213652.1\tLN:8881\n@SQ\tSN:APMT01213653.1\tLN:8881\n@SQ\tSN:KB709820.1\tLN:8880\n@SQ\tSN:APMT01213656.1\tLN:8880\n@SQ\tSN:APMT01213657.1\tLN:8879\n@SQ\tSN:APMT01213669.1\tLN:8876\n@SQ\tSN:APMT01213670.1\tLN:8875\n@SQ\tSN:APMT01213671.1\tLN:8875\n@SQ\tSN:APMT01213673.1\tLN:8874\n@SQ\tSN:KB709446.1\tLN:8873\n@SQ\tSN:APMT01213615.1\tLN:8872\n@SQ\tSN:APMT01213675.1\tLN:8872\n@SQ\tSN:APMT01213680.1\tLN:8865\n@SQ\tSN:APMT01213686.1\tLN:8863\n@SQ\tSN:APMT01213687.1\tLN:8863\n@SQ\tSN:APMT01213693.1\tLN:8858\n@SQ\tSN:APMT01213692.1\tLN:8857\n@SQ\tSN:APMT01213694.1\tLN:8856\n@SQ\tSN:APMT01213695.1\tLN:8855\n@SQ\tSN:KB709912.1\tLN:8855\n@SQ\tSN:KB709977.1\tLN:8855\n@SQ\tSN:APMT01213696.1\tLN:8853\n@SQ\tSN:APMT01213641.1\tLN:8852\n@SQ\tSN:APMT01213705.1\tLN:8850\n@SQ\tSN:KB709798.1\tLN:8848\n@SQ\tSN:APMT01213631.1\tLN:8847\n@SQ\tSN:KB710277.1\tLN:8845\n@SQ\tSN:KB709930.1\tLN:8844\n@SQ\tSN:KB709924.1\tLN:8843\n@SQ\tSN:APMT01213642.1\tLN:8837\n@SQ\tSN:APMT01213672.1\tLN:8837\n@SQ\tSN:APMT01213658.1\tLN:8835\n@SQ\tSN:KB709927.1\tLN:8832\n@SQ\tSN:KB709856.1\tLN:8830\n@SQ\tSN:KB710202.1\tLN:8830\n@SQ\tSN:KB710141.1\tLN:8827\n@SQ\tSN:APMT01213726.1\tLN:8825\n@SQ\tSN:APMT01213647.1\tLN:8823\n@SQ\tSN:APMT01213749.1\tLN:8821\n@SQ\tSN:KB710027.1\tLN:8821\n@SQ\tSN:KB710377.1\tLN:8817\n@SQ\tSN:APMT01213756.1\tLN:8815\n@SQ\tSN:APMT01213674.1\tLN:8814\n@SQ\tSN:KB709910.1\tLN:8814\n@SQ\tSN:KB709956.1\tLN:8813\n@SQ\tSN:APMT01213771.1\tLN:8810\n@SQ\tSN:APMT01213633.1\tLN:8809\n@SQ\tSN:APMT01213775.1\tLN:8809\n@SQ\tSN:APMT01213772.1\tLN:8808\n@SQ\tSN:APMT01213711.1\tLN:8807\n@SQ\tSN:APMT01213773.1\tLN:8807\n@SQ\tSN:APMT01213774.1\tLN:8807\n@SQ\tSN:APMT01213776.1\tLN:8803\n@SQ\tSN:KB709992.1\tLN:8803\n@SQ\tSN:APMT01213777.1\tLN:8801\n@SQ\tSN:APMT01213778.1\tLN:8798\n@SQ\tSN:APMT01213779.1\tLN:8798\n@SQ\tSN:KB709618.1\tLN:8795\n@SQ\tSN:KB709921.1\tLN:8795\n@SQ\tSN:APMT01213780.1\tLN:8795\n@SQ\tSN:APMT01213785.1\tLN:8793\n@SQ\tSN:KB710466.1\tLN:8788\n@SQ\tSN:KB709976.1\tLN:8786\n@SQ\tSN:KB709920.1\tLN:8781\n@SQ\tSN:APMT01213730.1\tLN:8779\n@SQ\tSN:APMT01213798.1\tLN:8779\n@SQ\tSN:KB709902.1\tLN:8777\n@SQ\tSN:APMT01213700.1\tLN:8776\n@SQ\tSN:APMT01213731.1\tLN:8773\n@SQ\tSN:APMT01213807.1\tLN:8773\n@SQ\tSN:APMT01213809.1\tLN:8770\n@SQ\tSN:APMT01213810.1\tLN:8769\n@SQ\tSN:APMT01213808.1\tLN:8761\n@SQ\tSN:APMT01213818.1\tLN:8761\n@SQ\tSN:APMT01213819.1\tLN:8761\n@SQ\tSN:APMT01213820.1\tLN:8759\n@SQ\tSN:APMT01213821.1\tLN:8757\n@SQ\tSN:APMT01213822.1\tLN:8757\n@SQ\tSN:APMT01213824.1\tLN:8757\n@SQ\tSN:APMT01213746.1\tLN:8756\n@SQ\tSN:APMT01213823.1\tLN:8756\n@SQ\tSN:KB709884.1\tLN:8754\n@SQ\tSN:APMT01213826.1\tLN:8753\n@SQ\tSN:APMT01213827.1\tLN:8753\n@SQ\tSN:APMT01213828.1\tLN:8753\n@SQ\tSN:KB710106.1\tLN:8744\n@SQ\tSN:KB709567.1\tLN:8742\n@SQ\tSN:APMT01213790.1\tLN:8742\n@SQ\tSN:KB709720.1\tLN:8738\n@SQ\tSN:APMT01213843.1\tLN:8736\n@SQ\tSN:KB709791.1\tLN:8732\n@SQ\tSN:KB709925.1\tLN:8731\n@SQ\tSN:APMT01213844.1\tLN:8728\n@SQ\tSN:APMT01213736.1\tLN:8723\n@SQ\tSN:APMT01213817.1\tLN:8721\n@SQ\tSN:KB711299.1\tLN:8721\n@SQ\tSN:APMT01213846.1\tLN:8720\n@SQ\tSN:APMT01213853.1\tLN:8713\n@SQ\tSN:APMT01213869.1\tLN:8709\n@SQ\tSN:APMT01213831.1\tLN:8707\n@SQ\tSN:KB709704.1\tLN:8704\n@SQ\tSN:APMT01213825.1\tLN:8702\n@SQ\tSN:APMT01213858.1\tLN:8702\n@SQ\tSN:KB709932.1\tLN:8701\n@SQ\tSN:APMT01213845.1\tLN:8700\n@SQ\tSN:KB709926.1\tLN:8697\n@SQ\tSN:APMT01213881.1\tLN:8693\n@SQ\tSN:APMT01213882.1\tLN:8692\n@SQ\tSN:APMT01213834.1\tLN:8690\n@SQ\tSN:KB709918.1\tLN:8686\n@SQ\tSN:APMT01213885.1\tLN:8686\n@SQ\tSN:APMT01213886.1\tLN:8686\n@SQ\tSN:APMT01213887.1\tLN:8686\n@SQ\tSN:KB709928.1\tLN:8681\n@SQ\tSN:KB709366.1\tLN:8677\n@SQ\tSN:APMT01213900.1\tLN:8675\n@SQ\tSN:KB709829.1\tLN:8674\n@SQ\tSN:APMT01213912.1\tLN:8668\n@SQ\tSN:KB710158.1\tLN:8668\n@SQ\tSN:KB710105.1\tLN:8666\n@SQ\tSN:APMT01213920.1\tLN:8664\n@SQ\tSN:KB709906.1\tLN:8660\n@SQ\tSN:APMT01213937.1\tLN:8659\n@SQ\tSN:APMT01213936.1\tLN:8655\n@SQ\tSN:APMT01213943.1\tLN:8654\n@SQ\tSN:APMT01213880.1\tLN:8650\n@SQ\tSN:APMT01213954.1\tLN:8649\n@SQ\tSN:APMT01213870.1\tLN:8647\n@SQ\tSN:APMT01213938.1\tLN:8644\n@SQ\tSN:APMT01213896.1\tLN:8640\n@SQ\tSN:APMT01213879.1\tLN:8639\n@SQ\tSN:APMT01213961.1\tLN:8634\n@SQ\tSN:APMT01213960.1\tLN:8633\n@SQ\tSN:KB710252.1\tLN:8632\n@SQ\tSN:APMT01213928.1\tLN:8629\n@SQ\tSN:APMT01213968.1\tLN:8625\n@SQ\tSN:APMT01213888.1\tLN:8620\n@SQ\tSN:KB709935.1\tLN:8619\n@SQ\tSN:APMT01213972.1\tLN:8618\n@SQ\tSN:APMT01213973.1\tLN:8615\n@SQ\tSN:APMT01213979.1\tLN:8608\n@SQ\tSN:KB709568.1\tLN:8606\n@SQ\tSN:APMT01213981.1\tLN:8606\n@SQ\tSN:KB709955.1\tLN:8605\n@SQ\tSN:KB709899.1\tLN:8604\n@SQ\tSN:APMT01213923.1\tLN:8603\n@SQ\tSN:KB710243.1\tLN:8600\n@SQ\tSN:APMT01213985.1\tLN:8599\n@SQ\tSN:APMT01213990.1\tLN:8594\n@SQ\tSN:APMT01213953.1\tLN:8593\n@SQ\tSN:KB709945.1\tLN:8592\n@SQ\tSN:APMT01213995.1\tLN:8590\n@SQ\tSN:KB709987.1\tLN:8589\n@SQ\tSN:KB710504.1\tLN:8589\n@SQ\tSN:KB709957.1\tLN:8588\n@SQ\tSN:APMT01213955.1\tLN:8582\n@SQ\tSN:KB709372.1\tLN:8577\n@SQ\tSN:APMT01213971.1\tLN:8572\n@SQ\tSN:APMT01214008.1\tLN:8572\n@SQ\tSN:APMT01214014.1\tLN:8570\n@SQ\tSN:APMT01214015.1\tLN:8570\n@SQ\tSN:APMT01213967.1\tLN:8568\n@SQ\tSN:KB709903.1\tLN:8566\n@SQ\tSN:KB709803.1\tLN:8565\n@SQ\tSN:KB709949.1\tLN:8560\n@SQ\tSN:KB709939.1\tLN:8558\n@SQ\tSN:APMT01213986.1\tLN:8558\n@SQ\tSN:KB709774.1\tLN:8557\n@SQ\tSN:APMT01214030.1\tLN:8555\n@SQ\tSN:KB709891.1\tLN:8554\n@SQ\tSN:APMT01213980.1\tLN:8553\n@SQ\tSN:APMT01213978.1\tLN:8552\n@SQ\tSN:KB709960.1\tLN:8549\n@SQ\tSN:KB710138.1\tLN:8549\n@SQ\tSN:KB710233.1\tLN:8548\n@SQ\tSN:KB709953.1\tLN:8547\n@SQ\tSN:APMT01213982.1\tLN:8547\n@SQ\tSN:APMT01214020.1\tLN:8547\n@SQ\tSN:APMT01214035.1\tLN:8544\n@SQ\tSN:APMT01214041.1\tLN:8541\n@SQ\tSN:APMT01214044.1\tLN:8540\n@SQ\tSN:APMT01214042.1\tLN:8539\n@SQ\tSN:KB710118.1\tLN:8535\n@SQ\tSN:APMT01214045.1\tLN:8534\n@SQ\tSN:KB710911.1\tLN:8529\n@SQ\tSN:APMT01214046.1\tLN:8528\n@SQ\tSN:APMT01214047.1\tLN:8528\n@SQ\tSN:KB709997.1\tLN:8528\n@SQ\tSN:APMT01214048.1\tLN:8525\n@SQ\tSN:KB710444.1\tLN:8525\n@SQ\tSN:APMT01214054.1\tLN:8519\n@SQ\tSN:APMT01214064.1\tLN:8517\n@SQ\tSN:APMT01214065.1\tLN:8515\n@SQ\tSN:APMT01214001.1\tLN:8514\n@SQ\tSN:APMT01214066.1\tLN:8512\n@SQ\tSN:APMT01214013.1\tLN:8510\n@SQ\tSN:APMT01214067.1\tLN:8505\n@SQ\tSN:APMT01214069.1\tLN:8504\n@SQ\tSN:APMT01214071.1\tLN:8504\n@SQ\tSN:APMT01214082.1\tLN:8500\n@SQ\tSN:APMT01214043.1\tLN:8499\n@SQ\tSN:APMT01214083.1\tLN:8499\n@SQ\tSN:APMT01214085.1\tLN:8498\n@SQ\tSN:KB709353.1\tLN:8497\n@SQ\tSN:KB710506.1\tLN:8497\n@SQ\tSN:APMT01214070.1\tLN:8496\n@SQ\tSN:APMT01214090.1\tLN:8494\n@SQ\tSN:APMT01214091.1\tLN:8494\n@SQ\tSN:KB709947.1\tLN:8492\n@SQ\tSN:KB709962.1\tLN:8489\n@SQ\tSN:APMT01214084.1\tLN:8488\n@SQ\tSN:APMT01214097.1\tLN:8488\n@SQ\tSN:APMT01214113.1\tLN:8486\n@SQ\tSN:APMT01213913.1\tLN:8485\n@SQ\tSN:KB709517.1\tLN:8484\n@SQ\tSN:APMT01214102.1\tLN:8484\n@SQ\tSN:APMT01214103.1\tLN:8483\n@SQ\tSN:KB709984.1\tLN:8481\n@SQ\tSN:APMT01214105.1\tLN:8480\n@SQ\tSN:KB710282.1\tLN:8478\n@SQ\tSN:APMT01214055.1\tLN:8476\n@SQ\tSN:APMT01214111.1\tLN:8475\n@SQ\tSN:APMT01214112.1\tLN:8473\n@SQ\tSN:APMT01214053.1\tLN:8470\n@SQ\tSN:APMT01214114.1\tLN:8469\n@SQ\tSN:KB709907.1\tLN:8460\n@SQ\tSN:KB710178.1\tLN:8456\n@SQ\tSN:APMT01214068.1\tLN:8453\n@SQ\tSN:APMT01214116.1\tLN:8452\n@SQ\tSN:KB709996.1\tLN:8450\n@SQ\tSN:KB709419.1\tLN:8442\n@SQ\tSN:APMT01214133.1\tLN:8441\n@SQ\tSN:KB709771.1\tLN:8434\n@SQ\tSN:APMT01214139.1\tLN:8434\n@SQ\tSN:APMT01214140.1\tLN:8434\n@SQ\tSN:APMT01214115.1\tLN:8433\n@SQ\tSN:APMT01214117.1\tLN:8432\n@SQ\tSN:KB709961.1\tLN:8430\n@SQ\tSN:KB709866.1\tLN:8424\n@SQ\tSN:APMT01214154.1\tLN:8423\n@SQ\tSN:APMT01214104.1\tLN:8422\n@SQ\tSN:KB709806.1\tLN:8420\n@SQ\tSN:APMT01214141.1\tLN:8419\n@SQ\tSN:KB709917.1\tLN:8418\n@SQ\tSN:KB710003.1\tLN:8415\n@SQ\tSN:KB710193.1\tLN:8414\n@SQ\tSN:APMT01214164.1\tLN:8411\n@SQ\tSN:APMT01214165.1\tLN:8411\n@SQ\tSN:KB709993.1\tLN:8409\n@SQ\tSN:APMT01214174.1\tLN:8407\n@SQ\tSN:APMT01214178.1\tLN:8407\n@SQ\tSN:KB709835.1\tLN:8406\n@SQ\tSN:KB712167.1\tLN:8406\n@SQ\tSN:APMT01214180.1\tLN:8405\n@SQ\tSN:KB711063.1\tLN:8404\n@SQ\tSN:APMT01214181.1\tLN:8402\n@SQ\tSN:KB709988.1\tLN:8397\n@SQ\tSN:KB710115.1\tLN:8397\n@SQ\tSN:APMT01214146.1\tLN:8396\n@SQ\tSN:APMT01214191.1\tLN:8396\n@SQ\tSN:APMT01214175.1\tLN:8393\n@SQ\tSN:APMT01214190.1\tLN:8392\n@SQ\tSN:KB709982.1\tLN:8391\n@SQ\tSN:APMT01214122.1\tLN:8390\n@SQ\tSN:APMT01214207.1\tLN:8388\n@SQ\tSN:KB709959.1\tLN:8386\n@SQ\tSN:APMT01214209.1\tLN:8382\n@SQ\tSN:APMT01214212.1\tLN:8382\n@SQ\tSN:KB710032.1\tLN:8382\n@SQ\tSN:APMT01214213.1\tLN:8379\n@SQ\tSN:APMT01214214.1\tLN:8377\n@SQ\tSN:APMT01214220.1\tLN:8374\n@SQ\tSN:APMT01214221.1\tLN:8374\n@SQ\tSN:APMT01214127.1\tLN:8371\n@SQ\tSN:KB709972.1\tLN:8370\n@SQ\tSN:APMT01214222.1\tLN:8369\n@SQ\tSN:KB710056.1\tLN:8368\n@SQ\tSN:APMT01214208.1\tLN:8367\n@SQ\tSN:KB710165.1\tLN:8365\n@SQ\tSN:APMT01214170.1\tLN:8362\n@SQ\tSN:APMT01214224.1\tLN:8362\n@SQ\tSN:APMT01214264.1\tLN:8361\n@SQ\tSN:APMT01214179.1\tLN:8359\n@SQ\tSN:APMT01214200.1\tLN:8358\n@SQ\tSN:APMT01214226.1\tLN:8358\n@SQ\tSN:APMT01214227.1\tLN:8358\n@SQ\tSN:APMT01214228.1\tLN:8357\n@SQ\tSN:APMT01214192.1\tLN:8356\n@SQ\tSN:APMT01214229.1\tLN:8356\n@SQ\tSN:KB709983.1\tLN:8354\n@SQ\tSN:APMT01214223.1\tLN:8354\n@SQ\tSN:KB710644.1\tLN:8351\n@SQ\tSN:APMT01214233.1\tLN:8350\n@SQ\tSN:KB709967.1\tLN:8349\n@SQ\tSN:APMT01214234.1\tLN:8348\n@SQ\tSN:APMT01214235.1\tLN:8348\n@SQ\tSN:APMT01214262.1\tLN:8348\n@SQ\tSN:KB710019.1\tLN:8341\n@SQ\tSN:KB710187.1\tLN:8340\n@SQ\tSN:KB710310.1\tLN:8339\n@SQ\tSN:KB709529.1\tLN:8338\n@SQ\tSN:KB710015.1\tLN:8338\n@SQ\tSN:APMT01214240.1\tLN:8338\n@SQ\tSN:APMT01214245.1\tLN:8337\n@SQ\tSN:APMT01214246.1\tLN:8331\n@SQ\tSN:APMT01214251.1\tLN:8326\n@SQ\tSN:APMT01214253.1\tLN:8322\n@SQ\tSN:KB710489.1\tLN:8322\n@SQ\tSN:APMT01214193.1\tLN:8321\n@SQ\tSN:APMT01214254.1\tLN:8321\n@SQ\tSN:APMT01214255.1\tLN:8320\n@SQ\tSN:APMT01214256.1\tLN:8320\n@SQ\tSN:APMT01214257.1\tLN:8319\n@SQ\tSN:KB710001.1\tLN:8315\n@SQ\tSN:KB710008.1\tLN:8315\n@SQ\tSN:KB710766.1\tLN:8315\n@SQ\tSN:APMT01214263.1\tLN:8314\n@SQ\tSN:APMT01214266.1\tLN:8310\n@SQ\tSN:APMT01214267.1\tLN:8310\n@SQ\tSN:KB710313.1\tLN:8306\n@SQ\tSN:KB710011.1\tLN:8305\n@SQ\tSN:APMT01214271.1\tLN:8305\n@SQ\tSN:APMT01214261.1\tLN:8303\n@SQ\tSN:KB709929.1\tLN:8301\n@SQ\tSN:APMT01214225.1\tLN:8300\n@SQ\tSN:KB710022.1\tLN:8300\n@SQ\tSN:APMT01214273.1\tLN:8296\n@SQ\tSN:KB709963.1\tLN:8294\n@SQ\tSN:KB710020.1\tLN:8292\n@SQ\tSN:APMT01214275.1\tLN:8291\n@SQ\tSN:APMT01214276.1\tLN:8291\n@SQ\tSN:APMT01214236.1\tLN:8287\n@SQ\tSN:KB709904.1\tLN:8280\n@SQ\tSN:APMT01214281.1\tLN:8280\n@SQ\tSN:APMT01214282.1\tLN:8278\n@SQ\tSN:APMT01214292.1\tLN:8274\n@SQ\tSN:APMT01214293.1\tLN:8274\n@SQ\tSN:KB710028.1\tLN:8273\n@SQ\tSN:KB710170.1\tLN:8270\n@SQ\tSN:APMT01214239.1\tLN:8267\n@SQ\tSN:KB710212.1\tLN:8267\n@SQ\tSN:KB710328.1\tLN:8267\n@SQ\tSN:APMT01214304.1\tLN:8266\n@SQ\tSN:APMT01214252.1\tLN:8265\n@SQ\tSN:APMT01214305.1\tLN:8264\n@SQ\tSN:KB710379.1\tLN:8262\n@SQ\tSN:KB710114.1\tLN:8261\n@SQ\tSN:APMT01214265.1\tLN:8260\n@SQ\tSN:KB709775.1\tLN:8257\n@SQ\tSN:KB709731.1\tLN:8254\n@SQ\tSN:KB709980.1\tLN:8253\n@SQ\tSN:APMT01214313.1\tLN:8252\n@SQ\tSN:APMT01214315.1\tLN:8250\n@SQ\tSN:KB709845.1\tLN:8249\n@SQ\tSN:APMT01214314.1\tLN:8249\n@SQ\tSN:KB710024.1\tLN:8247\n@SQ\tSN:APMT01214320.1\tLN:8246\n@SQ\tSN:APMT01214302.1\tLN:8243\n@SQ\tSN:APMT01214274.1\tLN:8242\n@SQ\tSN:KB709989.1\tLN:8241\n@SQ\tSN:APMT01214303.1\tLN:8239\n@SQ\tSN:APMT01214324.1\tLN:8239\n@SQ\tSN:APMT01214272.1\tLN:8237\n@SQ\tSN:APMT01214326.1\tLN:8236\n@SQ\tSN:APMT01214328.1\tLN:8235\n@SQ\tSN:APMT01214329.1\tLN:8235\n@SQ\tSN:APMT01214330.1\tLN:8234\n@SQ\tSN:APMT01214332.1\tLN:8234\n@SQ\tSN:APMT01214327.1\tLN:8233\n@SQ\tSN:KB709880.1\tLN:8231\n@SQ\tSN:KB710182.1\tLN:8231\n@SQ\tSN:APMT01214338.1\tLN:8223\n@SQ\tSN:APMT01214342.1\tLN:8218\n@SQ\tSN:KB709969.1\tLN:8217\n@SQ\tSN:APMT01214344.1\tLN:8216\n@SQ\tSN:KB710007.1\tLN:8215\n@SQ\tSN:KB710325.1\tLN:8213\n@SQ\tSN:APMT01214345.1\tLN:8212\n@SQ\tSN:APMT01214350.1\tLN:8209\n@SQ\tSN:APMT01214351.1\tLN:8206\n@SQ\tSN:APMT01214331.1\tLN:8205\n@SQ\tSN:APMT01214352.1\tLN:8205\n@SQ\tSN:APMT01214353.1\tLN:8205\n@SQ\tSN:KB710058.1\tLN:8205\n@SQ\tSN:KB710191.1\tLN:8205\n@SQ\tSN:APMT01214306.1\tLN:8202\n@SQ\tSN:APMT01214355.1\tLN:8202\n@SQ\tSN:APMT01214356.1\tLN:8202\n@SQ\tSN:APMT01214357.1\tLN:8202\n@SQ\tSN:APMT01214358.1\tLN:8202\n@SQ\tSN:KB710059.1\tLN:8201\n@SQ\tSN:APMT01214359.1\tLN:8200\n@SQ\tSN:APMT01214307.1\tLN:8199\n@SQ\tSN:KB709248.1\tLN:8198\n@SQ\tSN:APMT01214321.1\tLN:8196\n@SQ\tSN:APMT01214361.1\tLN:8195\n@SQ\tSN:APMT01214365.1\tLN:8193\n@SQ\tSN:APMT01214343.1\tLN:8192\n@SQ\tSN:KB710087.1\tLN:8187\n@SQ\tSN:APMT01214354.1\tLN:8186\n@SQ\tSN:APMT01214325.1\tLN:8185\n@SQ\tSN:APMT01214322.1\tLN:8183\n@SQ\tSN:APMT01214323.1\tLN:8182\n@SQ\tSN:APMT01214374.1\tLN:8181\n@SQ\tSN:KB709591.1\tLN:8179\n@SQ\tSN:KB710002.1\tLN:8179\n@SQ\tSN:APMT01214369.1\tLN:8179\n@SQ\tSN:APMT01214370.1\tLN:8177\n@SQ\tSN:KB710025.1\tLN:8172\n@SQ\tSN:APMT01214360.1\tLN:8172\n@SQ\tSN:APMT01214375.1\tLN:8171\n@SQ\tSN:KB710109.1\tLN:8170\n@SQ\tSN:APMT01214376.1\tLN:8167\n@SQ\tSN:KB710190.1\tLN:8164\n@SQ\tSN:APMT01214377.1\tLN:8163\n@SQ\tSN:APMT01214333.1\tLN:8162\n@SQ\tSN:APMT01214371.1\tLN:8162\n@SQ\tSN:APMT01214378.1\tLN:8162\n@SQ\tSN:APMT01214379.1\tLN:8162\n@SQ\tSN:APMT01214341.1\tLN:8161\n@SQ\tSN:APMT01214385.1\tLN:8156\n@SQ\tSN:KB710021.1\tLN:8155\n@SQ\tSN:APMT01214394.1\tLN:8155\n@SQ\tSN:APMT01214386.1\tLN:8153\n@SQ\tSN:APMT01214387.1\tLN:8153\n@SQ\tSN:APMT01214391.1\tLN:8145\n@SQ\tSN:APMT01214393.1\tLN:8143\n@SQ\tSN:APMT01214395.1\tLN:8140\n@SQ\tSN:APMT01214396.1\tLN:8140\n@SQ\tSN:APMT01214397.1\tLN:8139\n@SQ\tSN:APMT01214399.1\tLN:8138\n@SQ\tSN:APMT01214400.1\tLN:8132\n@SQ\tSN:APMT01214398.1\tLN:8131\n@SQ\tSN:APMT01214401.1\tLN:8131\n@SQ\tSN:APMT01214402.1\tLN:8131\n@SQ\tSN:KB709914.1\tLN:8126\n@SQ\tSN:APMT01214384.1\tLN:8126\n@SQ\tSN:KB709860.1\tLN:8124\n@SQ\tSN:APMT01214404.1\tLN:8119\n@SQ\tSN:APMT01214405.1\tLN:8118\n@SQ\tSN:APMT01214406.1\tLN:8118\n@SQ\tSN:APMT01214407.1\tLN:8118\n@SQ\tSN:APMT01214409.1\tLN:8115\n@SQ\tSN:APMT01214411.1\tLN:8105\n@SQ\tSN:APMT01214390.1\tLN:8101\n@SQ\tSN:KB710146.1\tLN:8101\n@SQ\tSN:APMT01214412.1\tLN:8094\n@SQ\tSN:KB710078.1\tLN:8094\n@SQ\tSN:APMT01214403.1\tLN:8092\n@SQ\tSN:APMT01214418.1\tLN:8092\n@SQ\tSN:KB710429.1\tLN:8092\n@SQ\tSN:KB710197.1\tLN:8090\n@SQ\tSN:KB710462.1\tLN:8087\n@SQ\tSN:APMT01214424.1\tLN:8086\n@SQ\tSN:APMT01214429.1\tLN:8084\n@SQ\tSN:KB709913.1\tLN:8083\n@SQ\tSN:APMT01214430.1\tLN:8079\n@SQ\tSN:APMT01214408.1\tLN:8074\n@SQ\tSN:APMT01214410.1\tLN:8071\n@SQ\tSN:KB710090.1\tLN:8068\n@SQ\tSN:APMT01214433.1\tLN:8065\n@SQ\tSN:APMT01214434.1\tLN:8065\n@SQ\tSN:KB710062.1\tLN:8065\n@SQ\tSN:APMT01214435.1\tLN:8064\n@SQ\tSN:APMT01214436.1\tLN:8064\n@SQ\tSN:APMT01214437.1\tLN:8062\n@SQ\tSN:APMT01214438.1\tLN:8060\n@SQ\tSN:APMT01214439.1\tLN:8060\n@SQ\tSN:KB710104.1\tLN:8055\n@SQ\tSN:KB710044.1\tLN:8051\n@SQ\tSN:KB710023.1\tLN:8048\n@SQ\tSN:APMT01214455.1\tLN:8048\n@SQ\tSN:KB710134.1\tLN:8048\n@SQ\tSN:APMT01214458.1\tLN:8046\n@SQ\tSN:APMT01214457.1\tLN:8045\n@SQ\tSN:APMT01214459.1\tLN:8045\n@SQ\tSN:KB710510.1\tLN:8044\n@SQ\tSN:KB710013.1\tLN:8040\n@SQ\tSN:KB710626.1\tLN:8039\n@SQ\tSN:APMT01214467.1\tLN:8036\n@SQ\tSN:APMT01214431.1\tLN:8035\n@SQ\tSN:APMT01214468.1\tLN:8035\n@SQ\tSN:APMT01214469.1\tLN:8035\n@SQ\tSN:KB709998.1\tLN:8033\n@SQ\tSN:APMT01214475.1\tLN:8032\n@SQ\tSN:APMT01214474.1\tLN:8031\n@SQ\tSN:KB710055.1\tLN:8030\n@SQ\tSN:KB710278.1\tLN:8030\n@SQ\tSN:APMT01214488.1\tLN:8028\n@SQ\tSN:APMT01214423.1\tLN:8027\n@SQ\tSN:KB709305.1\tLN:8024\n@SQ\tSN:APMT01214489.1\tLN:8024\n@SQ\tSN:APMT01214592.1\tLN:8023\n@SQ\tSN:APMT01214392.1\tLN:8022\n@SQ\tSN:APMT01214490.1\tLN:8022\n@SQ\tSN:APMT01214494.1\tLN:8018\n@SQ\tSN:KB710161.1\tLN:8017\n@SQ\tSN:APMT01214498.1\tLN:8015\n@SQ\tSN:KB710026.1\tLN:8014\n@SQ\tSN:APMT01214479.1\tLN:8010\n@SQ\tSN:KB710051.1\tLN:8010\n@SQ\tSN:APMT01214499.1\tLN:8009\n@SQ\tSN:APMT01214500.1\tLN:8009\n@SQ\tSN:KB710030.1\tLN:8008\n@SQ\tSN:APMT01214501.1\tLN:8007\n@SQ\tSN:KB710039.1\tLN:8006\n@SQ\tSN:KB710061.1\tLN:8006\n@SQ\tSN:KB710033.1\tLN:8004\n@SQ\tSN:APMT01214505.1\tLN:8003\n@SQ\tSN:APMT01214506.1\tLN:7997\n@SQ\tSN:APMT01214449.1\tLN:7994\n@SQ\tSN:APMT01214456.1\tLN:7993\n@SQ\tSN:KB710069.1\tLN:7993\n@SQ\tSN:KB710367.1\tLN:7992\n@SQ\tSN:APMT01214507.1\tLN:7980\n@SQ\tSN:APMT01214528.1\tLN:7978\n@SQ\tSN:APMT01214529.1\tLN:7978\n@SQ\tSN:APMT01214530.1\tLN:7975\n@SQ\tSN:APMT01214531.1\tLN:7973\n@SQ\tSN:APMT01214537.1\tLN:7973\n@SQ\tSN:APMT01214538.1\tLN:7973\n@SQ\tSN:KB709915.1\tLN:7969\n@SQ\tSN:KB710053.1\tLN:7966\n@SQ\tSN:KB709990.1\tLN:7963\n@SQ\tSN:APMT01214432.1\tLN:7958\n@SQ\tSN:KB709793.1\tLN:7954\n@SQ\tSN:KB710084.1\tLN:7952\n@SQ\tSN:APMT01214561.1\tLN:7950\n@SQ\tSN:APMT01214562.1\tLN:7948\n@SQ\tSN:APMT01214569.1\tLN:7942\n@SQ\tSN:APMT01214571.1\tLN:7941\n@SQ\tSN:KB710183.1\tLN:7936\n@SQ\tSN:APMT01214575.1\tLN:7935\n@SQ\tSN:KB710281.1\tLN:7935\n@SQ\tSN:APMT01214527.1\tLN:7933\n@SQ\tSN:APMT01214526.1\tLN:7932\n@SQ\tSN:APMT01214577.1\tLN:7932\n@SQ\tSN:APMT01214552.1\tLN:7930\n@SQ\tSN:KB709671.1\tLN:7925\n@SQ\tSN:KB710046.1\tLN:7925\n@SQ\tSN:KB710048.1\tLN:7925\n@SQ\tSN:APMT01214578.1\tLN:7918\n@SQ\tSN:KB712246.1\tLN:7918\n@SQ\tSN:KB709426.1\tLN:7917\n@SQ\tSN:APMT01214572.1\tLN:7917\n@SQ\tSN:KB710045.1\tLN:7912\n@SQ\tSN:KB710443.1\tLN:7912\n@SQ\tSN:APMT01214576.1\tLN:7911\n@SQ\tSN:APMT01214547.1\tLN:7905\n@SQ\tSN:APMT01214563.1\tLN:7905\n@SQ\tSN:KB710060.1\tLN:7900\n@SQ\tSN:APMT01214602.1\tLN:7899\n@SQ\tSN:APMT01214603.1\tLN:7897\n@SQ\tSN:KB710629.1\tLN:7897\n@SQ\tSN:APMT01214606.1\tLN:7894\n@SQ\tSN:APMT01214564.1\tLN:7891\n@SQ\tSN:APMT01214607.1\tLN:7891\n@SQ\tSN:APMT01214608.1\tLN:7887\n@SQ\tSN:KB710242.1\tLN:7887\n@SQ\tSN:APMT01214610.1\tLN:7886\n@SQ\tSN:APMT01214612.1\tLN:7886\n@SQ\tSN:APMT01214613.1\tLN:7883\n@SQ\tSN:APMT01214570.1\tLN:7881\n@SQ\tSN:APMT01214593.1\tLN:7878\n@SQ\tSN:APMT01214614.1\tLN:7878\n@SQ\tSN:KB710619.1\tLN:7878\n@SQ\tSN:KB710005.1\tLN:7876\n@SQ\tSN:APMT01214600.1\tLN:7874\n@SQ\tSN:APMT01214591.1\tLN:7873\n@SQ\tSN:APMT01214618.1\tLN:7870\n@SQ\tSN:KB709849.1\tLN:7866\n@SQ\tSN:KB710275.1\tLN:7862\n@SQ\tSN:APMT01214631.1\tLN:7858\n@SQ\tSN:APMT01214609.1\tLN:7856\n@SQ\tSN:APMT01214583.1\tLN:7855\n@SQ\tSN:APMT01214620.1\tLN:7854\n@SQ\tSN:KB710363.1\tLN:7854\n@SQ\tSN:APMT01214590.1\tLN:7852\n@SQ\tSN:KB710456.1\tLN:7852\n@SQ\tSN:APMT01214601.1\tLN:7851\n@SQ\tSN:APMT01214632.1\tLN:7845\n@SQ\tSN:APMT01214633.1\tLN:7845\n@SQ\tSN:KB710480.1\tLN:7843\n@SQ\tSN:APMT01214636.1\tLN:7842\n@SQ\tSN:KB710246.1\tLN:7842\n@SQ\tSN:KB710166.1\tLN:7839\n@SQ\tSN:APMT01214617.1\tLN:7837\n@SQ\tSN:APMT01214616.1\tLN:7836\n@SQ\tSN:APMT01214643.1\tLN:7836\n@SQ\tSN:APMT01214644.1\tLN:7836\n@SQ\tSN:APMT01214634.1\tLN:7835\n@SQ\tSN:KB710150.1\tLN:7831\n@SQ\tSN:APMT01214653.1\tLN:7827\n@SQ\tSN:APMT01214611.1\tLN:7826\n@SQ\tSN:APMT01214615.1\tLN:7825\n@SQ\tSN:APMT01214656.1\tLN:7823\n@SQ\tSN:APMT01214619.1\tLN:7820\n@SQ\tSN:KB709527.1\tLN:7819\n@SQ\tSN:APMT01214655.1\tLN:7816\n@SQ\tSN:KB709506.1\tLN:7812\n@SQ\tSN:APMT01214668.1\tLN:7812\n@SQ\tSN:APMT01214667.1\tLN:7810\n@SQ\tSN:APMT01214669.1\tLN:7810\n@SQ\tSN:KB710778.1\tLN:7810\n@SQ\tSN:APMT01214671.1\tLN:7808\n@SQ\tSN:KB710238.1\tLN:7806\n@SQ\tSN:APMT01214680.1\tLN:7802\n@SQ\tSN:APMT01214670.1\tLN:7801\n@SQ\tSN:KB710368.1\tLN:7801\n@SQ\tSN:APMT01214672.1\tLN:7800\n@SQ\tSN:APMT01214681.1\tLN:7797\n@SQ\tSN:KB710584.1\tLN:7795\n@SQ\tSN:APMT01214621.1\tLN:7794\n@SQ\tSN:APMT01214682.1\tLN:7790\n@SQ\tSN:APMT01214683.1\tLN:7790\n@SQ\tSN:APMT01214684.1\tLN:7787\n@SQ\tSN:APMT01214635.1\tLN:7786\n@SQ\tSN:APMT01214688.1\tLN:7784\n@SQ\tSN:APMT01214630.1\tLN:7782\n@SQ\tSN:APMT01214689.1\tLN:7781\n@SQ\tSN:KB710156.1\tLN:7780\n@SQ\tSN:APMT01214642.1\tLN:7779\n@SQ\tSN:APMT01214691.1\tLN:7779\n@SQ\tSN:KB710080.1\tLN:7776\n@SQ\tSN:APMT01214692.1\tLN:7774\n@SQ\tSN:APMT01214694.1\tLN:7773\n@SQ\tSN:KB710126.1\tLN:7768\n@SQ\tSN:APMT01214703.1\tLN:7765\n@SQ\tSN:APMT01214657.1\tLN:7763\n@SQ\tSN:APMT01214690.1\tLN:7763\n@SQ\tSN:KB710079.1\tLN:7762\n@SQ\tSN:APMT01214708.1\tLN:7761\n@SQ\tSN:APMT01214714.1\tLN:7759\n@SQ\tSN:APMT01214715.1\tLN:7758\n@SQ\tSN:KB710125.1\tLN:7756\n@SQ\tSN:KB710041.1\tLN:7755\n@SQ\tSN:KB713406.1\tLN:7753\n@SQ\tSN:KB709815.1\tLN:7751\n@SQ\tSN:APMT01214717.1\tLN:7751\n@SQ\tSN:KB710344.1\tLN:7751\n@SQ\tSN:APMT01214719.1\tLN:7745\n@SQ\tSN:APMT01214732.1\tLN:7739\n@SQ\tSN:APMT01214733.1\tLN:7737\n@SQ\tSN:APMT01214735.1\tLN:7735\n@SQ\tSN:APMT01214737.1\tLN:7734\n@SQ\tSN:KB710089.1\tLN:7733\n@SQ\tSN:APMT01214738.1\tLN:7732\n@SQ\tSN:KB710245.1\tLN:7729\n@SQ\tSN:APMT01214693.1\tLN:7727\n@SQ\tSN:APMT01214740.1\tLN:7725\n@SQ\tSN:APMT01214654.1\tLN:7724\n@SQ\tSN:APMT01214718.1\tLN:7724\n@SQ\tSN:APMT01214739.1\tLN:7722\n@SQ\tSN:KB710088.1\tLN:7720\n@SQ\tSN:APMT01214716.1\tLN:7719\n@SQ\tSN:APMT01214742.1\tLN:7719\n@SQ\tSN:APMT01214743.1\tLN:7719\n@SQ\tSN:KB710124.1\tLN:7719\n@SQ\tSN:APMT01214749.1\tLN:7715\n@SQ\tSN:APMT01214750.1\tLN:7714\n@SQ\tSN:APMT01214747.1\tLN:7713\n@SQ\tSN:KB710199.1\tLN:7713\n@SQ\tSN:KB709461.1\tLN:7712\n@SQ\tSN:KB710342.1\tLN:7712\n@SQ\tSN:APMT01214748.1\tLN:7711\n@SQ\tSN:APMT01214752.1\tLN:7711\n@SQ\tSN:KB710162.1\tLN:7710\n@SQ\tSN:APMT01214759.1\tLN:7707\n@SQ\tSN:APMT01214727.1\tLN:7706\n@SQ\tSN:APMT01214751.1\tLN:7704\n@SQ\tSN:APMT01214761.1\tLN:7704\n@SQ\tSN:APMT01214766.1\tLN:7703\n@SQ\tSN:KB710035.1\tLN:7702\n@SQ\tSN:APMT01214767.1\tLN:7702\n@SQ\tSN:APMT01214768.1\tLN:7701\n@SQ\tSN:APMT01214771.1\tLN:7700\n@SQ\tSN:APMT01214772.1\tLN:7700\n@SQ\tSN:APMT01214773.1\tLN:7698\n@SQ\tSN:KB710116.1\tLN:7698\n@SQ\tSN:APMT01214757.1\tLN:7697\n@SQ\tSN:APMT01214779.1\tLN:7696\n@SQ\tSN:KB710186.1\tLN:7695\n@SQ\tSN:KB709740.1\tLN:7689\n@SQ\tSN:KB710514.1\tLN:7689\n@SQ\tSN:APMT01214728.1\tLN:7686\n@SQ\tSN:APMT01214789.1\tLN:7686\n@SQ\tSN:APMT01214780.1\tLN:7685\n@SQ\tSN:APMT01214790.1\tLN:7685\n@SQ\tSN:APMT01214791.1\tLN:7685\n@SQ\tSN:KB710086.1\tLN:7684\n@SQ\tSN:APMT01214736.1\tLN:7684\n@SQ\tSN:APMT01214792.1\tLN:7683\n@SQ\tSN:APMT01214796.1\tLN:7683\n@SQ\tSN:APMT01214798.1\tLN:7677\n@SQ\tSN:KB710350.1\tLN:7674\n@SQ\tSN:KB710467.1\tLN:7674\n@SQ\tSN:KB710066.1\tLN:7673\n@SQ\tSN:APMT01214734.1\tLN:7672\n@SQ\tSN:KB710130.1\tLN:7672\n@SQ\tSN:KB710075.1\tLN:7671\n@SQ\tSN:KB710673.1\tLN:7671\n@SQ\tSN:KB710438.1\tLN:7669\n@SQ\tSN:APMT01214806.1\tLN:7668\n@SQ\tSN:APMT01214741.1\tLN:7666\n@SQ\tSN:APMT01214808.1\tLN:7662\n@SQ\tSN:APMT01214813.1\tLN:7659\n@SQ\tSN:APMT01214814.1\tLN:7659\n@SQ\tSN:APMT01214760.1\tLN:7658\n@SQ\tSN:APMT01214820.1\tLN:7653\n@SQ\tSN:APMT01214758.1\tLN:7652\n@SQ\tSN:APMT01214821.1\tLN:7652\n@SQ\tSN:KB710057.1\tLN:7645\n@SQ\tSN:APMT01214832.1\tLN:7643\n@SQ\tSN:APMT01214839.1\tLN:7639\n@SQ\tSN:KB709999.1\tLN:7632\n@SQ\tSN:APMT01214849.1\tLN:7631\n@SQ\tSN:APMT01214822.1\tLN:7630\n@SQ\tSN:APMT01214850.1\tLN:7630\n@SQ\tSN:KB710049.1\tLN:7628\n@SQ\tSN:APMT01214856.1\tLN:7627\n@SQ\tSN:APMT01214857.1\tLN:7627\n@SQ\tSN:KB710108.1\tLN:7626\n@SQ\tSN:KB710153.1\tLN:7625\n@SQ\tSN:KB710017.1\tLN:7624\n@SQ\tSN:APMT01214858.1\tLN:7623\n@SQ\tSN:APMT01214859.1\tLN:7623\n@SQ\tSN:APMT01214807.1\tLN:7622\n@SQ\tSN:APMT01214860.1\tLN:7622\n@SQ\tSN:APMT01214861.1\tLN:7621\n@SQ\tSN:APMT01214862.1\tLN:7621\n@SQ\tSN:APMT01214762.1\tLN:7620\n@SQ\tSN:APMT01214815.1\tLN:7618\n@SQ\tSN:APMT01214867.1\tLN:7618\n@SQ\tSN:APMT01214781.1\tLN:7617\n@SQ\tSN:KB710077.1\tLN:7616\n@SQ\tSN:APMT01214799.1\tLN:7616\n@SQ\tSN:APMT01214851.1\tLN:7614\n@SQ\tSN:APMT01214874.1\tLN:7613\n@SQ\tSN:APMT01214875.1\tLN:7612\n@SQ\tSN:APMT01214800.1\tLN:7611\n@SQ\tSN:APMT01214876.1\tLN:7611\n@SQ\tSN:APMT01214877.1\tLN:7611\n@SQ\tSN:APMT01214878.1\tLN:7610\n@SQ\tSN:APMT01214879.1\tLN:7610\n@SQ\tSN:APMT01214873.1\tLN:7609\n@SQ\tSN:APMT01214880.1\tLN:7607\n@SQ\tSN:APMT01214882.1\tLN:7605\n@SQ\tSN:APMT01214881.1\tLN:7604\n@SQ\tSN:APMT01214883.1\tLN:7603\n@SQ\tSN:KB710082.1\tLN:7602\n@SQ\tSN:APMT01214863.1\tLN:7602\n@SQ\tSN:APMT01214797.1\tLN:7600\n@SQ\tSN:KB710127.1\tLN:7600\n@SQ\tSN:APMT01214899.1\tLN:7597\n@SQ\tSN:APMT01214812.1\tLN:7596\n@SQ\tSN:APMT01214893.1\tLN:7594\n@SQ\tSN:APMT01214900.1\tLN:7594\n@SQ\tSN:APMT01214910.1\tLN:7593\n@SQ\tSN:APMT01214917.1\tLN:7587\n@SQ\tSN:APMT01214868.1\tLN:7585\n@SQ\tSN:KB710101.1\tLN:7584\n@SQ\tSN:APMT01214909.1\tLN:7583\n@SQ\tSN:APMT01214923.1\tLN:7583\n@SQ\tSN:APMT01214932.1\tLN:7583\n@SQ\tSN:KB710098.1\tLN:7581\n@SQ\tSN:APMT01214844.1\tLN:7578\n@SQ\tSN:APMT01214935.1\tLN:7578\n@SQ\tSN:APMT01214936.1\tLN:7574\n@SQ\tSN:APMT01214937.1\tLN:7572\n@SQ\tSN:APMT01214993.1\tLN:7571\n@SQ\tSN:KB710036.1\tLN:7569\n@SQ\tSN:APMT01214958.1\tLN:7564\n@SQ\tSN:KB710137.1\tLN:7561\n@SQ\tSN:APMT01214884.1\tLN:7559\n@SQ\tSN:APMT01214957.1\tLN:7559\n@SQ\tSN:APMT01214968.1\tLN:7559\n@SQ\tSN:APMT01214969.1\tLN:7558\n@SQ\tSN:APMT01214848.1\tLN:7555\n@SQ\tSN:APMT01214975.1\tLN:7552\n@SQ\tSN:APMT01214976.1\tLN:7552\n@SQ\tSN:KB710147.1\tLN:7551\n@SQ\tSN:APMT01214990.1\tLN:7545\n@SQ\tSN:KB710128.1\tLN:7544\n@SQ\tSN:APMT01214894.1\tLN:7541\n@SQ\tSN:APMT01214992.1\tLN:7541\n@SQ\tSN:KB710160.1\tLN:7541\n@SQ\tSN:KB710047.1\tLN:7540\n@SQ\tSN:APMT01214994.1\tLN:7535\n@SQ\tSN:APMT01214970.1\tLN:7532\n@SQ\tSN:APMT01214996.1\tLN:7531\n@SQ\tSN:KB710409.1\tLN:7531\n@SQ\tSN:APMT01215002.1\tLN:7529\n@SQ\tSN:APMT01215001.1\tLN:7528\n@SQ\tSN:KB710445.1\tLN:7528\n@SQ\tSN:APMT01214956.1\tLN:7525\n@SQ\tSN:APMT01214991.1\tLN:7525\n@SQ\tSN:APMT01215006.1\tLN:7524\n@SQ\tSN:APMT01214931.1\tLN:7523\n@SQ\tSN:APMT01215010.1\tLN:7523\n@SQ\tSN:KB710556.1\tLN:7523\n@SQ\tSN:APMT01215014.1\tLN:7520\n@SQ\tSN:APMT01215016.1\tLN:7517\n@SQ\tSN:KB710081.1\tLN:7515\n@SQ\tSN:KB710113.1\tLN:7514\n@SQ\tSN:KB710099.1\tLN:7512\n@SQ\tSN:APMT01215025.1\tLN:7512\n@SQ\tSN:APMT01215034.1\tLN:7507\n@SQ\tSN:APMT01214950.1\tLN:7506\n@SQ\tSN:KB710291.1\tLN:7506\n@SQ\tSN:KB709800.1\tLN:7502\n@SQ\tSN:APMT01215035.1\tLN:7502\n@SQ\tSN:KB710205.1\tLN:7501\n@SQ\tSN:KB710121.1\tLN:7500\n@SQ\tSN:APMT01214971.1\tLN:7499\n@SQ\tSN:KB710034.1\tLN:7497\n@SQ\tSN:APMT01215039.1\tLN:7497\n@SQ\tSN:KB710117.1\tLN:7496\n@SQ\tSN:APMT01215015.1\tLN:7495\n@SQ\tSN:APMT01215042.1\tLN:7493\n@SQ\tSN:KB710283.1\tLN:7492\n@SQ\tSN:KB710129.1\tLN:7490\n@SQ\tSN:KB709978.1\tLN:7487\n@SQ\tSN:KB710336.1\tLN:7487\n@SQ\tSN:APMT01215049.1\tLN:7486\n@SQ\tSN:KB710136.1\tLN:7485\n@SQ\tSN:APMT01214995.1\tLN:7479\n@SQ\tSN:APMT01215057.1\tLN:7479\n@SQ\tSN:APMT01215058.1\tLN:7479\n@SQ\tSN:APMT01215020.1\tLN:7475\n@SQ\tSN:APMT01215059.1\tLN:7475\n@SQ\tSN:APMT01215254.1\tLN:7473\n@SQ\tSN:APMT01215061.1\tLN:7471\n@SQ\tSN:KB709699.1\tLN:7470\n@SQ\tSN:KB711039.1\tLN:7470\n@SQ\tSN:APMT01215066.1\tLN:7467\n@SQ\tSN:APMT01215067.1\tLN:7467\n@SQ\tSN:APMT01215069.1\tLN:7466\n@SQ\tSN:APMT01215070.1\tLN:7465\n@SQ\tSN:APMT01215071.1\tLN:7463\n@SQ\tSN:APMT01215072.1\tLN:7463\n@SQ\tSN:APMT01215060.1\tLN:7461\n@SQ\tSN:KB710074.1\tLN:7459\n@SQ\tSN:APMT01215073.1\tLN:7458\n@SQ\tSN:APMT01215074.1\tLN:7458\n@SQ\tSN:KB710239.1\tLN:7456\n@SQ\tSN:KB710111.1\tLN:7455\n@SQ\tSN:APMT01215075.1\tLN:7454\n@SQ\tSN:APMT01215076.1\tLN:7452\n@SQ\tSN:APMT01215077.1\tLN:7451\n@SQ\tSN:KB710095.1\tLN:7448\n@SQ\tSN:KB709484.1\tLN:7446\n@SQ\tSN:KB710107.1\tLN:7443\n@SQ\tSN:APMT01215036.1\tLN:7441\n@SQ\tSN:APMT01215088.1\tLN:7441\n@SQ\tSN:APMT01215043.1\tLN:7434\n@SQ\tSN:APMT01215092.1\tLN:7434\n@SQ\tSN:APMT01215100.1\tLN:7433\n@SQ\tSN:KB710083.1\tLN:7431\n@SQ\tSN:KB710460.1\tLN:7431\n@SQ\tSN:KB709994.1\tLN:7430\n@SQ\tSN:APMT01215101.1\tLN:7428\n@SQ\tSN:KB711362.1\tLN:7426\n@SQ\tSN:APMT01215112.1\tLN:7422\n@SQ\tSN:APMT01215117.1\tLN:7418\n@SQ\tSN:APMT01215118.1\tLN:7418\n@SQ\tSN:KB710110.1\tLN:7416\n@SQ\tSN:KB710698.1\tLN:7412\n@SQ\tSN:APMT01215127.1\tLN:7411\n@SQ\tSN:APMT01215062.1\tLN:7409\n@SQ\tSN:KB710304.1\tLN:7409\n@SQ\tSN:KB710248.1\tLN:7407\n@SQ\tSN:KB710159.1\tLN:7403\n@SQ\tSN:APMT01215080.1\tLN:7402\n@SQ\tSN:APMT01215136.1\tLN:7401\n@SQ\tSN:APMT01215139.1\tLN:7399\n@SQ\tSN:APMT01215135.1\tLN:7397\n@SQ\tSN:APMT01215140.1\tLN:7391\n@SQ\tSN:APMT01215142.1\tLN:7390\n@SQ\tSN:APMT01215143.1\tLN:7390\n@SQ\tSN:KB710662.1\tLN:7390\n@SQ\tSN:APMT01215081.1\tLN:7389\n@SQ\tSN:APMT01215087.1\tLN:7389\n@SQ\tSN:KB710327.1\tLN:7386\n@SQ\tSN:KB710486.1\tLN:7386\n@SQ\tSN:APMT01215151.1\tLN:7383\n@SQ\tSN:APMT01215155.1\tLN:7380\n@SQ\tSN:APMT01215102.1\tLN:7379\n@SQ\tSN:KB710340.1\tLN:7379\n@SQ\tSN:APMT01215138.1\tLN:7377\n@SQ\tSN:APMT01215144.1\tLN:7372\n@SQ\tSN:APMT01215166.1\tLN:7372\n@SQ\tSN:APMT01215068.1\tLN:7371\n@SQ\tSN:APMT01215169.1\tLN:7371\n@SQ\tSN:APMT01215168.1\tLN:7369\n@SQ\tSN:KB710901.1\tLN:7368\n@SQ\tSN:APMT01215141.1\tLN:7363\n@SQ\tSN:APMT01215171.1\tLN:7363\n@SQ\tSN:APMT01215172.1\tLN:7363\n@SQ\tSN:APMT01215174.1\tLN:7360\n@SQ\tSN:APMT01215173.1\tLN:7358\n@SQ\tSN:APMT01215175.1\tLN:7357\n@SQ\tSN:APMT01215134.1\tLN:7356\n@SQ\tSN:APMT01215180.1\tLN:7356\n@SQ\tSN:APMT01215185.1\tLN:7356\n@SQ\tSN:KB710145.1\tLN:7355\n@SQ\tSN:APMT01215186.1\tLN:7355\n@SQ\tSN:APMT01215167.1\tLN:7354\n@SQ\tSN:KB710167.1\tLN:7353\n@SQ\tSN:APMT01215109.1\tLN:7352\n@SQ\tSN:APMT01215187.1\tLN:7352\n@SQ\tSN:APMT01215188.1\tLN:7351\n@SQ\tSN:KB710201.1\tLN:7351\n@SQ\tSN:APMT01215133.1\tLN:7349\n@SQ\tSN:APMT01215194.1\tLN:7349\n@SQ\tSN:APMT01215195.1\tLN:7348\n@SQ\tSN:APMT01215198.1\tLN:7346\n@SQ\tSN:KB710122.1\tLN:7343\n@SQ\tSN:KB710406.1\tLN:7343\n@SQ\tSN:KB709995.1\tLN:7337\n@SQ\tSN:APMT01215207.1\tLN:7336\n@SQ\tSN:APMT01215208.1\tLN:7336\n@SQ\tSN:APMT01215209.1\tLN:7334\n@SQ\tSN:APMT01215137.1\tLN:7333\n@SQ\tSN:APMT01215210.1\tLN:7331\n@SQ\tSN:KB710247.1\tLN:7330\n@SQ\tSN:KB710176.1\tLN:7329\n@SQ\tSN:KB710259.1\tLN:7329\n@SQ\tSN:KB710164.1\tLN:7327\n@SQ\tSN:APMT01215212.1\tLN:7327\n@SQ\tSN:KB710513.1\tLN:7327\n@SQ\tSN:APMT01215108.1\tLN:7326\n@SQ\tSN:KB710624.1\tLN:7326\n@SQ\tSN:KB710135.1\tLN:7325\n@SQ\tSN:KB709743.1\tLN:7321\n@SQ\tSN:APMT01215228.1\tLN:7319\n@SQ\tSN:APMT01215222.1\tLN:7318\n@SQ\tSN:KB710539.1\tLN:7318\n@SQ\tSN:APMT01215170.1\tLN:7317\n@SQ\tSN:KB709944.1\tLN:7316\n@SQ\tSN:KB710651.1\tLN:7316\n@SQ\tSN:APMT01215227.1\tLN:7310\n@SQ\tSN:APMT01215229.1\tLN:7310\n@SQ\tSN:APMT01215230.1\tLN:7309\n@SQ\tSN:APMT01215231.1\tLN:7309\n@SQ\tSN:APMT01215232.1\tLN:7309\n@SQ\tSN:KB710042.1\tLN:7304\n@SQ\tSN:KB710570.1\tLN:7303\n@SQ\tSN:APMT01215238.1\tLN:7301\n@SQ\tSN:APMT01215255.1\tLN:7300\n@SQ\tSN:APMT01215256.1\tLN:7300\n@SQ\tSN:APMT01215179.1\tLN:7298\n@SQ\tSN:APMT01215211.1\tLN:7297\n@SQ\tSN:APMT01215259.1\tLN:7297\n@SQ\tSN:KB710173.1\tLN:7294\n@SQ\tSN:KB710216.1\tLN:7294\n@SQ\tSN:KB710226.1\tLN:7293\n@SQ\tSN:APMT01215237.1\tLN:7290\n@SQ\tSN:APMT01215362.1\tLN:7289\n@SQ\tSN:APMT01215268.1\tLN:7286\n@SQ\tSN:KB710421.1\tLN:7285\n@SQ\tSN:KB710096.1\tLN:7283\n@SQ\tSN:APMT01215272.1\tLN:7282\n@SQ\tSN:APMT01215273.1\tLN:7282\n@SQ\tSN:APMT01215274.1\tLN:7282\n@SQ\tSN:APMT01215283.1\tLN:7280\n@SQ\tSN:KB710219.1\tLN:7280\n@SQ\tSN:APMT01215286.1\tLN:7276\n@SQ\tSN:APMT01215287.1\tLN:7276\n@SQ\tSN:KB710179.1\tLN:7269\n@SQ\tSN:APMT01215294.1\tLN:7266\n@SQ\tSN:KB710198.1\tLN:7265\n@SQ\tSN:APMT01215292.1\tLN:7264\n@SQ\tSN:APMT01215299.1\tLN:7264\n@SQ\tSN:KB710168.1\tLN:7262\n@SQ\tSN:KB710093.1\tLN:7257\n@SQ\tSN:APMT01215291.1\tLN:7257\n@SQ\tSN:APMT01215223.1\tLN:7256\n@SQ\tSN:APMT01215315.1\tLN:7253\n@SQ\tSN:APMT01215266.1\tLN:7252\n@SQ\tSN:APMT01215236.1\tLN:7251\n@SQ\tSN:APMT01215316.1\tLN:7250\n@SQ\tSN:APMT01215318.1\tLN:7248\n@SQ\tSN:KB710403.1\tLN:7247\n@SQ\tSN:APMT01215319.1\tLN:7246\n@SQ\tSN:APMT01215284.1\tLN:7245\n@SQ\tSN:KB710873.1\tLN:7242\n@SQ\tSN:KB710031.1\tLN:7237\n@SQ\tSN:APMT01215317.1\tLN:7237\n@SQ\tSN:KB710203.1\tLN:7236\n@SQ\tSN:KB710273.1\tLN:7236\n@SQ\tSN:KB710286.1\tLN:7234\n@SQ\tSN:APMT01215333.1\tLN:7233\n@SQ\tSN:APMT01215334.1\tLN:7233\n@SQ\tSN:APMT01215267.1\tLN:7231\n@SQ\tSN:KB710253.1\tLN:7231\n@SQ\tSN:KB710196.1\tLN:7230\n@SQ\tSN:KB710068.1\tLN:7226\n@SQ\tSN:APMT01215340.1\tLN:7225\n@SQ\tSN:APMT01215306.1\tLN:7224\n@SQ\tSN:APMT01215203.1\tLN:7223\n@SQ\tSN:KB710177.1\tLN:7223\n@SQ\tSN:KB710206.1\tLN:7223\n@SQ\tSN:APMT01215301.1\tLN:7221\n@SQ\tSN:APMT01215285.1\tLN:7220\n@SQ\tSN:KB710220.1\tLN:7219\n@SQ\tSN:APMT01215293.1\tLN:7217\n@SQ\tSN:APMT01215343.1\tLN:7216\n@SQ\tSN:APMT01215345.1\tLN:7215\n@SQ\tSN:APMT01215346.1\tLN:7214\n@SQ\tSN:APMT01215314.1\tLN:7213\n@SQ\tSN:KB710849.1\tLN:7213\n@SQ\tSN:KB710043.1\tLN:7210\n@SQ\tSN:APMT01215300.1\tLN:7210\n@SQ\tSN:APMT01215290.1\tLN:7209\n@SQ\tSN:APMT01215349.1\tLN:7209\n@SQ\tSN:APMT01215351.1\tLN:7209\n@SQ\tSN:KB710780.1\tLN:7206\n@SQ\tSN:APMT01215250.1\tLN:7205\n@SQ\tSN:KB709991.1\tLN:7204\n@SQ\tSN:KB711007.1\tLN:7204\n@SQ\tSN:KB710070.1\tLN:7202\n@SQ\tSN:APMT01215356.1\tLN:7201\n@SQ\tSN:KB711081.1\tLN:7201\n@SQ\tSN:APMT01215389.1\tLN:7200\n@SQ\tSN:KB710453.1\tLN:7199\n@SQ\tSN:KB710635.1\tLN:7199\n@SQ\tSN:APMT01215360.1\tLN:7197\n@SQ\tSN:KB710063.1\tLN:7195\n@SQ\tSN:APMT01215361.1\tLN:7195\n@SQ\tSN:APMT01215369.1\tLN:7193\n@SQ\tSN:KB710521.1\tLN:7193\n@SQ\tSN:KB710143.1\tLN:7192\n@SQ\tSN:KB710215.1\tLN:7192\n@SQ\tSN:APMT01215382.1\tLN:7188\n@SQ\tSN:APMT01215380.1\tLN:7187\n@SQ\tSN:APMT01215385.1\tLN:7187\n@SQ\tSN:APMT01215386.1\tLN:7187\n@SQ\tSN:APMT01215388.1\tLN:7184\n@SQ\tSN:KB710180.1\tLN:7183\n@SQ\tSN:APMT01215391.1\tLN:7182\n@SQ\tSN:APMT01215325.1\tLN:7181\n@SQ\tSN:APMT01215390.1\tLN:7180\n@SQ\tSN:APMT01215392.1\tLN:7180\n@SQ\tSN:APMT01215394.1\tLN:7179\n@SQ\tSN:KB712675.1\tLN:7179\n@SQ\tSN:APMT01215398.1\tLN:7177\n@SQ\tSN:APMT01215399.1\tLN:7177\n@SQ\tSN:APMT01215412.1\tLN:7176\n@SQ\tSN:KB710306.1\tLN:7173\n@SQ\tSN:KB710194.1\tLN:7172\n@SQ\tSN:APMT01215413.1\tLN:7172\n@SQ\tSN:APMT01215414.1\tLN:7169\n@SQ\tSN:KB710250.1\tLN:7169\n@SQ\tSN:APMT01215417.1\tLN:7168\n@SQ\tSN:APMT01215418.1\tLN:7167\n@SQ\tSN:APMT01215419.1\tLN:7165\n@SQ\tSN:KB710207.1\tLN:7159\n@SQ\tSN:APMT01215400.1\tLN:7159\n@SQ\tSN:KB709886.1\tLN:7158\n@SQ\tSN:APMT01215387.1\tLN:7158\n@SQ\tSN:APMT01215448.1\tLN:7156\n@SQ\tSN:KB710295.1\tLN:7156\n@SQ\tSN:APMT01215454.1\tLN:7149\n@SQ\tSN:APMT01215455.1\tLN:7149\n@SQ\tSN:KB710582.1\tLN:7149\n@SQ\tSN:APMT01215350.1\tLN:7148\n@SQ\tSN:KB710272.1\tLN:7148\n@SQ\tSN:APMT01215456.1\tLN:7147\n@SQ\tSN:KB710184.1\tLN:7146\n@SQ\tSN:APMT01215457.1\tLN:7145\n@SQ\tSN:APMT01215461.1\tLN:7141\n@SQ\tSN:APMT01215462.1\tLN:7140\n@SQ\tSN:APMT01215463.1\tLN:7140\n@SQ\tSN:KB710123.1\tLN:7138\n@SQ\tSN:APMT01215352.1\tLN:7137\n@SQ\tSN:APMT01215471.1\tLN:7137\n@SQ\tSN:KB710262.1\tLN:7133\n@SQ\tSN:APMT01215473.1\tLN:7132\n@SQ\tSN:APMT01215474.1\tLN:7132\n@SQ\tSN:KB710076.1\tLN:7131\n@SQ\tSN:APMT01215393.1\tLN:7131\n@SQ\tSN:APMT01215381.1\tLN:7129\n@SQ\tSN:KB710200.1\tLN:7128\n@SQ\tSN:APMT01215432.1\tLN:7128\n@SQ\tSN:APMT01215478.1\tLN:7128\n@SQ\tSN:KB710014.1\tLN:7125\n@SQ\tSN:APMT01215445.1\tLN:7124\n@SQ\tSN:KB710169.1\tLN:7123\n@SQ\tSN:APMT01215420.1\tLN:7122\n@SQ\tSN:APMT01215570.1\tLN:7121\n@SQ\tSN:KB710702.1\tLN:7118\n@SQ\tSN:APMT01215497.1\tLN:7116\n@SQ\tSN:APMT01215498.1\tLN:7113\n@SQ\tSN:APMT01215501.1\tLN:7112\n@SQ\tSN:APMT01215482.1\tLN:7110\n@SQ\tSN:KB710217.1\tLN:7109\n@SQ\tSN:APMT01215499.1\tLN:7109\n@SQ\tSN:APMT01215508.1\tLN:7109\n@SQ\tSN:APMT01215509.1\tLN:7108\n@SQ\tSN:KB710223.1\tLN:7107\n@SQ\tSN:KB710256.1\tLN:7107\n@SQ\tSN:APMT01215437.1\tLN:7106\n@SQ\tSN:KB710266.1\tLN:7106\n@SQ\tSN:APMT01215563.1\tLN:7104\n@SQ\tSN:APMT01215527.1\tLN:7102\n@SQ\tSN:APMT01215532.1\tLN:7101\n@SQ\tSN:KB709355.1\tLN:7100\n@SQ\tSN:APMT01215533.1\tLN:7100\n@SQ\tSN:KB710151.1\tLN:7099\n@SQ\tSN:KB710293.1\tLN:7099\n@SQ\tSN:APMT01215534.1\tLN:7098\n@SQ\tSN:APMT01215344.1\tLN:7097\n@SQ\tSN:APMT01215538.1\tLN:7097\n@SQ\tSN:APMT01215539.1\tLN:7097\n@SQ\tSN:APMT01215543.1\tLN:7096\n@SQ\tSN:APMT01215544.1\tLN:7095\n@SQ\tSN:APMT01215545.1\tLN:7094\n@SQ\tSN:APMT01215549.1\tLN:7093\n@SQ\tSN:KB710210.1\tLN:7091\n@SQ\tSN:KB710241.1\tLN:7089\n@SQ\tSN:APMT01215559.1\tLN:7089\n@SQ\tSN:KB710546.1\tLN:7089\n@SQ\tSN:APMT01215564.1\tLN:7088\n@SQ\tSN:APMT01215472.1\tLN:7087\n@SQ\tSN:APMT01215565.1\tLN:7087\n@SQ\tSN:KB712743.1\tLN:7087\n@SQ\tSN:APMT01215481.1\tLN:7086\n@SQ\tSN:KB710670.1\tLN:7086\n@SQ\tSN:APMT01215460.1\tLN:7085\n@SQ\tSN:APMT01215566.1\tLN:7083\n@SQ\tSN:APMT01215576.1\tLN:7082\n@SQ\tSN:APMT01215578.1\tLN:7082\n@SQ\tSN:APMT01215582.1\tLN:7082\n@SQ\tSN:KB710195.1\tLN:7077\n@SQ\tSN:KB710332.1\tLN:7077\n@SQ\tSN:APMT01215591.1\tLN:7076\n@SQ\tSN:APMT01215592.1\tLN:7075\n@SQ\tSN:KB710540.1\tLN:7074\n@SQ\tSN:APMT01215496.1\tLN:7073\n@SQ\tSN:APMT01215593.1\tLN:7073\n@SQ\tSN:APMT01215596.1\tLN:7071\n@SQ\tSN:APMT01215605.1\tLN:7070\n@SQ\tSN:APMT01215608.1\tLN:7070\n@SQ\tSN:APMT01215577.1\tLN:7069\n@SQ\tSN:KB711131.1\tLN:7069\n@SQ\tSN:KB710229.1\tLN:7063\n@SQ\tSN:KB710231.1\tLN:7063\n@SQ\tSN:APMT01215610.1\tLN:7062\n@SQ\tSN:APMT01215614.1\tLN:7059\n@SQ\tSN:APMT01215615.1\tLN:7059\n@SQ\tSN:APMT01215611.1\tLN:7057\n@SQ\tSN:APMT01215609.1\tLN:7056\n@SQ\tSN:APMT01215625.1\tLN:7054\n@SQ\tSN:KB709513.1\tLN:7053\n@SQ\tSN:APMT01215500.1\tLN:7053\n@SQ\tSN:KB709887.1\tLN:7048\n@SQ\tSN:APMT01215571.1\tLN:7047\n@SQ\tSN:APMT01215641.1\tLN:7043\n@SQ\tSN:APMT01215643.1\tLN:7042\n@SQ\tSN:APMT01215644.1\tLN:7041\n@SQ\tSN:APMT01215645.1\tLN:7041\n@SQ\tSN:APMT01215642.1\tLN:7040\n@SQ\tSN:KB710318.1\tLN:7040\n@SQ\tSN:APMT01215647.1\tLN:7038\n@SQ\tSN:KB710132.1\tLN:7034\n@SQ\tSN:APMT01215651.1\tLN:7031\n@SQ\tSN:APMT01215652.1\tLN:7030\n@SQ\tSN:APMT01215664.1\tLN:7026\n@SQ\tSN:APMT01215668.1\tLN:7026\n@SQ\tSN:KB710208.1\tLN:7025\n@SQ\tSN:APMT01215675.1\tLN:7023\n@SQ\tSN:KB710317.1\tLN:7021\n@SQ\tSN:KB710292.1\tLN:7020\n@SQ\tSN:KB709900.1\tLN:7019\n@SQ\tSN:APMT01215680.1\tLN:7018\n@SQ\tSN:KB710230.1\tLN:7017\n@SQ\tSN:APMT01215717.1\tLN:7016\n@SQ\tSN:APMT01215694.1\tLN:7015\n@SQ\tSN:KB710251.1\tLN:7014\n@SQ\tSN:KB710257.1\tLN:7013\n@SQ\tSN:APMT01215698.1\tLN:7013\n@SQ\tSN:APMT01215604.1\tLN:7011\n@SQ\tSN:APMT01215703.1\tLN:7011\n@SQ\tSN:KB709909.1\tLN:7010\n@SQ\tSN:KB710188.1\tLN:7009\n@SQ\tSN:APMT01215626.1\tLN:7009\n@SQ\tSN:APMT01215709.1\tLN:7009\n@SQ\tSN:KB709773.1\tLN:7005\n@SQ\tSN:APMT01215712.1\tLN:7005\n@SQ\tSN:APMT01215715.1\tLN:7000\n@SQ\tSN:KB710519.1\tLN:7000\n@SQ\tSN:KB710371.1\tLN:6998\n@SQ\tSN:APMT01215721.1\tLN:6997\n@SQ\tSN:APMT01215725.1\tLN:6996\n@SQ\tSN:APMT01215730.1\tLN:6995\n@SQ\tSN:APMT01215731.1\tLN:6994\n@SQ\tSN:KB710213.1\tLN:6992\n@SQ\tSN:APMT01215831.1\tLN:6992\n@SQ\tSN:APMT01215646.1\tLN:6991\n@SQ\tSN:KB710335.1\tLN:6991\n@SQ\tSN:KB710270.1\tLN:6990\n@SQ\tSN:APMT01215735.1\tLN:6990\n@SQ\tSN:KB710609.1\tLN:6989\n@SQ\tSN:APMT01215740.1\tLN:6988\n@SQ\tSN:KB710341.1\tLN:6988\n@SQ\tSN:KB710192.1\tLN:6985\n@SQ\tSN:KB710171.1\tLN:6984\n@SQ\tSN:APMT01215716.1\tLN:6984\n@SQ\tSN:APMT01215750.1\tLN:6984\n@SQ\tSN:KB710254.1\tLN:6981\n@SQ\tSN:APMT01215758.1\tLN:6980\n@SQ\tSN:APMT01215761.1\tLN:6979\n@SQ\tSN:APMT01215765.1\tLN:6977\n@SQ\tSN:KB710320.1\tLN:6977\n@SQ\tSN:KB710274.1\tLN:6973\n@SQ\tSN:APMT01215679.1\tLN:6972\n@SQ\tSN:KB710899.1\tLN:6972\n@SQ\tSN:APMT01215769.1\tLN:6970\n@SQ\tSN:KB710305.1\tLN:6969\n@SQ\tSN:APMT01215770.1\tLN:6968\n@SQ\tSN:APMT01215771.1\tLN:6968\n@SQ\tSN:KB710085.1\tLN:6964\n@SQ\tSN:APMT01215781.1\tLN:6964\n@SQ\tSN:KB710264.1\tLN:6962\n@SQ\tSN:APMT01215789.1\tLN:6960\n@SQ\tSN:APMT01215766.1\tLN:6956\n@SQ\tSN:APMT01215790.1\tLN:6956\n@SQ\tSN:APMT01215791.1\tLN:6956\n@SQ\tSN:APMT01215792.1\tLN:6956\n@SQ\tSN:KB709576.1\tLN:6955\n@SQ\tSN:APMT01215697.1\tLN:6955\n@SQ\tSN:APMT01215793.1\tLN:6955\n@SQ\tSN:APMT01215794.1\tLN:6955\n@SQ\tSN:KB710240.1\tLN:6953\n@SQ\tSN:APMT01215711.1\tLN:6953\n@SQ\tSN:APMT01215718.1\tLN:6952\n@SQ\tSN:KB710622.1\tLN:6952\n@SQ\tSN:KB710531.1\tLN:6951\n@SQ\tSN:APMT01215710.1\tLN:6949\n@SQ\tSN:APMT01215812.1\tLN:6949\n@SQ\tSN:APMT01215813.1\tLN:6948\n@SQ\tSN:APMT01215814.1\tLN:6948\n@SQ\tSN:APMT01215815.1\tLN:6948\n@SQ\tSN:KB709864.1\tLN:6946\n@SQ\tSN:KB710301.1\tLN:6945\n@SQ\tSN:KB710263.1\tLN:6942\n@SQ\tSN:KB710288.1\tLN:6942\n@SQ\tSN:APMT01215736.1\tLN:6941\n@SQ\tSN:APMT01215627.1\tLN:6938\n@SQ\tSN:KB710845.1\tLN:6934\n@SQ\tSN:KB710524.1\tLN:6933\n@SQ\tSN:APMT01215834.1\tLN:6931\n@SQ\tSN:KB710333.1\tLN:6931\n@SQ\tSN:KB710369.1\tLN:6931\n@SQ\tSN:KB710237.1\tLN:6930\n@SQ\tSN:APMT01215764.1\tLN:6930\n@SQ\tSN:APMT01215835.1\tLN:6930\n@SQ\tSN:KB710307.1\tLN:6928\n@SQ\tSN:KB710285.1\tLN:6926\n@SQ\tSN:APMT01215836.1\tLN:6925\n@SQ\tSN:APMT01215837.1\tLN:6925\n@SQ\tSN:APMT01215838.1\tLN:6925\n@SQ\tSN:KB710361.1\tLN:6924\n@SQ\tSN:APMT01215843.1\tLN:6921\n@SQ\tSN:KB710222.1\tLN:6920\n@SQ\tSN:APMT01215847.1\tLN:6920\n@SQ\tSN:APMT01215848.1\tLN:6920\n@SQ\tSN:APMT01215842.1\tLN:6919\n@SQ\tSN:APMT01215852.1\tLN:6918\n@SQ\tSN:APMT01215820.1\tLN:6917\n@SQ\tSN:APMT01215856.1\tLN:6917\n@SQ\tSN:KB710331.1\tLN:6917\n@SQ\tSN:KB709602.1\tLN:6916\n@SQ\tSN:KB710225.1\tLN:6916\n@SQ\tSN:KB710268.1\tLN:6913\n@SQ\tSN:KB710296.1\tLN:6913\n@SQ\tSN:KB709881.1\tLN:6911\n@SQ\tSN:APMT01215702.1\tLN:6909\n@SQ\tSN:APMT01215864.1\tLN:6909\n@SQ\tSN:KB710373.1\tLN:6907\n@SQ\tSN:APMT01215872.1\tLN:6906\n@SQ\tSN:KB710172.1\tLN:6904\n@SQ\tSN:KB709946.1\tLN:6902\n@SQ\tSN:APMT01215785.1\tLN:6902\n@SQ\tSN:APMT01215863.1\tLN:6900\n@SQ\tSN:APMT01215878.1\tLN:6900\n@SQ\tSN:APMT01215879.1\tLN:6899\n@SQ\tSN:KB710265.1\tLN:6897\n@SQ\tSN:APMT01215798.1\tLN:6897\n@SQ\tSN:APMT01215819.1\tLN:6896\n@SQ\tSN:KB710249.1\tLN:6895\n@SQ\tSN:APMT01215887.1\tLN:6895\n@SQ\tSN:KB710290.1\tLN:6893\n@SQ\tSN:APMT01215890.1\tLN:6893\n@SQ\tSN:APMT01215888.1\tLN:6892\n@SQ\tSN:APMT01215896.1\tLN:6892\n@SQ\tSN:APMT01215897.1\tLN:6891\n@SQ\tSN:APMT01215861.1\tLN:6889\n@SQ\tSN:KB710988.1\tLN:6889\n@SQ\tSN:APMT01215901.1\tLN:6888\n@SQ\tSN:APMT01215902.1\tLN:6888\n@SQ\tSN:APMT01215903.1\tLN:6888\n@SQ\tSN:APMT01215904.1\tLN:6887\n@SQ\tSN:KB710294.1\tLN:6884\n@SQ\tSN:APMT01215908.1\tLN:6884\n@SQ\tSN:APMT01215909.1\tLN:6883\n@SQ\tSN:KB710408.1\tLN:6883\n@SQ\tSN:APMT01215917.1\tLN:6881\n@SQ\tSN:APMT01215921.1\tLN:6880\n@SQ\tSN:APMT01215922.1\tLN:6879\n@SQ\tSN:APMT01215923.1\tLN:6879\n@SQ\tSN:APMT01215889.1\tLN:6878\n@SQ\tSN:APMT01215924.1\tLN:6878\n@SQ\tSN:KB710267.1\tLN:6877\n@SQ\tSN:KB710319.1\tLN:6877\n@SQ\tSN:KB711959.1\tLN:6877\n@SQ\tSN:KB709872.1\tLN:6873\n@SQ\tSN:APMT01215949.1\tLN:6870\n@SQ\tSN:APMT01215950.1\tLN:6870\n@SQ\tSN:KB710321.1\tLN:6868\n@SQ\tSN:APMT01215948.1\tLN:6868\n@SQ\tSN:KB710339.1\tLN:6868\n@SQ\tSN:APMT01215957.1\tLN:6867\n@SQ\tSN:APMT01215862.1\tLN:6866\n@SQ\tSN:KB710579.1\tLN:6866\n@SQ\tSN:APMT01215860.1\tLN:6864\n@SQ\tSN:KB710418.1\tLN:6864\n@SQ\tSN:KB710092.1\tLN:6863\n@SQ\tSN:APMT01215962.1\tLN:6860\n@SQ\tSN:KB710349.1\tLN:6858\n@SQ\tSN:APMT01215891.1\tLN:6856\n@SQ\tSN:KB711559.1\tLN:6856\n@SQ\tSN:KB710323.1\tLN:6855\n@SQ\tSN:APMT01215964.1\tLN:6853\n@SQ\tSN:KB710823.1\tLN:6852\n@SQ\tSN:APMT01215969.1\tLN:6851\n@SQ\tSN:APMT01215972.1\tLN:6849\n@SQ\tSN:APMT01215973.1\tLN:6849\n@SQ\tSN:KB710665.1\tLN:6849\n@SQ\tSN:APMT01215968.1\tLN:6845\n@SQ\tSN:APMT01215985.1\tLN:6845\n@SQ\tSN:APMT01215987.1\tLN:6845\n@SQ\tSN:APMT01215988.1\tLN:6845\n@SQ\tSN:APMT01215989.1\tLN:6844\n@SQ\tSN:APMT01215990.1\tLN:6844\n@SQ\tSN:APMT01215993.1\tLN:6843\n@SQ\tSN:APMT01215907.1\tLN:6842\n@SQ\tSN:KB710896.1\tLN:6840\n@SQ\tSN:APMT01216006.1\tLN:6838\n@SQ\tSN:APMT01215916.1\tLN:6836\n@SQ\tSN:APMT01216010.1\tLN:6835\n@SQ\tSN:APMT01216011.1\tLN:6835\n@SQ\tSN:APMT01216012.1\tLN:6835\n@SQ\tSN:APMT01216013.1\tLN:6834\n@SQ\tSN:APMT01216014.1\tLN:6833\n@SQ\tSN:KB710316.1\tLN:6832\n@SQ\tSN:KB710326.1\tLN:6832\n@SQ\tSN:APMT01215915.1\tLN:6828\n@SQ\tSN:APMT01215905.1\tLN:6826\n@SQ\tSN:APMT01215977.1\tLN:6824\n@SQ\tSN:APMT01216028.1\tLN:6824\n@SQ\tSN:KB709596.1\tLN:6823\n@SQ\tSN:KB710227.1\tLN:6823\n@SQ\tSN:APMT01215906.1\tLN:6823\n@SQ\tSN:KB710355.1\tLN:6823\n@SQ\tSN:APMT01216032.1\tLN:6818\n@SQ\tSN:APMT01216031.1\tLN:6817\n@SQ\tSN:APMT01216033.1\tLN:6817\n@SQ\tSN:APMT01216034.1\tLN:6817\n@SQ\tSN:APMT01215928.1\tLN:6815\n@SQ\tSN:APMT01216043.1\tLN:6813\n@SQ\tSN:APMT01216047.1\tLN:6812\n@SQ\tSN:APMT01215958.1\tLN:6810\n@SQ\tSN:APMT01216055.1\tLN:6810\n@SQ\tSN:APMT01216056.1\tLN:6809\n@SQ\tSN:APMT01215963.1\tLN:6806\n@SQ\tSN:KB710924.1\tLN:6806\n@SQ\tSN:KB710324.1\tLN:6803\n@SQ\tSN:APMT01216041.1\tLN:6802\n@SQ\tSN:APMT01216063.1\tLN:6799\n@SQ\tSN:APMT01216024.1\tLN:6798\n@SQ\tSN:APMT01216067.1\tLN:6798\n@SQ\tSN:APMT01216068.1\tLN:6797\n@SQ\tSN:APMT01216069.1\tLN:6796\n@SQ\tSN:KB709528.1\tLN:6794\n@SQ\tSN:APMT01216070.1\tLN:6794\n@SQ\tSN:KB710366.1\tLN:6793\n@SQ\tSN:APMT01216071.1\tLN:6793\n@SQ\tSN:APMT01216072.1\tLN:6792\n@SQ\tSN:KB710391.1\tLN:6792\n@SQ\tSN:KB710322.1\tLN:6791\n@SQ\tSN:APMT01215986.1\tLN:6791\n@SQ\tSN:KB710393.1\tLN:6787\n@SQ\tSN:APMT01216074.1\tLN:6785\n@SQ\tSN:APMT01216075.1\tLN:6785\n@SQ\tSN:KB710330.1\tLN:6779\n@SQ\tSN:APMT01216090.1\tLN:6779\n@SQ\tSN:KB710680.1\tLN:6779\n@SQ\tSN:KB710364.1\tLN:6778\n@SQ\tSN:APMT01216091.1\tLN:6778\n@SQ\tSN:KB710308.1\tLN:6777\n@SQ\tSN:APMT01216094.1\tLN:6775\n@SQ\tSN:APMT01216092.1\tLN:6774\n@SQ\tSN:APMT01216082.1\tLN:6773\n@SQ\tSN:APMT01216095.1\tLN:6772\n@SQ\tSN:APMT01216099.1\tLN:6772\n@SQ\tSN:APMT01216103.1\tLN:6770\n@SQ\tSN:APMT01216108.1\tLN:6766\n@SQ\tSN:APMT01216109.1\tLN:6764\n@SQ\tSN:KB710405.1\tLN:6764\n@SQ\tSN:APMT01216117.1\tLN:6763\n@SQ\tSN:APMT01216118.1\tLN:6761\n@SQ\tSN:KB710413.1\tLN:6760\n@SQ\tSN:APMT01216104.1\tLN:6759\n@SQ\tSN:KB710359.1\tLN:6756\n@SQ\tSN:APMT01216131.1\tLN:6756\n@SQ\tSN:KB710334.1\tLN:6755\n@SQ\tSN:KB710458.1\tLN:6755\n@SQ\tSN:KB710392.1\tLN:6754\n@SQ\tSN:APMT01216042.1\tLN:6753\n@SQ\tSN:APMT01216134.1\tLN:6753\n@SQ\tSN:APMT01216135.1\tLN:6752\n@SQ\tSN:APMT01215978.1\tLN:6751\n@SQ\tSN:APMT01216136.1\tLN:6751\n@SQ\tSN:APMT01216140.1\tLN:6748\n@SQ\tSN:APMT01216142.1\tLN:6747\n@SQ\tSN:KB710372.1\tLN:6746\n@SQ\tSN:APMT01216143.1\tLN:6745\n@SQ\tSN:APMT01216144.1\tLN:6745\n@SQ\tSN:KB710358.1\tLN:6743\n@SQ\tSN:APMT01216073.1\tLN:6743\n@SQ\tSN:APMT01216150.1\tLN:6742\n@SQ\tSN:APMT01216151.1\tLN:6742\n@SQ\tSN:APMT01216152.1\tLN:6740\n@SQ\tSN:APMT01216153.1\tLN:6739\n@SQ\tSN:APMT01216145.1\tLN:6738\n@SQ\tSN:KB710374.1\tLN:6736\n@SQ\tSN:KB710387.1\tLN:6735\n@SQ\tSN:KB709919.1\tLN:6732\n@SQ\tSN:KB710487.1\tLN:6731\n@SQ\tSN:APMT01216170.1\tLN:6729\n@SQ\tSN:APMT01216171.1\tLN:6729\n@SQ\tSN:KB710351.1\tLN:6728\n@SQ\tSN:APMT01216184.1\tLN:6726\n@SQ\tSN:APMT01216185.1\tLN:6726\n@SQ\tSN:APMT01216188.1\tLN:6725\n@SQ\tSN:KB710795.1\tLN:6725\n@SQ\tSN:APMT01216187.1\tLN:6724\n@SQ\tSN:APMT01216189.1\tLN:6723\n@SQ\tSN:APMT01216196.1\tLN:6723\n@SQ\tSN:APMT01216197.1\tLN:6722\n@SQ\tSN:APMT01216198.1\tLN:6721\n@SQ\tSN:APMT01216199.1\tLN:6721\n@SQ\tSN:APMT01216200.1\tLN:6720\n@SQ\tSN:KB710586.1\tLN:6720\n@SQ\tSN:KB710657.1\tLN:6720\n@SQ\tSN:APMT01216204.1\tLN:6718\n@SQ\tSN:APMT01216205.1\tLN:6718\n@SQ\tSN:APMT01216093.1\tLN:6717\n@SQ\tSN:APMT01216207.1\tLN:6715\n@SQ\tSN:KB710718.1\tLN:6715\n@SQ\tSN:KB710352.1\tLN:6714\n@SQ\tSN:APMT01216186.1\tLN:6712\n@SQ\tSN:KB710660.1\tLN:6712\n@SQ\tSN:APMT01216211.1\tLN:6710\n@SQ\tSN:KB710425.1\tLN:6710\n@SQ\tSN:APMT01216217.1\tLN:6709\n@SQ\tSN:KB712892.1\tLN:6709\n@SQ\tSN:KB709632.1\tLN:6707\n@SQ\tSN:KB710353.1\tLN:6707\n@SQ\tSN:APMT01216219.1\tLN:6707\n@SQ\tSN:APMT01216220.1\tLN:6706\n@SQ\tSN:KB711324.1\tLN:6706\n@SQ\tSN:APMT01216137.1\tLN:6705\n@SQ\tSN:APMT01216218.1\tLN:6704\n@SQ\tSN:KB710663.1\tLN:6704\n@SQ\tSN:KB710189.1\tLN:6703\n@SQ\tSN:KB710958.1\tLN:6703\n@SQ\tSN:APMT01216236.1\tLN:6698\n@SQ\tSN:KB710881.1\tLN:6698\n@SQ\tSN:KB710457.1\tLN:6696\n@SQ\tSN:APMT01216149.1\tLN:6694\n@SQ\tSN:APMT01216244.1\tLN:6692\n@SQ\tSN:APMT01216245.1\tLN:6692\n@SQ\tSN:KB710550.1\tLN:6692\n@SQ\tSN:KB710627.1\tLN:6692\n@SQ\tSN:APMT01216246.1\tLN:6689\n@SQ\tSN:APMT01216237.1\tLN:6687\n@SQ\tSN:APMT01216247.1\tLN:6687\n@SQ\tSN:APMT01216248.1\tLN:6685\n@SQ\tSN:APMT01216249.1\tLN:6684\n@SQ\tSN:APMT01216179.1\tLN:6682\n@SQ\tSN:KB709702.1\tLN:6681\n@SQ\tSN:APMT01216258.1\tLN:6681\n@SQ\tSN:APMT01216260.1\tLN:6680\n@SQ\tSN:APMT01216261.1\tLN:6680\n@SQ\tSN:KB713183.1\tLN:6680\n@SQ\tSN:APMT01216254.1\tLN:6676\n@SQ\tSN:APMT01216266.1\tLN:6676\n@SQ\tSN:APMT01216267.1\tLN:6675\n@SQ\tSN:KB710204.1\tLN:6674\n@SQ\tSN:APMT01216268.1\tLN:6674\n@SQ\tSN:KB710376.1\tLN:6671\n@SQ\tSN:KB710397.1\tLN:6671\n@SQ\tSN:APMT01216273.1\tLN:6671\n@SQ\tSN:KB709637.1\tLN:6670\n@SQ\tSN:APMT01216272.1\tLN:6670\n@SQ\tSN:APMT01216274.1\tLN:6669\n@SQ\tSN:APMT01216275.1\tLN:6669\n@SQ\tSN:KB710747.1\tLN:6669\n@SQ\tSN:KB710309.1\tLN:6668\n@SQ\tSN:KB710448.1\tLN:6665\n@SQ\tSN:KB710280.1\tLN:6664\n@SQ\tSN:APMT01216282.1\tLN:6663\n@SQ\tSN:KB710384.1\tLN:6662\n@SQ\tSN:APMT01216283.1\tLN:6662\n@SQ\tSN:APMT01216284.1\tLN:6661\n@SQ\tSN:KB710360.1\tLN:6659\n@SQ\tSN:KB710396.1\tLN:6659\n@SQ\tSN:APMT01216286.1\tLN:6659\n@SQ\tSN:APMT01216294.1\tLN:6656\n@SQ\tSN:KB710468.1\tLN:6655\n@SQ\tSN:APMT01216295.1\tLN:6654\n@SQ\tSN:APMT01216296.1\tLN:6654\n@SQ\tSN:KB711174.1\tLN:6654\n@SQ\tSN:KB710345.1\tLN:6653\n@SQ\tSN:KB710402.1\tLN:6653\n@SQ\tSN:KB710571.1\tLN:6652\n@SQ\tSN:KB709158.1\tLN:6651\n@SQ\tSN:APMT01216302.1\tLN:6650\n@SQ\tSN:KB710302.1\tLN:6647\n@SQ\tSN:KB709600.1\tLN:6646\n@SQ\tSN:APMT01216312.1\tLN:6646\n@SQ\tSN:APMT01216314.1\tLN:6644\n@SQ\tSN:APMT01216315.1\tLN:6644\n@SQ\tSN:KB710739.1\tLN:6644\n@SQ\tSN:APMT01216317.1\tLN:6642\n@SQ\tSN:KB710185.1\tLN:6641\n@SQ\tSN:APMT01216318.1\tLN:6640\n@SQ\tSN:APMT01216319.1\tLN:6637\n@SQ\tSN:KB711307.1\tLN:6636\n@SQ\tSN:APMT01216326.1\tLN:6635\n@SQ\tSN:KB710394.1\tLN:6634\n@SQ\tSN:APMT01216330.1\tLN:6634\n@SQ\tSN:APMT01216180.1\tLN:6633\n@SQ\tSN:KB710404.1\tLN:6633\n@SQ\tSN:APMT01216262.1\tLN:6630\n@SQ\tSN:KB710484.1\tLN:6630\n@SQ\tSN:KB710346.1\tLN:6627\n@SQ\tSN:KB710378.1\tLN:6627\n@SQ\tSN:APMT01216340.1\tLN:6625\n@SQ\tSN:APMT01216293.1\tLN:6624\n@SQ\tSN:APMT01216259.1\tLN:6622\n@SQ\tSN:APMT01216344.1\tLN:6621\n@SQ\tSN:KB710842.1\tLN:6621\n@SQ\tSN:KB710388.1\tLN:6620\n@SQ\tSN:APMT01216206.1\tLN:6620\n@SQ\tSN:KB710382.1\tLN:6619\n@SQ\tSN:KB710563.1\tLN:6619\n@SQ\tSN:KB710398.1\tLN:6618\n@SQ\tSN:APMT01216351.1\tLN:6618\n@SQ\tSN:KB710314.1\tLN:6616\n@SQ\tSN:APMT01216166.1\tLN:6615\n@SQ\tSN:KB710375.1\tLN:6614\n@SQ\tSN:APMT01216359.1\tLN:6613\n@SQ\tSN:APMT01216360.1\tLN:6613\n@SQ\tSN:KB710414.1\tLN:6612\n@SQ\tSN:APMT01216368.1\tLN:6609\n@SQ\tSN:APMT01216369.1\tLN:6609\n@SQ\tSN:APMT01216373.1\tLN:6608\n@SQ\tSN:KB710300.1\tLN:6606\n@SQ\tSN:APMT01216352.1\tLN:6605\n@SQ\tSN:KB710436.1\tLN:6605\n@SQ\tSN:KB710234.1\tLN:6604\n@SQ\tSN:APMT01216374.1\tLN:6604\n@SQ\tSN:APMT01216313.1\tLN:6601\n@SQ\tSN:KB710451.1\tLN:6598\n@SQ\tSN:APMT01216297.1\tLN:6595\n@SQ\tSN:KB710749.1\tLN:6595\n@SQ\tSN:APMT01216311.1\tLN:6594\n@SQ\tSN:APMT01216392.1\tLN:6592\n@SQ\tSN:APMT01216393.1\tLN:6591\n@SQ\tSN:APMT01216361.1\tLN:6589\n@SQ\tSN:APMT01216394.1\tLN:6588\n@SQ\tSN:APMT01216395.1\tLN:6588\n@SQ\tSN:KB710386.1\tLN:6585\n@SQ\tSN:APMT01216399.1\tLN:6585\n@SQ\tSN:KB710427.1\tLN:6584\n@SQ\tSN:APMT01216316.1\tLN:6583\n@SQ\tSN:APMT01216285.1\tLN:6582\n@SQ\tSN:APMT01216331.1\tLN:6578\n@SQ\tSN:KB710835.1\tLN:6578\n@SQ\tSN:APMT01216405.1\tLN:6576\n@SQ\tSN:KB710439.1\tLN:6575\n@SQ\tSN:APMT01216342.1\tLN:6574\n@SQ\tSN:APMT01216412.1\tLN:6573\n@SQ\tSN:APMT01216413.1\tLN:6573\n@SQ\tSN:KB710476.1\tLN:6573\n@SQ\tSN:APMT01216343.1\tLN:6571\n@SQ\tSN:KB710434.1\tLN:6571\n@SQ\tSN:KB710822.1\tLN:6570\n@SQ\tSN:APMT01216421.1\tLN:6569\n@SQ\tSN:APMT01216341.1\tLN:6566\n@SQ\tSN:KB710435.1\tLN:6566\n@SQ\tSN:APMT01216419.1\tLN:6565\n@SQ\tSN:APMT01216428.1\tLN:6565\n@SQ\tSN:APMT01216429.1\tLN:6565\n@SQ\tSN:KB711301.1\tLN:6564\n@SQ\tSN:APMT01216425.1\tLN:6563\n@SQ\tSN:KB711245.1\tLN:6562\n@SQ\tSN:KB710329.1\tLN:6561\n@SQ\tSN:KB710798.1\tLN:6557\n@SQ\tSN:APMT01216436.1\tLN:6556\n@SQ\tSN:APMT01216375.1\tLN:6555\n@SQ\tSN:KB710431.1\tLN:6554\n@SQ\tSN:APMT01216440.1\tLN:6554\n@SQ\tSN:KB710526.1\tLN:6554\n@SQ\tSN:KB711052.1\tLN:6554\n@SQ\tSN:APMT01216445.1\tLN:6553\n@SQ\tSN:KB710424.1\tLN:6552\n@SQ\tSN:APMT01216446.1\tLN:6552\n@SQ\tSN:APMT01216434.1\tLN:6550\n@SQ\tSN:KB710416.1\tLN:6549\n@SQ\tSN:KB710428.1\tLN:6548\n@SQ\tSN:APMT01216450.1\tLN:6546\n@SQ\tSN:APMT01216451.1\tLN:6545\n@SQ\tSN:APMT01216455.1\tLN:6544\n@SQ\tSN:APMT01216456.1\tLN:6543\n@SQ\tSN:KB710419.1\tLN:6541\n@SQ\tSN:KB710426.1\tLN:6540\n@SQ\tSN:APMT01216460.1\tLN:6540\n@SQ\tSN:APMT01216467.1\tLN:6539\n@SQ\tSN:APMT01216468.1\tLN:6539\n@SQ\tSN:APMT01216469.1\tLN:6539\n@SQ\tSN:APMT01216470.1\tLN:6538\n@SQ\tSN:APMT01216471.1\tLN:6537\n@SQ\tSN:APMT01216472.1\tLN:6537\n@SQ\tSN:KB710440.1\tLN:6533\n@SQ\tSN:KB709635.1\tLN:6532\n@SQ\tSN:KB710433.1\tLN:6532\n@SQ\tSN:KB710455.1\tLN:6526\n@SQ\tSN:KB710477.1\tLN:6525\n@SQ\tSN:KB710810.1\tLN:6524\n@SQ\tSN:APMT01216493.1\tLN:6521\n@SQ\tSN:APMT01216494.1\tLN:6520\n@SQ\tSN:APMT01216499.1\tLN:6519\n@SQ\tSN:KB710423.1\tLN:6518\n@SQ\tSN:APMT01216498.1\tLN:6518\n@SQ\tSN:APMT01216503.1\tLN:6518\n@SQ\tSN:APMT01216504.1\tLN:6517\n@SQ\tSN:APMT01216420.1\tLN:6515\n@SQ\tSN:APMT01216508.1\tLN:6514\n@SQ\tSN:KB709893.1\tLN:6513\n@SQ\tSN:APMT01216509.1\tLN:6513\n@SQ\tSN:APMT01216518.1\tLN:6509\n@SQ\tSN:APMT01216430.1\tLN:6508\n@SQ\tSN:APMT01216519.1\tLN:6507\n@SQ\tSN:KB710751.1\tLN:6506\n@SQ\tSN:KB710595.1\tLN:6505\n@SQ\tSN:APMT01216533.1\tLN:6503\n@SQ\tSN:APMT01216534.1\tLN:6502\n@SQ\tSN:APMT01216535.1\tLN:6502\n@SQ\tSN:APMT01216540.1\tLN:6500\n@SQ\tSN:APMT01216435.1\tLN:6499\n@SQ\tSN:APMT01216541.1\tLN:6499\n@SQ\tSN:KB710442.1\tLN:6498\n@SQ\tSN:KB710390.1\tLN:6497\n@SQ\tSN:APMT01216555.1\tLN:6490\n@SQ\tSN:APMT01216556.1\tLN:6489\n@SQ\tSN:KB710500.1\tLN:6487\n@SQ\tSN:KB710415.1\tLN:6486\n@SQ\tSN:APMT01216563.1\tLN:6486\n@SQ\tSN:KB710469.1\tLN:6482\n@SQ\tSN:KB709586.1\tLN:6478\n@SQ\tSN:APMT01216571.1\tLN:6478\n@SQ\tSN:KB711213.1\tLN:6477\n@SQ\tSN:APMT01216576.1\tLN:6475\n@SQ\tSN:APMT01216542.1\tLN:6474\n@SQ\tSN:APMT01216536.1\tLN:6473\n@SQ\tSN:APMT01216583.1\tLN:6473\n@SQ\tSN:APMT01216584.1\tLN:6472\n@SQ\tSN:KB710551.1\tLN:6472\n@SQ\tSN:KB710465.1\tLN:6467\n@SQ\tSN:APMT01216598.1\tLN:6464\n@SQ\tSN:APMT01216517.1\tLN:6462\n@SQ\tSN:KB710410.1\tLN:6461\n@SQ\tSN:APMT01216600.1\tLN:6458\n@SQ\tSN:APMT01216601.1\tLN:6457\n@SQ\tSN:APMT01216604.1\tLN:6457\n@SQ\tSN:KB710498.1\tLN:6457\n@SQ\tSN:KB710851.1\tLN:6457\n@SQ\tSN:APMT01216520.1\tLN:6456\n@SQ\tSN:APMT01216605.1\tLN:6456\n@SQ\tSN:KB711166.1\tLN:6456\n@SQ\tSN:KB709589.1\tLN:6454\n@SQ\tSN:KB710472.1\tLN:6453\n@SQ\tSN:APMT01216510.1\tLN:6451\n@SQ\tSN:APMT01216616.1\tLN:6451\n@SQ\tSN:APMT01216618.1\tLN:6450\n@SQ\tSN:APMT01216619.1\tLN:6449\n@SQ\tSN:APMT01216625.1\tLN:6448\n@SQ\tSN:KB710449.1\tLN:6447\n@SQ\tSN:APMT01216620.1\tLN:6447\n@SQ\tSN:APMT01216626.1\tLN:6447\n@SQ\tSN:KB710497.1\tLN:6446\n@SQ\tSN:KB710520.1\tLN:6444\n@SQ\tSN:KB709847.1\tLN:6443\n@SQ\tSN:KB710470.1\tLN:6442\n@SQ\tSN:APMT01216639.1\tLN:6442\n@SQ\tSN:APMT01216640.1\tLN:6441\n@SQ\tSN:APMT01216645.1\tLN:6441\n@SQ\tSN:KB709979.1\tLN:6440\n@SQ\tSN:APMT01216647.1\tLN:6440\n@SQ\tSN:APMT01216648.1\tLN:6439\n@SQ\tSN:APMT01216654.1\tLN:6439\n@SQ\tSN:APMT01216543.1\tLN:6438\n@SQ\tSN:APMT01216646.1\tLN:6438\n@SQ\tSN:APMT01216655.1\tLN:6435\n@SQ\tSN:KB709971.1\tLN:6434\n@SQ\tSN:KB711242.1\tLN:6432\n@SQ\tSN:APMT01216564.1\tLN:6430\n@SQ\tSN:APMT01216668.1\tLN:6430\n@SQ\tSN:KB710494.1\tLN:6428\n@SQ\tSN:KB710354.1\tLN:6427\n@SQ\tSN:APMT01216644.1\tLN:6426\n@SQ\tSN:APMT01216683.1\tLN:6426\n@SQ\tSN:KB710608.1\tLN:6426\n@SQ\tSN:KB710000.1\tLN:6425\n@SQ\tSN:KB709841.1\tLN:6424\n@SQ\tSN:KB710496.1\tLN:6423\n@SQ\tSN:KB710523.1\tLN:6423\n@SQ\tSN:KB710847.1\tLN:6423\n@SQ\tSN:APMT01216667.1\tLN:6422\n@SQ\tSN:APMT01216750.1\tLN:6421\n@SQ\tSN:APMT01216591.1\tLN:6420\n@SQ\tSN:APMT01216691.1\tLN:6419\n@SQ\tSN:KB710474.1\tLN:6417\n@SQ\tSN:APMT01216704.1\tLN:6416\n@SQ\tSN:APMT01216599.1\tLN:6414\n@SQ\tSN:KB710509.1\tLN:6414\n@SQ\tSN:KB710447.1\tLN:6413\n@SQ\tSN:APMT01216708.1\tLN:6412\n@SQ\tSN:APMT01216709.1\tLN:6412\n@SQ\tSN:APMT01216714.1\tLN:6411\n@SQ\tSN:KB710557.1\tLN:6411\n@SQ\tSN:APMT01216720.1\tLN:6409\n@SQ\tSN:KB710711.1\tLN:6409\n@SQ\tSN:KB709656.1\tLN:6407\n@SQ\tSN:APMT01216703.1\tLN:6407\n@SQ\tSN:APMT01216733.1\tLN:6407\n@SQ\tSN:KB711401.1\tLN:6407\n@SQ\tSN:KB710912.1\tLN:6405\n@SQ\tSN:KB710931.1\tLN:6403\n@SQ\tSN:APMT01216736.1\tLN:6402\n@SQ\tSN:APMT01216735.1\tLN:6401\n@SQ\tSN:APMT01216737.1\tLN:6401\n@SQ\tSN:APMT01216575.1\tLN:6400\n@SQ\tSN:KB710459.1\tLN:6398\n@SQ\tSN:APMT01216734.1\tLN:6397\n@SQ\tSN:APMT01216741.1\tLN:6396\n@SQ\tSN:KB710475.1\tLN:6395\n@SQ\tSN:APMT01216729.1\tLN:6395\n@SQ\tSN:KB714425.1\tLN:6395\n@SQ\tSN:KB710464.1\tLN:6394\n@SQ\tSN:APMT01216742.1\tLN:6394\n@SQ\tSN:APMT01216746.1\tLN:6394\n@SQ\tSN:KB710535.1\tLN:6394\n@SQ\tSN:KB710218.1\tLN:6393\n@SQ\tSN:KB710473.1\tLN:6393\n@SQ\tSN:KB711456.1\tLN:6393\n@SQ\tSN:APMT01216766.1\tLN:6392\n@SQ\tSN:APMT01216752.1\tLN:6390\n@SQ\tSN:APMT01216753.1\tLN:6390\n@SQ\tSN:KB710479.1\tLN:6388\n@SQ\tSN:APMT01216754.1\tLN:6388\n@SQ\tSN:KB710543.1\tLN:6387\n@SQ\tSN:KB710502.1\tLN:6386\n@SQ\tSN:APMT01216755.1\tLN:6386\n@SQ\tSN:APMT01216756.1\tLN:6386\n@SQ\tSN:APMT01216757.1\tLN:6386\n@SQ\tSN:APMT01216676.1\tLN:6385\n@SQ\tSN:APMT01216751.1\tLN:6383\n@SQ\tSN:KB710261.1\tLN:6382\n@SQ\tSN:KB710512.1\tLN:6381\n@SQ\tSN:KB710315.1\tLN:6380\n@SQ\tSN:KB710518.1\tLN:6380\n@SQ\tSN:KB711079.1\tLN:6380\n@SQ\tSN:APMT01216758.1\tLN:6379\n@SQ\tSN:APMT01216759.1\tLN:6379\n@SQ\tSN:APMT01216760.1\tLN:6379\n@SQ\tSN:KB711357.1\tLN:6379\n@SQ\tSN:APMT01216770.1\tLN:6378\n@SQ\tSN:APMT01216771.1\tLN:6377\n@SQ\tSN:APMT01216772.1\tLN:6376\n@SQ\tSN:APMT01216781.1\tLN:6375\n@SQ\tSN:KB710463.1\tLN:6374\n@SQ\tSN:APMT01216783.1\tLN:6374\n@SQ\tSN:KB711128.1\tLN:6374\n@SQ\tSN:APMT01216784.1\tLN:6372\n@SQ\tSN:APMT01216785.1\tLN:6372\n@SQ\tSN:APMT01216786.1\tLN:6372\n@SQ\tSN:APMT01216790.1\tLN:6372\n@SQ\tSN:APMT01216791.1\tLN:6371\n@SQ\tSN:APMT01216794.1\tLN:6369\n@SQ\tSN:APMT01216672.1\tLN:6368\n@SQ\tSN:APMT01216692.1\tLN:6365\n@SQ\tSN:APMT01216799.1\tLN:6365\n@SQ\tSN:APMT01216805.1\tLN:6364\n@SQ\tSN:KB710471.1\tLN:6361\n@SQ\tSN:APMT01216782.1\tLN:6358\n@SQ\tSN:APMT01216810.1\tLN:6358\n@SQ\tSN:APMT01216811.1\tLN:6357\n@SQ\tSN:APMT01216617.1\tLN:6352\n@SQ\tSN:APMT01216819.1\tLN:6352\n@SQ\tSN:APMT01216820.1\tLN:6352\n@SQ\tSN:KB710562.1\tLN:6352\n@SQ\tSN:APMT01216719.1\tLN:6351\n@SQ\tSN:KB710517.1\tLN:6347\n@SQ\tSN:KB710916.1\tLN:6346\n@SQ\tSN:KB710515.1\tLN:6344\n@SQ\tSN:APMT01216852.1\tLN:6342\n@SQ\tSN:KB710534.1\tLN:6340\n@SQ\tSN:APMT01216848.1\tLN:6340\n@SQ\tSN:APMT01216829.1\tLN:6339\n@SQ\tSN:KB710508.1\tLN:6338\n@SQ\tSN:KB711120.1\tLN:6336\n@SQ\tSN:APMT01216821.1\tLN:6334\n@SQ\tSN:KB710493.1\tLN:6332\n@SQ\tSN:KB710395.1\tLN:6331\n@SQ\tSN:KB711118.1\tLN:6327\n@SQ\tSN:KB710542.1\tLN:6326\n@SQ\tSN:KB710573.1\tLN:6321\n@SQ\tSN:APMT01216880.1\tLN:6315\n@SQ\tSN:APMT01216887.1\tLN:6315\n@SQ\tSN:APMT01216888.1\tLN:6315\n@SQ\tSN:APMT01216917.1\tLN:6313\n@SQ\tSN:APMT01216892.1\tLN:6312\n@SQ\tSN:APMT01216884.1\tLN:6311\n@SQ\tSN:KB710928.1\tLN:6311\n@SQ\tSN:APMT01216903.1\tLN:6309\n@SQ\tSN:APMT01216904.1\tLN:6309\n@SQ\tSN:KB711069.1\tLN:6309\n@SQ\tSN:KB710450.1\tLN:6308\n@SQ\tSN:APMT01216795.1\tLN:6307\n@SQ\tSN:APMT01216913.1\tLN:6307\n@SQ\tSN:APMT01216914.1\tLN:6307\n@SQ\tSN:KB711260.1\tLN:6306\n@SQ\tSN:KB709620.1\tLN:6305\n@SQ\tSN:APMT01216918.1\tLN:6302\n@SQ\tSN:KB710953.1\tLN:6301\n@SQ\tSN:KB710255.1\tLN:6300\n@SQ\tSN:KB710532.1\tLN:6298\n@SQ\tSN:KB710554.1\tLN:6297\n@SQ\tSN:KB710575.1\tLN:6297\n@SQ\tSN:KB710598.1\tLN:6297\n@SQ\tSN:APMT01216825.1\tLN:6296\n@SQ\tSN:KB710541.1\tLN:6296\n@SQ\tSN:APMT01216930.1\tLN:6296\n@SQ\tSN:KB710006.1\tLN:6294\n@SQ\tSN:KB710399.1\tLN:6293\n@SQ\tSN:APMT01216835.1\tLN:6293\n@SQ\tSN:APMT01216935.1\tLN:6292\n@SQ\tSN:APMT01216936.1\tLN:6292\n@SQ\tSN:KB710221.1\tLN:6291\n@SQ\tSN:KB710537.1\tLN:6291\n@SQ\tSN:APMT01216944.1\tLN:6290\n@SQ\tSN:APMT01216946.1\tLN:6289\n@SQ\tSN:APMT01216947.1\tLN:6287\n@SQ\tSN:KB709598.1\tLN:6286\n@SQ\tSN:KB710097.1\tLN:6286\n@SQ\tSN:APMT01216885.1\tLN:6286\n@SQ\tSN:APMT01216896.1\tLN:6286\n@SQ\tSN:KB710566.1\tLN:6286\n@SQ\tSN:KB710503.1\tLN:6285\n@SQ\tSN:KB710948.1\tLN:6285\n@SQ\tSN:APMT01216948.1\tLN:6283\n@SQ\tSN:APMT01216949.1\tLN:6283\n@SQ\tSN:APMT01216886.1\tLN:6281\n@SQ\tSN:APMT01216950.1\tLN:6280\n@SQ\tSN:KB710516.1\tLN:6277\n@SQ\tSN:APMT01216856.1\tLN:6277\n@SQ\tSN:KB710441.1\tLN:6276\n@SQ\tSN:KB710538.1\tLN:6276\n@SQ\tSN:APMT01216958.1\tLN:6275\n@SQ\tSN:KB710838.1\tLN:6275\n@SQ\tSN:APMT01216937.1\tLN:6274\n@SQ\tSN:KB710533.1\tLN:6272\n@SQ\tSN:APMT01216868.1\tLN:6272\n@SQ\tSN:APMT01216963.1\tLN:6272\n@SQ\tSN:KB710600.1\tLN:6272\n@SQ\tSN:KB709603.1\tLN:6266\n@SQ\tSN:APMT01216982.1\tLN:6266\n@SQ\tSN:APMT01216983.1\tLN:6266\n@SQ\tSN:KB709634.1\tLN:6265\n@SQ\tSN:KB710175.1\tLN:6264\n@SQ\tSN:KB710488.1\tLN:6263\n@SQ\tSN:APMT01216996.1\tLN:6261\n@SQ\tSN:APMT01216931.1\tLN:6259\n@SQ\tSN:APMT01217009.1\tLN:6259\n@SQ\tSN:APMT01217010.1\tLN:6259\n@SQ\tSN:KB710348.1\tLN:6257\n@SQ\tSN:KB710485.1\tLN:6257\n@SQ\tSN:APMT01216926.1\tLN:6257\n@SQ\tSN:KB710559.1\tLN:6257\n@SQ\tSN:APMT01217012.1\tLN:6255\n@SQ\tSN:APMT01217013.1\tLN:6255\n@SQ\tSN:KB710018.1\tLN:6254\n@SQ\tSN:APMT01216818.1\tLN:6253\n@SQ\tSN:KB710501.1\tLN:6252\n@SQ\tSN:APMT01217024.1\tLN:6251\n@SQ\tSN:KB711029.1\tLN:6251\n@SQ\tSN:KB711349.1\tLN:6250\n@SQ\tSN:KB709582.1\tLN:6249\n@SQ\tSN:KB710578.1\tLN:6247\n@SQ\tSN:APMT01216971.1\tLN:6243\n@SQ\tSN:APMT01217046.1\tLN:6243\n@SQ\tSN:KB710481.1\tLN:6242\n@SQ\tSN:KB710525.1\tLN:6242\n@SQ\tSN:APMT01217047.1\tLN:6242\n@SQ\tSN:APMT01217048.1\tLN:6242\n@SQ\tSN:KB710639.1\tLN:6242\n@SQ\tSN:KB713654.1\tLN:6242\n@SQ\tSN:APMT01217049.1\tLN:6241\n@SQ\tSN:APMT01216809.1\tLN:6239\n@SQ\tSN:APMT01217029.1\tLN:6239\n@SQ\tSN:APMT01217051.1\tLN:6239\n@SQ\tSN:APMT01217052.1\tLN:6239\n@SQ\tSN:KB710522.1\tLN:6237\n@SQ\tSN:APMT01216945.1\tLN:6236\n@SQ\tSN:APMT01217053.1\tLN:6235\n@SQ\tSN:KB709852.1\tLN:6234\n@SQ\tSN:KB710482.1\tLN:6234\n@SQ\tSN:APMT01217008.1\tLN:6234\n@SQ\tSN:APMT01217056.1\tLN:6232\n@SQ\tSN:APMT01217055.1\tLN:6231\n@SQ\tSN:KB710547.1\tLN:6230\n@SQ\tSN:APMT01216959.1\tLN:6230\n@SQ\tSN:APMT01217057.1\tLN:6230\n@SQ\tSN:KB711399.1\tLN:6229\n@SQ\tSN:APMT01216995.1\tLN:6226\n@SQ\tSN:KB709968.1\tLN:6225\n@SQ\tSN:KB710564.1\tLN:6225\n@SQ\tSN:KB710601.1\tLN:6225\n@SQ\tSN:APMT01217062.1\tLN:6224\n@SQ\tSN:APMT01217063.1\tLN:6223\n@SQ\tSN:KB710536.1\tLN:6220\n@SQ\tSN:APMT01217025.1\tLN:6220\n@SQ\tSN:KB711004.1\tLN:6220\n@SQ\tSN:APMT01217069.1\tLN:6219\n@SQ\tSN:APMT01217070.1\tLN:6219\n@SQ\tSN:KB711317.1\tLN:6219\n@SQ\tSN:APMT01216970.1\tLN:6218\n@SQ\tSN:APMT01217076.1\tLN:6216\n@SQ\tSN:APMT01217071.1\tLN:6215\n@SQ\tSN:KB710590.1\tLN:6214\n@SQ\tSN:KB710859.1\tLN:6213\n@SQ\tSN:APMT01217085.1\tLN:6212\n@SQ\tSN:APMT01217086.1\tLN:6211\n@SQ\tSN:APMT01217087.1\tLN:6211\n@SQ\tSN:KB710530.1\tLN:6209\n@SQ\tSN:APMT01217054.1\tLN:6208\n@SQ\tSN:APMT01217090.1\tLN:6208\n@SQ\tSN:APMT01217091.1\tLN:6208\n@SQ\tSN:APMT01217089.1\tLN:6207\n@SQ\tSN:APMT01217088.1\tLN:6206\n@SQ\tSN:APMT01217095.1\tLN:6206\n@SQ\tSN:APMT01217096.1\tLN:6206\n@SQ\tSN:APMT01217097.1\tLN:6206\n@SQ\tSN:APMT01217099.1\tLN:6204\n@SQ\tSN:APMT01217100.1\tLN:6204\n@SQ\tSN:KB710529.1\tLN:6202\n@SQ\tSN:APMT01217101.1\tLN:6201\n@SQ\tSN:APMT01217113.1\tLN:6201\n@SQ\tSN:APMT01217114.1\tLN:6201\n@SQ\tSN:APMT01217116.1\tLN:6200\n@SQ\tSN:KB709612.1\tLN:6195\n@SQ\tSN:APMT01217011.1\tLN:6195\n@SQ\tSN:APMT01217072.1\tLN:6194\n@SQ\tSN:APMT01217126.1\tLN:6194\n@SQ\tSN:APMT01217033.1\tLN:6193\n@SQ\tSN:KB710544.1\tLN:6192\n@SQ\tSN:APMT01217098.1\tLN:6192\n@SQ\tSN:APMT01217136.1\tLN:6191\n@SQ\tSN:APMT01217137.1\tLN:6191\n@SQ\tSN:KB710452.1\tLN:6190\n@SQ\tSN:APMT01217139.1\tLN:6190\n@SQ\tSN:APMT01217140.1\tLN:6190\n@SQ\tSN:KB710605.1\tLN:6188\n@SQ\tSN:APMT01217050.1\tLN:6185\n@SQ\tSN:KB709652.1\tLN:6182\n@SQ\tSN:APMT01217144.1\tLN:6182\n@SQ\tSN:KB710337.1\tLN:6181\n@SQ\tSN:APMT01217146.1\tLN:6179\n@SQ\tSN:APMT01217145.1\tLN:6177\n@SQ\tSN:KB710834.1\tLN:6177\n@SQ\tSN:KB710560.1\tLN:6174\n@SQ\tSN:KB710224.1\tLN:6169\n@SQ\tSN:APMT01216954.1\tLN:6169\n@SQ\tSN:KB710511.1\tLN:6167\n@SQ\tSN:APMT01217162.1\tLN:6167\n@SQ\tSN:APMT01217058.1\tLN:6166\n@SQ\tSN:APMT01217064.1\tLN:6166\n@SQ\tSN:KB710742.1\tLN:6166\n@SQ\tSN:KB710343.1\tLN:6165\n@SQ\tSN:KB710581.1\tLN:6165\n@SQ\tSN:KB709922.1\tLN:6164\n@SQ\tSN:KB710588.1\tLN:6163\n@SQ\tSN:KB710591.1\tLN:6163\n@SQ\tSN:APMT01217165.1\tLN:6163\n@SQ\tSN:KB710593.1\tLN:6161\n@SQ\tSN:APMT01217173.1\tLN:6161\n@SQ\tSN:APMT01217174.1\tLN:6160\n@SQ\tSN:APMT01217175.1\tLN:6160\n@SQ\tSN:APMT01217176.1\tLN:6159\n@SQ\tSN:APMT01217180.1\tLN:6159\n@SQ\tSN:KB709931.1\tLN:6157\n@SQ\tSN:KB710432.1\tLN:6156\n@SQ\tSN:KB710583.1\tLN:6156\n@SQ\tSN:KB710287.1\tLN:6155\n@SQ\tSN:APMT01217190.1\tLN:6155\n@SQ\tSN:KB710299.1\tLN:6154\n@SQ\tSN:KB710607.1\tLN:6154\n@SQ\tSN:KB710599.1\tLN:6153\n@SQ\tSN:APMT01217084.1\tLN:6152\n@SQ\tSN:APMT01217192.1\tLN:6151\n@SQ\tSN:APMT01217193.1\tLN:6150\n@SQ\tSN:KB710527.1\tLN:6149\n@SQ\tSN:APMT01217194.1\tLN:6149\n@SQ\tSN:APMT01217115.1\tLN:6148\n@SQ\tSN:APMT01217154.1\tLN:6147\n@SQ\tSN:KB710558.1\tLN:6146\n@SQ\tSN:APMT01217161.1\tLN:6146\n@SQ\tSN:KB710357.1\tLN:6145\n@SQ\tSN:APMT01217152.1\tLN:6141\n@SQ\tSN:KB709853.1\tLN:6138\n@SQ\tSN:KB711021.1\tLN:6138\n@SQ\tSN:KB710430.1\tLN:6137\n@SQ\tSN:APMT01217211.1\tLN:6137\n@SQ\tSN:APMT01217212.1\tLN:6136\n@SQ\tSN:APMT01217118.1\tLN:6135\n@SQ\tSN:APMT01217213.1\tLN:6135\n@SQ\tSN:KB710389.1\tLN:6134\n@SQ\tSN:KB710569.1\tLN:6134\n@SQ\tSN:APMT01217214.1\tLN:6133\n@SQ\tSN:APMT01217138.1\tLN:6132\n@SQ\tSN:KB710555.1\tLN:6131\n@SQ\tSN:KB711945.1\tLN:6131\n@SQ\tSN:KB711057.1\tLN:6130\n@SQ\tSN:KB710561.1\tLN:6129\n@SQ\tSN:APMT01217164.1\tLN:6129\n@SQ\tSN:APMT01217210.1\tLN:6129\n@SQ\tSN:KB710495.1\tLN:6127\n@SQ\tSN:APMT01217221.1\tLN:6127\n@SQ\tSN:APMT01217153.1\tLN:6126\n@SQ\tSN:APMT01217222.1\tLN:6126\n@SQ\tSN:APMT01217226.1\tLN:6125\n@SQ\tSN:KB710553.1\tLN:6124\n@SQ\tSN:APMT01217218.1\tLN:6124\n@SQ\tSN:KB710269.1\tLN:6122\n@SQ\tSN:APMT01217231.1\tLN:6121\n@SQ\tSN:APMT01217232.1\tLN:6118\n@SQ\tSN:KB710736.1\tLN:6118\n@SQ\tSN:KB711237.1\tLN:6117\n@SQ\tSN:APMT01217068.1\tLN:6116\n@SQ\tSN:APMT01217234.1\tLN:6116\n@SQ\tSN:APMT01217235.1\tLN:6116\n@SQ\tSN:KB710664.1\tLN:6114\n@SQ\tSN:KB710587.1\tLN:6113\n@SQ\tSN:KB710610.1\tLN:6113\n@SQ\tSN:KB710617.1\tLN:6113\n@SQ\tSN:KB709876.1\tLN:6108\n@SQ\tSN:APMT01217163.1\tLN:6108\n@SQ\tSN:APMT01217254.1\tLN:6107\n@SQ\tSN:KB711111.1\tLN:6107\n@SQ\tSN:APMT01217257.1\tLN:6106\n@SQ\tSN:APMT01217219.1\tLN:6105\n@SQ\tSN:APMT01217258.1\tLN:6105\n@SQ\tSN:APMT01217259.1\tLN:6105\n@SQ\tSN:KB710643.1\tLN:6105\n@SQ\tSN:APMT01217260.1\tLN:6104\n@SQ\tSN:KB710943.1\tLN:6102\n@SQ\tSN:KB710311.1\tLN:6101\n@SQ\tSN:APMT01217269.1\tLN:6101\n@SQ\tSN:APMT01217273.1\tLN:6101\n@SQ\tSN:APMT01217206.1\tLN:6100\n@SQ\tSN:APMT01217275.1\tLN:6099\n@SQ\tSN:KB710945.1\tLN:6097\n@SQ\tSN:KB710545.1\tLN:6096\n@SQ\tSN:APMT01217279.1\tLN:6096\n@SQ\tSN:APMT01217280.1\tLN:6096\n@SQ\tSN:APMT01217281.1\tLN:6096\n@SQ\tSN:KB710298.1\tLN:6095\n@SQ\tSN:KB710422.1\tLN:6095\n@SQ\tSN:KB710604.1\tLN:6094\n@SQ\tSN:APMT01217284.1\tLN:6094\n@SQ\tSN:APMT01217285.1\tLN:6094\n@SQ\tSN:APMT01217191.1\tLN:6092\n@SQ\tSN:APMT01217283.1\tLN:6092\n@SQ\tSN:APMT01217286.1\tLN:6092\n@SQ\tSN:APMT01217287.1\tLN:6092\n@SQ\tSN:KB711115.1\tLN:6090\n@SQ\tSN:KB709966.1\tLN:6087\n@SQ\tSN:APMT01217292.1\tLN:6087\n@SQ\tSN:APMT01217297.1\tLN:6086\n@SQ\tSN:KB711717.1\tLN:6086\n@SQ\tSN:KB710727.1\tLN:6084\n@SQ\tSN:APMT01217205.1\tLN:6081\n@SQ\tSN:APMT01217241.1\tLN:6081\n@SQ\tSN:APMT01217306.1\tLN:6081\n@SQ\tSN:KB710580.1\tLN:6080\n@SQ\tSN:KB710634.1\tLN:6077\n@SQ\tSN:APMT01217315.1\tLN:6073\n@SQ\tSN:KB710638.1\tLN:6073\n@SQ\tSN:APMT01217117.1\tLN:6071\n@SQ\tSN:APMT01217267.1\tLN:6070\n@SQ\tSN:APMT01217319.1\tLN:6070\n@SQ\tSN:APMT01217220.1\tLN:6068\n@SQ\tSN:APMT01217329.1\tLN:6067\n@SQ\tSN:KB710574.1\tLN:6066\n@SQ\tSN:APMT01217230.1\tLN:6065\n@SQ\tSN:APMT01217333.1\tLN:6065\n@SQ\tSN:APMT01217335.1\tLN:6064\n@SQ\tSN:KB709948.1\tLN:6063\n@SQ\tSN:APMT01217334.1\tLN:6063\n@SQ\tSN:APMT01217233.1\tLN:6062\n@SQ\tSN:KB710650.1\tLN:6062\n@SQ\tSN:KB709636.1\tLN:6061\n@SQ\tSN:KB710602.1\tLN:6060\n@SQ\tSN:KB710549.1\tLN:6059\n@SQ\tSN:KB710614.1\tLN:6059\n@SQ\tSN:APMT01217346.1\tLN:6059\n@SQ\tSN:KB710576.1\tLN:6058\n@SQ\tSN:APMT01217341.1\tLN:6058\n@SQ\tSN:APMT01217274.1\tLN:6057\n@SQ\tSN:APMT01217316.1\tLN:6057\n@SQ\tSN:APMT01217347.1\tLN:6057\n@SQ\tSN:KB710567.1\tLN:6055\n@SQ\tSN:KB711003.1\tLN:6054\n@SQ\tSN:APMT01217356.1\tLN:6053\n@SQ\tSN:APMT01217376.1\tLN:6052\n@SQ\tSN:APMT01217377.1\tLN:6052\n@SQ\tSN:APMT01217378.1\tLN:6051\n@SQ\tSN:APMT01217379.1\tLN:6051\n@SQ\tSN:APMT01217246.1\tLN:6050\n@SQ\tSN:APMT01217384.1\tLN:6050\n@SQ\tSN:APMT01217385.1\tLN:6050\n@SQ\tSN:APMT01217386.1\tLN:6050\n@SQ\tSN:KB711432.1\tLN:6050\n@SQ\tSN:APMT01217387.1\tLN:6048\n@SQ\tSN:KB711005.1\tLN:6048\n@SQ\tSN:APMT01217348.1\tLN:6047\n@SQ\tSN:APMT01217268.1\tLN:6046\n@SQ\tSN:APMT01217360.1\tLN:6046\n@SQ\tSN:KB710228.1\tLN:6044\n@SQ\tSN:APMT01217394.1\tLN:6044\n@SQ\tSN:APMT01217395.1\tLN:6042\n@SQ\tSN:APMT01217399.1\tLN:6041\n@SQ\tSN:APMT01217400.1\tLN:6039\n@SQ\tSN:KB710966.1\tLN:6039\n@SQ\tSN:KB710683.1\tLN:6038\n@SQ\tSN:APMT01217291.1\tLN:6037\n@SQ\tSN:KB710693.1\tLN:6037\n@SQ\tSN:APMT01217282.1\tLN:6034\n@SQ\tSN:KB710649.1\tLN:6034\n@SQ\tSN:APMT01217410.1\tLN:6034\n@SQ\tSN:APMT01217416.1\tLN:6032\n@SQ\tSN:APMT01217417.1\tLN:6031\n@SQ\tSN:KB710577.1\tLN:6029\n@SQ\tSN:APMT01217618.1\tLN:6029\n@SQ\tSN:APMT01217421.1\tLN:6025\n@SQ\tSN:APMT01217422.1\tLN:6025\n@SQ\tSN:APMT01217423.1\tLN:6025\n@SQ\tSN:KB710612.1\tLN:6024\n@SQ\tSN:KB710631.1\tLN:6024\n@SQ\tSN:KB710565.1\tLN:6023\n@SQ\tSN:KB710633.1\tLN:6023\n@SQ\tSN:APMT01217431.1\tLN:6023\n@SQ\tSN:APMT01217433.1\tLN:6022\n@SQ\tSN:APMT01217437.1\tLN:6022\n@SQ\tSN:APMT01217424.1\tLN:6021\n@SQ\tSN:APMT01217427.1\tLN:6021\n@SQ\tSN:APMT01217438.1\tLN:6021\n@SQ\tSN:KB710661.1\tLN:6021\n@SQ\tSN:APMT01217442.1\tLN:6018\n@SQ\tSN:APMT01217450.1\tLN:6014\n@SQ\tSN:APMT01217425.1\tLN:6012\n@SQ\tSN:APMT01217432.1\tLN:6011\n@SQ\tSN:KB710653.1\tLN:6010\n@SQ\tSN:APMT01217454.1\tLN:6010\n@SQ\tSN:APMT01217456.1\tLN:6008\n@SQ\tSN:APMT01217457.1\tLN:6007\n@SQ\tSN:KB710717.1\tLN:6007\n@SQ\tSN:KB711789.1\tLN:6007\n@SQ\tSN:APMT01217455.1\tLN:6004\n@SQ\tSN:KB709901.1\tLN:6003\n@SQ\tSN:KB711229.1\tLN:6000\n@SQ\tSN:APMT01217464.1\tLN:5999\n@SQ\tSN:APMT01217465.1\tLN:5999\n@SQ\tSN:APMT01217466.1\tLN:5999\n@SQ\tSN:APMT01217468.1\tLN:5998\n@SQ\tSN:KB710276.1\tLN:5997\n@SQ\tSN:KB710585.1\tLN:5997\n@SQ\tSN:APMT01217469.1\tLN:5996\n@SQ\tSN:APMT01217479.1\tLN:5994\n@SQ\tSN:KB710697.1\tLN:5993\n@SQ\tSN:KB709719.1\tLN:5992\n@SQ\tSN:APMT01217480.1\tLN:5992\n@SQ\tSN:APMT01217481.1\tLN:5992\n@SQ\tSN:KB710589.1\tLN:5991\n@SQ\tSN:APMT01217489.1\tLN:5991\n@SQ\tSN:APMT01217488.1\tLN:5990\n@SQ\tSN:APMT01217490.1\tLN:5990\n@SQ\tSN:KB710674.1\tLN:5990\n@SQ\tSN:APMT01217494.1\tLN:5989\n@SQ\tSN:APMT01217495.1\tLN:5988\n@SQ\tSN:KB711408.1\tLN:5988\n@SQ\tSN:KB710236.1\tLN:5987\n@SQ\tSN:APMT01217497.1\tLN:5987\n@SQ\tSN:APMT01217496.1\tLN:5986\n@SQ\tSN:APMT01217500.1\tLN:5984\n@SQ\tSN:KB710755.1\tLN:5984\n@SQ\tSN:APMT01217501.1\tLN:5983\n@SQ\tSN:APMT01217502.1\tLN:5981\n@SQ\tSN:KB710763.1\tLN:5981\n@SQ\tSN:APMT01217510.1\tLN:5980\n@SQ\tSN:KB711369.1\tLN:5980\n@SQ\tSN:APMT01217511.1\tLN:5979\n@SQ\tSN:KB711527.1\tLN:5979\n@SQ\tSN:KB709706.1\tLN:5978\n@SQ\tSN:APMT01217513.1\tLN:5978\n@SQ\tSN:APMT01217514.1\tLN:5978\n@SQ\tSN:KB710630.1\tLN:5977\n@SQ\tSN:APMT01217512.1\tLN:5976\n@SQ\tSN:APMT01217525.1\tLN:5976\n@SQ\tSN:APMT01217526.1\tLN:5975\n@SQ\tSN:APMT01217527.1\tLN:5974\n@SQ\tSN:APMT01217529.1\tLN:5972\n@SQ\tSN:APMT01217530.1\tLN:5971\n@SQ\tSN:KB712112.1\tLN:5970\n@SQ\tSN:APMT01217426.1\tLN:5968\n@SQ\tSN:APMT01217462.1\tLN:5968\n@SQ\tSN:APMT01217521.1\tLN:5967\n@SQ\tSN:KB710258.1\tLN:5966\n@SQ\tSN:KB710611.1\tLN:5966\n@SQ\tSN:APMT01217539.1\tLN:5966\n@SQ\tSN:APMT01217540.1\tLN:5966\n@SQ\tSN:KB710688.1\tLN:5966\n@SQ\tSN:APMT01217545.1\tLN:5965\n@SQ\tSN:KB710616.1\tLN:5963\n@SQ\tSN:APMT01217548.1\tLN:5961\n@SQ\tSN:APMT01217549.1\tLN:5961\n@SQ\tSN:KB710682.1\tLN:5961\n@SQ\tSN:KB710696.1\tLN:5959\n@SQ\tSN:KB711442.1\tLN:5958\n@SQ\tSN:KB710647.1\tLN:5957\n@SQ\tSN:APMT01217560.1\tLN:5957\n@SQ\tSN:KB710648.1\tLN:5956\n@SQ\tSN:APMT01217564.1\tLN:5954\n@SQ\tSN:APMT01217565.1\tLN:5953\n@SQ\tSN:KB711306.1\tLN:5953\n@SQ\tSN:KB710597.1\tLN:5951\n@SQ\tSN:KB710548.1\tLN:5950\n@SQ\tSN:KB710572.1\tLN:5950\n@SQ\tSN:KB710654.1\tLN:5950\n@SQ\tSN:APMT01217575.1\tLN:5949\n@SQ\tSN:APMT01217463.1\tLN:5948\n@SQ\tSN:APMT01217580.1\tLN:5948\n@SQ\tSN:APMT01217561.1\tLN:5947\n@SQ\tSN:KB711247.1\tLN:5946\n@SQ\tSN:KB710699.1\tLN:5945\n@SQ\tSN:KB710303.1\tLN:5944\n@SQ\tSN:APMT01217586.1\tLN:5944\n@SQ\tSN:KB710700.1\tLN:5944\n@SQ\tSN:APMT01217585.1\tLN:5943\n@SQ\tSN:KB710628.1\tLN:5942\n@SQ\tSN:APMT01217595.1\tLN:5941\n@SQ\tSN:APMT01217596.1\tLN:5941\n@SQ\tSN:KB710659.1\tLN:5940\n@SQ\tSN:APMT01217478.1\tLN:5940\n@SQ\tSN:APMT01217581.1\tLN:5939\n@SQ\tSN:APMT01217599.1\tLN:5939\n@SQ\tSN:APMT01217601.1\tLN:5939\n@SQ\tSN:APMT01217499.1\tLN:5938\n@SQ\tSN:APMT01217579.1\tLN:5938\n@SQ\tSN:APMT01217602.1\tLN:5938\n@SQ\tSN:KB710918.1\tLN:5938\n@SQ\tSN:KB710636.1\tLN:5936\n@SQ\tSN:APMT01217612.1\tLN:5936\n@SQ\tSN:APMT01217614.1\tLN:5936\n@SQ\tSN:KB709877.1\tLN:5935\n@SQ\tSN:APMT01217498.1\tLN:5935\n@SQ\tSN:KB710618.1\tLN:5934\n@SQ\tSN:KB710816.1\tLN:5934\n@SQ\tSN:KB709879.1\tLN:5933\n@SQ\tSN:APMT01217622.1\tLN:5932\n@SQ\tSN:APMT01217625.1\tLN:5931\n@SQ\tSN:KB710689.1\tLN:5930\n@SQ\tSN:APMT01217467.1\tLN:5929\n@SQ\tSN:KB712366.1\tLN:5929\n@SQ\tSN:APMT01217631.1\tLN:5926\n@SQ\tSN:APMT01217637.1\tLN:5925\n@SQ\tSN:APMT01217634.1\tLN:5924\n@SQ\tSN:KB710686.1\tLN:5923\n@SQ\tSN:KB710401.1\tLN:5922\n@SQ\tSN:APMT01217641.1\tLN:5922\n@SQ\tSN:APMT01217645.1\tLN:5920\n@SQ\tSN:KB711382.1\tLN:5919\n@SQ\tSN:KB710685.1\tLN:5918\n@SQ\tSN:APMT01217651.1\tLN:5918\n@SQ\tSN:APMT01217653.1\tLN:5917\n@SQ\tSN:APMT01217654.1\tLN:5916\n@SQ\tSN:APMT01217658.1\tLN:5916\n@SQ\tSN:APMT01217522.1\tLN:5915\n@SQ\tSN:APMT01217528.1\tLN:5914\n@SQ\tSN:APMT01217659.1\tLN:5913\n@SQ\tSN:KB710708.1\tLN:5913\n@SQ\tSN:KB710623.1\tLN:5912\n@SQ\tSN:APMT01217652.1\tLN:5912\n@SQ\tSN:APMT01217661.1\tLN:5911\n@SQ\tSN:APMT01217662.1\tLN:5911\n@SQ\tSN:APMT01217666.1\tLN:5910\n@SQ\tSN:APMT01217591.1\tLN:5909\n@SQ\tSN:APMT01217600.1\tLN:5909\n@SQ\tSN:KB710645.1\tLN:5908\n@SQ\tSN:APMT01217660.1\tLN:5907\n@SQ\tSN:KB710694.1\tLN:5906\n@SQ\tSN:APMT01217673.1\tLN:5905\n@SQ\tSN:KB710613.1\tLN:5903\n@SQ\tSN:KB710986.1\tLN:5903\n@SQ\tSN:APMT01217550.1\tLN:5902\n@SQ\tSN:APMT01217674.1\tLN:5902\n@SQ\tSN:APMT01217678.1\tLN:5901\n@SQ\tSN:KB710312.1\tLN:5899\n@SQ\tSN:APMT01217686.1\tLN:5898\n@SQ\tSN:KB711167.1\tLN:5898\n@SQ\tSN:KB710594.1\tLN:5897\n@SQ\tSN:APMT01217689.1\tLN:5897\n@SQ\tSN:KB709974.1\tLN:5896\n@SQ\tSN:KB711643.1\tLN:5896\n@SQ\tSN:KB712033.1\tLN:5895\n@SQ\tSN:KB710641.1\tLN:5894\n@SQ\tSN:APMT01217690.1\tLN:5894\n@SQ\tSN:KB710676.1\tLN:5892\n@SQ\tSN:KB710692.1\tLN:5892\n@SQ\tSN:APMT01217569.1\tLN:5891\n@SQ\tSN:APMT01217700.1\tLN:5890\n@SQ\tSN:APMT01217692.1\tLN:5889\n@SQ\tSN:KB710681.1\tLN:5888\n@SQ\tSN:KB710658.1\tLN:5887\n@SQ\tSN:APMT01217708.1\tLN:5887\n@SQ\tSN:KB710592.1\tLN:5886\n@SQ\tSN:APMT01217717.1\tLN:5885\n@SQ\tSN:APMT01217719.1\tLN:5885\n@SQ\tSN:KB710297.1\tLN:5884\n@SQ\tSN:APMT01217613.1\tLN:5882\n@SQ\tSN:KB710677.1\tLN:5881\n@SQ\tSN:APMT01217720.1\tLN:5881\n@SQ\tSN:KB710712.1\tLN:5879\n@SQ\tSN:APMT01217721.1\tLN:5878\n@SQ\tSN:APMT01217729.1\tLN:5875\n@SQ\tSN:KB711414.1\tLN:5875\n@SQ\tSN:KB710716.1\tLN:5874\n@SQ\tSN:APMT01217722.1\tLN:5874\n@SQ\tSN:APMT01217728.1\tLN:5874\n@SQ\tSN:KB710606.1\tLN:5873\n@SQ\tSN:KB710684.1\tLN:5872\n@SQ\tSN:APMT01217733.1\tLN:5871\n@SQ\tSN:KB710637.1\tLN:5870\n@SQ\tSN:KB710620.1\tLN:5868\n@SQ\tSN:APMT01217736.1\tLN:5867\n@SQ\tSN:KB710615.1\tLN:5865\n@SQ\tSN:APMT01217746.1\tLN:5862\n@SQ\tSN:APMT01217747.1\tLN:5861\n@SQ\tSN:APMT01217748.1\tLN:5860\n@SQ\tSN:APMT01217745.1\tLN:5859\n@SQ\tSN:APMT01217707.1\tLN:5858\n@SQ\tSN:APMT01217763.1\tLN:5857\n@SQ\tSN:KB710679.1\tLN:5856\n@SQ\tSN:APMT01217759.1\tLN:5856\n@SQ\tSN:APMT01217772.1\tLN:5855\n@SQ\tSN:KB710962.1\tLN:5855\n@SQ\tSN:APMT01217768.1\tLN:5853\n@SQ\tSN:APMT01217769.1\tLN:5852\n@SQ\tSN:APMT01217770.1\tLN:5852\n@SQ\tSN:APMT01217771.1\tLN:5852\n@SQ\tSN:APMT01217773.1\tLN:5851\n@SQ\tSN:KB710446.1\tLN:5849\n@SQ\tSN:APMT01217774.1\tLN:5849\n@SQ\tSN:APMT01217775.1\tLN:5848\n@SQ\tSN:APMT01217776.1\tLN:5848\n@SQ\tSN:APMT01217777.1\tLN:5848\n@SQ\tSN:KB711482.1\tLN:5848\n@SQ\tSN:KB710244.1\tLN:5847\n@SQ\tSN:APMT01217778.1\tLN:5844\n@SQ\tSN:KB711779.1\tLN:5844\n@SQ\tSN:APMT01217691.1\tLN:5842\n@SQ\tSN:KB710347.1\tLN:5840\n@SQ\tSN:KB710666.1\tLN:5840\n@SQ\tSN:APMT01217681.1\tLN:5839\n@SQ\tSN:KB711479.1\tLN:5839\n@SQ\tSN:KB710603.1\tLN:5838\n@SQ\tSN:KB710723.1\tLN:5837\n@SQ\tSN:APMT01217786.1\tLN:5837\n@SQ\tSN:KB710232.1\tLN:5835\n@SQ\tSN:APMT01217791.1\tLN:5835\n@SQ\tSN:APMT01217803.1\tLN:5834\n@SQ\tSN:APMT01217792.1\tLN:5833\n@SQ\tSN:APMT01217804.1\tLN:5833\n@SQ\tSN:APMT01217764.1\tLN:5832\n@SQ\tSN:APMT01217815.1\tLN:5832\n@SQ\tSN:APMT01217820.1\tLN:5829\n@SQ\tSN:APMT01217821.1\tLN:5829\n@SQ\tSN:APMT01217825.1\tLN:5829\n@SQ\tSN:KB710725.1\tLN:5828\n@SQ\tSN:KB711292.1\tLN:5827\n@SQ\tSN:APMT01217740.1\tLN:5825\n@SQ\tSN:KB710870.1\tLN:5824\n@SQ\tSN:KB709858.1\tLN:5821\n@SQ\tSN:KB710687.1\tLN:5821\n@SQ\tSN:APMT01217844.1\tLN:5821\n@SQ\tSN:APMT01217838.1\tLN:5819\n@SQ\tSN:APMT01217845.1\tLN:5819\n@SQ\tSN:KB711254.1\tLN:5819\n@SQ\tSN:APMT01217849.1\tLN:5818\n@SQ\tSN:APMT01217850.1\tLN:5818\n@SQ\tSN:APMT01217851.1\tLN:5817\n@SQ\tSN:APMT01217726.1\tLN:5815\n@SQ\tSN:KB710746.1\tLN:5815\n@SQ\tSN:KB710715.1\tLN:5813\n@SQ\tSN:KB709937.1\tLN:5812\n@SQ\tSN:KB710856.1\tLN:5811\n@SQ\tSN:APMT01217866.1\tLN:5809\n@SQ\tSN:APMT01217867.1\tLN:5809\n@SQ\tSN:KB710719.1\tLN:5807\n@SQ\tSN:KB709894.1\tLN:5806\n@SQ\tSN:KB711275.1\tLN:5806\n@SQ\tSN:KB710625.1\tLN:5804\n@SQ\tSN:KB710713.1\tLN:5803\n@SQ\tSN:APMT01217873.1\tLN:5803\n@SQ\tSN:APMT01217874.1\tLN:5803\n@SQ\tSN:APMT01217875.1\tLN:5803\n@SQ\tSN:APMT01217884.1\tLN:5802\n@SQ\tSN:APMT01217880.1\tLN:5801\n@SQ\tSN:KB710695.1\tLN:5799\n@SQ\tSN:KB710735.1\tLN:5799\n@SQ\tSN:APMT01217885.1\tLN:5799\n@SQ\tSN:KB710706.1\tLN:5798\n@SQ\tSN:APMT01217896.1\tLN:5795\n@SQ\tSN:KB711019.1\tLN:5795\n@SQ\tSN:APMT01217876.1\tLN:5794\n@SQ\tSN:APMT01217898.1\tLN:5794\n@SQ\tSN:KB710703.1\tLN:5793\n@SQ\tSN:APMT01217899.1\tLN:5793\n@SQ\tSN:APMT01217902.1\tLN:5793\n@SQ\tSN:APMT01217699.1\tLN:5792\n@SQ\tSN:KB710757.1\tLN:5792\n@SQ\tSN:APMT01217904.1\tLN:5791\n@SQ\tSN:KB710960.1\tLN:5791\n@SQ\tSN:KB710632.1\tLN:5790\n@SQ\tSN:APMT01217908.1\tLN:5790\n@SQ\tSN:APMT01217727.1\tLN:5789\n@SQ\tSN:KB710740.1\tLN:5789\n@SQ\tSN:KB710380.1\tLN:5787\n@SQ\tSN:APMT01217785.1\tLN:5787\n@SQ\tSN:APMT01217912.1\tLN:5785\n@SQ\tSN:KB709888.1\tLN:5784\n@SQ\tSN:APMT01217913.1\tLN:5784\n@SQ\tSN:KB710745.1\tLN:5783\n@SQ\tSN:KB710370.1\tLN:5782\n@SQ\tSN:APMT01217918.1\tLN:5782\n@SQ\tSN:KB710690.1\tLN:5781\n@SQ\tSN:KB711679.1\tLN:5780\n@SQ\tSN:KB710642.1\tLN:5779\n@SQ\tSN:KB710701.1\tLN:5778\n@SQ\tSN:KB711040.1\tLN:5778\n@SQ\tSN:KB711536.1\tLN:5777\n@SQ\tSN:KB710672.1\tLN:5776\n@SQ\tSN:APMT01217929.1\tLN:5775\n@SQ\tSN:APMT01217934.1\tLN:5775\n@SQ\tSN:KB711205.1\tLN:5775\n@SQ\tSN:APMT01217935.1\tLN:5774\n@SQ\tSN:APMT01217936.1\tLN:5774\n@SQ\tSN:KB711196.1\tLN:5773\n@SQ\tSN:APMT01217816.1\tLN:5772\n@SQ\tSN:APMT01217940.1\tLN:5772\n@SQ\tSN:APMT01217941.1\tLN:5772\n@SQ\tSN:KB711350.1\tLN:5772\n@SQ\tSN:APMT01217942.1\tLN:5770\n@SQ\tSN:APMT01217943.1\tLN:5769\n@SQ\tSN:APMT01217944.1\tLN:5769\n@SQ\tSN:KB710753.1\tLN:5767\n@SQ\tSN:APMT01217945.1\tLN:5767\n@SQ\tSN:KB710770.1\tLN:5767\n@SQ\tSN:KB712330.1\tLN:5767\n@SQ\tSN:KB709923.1\tLN:5764\n@SQ\tSN:KB710775.1\tLN:5764\n@SQ\tSN:APMT01217947.1\tLN:5763\n@SQ\tSN:KB710771.1\tLN:5763\n@SQ\tSN:KB711169.1\tLN:5760\n@SQ\tSN:KB710365.1\tLN:5758\n@SQ\tSN:KB710769.1\tLN:5758\n@SQ\tSN:KB710667.1\tLN:5757\n@SQ\tSN:APMT01217903.1\tLN:5756\n@SQ\tSN:KB710640.1\tLN:5754\n@SQ\tSN:APMT01217854.1\tLN:5754\n@SQ\tSN:APMT01217865.1\tLN:5753\n@SQ\tSN:KB711256.1\tLN:5753\n@SQ\tSN:KB711585.1\tLN:5753\n@SQ\tSN:KB709561.1\tLN:5752\n@SQ\tSN:APMT01217958.1\tLN:5752\n@SQ\tSN:APMT01217962.1\tLN:5751\n@SQ\tSN:KB709938.1\tLN:5750\n@SQ\tSN:KB710790.1\tLN:5750\n@SQ\tSN:APMT01217895.1\tLN:5749\n@SQ\tSN:APMT01217963.1\tLN:5749\n@SQ\tSN:APMT01217897.1\tLN:5748\n@SQ\tSN:KB709896.1\tLN:5747\n@SQ\tSN:KB710721.1\tLN:5747\n@SQ\tSN:APMT01217872.1\tLN:5747\n@SQ\tSN:KB710760.1\tLN:5747\n@SQ\tSN:APMT01217974.1\tLN:5747\n@SQ\tSN:KB710748.1\tLN:5745\n@SQ\tSN:KB711129.1\tLN:5744\n@SQ\tSN:APMT01217969.1\tLN:5742\n@SQ\tSN:KB712084.1\tLN:5740\n@SQ\tSN:APMT01217979.1\tLN:5739\n@SQ\tSN:KB710768.1\tLN:5738\n@SQ\tSN:APMT01217982.1\tLN:5736\n@SQ\tSN:KB710741.1\tLN:5735\n@SQ\tSN:APMT01217968.1\tLN:5735\n@SQ\tSN:APMT01217983.1\tLN:5734\n@SQ\tSN:KB710946.1\tLN:5734\n@SQ\tSN:APMT01217985.1\tLN:5733\n@SQ\tSN:KB711089.1\tLN:5733\n@SQ\tSN:KB711108.1\tLN:5733\n@SQ\tSN:APMT01217986.1\tLN:5732\n@SQ\tSN:APMT01217987.1\tLN:5732\n@SQ\tSN:KB710412.1\tLN:5729\n@SQ\tSN:KB710669.1\tLN:5728\n@SQ\tSN:KB710362.1\tLN:5727\n@SQ\tSN:APMT01217999.1\tLN:5725\n@SQ\tSN:KB711187.1\tLN:5724\n@SQ\tSN:APMT01218001.1\tLN:5723\n@SQ\tSN:KB710787.1\tLN:5723\n@SQ\tSN:KB711570.1\tLN:5723\n@SQ\tSN:KB710710.1\tLN:5722\n@SQ\tSN:APMT01218008.1\tLN:5721\n@SQ\tSN:KB710779.1\tLN:5719\n@SQ\tSN:APMT01218009.1\tLN:5719\n@SQ\tSN:APMT01218013.1\tLN:5719\n@SQ\tSN:KB710752.1\tLN:5716\n@SQ\tSN:APMT01218018.1\tLN:5715\n@SQ\tSN:KB711231.1\tLN:5715\n@SQ\tSN:APMT01218000.1\tLN:5714\n@SQ\tSN:APMT01218020.1\tLN:5714\n@SQ\tSN:APMT01218021.1\tLN:5711\n@SQ\tSN:APMT01217868.1\tLN:5710\n@SQ\tSN:APMT01218019.1\tLN:5710\n@SQ\tSN:APMT01218023.1\tLN:5708\n@SQ\tSN:APMT01218035.1\tLN:5708\n@SQ\tSN:APMT01218032.1\tLN:5706\n@SQ\tSN:APMT01217946.1\tLN:5705\n@SQ\tSN:KB711780.1\tLN:5705\n@SQ\tSN:APMT01218034.1\tLN:5704\n@SQ\tSN:KB710381.1\tLN:5700\n@SQ\tSN:APMT01218040.1\tLN:5700\n@SQ\tSN:APMT01217956.1\tLN:5699\n@SQ\tSN:APMT01218041.1\tLN:5699\n@SQ\tSN:APMT01218044.1\tLN:5698\n@SQ\tSN:KB711298.1\tLN:5698\n@SQ\tSN:KB710814.1\tLN:5696\n@SQ\tSN:KB710826.1\tLN:5696\n@SQ\tSN:APMT01217973.1\tLN:5695\n@SQ\tSN:APMT01218046.1\tLN:5695\n@SQ\tSN:KB711212.1\tLN:5695\n@SQ\tSN:APMT01218048.1\tLN:5693\n@SQ\tSN:APMT01218047.1\tLN:5692\n@SQ\tSN:KB710862.1\tLN:5692\n@SQ\tSN:APMT01218052.1\tLN:5691\n@SQ\tSN:APMT01217957.1\tLN:5690\n@SQ\tSN:APMT01217914.1\tLN:5689\n@SQ\tSN:APMT01218056.1\tLN:5688\n@SQ\tSN:APMT01217978.1\tLN:5686\n@SQ\tSN:APMT01218057.1\tLN:5686\n@SQ\tSN:APMT01218058.1\tLN:5686\n@SQ\tSN:APMT01218059.1\tLN:5686\n@SQ\tSN:APMT01218061.1\tLN:5684\n@SQ\tSN:APMT01218067.1\tLN:5684\n@SQ\tSN:APMT01218068.1\tLN:5683\n@SQ\tSN:APMT01217984.1\tLN:5682\n@SQ\tSN:APMT01218045.1\tLN:5682\n@SQ\tSN:APMT01218069.1\tLN:5682\n@SQ\tSN:KB710765.1\tLN:5681\n@SQ\tSN:APMT01217991.1\tLN:5681\n@SQ\tSN:KB710785.1\tLN:5681\n@SQ\tSN:APMT01218074.1\tLN:5680\n@SQ\tSN:APMT01218075.1\tLN:5680\n@SQ\tSN:APMT01218076.1\tLN:5679\n@SQ\tSN:APMT01218077.1\tLN:5678\n@SQ\tSN:KB710797.1\tLN:5677\n@SQ\tSN:KB710732.1\tLN:5675\n@SQ\tSN:APMT01217967.1\tLN:5675\n@SQ\tSN:KB710927.1\tLN:5675\n@SQ\tSN:APMT01218084.1\tLN:5674\n@SQ\tSN:KB710852.1\tLN:5672\n@SQ\tSN:KB710744.1\tLN:5671\n@SQ\tSN:KB710714.1\tLN:5670\n@SQ\tSN:KB710792.1\tLN:5670\n@SQ\tSN:KB710726.1\tLN:5669\n@SQ\tSN:APMT01218014.1\tLN:5668\n@SQ\tSN:KB710691.1\tLN:5667\n@SQ\tSN:APMT01218091.1\tLN:5667\n@SQ\tSN:APMT01218094.1\tLN:5667\n@SQ\tSN:APMT01218089.1\tLN:5666\n@SQ\tSN:KB710211.1\tLN:5665\n@SQ\tSN:KB710762.1\tLN:5665\n@SQ\tSN:APMT01218039.1\tLN:5665\n@SQ\tSN:APMT01218098.1\tLN:5665\n@SQ\tSN:APMT01218099.1\tLN:5665\n@SQ\tSN:APMT01218104.1\tLN:5663\n@SQ\tSN:KB710758.1\tLN:5662\n@SQ\tSN:APMT01218108.1\tLN:5662\n@SQ\tSN:KB710400.1\tLN:5661\n@SQ\tSN:KB710764.1\tLN:5661\n@SQ\tSN:KB710782.1\tLN:5661\n@SQ\tSN:APMT01218114.1\tLN:5661\n@SQ\tSN:APMT01218115.1\tLN:5661\n@SQ\tSN:APMT01218116.1\tLN:5659\n@SQ\tSN:APMT01218117.1\tLN:5659\n@SQ\tSN:KB710720.1\tLN:5658\n@SQ\tSN:APMT01218033.1\tLN:5657\n@SQ\tSN:APMT01217718.1\tLN:5656\n@SQ\tSN:APMT01218126.1\tLN:5655\n@SQ\tSN:APMT01218134.1\tLN:5652\n@SQ\tSN:APMT01218135.1\tLN:5650\n@SQ\tSN:APMT01218060.1\tLN:5649\n@SQ\tSN:APMT01218137.1\tLN:5648\n@SQ\tSN:APMT01218141.1\tLN:5648\n@SQ\tSN:APMT01218142.1\tLN:5648\n@SQ\tSN:APMT01218130.1\tLN:5647\n@SQ\tSN:APMT01218143.1\tLN:5647\n@SQ\tSN:APMT01218144.1\tLN:5646\n@SQ\tSN:APMT01218148.1\tLN:5646\n@SQ\tSN:KB711161.1\tLN:5646\n@SQ\tSN:APMT01218088.1\tLN:5645\n@SQ\tSN:KB711673.1\tLN:5645\n@SQ\tSN:KB710407.1\tLN:5640\n@SQ\tSN:APMT01218174.1\tLN:5638\n@SQ\tSN:KB711370.1\tLN:5638\n@SQ\tSN:KB711946.1\tLN:5637\n@SQ\tSN:APMT01218175.1\tLN:5636\n@SQ\tSN:APMT01218176.1\tLN:5636\n@SQ\tSN:KB710709.1\tLN:5635\n@SQ\tSN:APMT01218177.1\tLN:5635\n@SQ\tSN:APMT01218178.1\tLN:5635\n@SQ\tSN:APMT01218073.1\tLN:5634\n@SQ\tSN:APMT01218136.1\tLN:5634\n@SQ\tSN:APMT01218182.1\tLN:5633\n@SQ\tSN:KB710385.1\tLN:5632\n@SQ\tSN:APMT01218190.1\tLN:5630\n@SQ\tSN:APMT01218191.1\tLN:5630\n@SQ\tSN:KB710730.1\tLN:5629\n@SQ\tSN:APMT01218195.1\tLN:5629\n@SQ\tSN:APMT01218200.1\tLN:5628\n@SQ\tSN:KB710836.1\tLN:5626\n@SQ\tSN:KB709943.1\tLN:5625\n@SQ\tSN:APMT01218201.1\tLN:5624\n@SQ\tSN:APMT01218203.1\tLN:5624\n@SQ\tSN:APMT01218207.1\tLN:5624\n@SQ\tSN:APMT01218208.1\tLN:5623\n@SQ\tSN:APMT01218215.1\tLN:5621\n@SQ\tSN:KB710781.1\tLN:5619\n@SQ\tSN:APMT01218213.1\tLN:5619\n@SQ\tSN:APMT01218214.1\tLN:5619\n@SQ\tSN:KB712195.1\tLN:5618\n@SQ\tSN:APMT01218022.1\tLN:5617\n@SQ\tSN:APMT01218216.1\tLN:5615\n@SQ\tSN:APMT01218151.1\tLN:5614\n@SQ\tSN:APMT01217744.1\tLN:5613\n@SQ\tSN:KB710799.1\tLN:5613\n@SQ\tSN:APMT01218225.1\tLN:5612\n@SQ\tSN:APMT01218226.1\tLN:5612\n@SQ\tSN:APMT01218227.1\tLN:5612\n@SQ\tSN:KB710784.1\tLN:5611\n@SQ\tSN:APMT01218229.1\tLN:5609\n@SQ\tSN:KB709981.1\tLN:5608\n@SQ\tSN:APMT01218199.1\tLN:5608\n@SQ\tSN:APMT01218170.1\tLN:5605\n@SQ\tSN:APMT01218235.1\tLN:5605\n@SQ\tSN:APMT01218236.1\tLN:5605\n@SQ\tSN:APMT01218237.1\tLN:5605\n@SQ\tSN:APMT01218238.1\tLN:5605\n@SQ\tSN:KB710818.1\tLN:5604\n@SQ\tSN:APMT01218228.1\tLN:5603\n@SQ\tSN:APMT01218244.1\tLN:5601\n@SQ\tSN:APMT01218247.1\tLN:5600\n@SQ\tSN:KB711346.1\tLN:5600\n@SQ\tSN:KB712445.1\tLN:5600\n@SQ\tSN:KB710806.1\tLN:5597\n@SQ\tSN:APMT01218250.1\tLN:5597\n@SQ\tSN:APMT01218118.1\tLN:5595\n@SQ\tSN:APMT01218256.1\tLN:5595\n@SQ\tSN:KB710794.1\tLN:5594\n@SQ\tSN:APMT01218263.1\tLN:5594\n@SQ\tSN:APMT01218264.1\tLN:5594\n@SQ\tSN:APMT01218202.1\tLN:5593\n@SQ\tSN:APMT01218267.1\tLN:5593\n@SQ\tSN:APMT01218268.1\tLN:5593\n@SQ\tSN:APMT01218269.1\tLN:5591\n@SQ\tSN:KB710888.1\tLN:5590\n@SQ\tSN:KB711425.1\tLN:5589\n@SQ\tSN:KB711854.1\tLN:5587\n@SQ\tSN:KB710750.1\tLN:5586\n@SQ\tSN:APMT01218278.1\tLN:5586\n@SQ\tSN:APMT01218189.1\tLN:5585\n@SQ\tSN:APMT01218280.1\tLN:5584\n@SQ\tSN:APMT01218281.1\tLN:5584\n@SQ\tSN:APMT01218306.1\tLN:5584\n@SQ\tSN:APMT01218090.1\tLN:5582\n@SQ\tSN:APMT01218282.1\tLN:5582\n@SQ\tSN:APMT01218288.1\tLN:5580\n@SQ\tSN:APMT01218292.1\tLN:5576\n@SQ\tSN:KB710828.1\tLN:5575\n@SQ\tSN:APMT01218119.1\tLN:5574\n@SQ\tSN:KB710791.1\tLN:5573\n@SQ\tSN:APMT01218305.1\tLN:5573\n@SQ\tSN:APMT01218307.1\tLN:5572\n@SQ\tSN:APMT01218311.1\tLN:5572\n@SQ\tSN:KB710839.1\tLN:5570\n@SQ\tSN:KB710783.1\tLN:5569\n@SQ\tSN:APMT01218318.1\tLN:5569\n@SQ\tSN:APMT01218319.1\tLN:5568\n@SQ\tSN:KB710801.1\tLN:5567\n@SQ\tSN:KB710817.1\tLN:5565\n@SQ\tSN:APMT01218326.1\tLN:5565\n@SQ\tSN:KB709892.1\tLN:5560\n@SQ\tSN:APMT01218329.1\tLN:5560\n@SQ\tSN:APMT01218331.1\tLN:5560\n@SQ\tSN:APMT01218332.1\tLN:5560\n@SQ\tSN:KB710776.1\tLN:5559\n@SQ\tSN:APMT01218327.1\tLN:5559\n@SQ\tSN:APMT01218336.1\tLN:5558\n@SQ\tSN:KB710733.1\tLN:5557\n@SQ\tSN:KB710827.1\tLN:5556\n@SQ\tSN:KB710860.1\tLN:5556\n@SQ\tSN:KB711935.1\tLN:5556\n@SQ\tSN:KB710802.1\tLN:5555\n@SQ\tSN:APMT01218279.1\tLN:5555\n@SQ\tSN:KB710786.1\tLN:5554\n@SQ\tSN:APMT01218248.1\tLN:5554\n@SQ\tSN:APMT01218346.1\tLN:5554\n@SQ\tSN:APMT01218220.1\tLN:5553\n@SQ\tSN:APMT01218230.1\tLN:5553\n@SQ\tSN:APMT01218231.1\tLN:5553\n@SQ\tSN:KB711025.1\tLN:5553\n@SQ\tSN:APMT01218347.1\tLN:5552\n@SQ\tSN:KB710825.1\tLN:5551\n@SQ\tSN:KB711147.1\tLN:5551\n@SQ\tSN:APMT01218351.1\tLN:5550\n@SQ\tSN:KB710767.1\tLN:5549\n@SQ\tSN:APMT01218315.1\tLN:5549\n@SQ\tSN:APMT01218249.1\tLN:5548\n@SQ\tSN:APMT01218352.1\tLN:5548\n@SQ\tSN:APMT01218353.1\tLN:5548\n@SQ\tSN:APMT01218354.1\tLN:5547\n@SQ\tSN:APMT01218266.1\tLN:5545\n@SQ\tSN:APMT01218355.1\tLN:5545\n@SQ\tSN:APMT01218359.1\tLN:5543\n@SQ\tSN:KB710919.1\tLN:5543\n@SQ\tSN:APMT01218361.1\tLN:5542\n@SQ\tSN:APMT01218362.1\tLN:5542\n@SQ\tSN:APMT01218363.1\tLN:5541\n@SQ\tSN:KB710793.1\tLN:5540\n@SQ\tSN:APMT01218367.1\tLN:5540\n@SQ\tSN:APMT01232983.1\tLN:5540\n@SQ\tSN:APMT01218255.1\tLN:5539\n@SQ\tSN:APMT01218293.1\tLN:5538\n@SQ\tSN:KB712083.1\tLN:5537\n@SQ\tSN:KB711451.1\tLN:5535\n@SQ\tSN:KB710840.1\tLN:5532\n@SQ\tSN:APMT01218384.1\tLN:5532\n@SQ\tSN:APMT01218385.1\tLN:5532\n@SQ\tSN:APMT01218314.1\tLN:5530\n@SQ\tSN:APMT01218389.1\tLN:5530\n@SQ\tSN:KB710807.1\tLN:5529\n@SQ\tSN:APMT01218396.1\tLN:5528\n@SQ\tSN:KB711067.1\tLN:5528\n@SQ\tSN:KB711938.1\tLN:5528\n@SQ\tSN:APMT01218391.1\tLN:5527\n@SQ\tSN:APMT01218328.1\tLN:5526\n@SQ\tSN:APMT01218392.1\tLN:5526\n@SQ\tSN:APMT01218393.1\tLN:5526\n@SQ\tSN:APMT01218287.1\tLN:5525\n@SQ\tSN:APMT01218394.1\tLN:5525\n@SQ\tSN:APMT01218395.1\tLN:5525\n@SQ\tSN:APMT01218397.1\tLN:5525\n@SQ\tSN:APMT01218398.1\tLN:5524\n@SQ\tSN:APMT01218295.1\tLN:5522\n@SQ\tSN:APMT01218408.1\tLN:5522\n@SQ\tSN:APMT01218457.1\tLN:5522\n@SQ\tSN:KB710809.1\tLN:5521\n@SQ\tSN:KB709933.1\tLN:5520\n@SQ\tSN:APMT01218410.1\tLN:5520\n@SQ\tSN:APMT01218411.1\tLN:5520\n@SQ\tSN:KB710756.1\tLN:5518\n@SQ\tSN:KB710737.1\tLN:5517\n@SQ\tSN:APMT01218294.1\tLN:5517\n@SQ\tSN:KB710678.1\tLN:5516\n@SQ\tSN:APMT01218360.1\tLN:5516\n@SQ\tSN:APMT01218420.1\tLN:5515\n@SQ\tSN:KB710824.1\tLN:5514\n@SQ\tSN:APMT01218419.1\tLN:5514\n@SQ\tSN:APMT01218422.1\tLN:5514\n@SQ\tSN:APMT01218423.1\tLN:5514\n@SQ\tSN:APMT01218296.1\tLN:5513\n@SQ\tSN:APMT01218342.1\tLN:5513\n@SQ\tSN:APMT01218424.1\tLN:5513\n@SQ\tSN:APMT01218428.1\tLN:5513\n@SQ\tSN:APMT01218429.1\tLN:5513\n@SQ\tSN:APMT01218399.1\tLN:5512\n@SQ\tSN:APMT01218403.1\tLN:5512\n@SQ\tSN:APMT01218356.1\tLN:5511\n@SQ\tSN:KB710898.1\tLN:5511\n@SQ\tSN:KB711195.1\tLN:5511\n@SQ\tSN:APMT01218430.1\tLN:5510\n@SQ\tSN:KB710668.1\tLN:5509\n@SQ\tSN:KB710866.1\tLN:5509\n@SQ\tSN:APMT01218437.1\tLN:5507\n@SQ\tSN:APMT01218438.1\tLN:5505\n@SQ\tSN:KB711133.1\tLN:5505\n@SQ\tSN:APMT01218439.1\tLN:5504\n@SQ\tSN:KB711126.1\tLN:5504\n@SQ\tSN:APMT01218440.1\tLN:5503\n@SQ\tSN:KB710811.1\tLN:5501\n@SQ\tSN:APMT01218443.1\tLN:5501\n@SQ\tSN:KB710728.1\tLN:5500\n@SQ\tSN:KB710729.1\tLN:5500\n@SQ\tSN:APMT01218337.1\tLN:5500\n@SQ\tSN:APMT01218377.1\tLN:5500\n@SQ\tSN:KB711366.1\tLN:5500\n@SQ\tSN:APMT01218330.1\tLN:5499\n@SQ\tSN:APMT01218421.1\tLN:5499\n@SQ\tSN:APMT01218451.1\tLN:5499\n@SQ\tSN:APMT01218450.1\tLN:5498\n@SQ\tSN:KB710865.1\tLN:5497\n@SQ\tSN:KB711337.1\tLN:5497\n@SQ\tSN:KB710846.1\tLN:5495\n@SQ\tSN:APMT01218470.1\tLN:5495\n@SQ\tSN:APMT01218584.1\tLN:5494\n@SQ\tSN:KB711332.1\tLN:5494\n@SQ\tSN:APMT01218390.1\tLN:5492\n@SQ\tSN:KB710804.1\tLN:5491\n@SQ\tSN:KB711279.1\tLN:5489\n@SQ\tSN:APMT01218461.1\tLN:5488\n@SQ\tSN:APMT01218462.1\tLN:5488\n@SQ\tSN:APMT01218265.1\tLN:5487\n@SQ\tSN:KB710914.1\tLN:5487\n@SQ\tSN:APMT01218463.1\tLN:5485\n@SQ\tSN:KB710789.1\tLN:5484\n@SQ\tSN:APMT01218465.1\tLN:5484\n@SQ\tSN:KB711400.1\tLN:5484\n@SQ\tSN:APMT01218466.1\tLN:5483\n@SQ\tSN:KB711586.1\tLN:5480\n@SQ\tSN:KB711524.1\tLN:5479\n@SQ\tSN:KB711070.1\tLN:5478\n@SQ\tSN:APMT01218475.1\tLN:5474\n@SQ\tSN:KB710831.1\tLN:5473\n@SQ\tSN:KB710821.1\tLN:5472\n@SQ\tSN:APMT01218476.1\tLN:5472\n@SQ\tSN:APMT01218479.1\tLN:5470\n@SQ\tSN:KB710878.1\tLN:5470\n@SQ\tSN:KB710837.1\tLN:5469\n@SQ\tSN:APMT01218480.1\tLN:5469\n@SQ\tSN:KB710707.1\tLN:5467\n@SQ\tSN:APMT01218487.1\tLN:5464\n@SQ\tSN:APMT01218492.1\tLN:5464\n@SQ\tSN:APMT01218416.1\tLN:5463\n@SQ\tSN:APMT01218494.1\tLN:5462\n@SQ\tSN:KB710907.1\tLN:5462\n@SQ\tSN:KB710848.1\tLN:5460\n@SQ\tSN:APMT01218496.1\tLN:5458\n@SQ\tSN:KB710955.1\tLN:5458\n@SQ\tSN:KB710754.1\tLN:5456\n@SQ\tSN:APMT01218508.1\tLN:5455\n@SQ\tSN:APMT01218509.1\tLN:5455\n@SQ\tSN:APMT01218409.1\tLN:5454\n@SQ\tSN:KB710868.1\tLN:5454\n@SQ\tSN:APMT01218510.1\tLN:5454\n@SQ\tSN:APMT01218452.1\tLN:5450\n@SQ\tSN:APMT01218526.1\tLN:5450\n@SQ\tSN:KB710094.1\tLN:5449\n@SQ\tSN:APMT01218506.1\tLN:5448\n@SQ\tSN:APMT01218527.1\tLN:5447\n@SQ\tSN:APMT01218528.1\tLN:5446\n@SQ\tSN:KB710655.1\tLN:5445\n@SQ\tSN:KB710874.1\tLN:5445\n@SQ\tSN:APMT01218537.1\tLN:5443\n@SQ\tSN:APMT01218540.1\tLN:5443\n@SQ\tSN:KB711931.1\tLN:5443\n@SQ\tSN:KB710882.1\tLN:5442\n@SQ\tSN:APMT01218541.1\tLN:5442\n@SQ\tSN:KB711409.1\tLN:5442\n@SQ\tSN:APMT01218532.1\tLN:5441\n@SQ\tSN:APMT01218545.1\tLN:5441\n@SQ\tSN:APMT01218546.1\tLN:5441\n@SQ\tSN:APMT01218547.1\tLN:5439\n@SQ\tSN:APMT01218548.1\tLN:5438\n@SQ\tSN:KB710850.1\tLN:5436\n@SQ\tSN:APMT01218456.1\tLN:5436\n@SQ\tSN:APMT01218464.1\tLN:5435\n@SQ\tSN:APMT01218468.1\tLN:5434\n@SQ\tSN:APMT01218576.1\tLN:5434\n@SQ\tSN:APMT01218559.1\tLN:5432\n@SQ\tSN:APMT01218562.1\tLN:5431\n@SQ\tSN:KB710808.1\tLN:5430\n@SQ\tSN:APMT01218493.1\tLN:5430\n@SQ\tSN:APMT01218495.1\tLN:5430\n@SQ\tSN:KB710864.1\tLN:5429\n@SQ\tSN:APMT01218518.1\tLN:5429\n@SQ\tSN:APMT01218563.1\tLN:5429\n@SQ\tSN:KB711318.1\tLN:5429\n@SQ\tSN:KB710743.1\tLN:5428\n@SQ\tSN:KB710891.1\tLN:5428\n@SQ\tSN:KB710981.1\tLN:5428\n@SQ\tSN:KB710830.1\tLN:5427\n@SQ\tSN:APMT01218469.1\tLN:5427\n@SQ\tSN:APMT01218566.1\tLN:5427\n@SQ\tSN:KB710478.1\tLN:5426\n@SQ\tSN:KB710761.1\tLN:5426\n@SQ\tSN:APMT01218378.1\tLN:5424\n@SQ\tSN:APMT01218467.1\tLN:5424\n@SQ\tSN:KB710890.1\tLN:5424\n@SQ\tSN:KB710181.1\tLN:5421\n@SQ\tSN:APMT01218511.1\tLN:5421\n@SQ\tSN:KB711100.1\tLN:5421\n@SQ\tSN:KB710853.1\tLN:5419\n@SQ\tSN:APMT01218575.1\tLN:5419\n@SQ\tSN:KB710803.1\tLN:5418\n@SQ\tSN:APMT01218404.1\tLN:5418\n@SQ\tSN:APMT01218571.1\tLN:5418\n@SQ\tSN:KB711363.1\tLN:5418\n@SQ\tSN:APMT01218581.1\tLN:5417\n@SQ\tSN:APMT01218549.1\tLN:5416\n@SQ\tSN:APMT01218564.1\tLN:5416\n@SQ\tSN:APMT01218580.1\tLN:5416\n@SQ\tSN:APMT01218582.1\tLN:5416\n@SQ\tSN:APMT01218583.1\tLN:5416\n@SQ\tSN:APMT01218539.1\tLN:5414\n@SQ\tSN:KB710855.1\tLN:5413\n@SQ\tSN:KB711286.1\tLN:5413\n@SQ\tSN:APMT01218477.1\tLN:5412\n@SQ\tSN:KB710883.1\tLN:5412\n@SQ\tSN:APMT01218590.1\tLN:5412\n@SQ\tSN:APMT01218591.1\tLN:5410\n@SQ\tSN:APMT01218598.1\tLN:5407\n@SQ\tSN:KB710906.1\tLN:5407\n@SQ\tSN:KB711300.1\tLN:5407\n@SQ\tSN:APMT01218599.1\tLN:5406\n@SQ\tSN:APMT01218521.1\tLN:5405\n@SQ\tSN:APMT01218601.1\tLN:5405\n@SQ\tSN:KB710832.1\tLN:5404\n@SQ\tSN:KB711200.1\tLN:5404\n@SQ\tSN:APMT01218604.1\tLN:5403\n@SQ\tSN:KB711367.1\tLN:5403\n@SQ\tSN:APMT01218602.1\tLN:5402\n@SQ\tSN:APMT01218612.1\tLN:5400\n@SQ\tSN:KB710800.1\tLN:5398\n@SQ\tSN:APMT01218613.1\tLN:5398\n@SQ\tSN:APMT01218614.1\tLN:5398\n@SQ\tSN:KB712477.1\tLN:5398\n@SQ\tSN:APMT01218605.1\tLN:5395\n@SQ\tSN:APMT01218436.1\tLN:5394\n@SQ\tSN:APMT01218618.1\tLN:5394\n@SQ\tSN:KB711097.1\tLN:5394\n@SQ\tSN:KB710913.1\tLN:5393\n@SQ\tSN:KB712485.1\tLN:5391\n@SQ\tSN:APMT01218624.1\tLN:5390\n@SQ\tSN:APMT01218625.1\tLN:5390\n@SQ\tSN:APMT01218507.1\tLN:5389\n@SQ\tSN:APMT01218623.1\tLN:5389\n@SQ\tSN:KB711199.1\tLN:5389\n@SQ\tSN:APMT01218626.1\tLN:5388\n@SQ\tSN:KB711330.1\tLN:5387\n@SQ\tSN:APMT01218630.1\tLN:5386\n@SQ\tSN:APMT01218597.1\tLN:5385\n@SQ\tSN:KB710833.1\tLN:5384\n@SQ\tSN:APMT01218634.1\tLN:5384\n@SQ\tSN:KB710214.1\tLN:5383\n@SQ\tSN:APMT01218635.1\tLN:5382\n@SQ\tSN:KB710731.1\tLN:5381\n@SQ\tSN:APMT01218538.1\tLN:5381\n@SQ\tSN:KB711483.1\tLN:5381\n@SQ\tSN:APMT01218637.1\tLN:5380\n@SQ\tSN:APMT01218641.1\tLN:5380\n@SQ\tSN:APMT01218574.1\tLN:5379\n@SQ\tSN:KB710982.1\tLN:5378\n@SQ\tSN:APMT01218565.1\tLN:5375\n@SQ\tSN:APMT01218649.1\tLN:5375\n@SQ\tSN:KB711514.1\tLN:5375\n@SQ\tSN:APMT01218558.1\tLN:5373\n@SQ\tSN:APMT01218648.1\tLN:5373\n@SQ\tSN:KB710993.1\tLN:5373\n@SQ\tSN:KB710858.1\tLN:5372\n@SQ\tSN:KB710875.1\tLN:5372\n@SQ\tSN:APMT01218650.1\tLN:5372\n@SQ\tSN:KB710829.1\tLN:5371\n@SQ\tSN:APMT01218603.1\tLN:5367\n@SQ\tSN:APMT01218652.1\tLN:5367\n@SQ\tSN:KB711198.1\tLN:5367\n@SQ\tSN:KB711343.1\tLN:5367\n@SQ\tSN:APMT01218654.1\tLN:5366\n@SQ\tSN:KB710646.1\tLN:5365\n@SQ\tSN:APMT01218570.1\tLN:5365\n@SQ\tSN:APMT01218655.1\tLN:5365\n@SQ\tSN:KB711533.1\tLN:5365\n@SQ\tSN:APMT01218656.1\tLN:5364\n@SQ\tSN:APMT01218478.1\tLN:5363\n@SQ\tSN:APMT01218653.1\tLN:5363\n@SQ\tSN:APMT01218657.1\tLN:5363\n@SQ\tSN:APMT01218596.1\tLN:5362\n@SQ\tSN:APMT01218633.1\tLN:5362\n@SQ\tSN:KB711943.1\tLN:5361\n@SQ\tSN:APMT01218658.1\tLN:5359\n@SQ\tSN:KB710796.1\tLN:5358\n@SQ\tSN:APMT01218661.1\tLN:5357\n@SQ\tSN:APMT01218662.1\tLN:5356\n@SQ\tSN:KB710805.1\tLN:5355\n@SQ\tSN:APMT01218663.1\tLN:5355\n@SQ\tSN:APMT01218665.1\tLN:5355\n@SQ\tSN:KB710857.1\tLN:5354\n@SQ\tSN:KB710959.1\tLN:5354\n@SQ\tSN:APMT01218673.1\tLN:5351\n@SQ\tSN:APMT01218674.1\tLN:5351\n@SQ\tSN:APMT01218600.1\tLN:5349\n@SQ\tSN:KB711776.1\tLN:5349\n@SQ\tSN:APMT01218622.1\tLN:5348\n@SQ\tSN:APMT01218678.1\tLN:5348\n@SQ\tSN:APMT01218679.1\tLN:5348\n@SQ\tSN:KB710284.1\tLN:5347\n@SQ\tSN:APMT01218557.1\tLN:5345\n@SQ\tSN:APMT01218684.1\tLN:5345\n@SQ\tSN:KB711397.1\tLN:5345\n@SQ\tSN:APMT01218685.1\tLN:5344\n@SQ\tSN:APMT01218686.1\tLN:5344\n@SQ\tSN:APMT01218691.1\tLN:5343\n@SQ\tSN:KB710877.1\tLN:5342\n@SQ\tSN:KB710863.1\tLN:5341\n@SQ\tSN:APMT01218636.1\tLN:5340\n@SQ\tSN:APMT01218692.1\tLN:5340\n@SQ\tSN:KB711981.1\tLN:5340\n@SQ\tSN:APMT01218693.1\tLN:5339\n@SQ\tSN:KB711769.1\tLN:5337\n@SQ\tSN:APMT01218615.1\tLN:5336\n@SQ\tSN:APMT01218694.1\tLN:5336\n@SQ\tSN:APMT01218695.1\tLN:5336\n@SQ\tSN:KB711035.1\tLN:5336\n@SQ\tSN:KB710879.1\tLN:5334\n@SQ\tSN:APMT01218705.1\tLN:5331\n@SQ\tSN:KB712147.1\tLN:5331\n@SQ\tSN:KB710897.1\tLN:5330\n@SQ\tSN:KB710872.1\tLN:5327\n@SQ\tSN:APMT01218712.1\tLN:5327\n@SQ\tSN:APMT01218713.1\tLN:5327\n@SQ\tSN:KB711287.1\tLN:5325\n@SQ\tSN:KB710844.1\tLN:5324\n@SQ\tSN:KB710885.1\tLN:5324\n@SQ\tSN:KB710991.1\tLN:5323\n@SQ\tSN:APMT01218664.1\tLN:5322\n@SQ\tSN:KB710915.1\tLN:5322\n@SQ\tSN:APMT01218720.1\tLN:5321\n@SQ\tSN:APMT01218721.1\tLN:5319\n@SQ\tSN:APMT01218722.1\tLN:5318\n@SQ\tSN:APMT01218651.1\tLN:5317\n@SQ\tSN:APMT01218723.1\tLN:5316\n@SQ\tSN:APMT01218724.1\tLN:5316\n@SQ\tSN:KB710777.1\tLN:5312\n@SQ\tSN:KB710759.1\tLN:5309\n@SQ\tSN:KB710869.1\tLN:5308\n@SQ\tSN:APMT01218735.1\tLN:5307\n@SQ\tSN:KB711278.1\tLN:5306\n@SQ\tSN:APMT01218737.1\tLN:5305\n@SQ\tSN:APMT01218738.1\tLN:5305\n@SQ\tSN:KB711066.1\tLN:5305\n@SQ\tSN:KB710889.1\tLN:5304\n@SQ\tSN:APMT01218739.1\tLN:5304\n@SQ\tSN:KB710867.1\tLN:5303\n@SQ\tSN:APMT01218740.1\tLN:5303\n@SQ\tSN:KB711084.1\tLN:5303\n@SQ\tSN:APMT01218716.1\tLN:5301\n@SQ\tSN:APMT01218741.1\tLN:5301\n@SQ\tSN:APMT01218743.1\tLN:5301\n@SQ\tSN:APMT01218711.1\tLN:5299\n@SQ\tSN:APMT01218751.1\tLN:5299\n@SQ\tSN:APMT01218714.1\tLN:5298\n@SQ\tSN:APMT01218752.1\tLN:5298\n@SQ\tSN:KB710417.1\tLN:5295\n@SQ\tSN:KB710909.1\tLN:5295\n@SQ\tSN:APMT01218754.1\tLN:5294\n@SQ\tSN:APMT01218750.1\tLN:5293\n@SQ\tSN:KB711446.1\tLN:5293\n@SQ\tSN:KB710886.1\tLN:5291\n@SQ\tSN:APMT01218736.1\tLN:5291\n@SQ\tSN:APMT01218755.1\tLN:5291\n@SQ\tSN:APMT01218762.1\tLN:5290\n@SQ\tSN:APMT01218759.1\tLN:5289\n@SQ\tSN:APMT01218760.1\tLN:5289\n@SQ\tSN:APMT01218761.1\tLN:5289\n@SQ\tSN:KB710871.1\tLN:5286\n@SQ\tSN:KB710973.1\tLN:5286\n@SQ\tSN:APMT01218765.1\tLN:5285\n@SQ\tSN:APMT01218769.1\tLN:5285\n@SQ\tSN:KB711796.1\tLN:5284\n@SQ\tSN:APMT01218770.1\tLN:5283\n@SQ\tSN:APMT01218690.1\tLN:5282\n@SQ\tSN:APMT01218764.1\tLN:5282\n@SQ\tSN:APMT01218774.1\tLN:5280\n@SQ\tSN:APMT01218781.1\tLN:5279\n@SQ\tSN:KB711339.1\tLN:5278\n@SQ\tSN:KB710815.1\tLN:5277\n@SQ\tSN:KB711285.1\tLN:5276\n@SQ\tSN:APMT01218783.1\tLN:5275\n@SQ\tSN:APMT01218704.1\tLN:5273\n@SQ\tSN:APMT01218793.1\tLN:5271\n@SQ\tSN:APMT01218715.1\tLN:5270\n@SQ\tSN:KB711718.1\tLN:5269\n@SQ\tSN:APMT01218795.1\tLN:5268\n@SQ\tSN:KB710917.1\tLN:5267\n@SQ\tSN:APMT01218797.1\tLN:5266\n@SQ\tSN:APMT01218800.1\tLN:5266\n@SQ\tSN:APMT01218782.1\tLN:5265\n@SQ\tSN:APMT01218798.1\tLN:5265\n@SQ\tSN:APMT01218799.1\tLN:5265\n@SQ\tSN:APMT01218805.1\tLN:5263\n@SQ\tSN:APMT01218796.1\tLN:5262\n@SQ\tSN:APMT01218806.1\tLN:5262\n@SQ\tSN:APMT01218647.1\tLN:5261\n@SQ\tSN:APMT01218763.1\tLN:5261\n@SQ\tSN:APMT01218804.1\tLN:5261\n@SQ\tSN:APMT01218807.1\tLN:5260\n@SQ\tSN:KB711587.1\tLN:5259\n@SQ\tSN:APMT01218789.1\tLN:5258\n@SQ\tSN:APMT01218728.1\tLN:5255\n@SQ\tSN:APMT01218812.1\tLN:5255\n@SQ\tSN:APMT01218819.1\tLN:5253\n@SQ\tSN:APMT01218820.1\tLN:5252\n@SQ\tSN:APMT01218821.1\tLN:5252\n@SQ\tSN:APMT01218725.1\tLN:5251\n@SQ\tSN:APMT01218826.1\tLN:5247\n@SQ\tSN:APMT01218794.1\tLN:5244\n@SQ\tSN:APMT01218827.1\tLN:5244\n@SQ\tSN:APMT01218828.1\tLN:5244\n@SQ\tSN:KB710722.1\tLN:5240\n@SQ\tSN:APMT01218744.1\tLN:5240\n@SQ\tSN:APMT01218813.1\tLN:5239\n@SQ\tSN:APMT01218835.1\tLN:5239\n@SQ\tSN:APMT01218836.1\tLN:5239\n@SQ\tSN:KB711447.1\tLN:5238\n@SQ\tSN:APMT01218841.1\tLN:5235\n@SQ\tSN:KB711453.1\tLN:5235\n@SQ\tSN:APMT01218842.1\tLN:5234\n@SQ\tSN:APMT01218843.1\tLN:5234\n@SQ\tSN:APMT01218844.1\tLN:5234\n@SQ\tSN:KB710937.1\tLN:5233\n@SQ\tSN:APMT01218845.1\tLN:5232\n@SQ\tSN:KB711150.1\tLN:5232\n@SQ\tSN:APMT01218855.1\tLN:5231\n@SQ\tSN:APMT01218854.1\tLN:5228\n@SQ\tSN:APMT01218788.1\tLN:5226\n@SQ\tSN:APMT01218742.1\tLN:5223\n@SQ\tSN:APMT01218859.1\tLN:5223\n@SQ\tSN:KB712067.1\tLN:5223\n@SQ\tSN:APMT01218866.1\tLN:5220\n@SQ\tSN:APMT01218822.1\tLN:5219\n@SQ\tSN:APMT01218811.1\tLN:5218\n@SQ\tSN:APMT01218872.1\tLN:5218\n@SQ\tSN:APMT01218873.1\tLN:5218\n@SQ\tSN:KB710951.1\tLN:5218\n@SQ\tSN:APMT01218874.1\tLN:5216\n@SQ\tSN:KB710621.1\tLN:5215\n@SQ\tSN:APMT01218877.1\tLN:5214\n@SQ\tSN:KB712244.1\tLN:5212\n@SQ\tSN:KB710934.1\tLN:5211\n@SQ\tSN:APMT01218886.1\tLN:5206\n@SQ\tSN:APMT01218888.1\tLN:5204\n@SQ\tSN:KB710819.1\tLN:5203\n@SQ\tSN:APMT01218889.1\tLN:5203\n@SQ\tSN:KB711412.1\tLN:5203\n@SQ\tSN:KB711633.1\tLN:5202\n@SQ\tSN:APMT01218893.1\tLN:5201\n@SQ\tSN:APMT01218871.1\tLN:5199\n@SQ\tSN:APMT01218881.1\tLN:5199\n@SQ\tSN:KB710938.1\tLN:5197\n@SQ\tSN:APMT01218846.1\tLN:5195\n@SQ\tSN:APMT01218865.1\tLN:5194\n@SQ\tSN:APMT01218818.1\tLN:5193\n@SQ\tSN:APMT01218905.1\tLN:5193\n@SQ\tSN:KB710902.1\tLN:5192\n@SQ\tSN:APMT01218814.1\tLN:5192\n@SQ\tSN:APMT01218815.1\tLN:5192\n@SQ\tSN:KB710940.1\tLN:5192\n@SQ\tSN:APMT01218907.1\tLN:5192\n@SQ\tSN:APMT01218908.1\tLN:5192\n@SQ\tSN:APMT01218912.1\tLN:5189\n@SQ\tSN:APMT01218913.1\tLN:5187\n@SQ\tSN:APMT01218914.1\tLN:5187\n@SQ\tSN:KB710552.1\tLN:5186\n@SQ\tSN:APMT01218916.1\tLN:5186\n@SQ\tSN:APMT01218915.1\tLN:5185\n@SQ\tSN:APMT01218904.1\tLN:5184\n@SQ\tSN:APMT01218923.1\tLN:5182\n@SQ\tSN:KB710812.1\tLN:5181\n@SQ\tSN:APMT01218924.1\tLN:5181\n@SQ\tSN:APMT01218925.1\tLN:5181\n@SQ\tSN:KB711689.1\tLN:5180\n@SQ\tSN:KB711884.1\tLN:5180\n@SQ\tSN:KB710925.1\tLN:5178\n@SQ\tSN:APMT01218933.1\tLN:5178\n@SQ\tSN:APMT01218934.1\tLN:5177\n@SQ\tSN:APMT01218753.1\tLN:5176\n@SQ\tSN:APMT01218935.1\tLN:5174\n@SQ\tSN:APMT01218936.1\tLN:5174\n@SQ\tSN:KB711163.1\tLN:5174\n@SQ\tSN:APMT01218850.1\tLN:5173\n@SQ\tSN:APMT01218945.1\tLN:5170\n@SQ\tSN:KB710922.1\tLN:5169\n@SQ\tSN:KB710987.1\tLN:5169\n@SQ\tSN:KB711293.1\tLN:5168\n@SQ\tSN:KB710820.1\tLN:5167\n@SQ\tSN:APMT01218926.1\tLN:5167\n@SQ\tSN:APMT01218951.1\tLN:5167\n@SQ\tSN:APMT01218952.1\tLN:5167\n@SQ\tSN:APMT01218954.1\tLN:5167\n@SQ\tSN:KB712132.1\tLN:5166\n@SQ\tSN:APMT01218956.1\tLN:5165\n@SQ\tSN:KB710936.1\tLN:5160\n@SQ\tSN:APMT01218885.1\tLN:5159\n@SQ\tSN:APMT01218966.1\tLN:5159\n@SQ\tSN:APMT01218967.1\tLN:5159\n@SQ\tSN:APMT01218968.1\tLN:5159\n@SQ\tSN:APMT01218969.1\tLN:5159\n@SQ\tSN:KB711659.1\tLN:5159\n@SQ\tSN:APMT01218965.1\tLN:5153\n@SQ\tSN:APMT01218974.1\tLN:5153\n@SQ\tSN:KB710985.1\tLN:5152\n@SQ\tSN:APMT01218880.1\tLN:5151\n@SQ\tSN:APMT01218975.1\tLN:5151\n@SQ\tSN:KB711388.1\tLN:5151\n@SQ\tSN:APMT01218976.1\tLN:5150\n@SQ\tSN:APMT01218977.1\tLN:5149\n@SQ\tSN:KB710903.1\tLN:5147\n@SQ\tSN:APMT01218984.1\tLN:5146\n@SQ\tSN:APMT01218998.1\tLN:5146\n@SQ\tSN:APMT01218887.1\tLN:5144\n@SQ\tSN:APMT01218937.1\tLN:5144\n@SQ\tSN:APMT01218991.1\tLN:5144\n@SQ\tSN:APMT01218992.1\tLN:5144\n@SQ\tSN:KB710994.1\tLN:5144\n@SQ\tSN:KB710929.1\tLN:5143\n@SQ\tSN:KB710921.1\tLN:5141\n@SQ\tSN:APMT01218946.1\tLN:5141\n@SQ\tSN:APMT01218999.1\tLN:5141\n@SQ\tSN:APMT01219000.1\tLN:5141\n@SQ\tSN:APMT01218953.1\tLN:5140\n@SQ\tSN:APMT01218895.1\tLN:5139\n@SQ\tSN:APMT01218955.1\tLN:5138\n@SQ\tSN:APMT01219001.1\tLN:5138\n@SQ\tSN:KB710956.1\tLN:5136\n@SQ\tSN:KB710461.1\tLN:5134\n@SQ\tSN:APMT01219006.1\tLN:5134\n@SQ\tSN:KB710774.1\tLN:5133\n@SQ\tSN:APMT01218906.1\tLN:5132\n@SQ\tSN:APMT01219007.1\tLN:5132\n@SQ\tSN:KB711104.1\tLN:5132\n@SQ\tSN:APMT01219011.1\tLN:5130\n@SQ\tSN:KB711006.1\tLN:5130\n@SQ\tSN:APMT01219019.1\tLN:5125\n@SQ\tSN:APMT01219020.1\tLN:5125\n@SQ\tSN:KB710843.1\tLN:5124\n@SQ\tSN:APMT01219018.1\tLN:5124\n@SQ\tSN:APMT01219021.1\tLN:5124\n@SQ\tSN:APMT01219023.1\tLN:5123\n@SQ\tSN:KB711041.1\tLN:5123\n@SQ\tSN:APMT01219024.1\tLN:5122\n@SQ\tSN:APMT01219030.1\tLN:5120\n@SQ\tSN:APMT01219031.1\tLN:5120\n@SQ\tSN:KB712216.1\tLN:5120\n@SQ\tSN:APMT01219041.1\tLN:5116\n@SQ\tSN:APMT01219042.1\tLN:5115\n@SQ\tSN:APMT01218840.1\tLN:5114\n@SQ\tSN:APMT01219043.1\tLN:5114\n@SQ\tSN:APMT01219026.1\tLN:5112\n@SQ\tSN:APMT01218983.1\tLN:5111\n@SQ\tSN:APMT01219044.1\tLN:5111\n@SQ\tSN:APMT01219045.1\tLN:5111\n@SQ\tSN:APMT01218894.1\tLN:5110\n@SQ\tSN:APMT01219049.1\tLN:5109\n@SQ\tSN:APMT01219050.1\tLN:5109\n@SQ\tSN:APMT01219052.1\tLN:5109\n@SQ\tSN:APMT01219022.1\tLN:5108\n@SQ\tSN:KB710968.1\tLN:5107\n@SQ\tSN:APMT01219054.1\tLN:5107\n@SQ\tSN:APMT01219055.1\tLN:5107\n@SQ\tSN:APMT01219056.1\tLN:5107\n@SQ\tSN:APMT01219057.1\tLN:5106\n@SQ\tSN:APMT01219058.1\tLN:5105\n@SQ\tSN:APMT01219059.1\tLN:5105\n@SQ\tSN:KB710977.1\tLN:5105\n@SQ\tSN:APMT01218973.1\tLN:5104\n@SQ\tSN:APMT01219060.1\tLN:5104\n@SQ\tSN:APMT01219066.1\tLN:5099\n@SQ\tSN:APMT01219067.1\tLN:5098\n@SQ\tSN:APMT01218938.1\tLN:5097\n@SQ\tSN:APMT01219073.1\tLN:5096\n@SQ\tSN:KB710930.1\tLN:5095\n@SQ\tSN:APMT01219074.1\tLN:5095\n@SQ\tSN:APMT01219076.1\tLN:5094\n@SQ\tSN:APMT01219077.1\tLN:5090\n@SQ\tSN:APMT01219078.1\tLN:5090\n@SQ\tSN:APMT01219079.1\tLN:5090\n@SQ\tSN:APMT01219061.1\tLN:5088\n@SQ\tSN:KB710983.1\tLN:5087\n@SQ\tSN:APMT01219083.1\tLN:5086\n@SQ\tSN:APMT01219084.1\tLN:5086\n@SQ\tSN:KB710923.1\tLN:5084\n@SQ\tSN:KB710926.1\tLN:5083\n@SQ\tSN:APMT01219089.1\tLN:5082\n@SQ\tSN:KB710892.1\tLN:5081\n@SQ\tSN:APMT01218997.1\tLN:5081\n@SQ\tSN:APMT01219090.1\tLN:5081\n@SQ\tSN:KB711075.1\tLN:5081\n@SQ\tSN:APMT01219098.1\tLN:5079\n@SQ\tSN:APMT01219099.1\tLN:5078\n@SQ\tSN:APMT01219104.1\tLN:5077\n@SQ\tSN:KB711215.1\tLN:5077\n@SQ\tSN:KB711714.1\tLN:5077\n@SQ\tSN:APMT01219069.1\tLN:5074\n@SQ\tSN:APMT01219014.1\tLN:5073\n@SQ\tSN:KB710975.1\tLN:5073\n@SQ\tSN:APMT01219115.1\tLN:5073\n@SQ\tSN:APMT01219013.1\tLN:5072\n@SQ\tSN:APMT01219117.1\tLN:5072\n@SQ\tSN:KB711016.1\tLN:5072\n@SQ\tSN:APMT01219118.1\tLN:5071\n@SQ\tSN:KB710941.1\tLN:5070\n@SQ\tSN:APMT01219012.1\tLN:5070\n@SQ\tSN:APMT01219123.1\tLN:5070\n@SQ\tSN:APMT01219125.1\tLN:5068\n@SQ\tSN:APMT01219126.1\tLN:5068\n@SQ\tSN:APMT01219127.1\tLN:5068\n@SQ\tSN:APMT01219128.1\tLN:5065\n@SQ\tSN:APMT01219129.1\tLN:5065\n@SQ\tSN:KB710652.1\tLN:5063\n@SQ\tSN:KB710895.1\tLN:5063\n@SQ\tSN:APMT01218939.1\tLN:5063\n@SQ\tSN:APMT01219068.1\tLN:5063\n@SQ\tSN:APMT01219134.1\tLN:5061\n@SQ\tSN:APMT01219136.1\tLN:5061\n@SQ\tSN:APMT01219135.1\tLN:5059\n@SQ\tSN:APMT01219140.1\tLN:5059\n@SQ\tSN:KB711732.1\tLN:5058\n@SQ\tSN:KB712134.1\tLN:5058\n@SQ\tSN:KB710920.1\tLN:5055\n@SQ\tSN:APMT01219025.1\tLN:5055\n@SQ\tSN:APMT01219036.1\tLN:5055\n@SQ\tSN:APMT01219142.1\tLN:5055\n@SQ\tSN:APMT01219143.1\tLN:5055\n@SQ\tSN:APMT01219144.1\tLN:5055\n@SQ\tSN:KB711385.1\tLN:5055\n@SQ\tSN:APMT01219146.1\tLN:5054\n@SQ\tSN:APMT01219141.1\tLN:5053\n@SQ\tSN:APMT01219147.1\tLN:5053\n@SQ\tSN:APMT01219053.1\tLN:5052\n@SQ\tSN:APMT01219148.1\tLN:5052\n@SQ\tSN:APMT01219149.1\tLN:5052\n@SQ\tSN:KB712227.1\tLN:5052\n@SQ\tSN:APMT01219150.1\tLN:5051\n@SQ\tSN:APMT01219070.1\tLN:5050\n@SQ\tSN:APMT01219151.1\tLN:5050\n@SQ\tSN:APMT01219051.1\tLN:5049\n@SQ\tSN:APMT01219158.1\tLN:5043\n@SQ\tSN:APMT01219075.1\tLN:5042\n@SQ\tSN:KB710932.1\tLN:5039\n@SQ\tSN:APMT01219160.1\tLN:5039\n@SQ\tSN:APMT01219034.1\tLN:5038\n@SQ\tSN:KB711181.1\tLN:5037\n@SQ\tSN:KB711083.1\tLN:5035\n@SQ\tSN:APMT01219171.1\tLN:5031\n@SQ\tSN:APMT01219173.1\tLN:5030\n@SQ\tSN:APMT01219082.1\tLN:5029\n@SQ\tSN:APMT01219169.1\tLN:5029\n@SQ\tSN:APMT01219170.1\tLN:5029\n@SQ\tSN:APMT01219176.1\tLN:5026\n@SQ\tSN:APMT01219180.1\tLN:5026\n@SQ\tSN:KB711611.1\tLN:5026\n@SQ\tSN:APMT01219175.1\tLN:5025\n@SQ\tSN:KB711160.1\tLN:5025\n@SQ\tSN:APMT01219105.1\tLN:5024\n@SQ\tSN:APMT01219184.1\tLN:5023\n@SQ\tSN:APMT01219185.1\tLN:5023\n@SQ\tSN:KB711564.1\tLN:5022\n@SQ\tSN:APMT01219035.1\tLN:5021\n@SQ\tSN:APMT01219190.1\tLN:5020\n@SQ\tSN:KB710944.1\tLN:5019\n@SQ\tSN:APMT01219196.1\tLN:5018\n@SQ\tSN:APMT01219103.1\tLN:5017\n@SQ\tSN:APMT01219133.1\tLN:5017\n@SQ\tSN:APMT01219195.1\tLN:5017\n@SQ\tSN:APMT01219198.1\tLN:5016\n@SQ\tSN:APMT01219145.1\tLN:5015\n@SQ\tSN:APMT01219200.1\tLN:5014\n@SQ\tSN:APMT01218957.1\tLN:5012\n@SQ\tSN:APMT01219210.1\tLN:5011\n@SQ\tSN:APMT01219209.1\tLN:5010\n@SQ\tSN:APMT01219161.1\tLN:5009\n@SQ\tSN:APMT01219197.1\tLN:5009\n@SQ\tSN:APMT01219211.1\tLN:5009\n@SQ\tSN:APMT01219212.1\tLN:5009\n@SQ\tSN:APMT01219213.1\tLN:5009\n@SQ\tSN:APMT01219214.1\tLN:5008\n@SQ\tSN:APMT01219216.1\tLN:5007\n@SQ\tSN:APMT01219217.1\tLN:5007\n@SQ\tSN:APMT01219222.1\tLN:5006\n@SQ\tSN:KB713127.1\tLN:5005\n@SQ\tSN:APMT01219221.1\tLN:5003\n@SQ\tSN:APMT01219228.1\tLN:5003\n@SQ\tSN:APMT01219215.1\tLN:5002\n@SQ\tSN:APMT01219229.1\tLN:5002\n@SQ\tSN:KB711420.1\tLN:5002\n@SQ\tSN:KB711148.1\tLN:5000\n@SQ\tSN:KB710772.1\tLN:4999\n@SQ\tSN:APMT01219124.1\tLN:4998\n@SQ\tSN:KB710841.1\tLN:4997\n@SQ\tSN:APMT01219232.1\tLN:4997\n@SQ\tSN:APMT01219119.1\tLN:4996\n@SQ\tSN:APMT01219189.1\tLN:4995\n@SQ\tSN:APMT01219194.1\tLN:4995\n@SQ\tSN:APMT01219199.1\tLN:4994\n@SQ\tSN:KB710995.1\tLN:4994\n@SQ\tSN:APMT01219204.1\tLN:4994\n@SQ\tSN:APMT01219233.1\tLN:4994\n@SQ\tSN:KB710950.1\tLN:4993\n@SQ\tSN:KB711140.1\tLN:4993\n@SQ\tSN:KB710949.1\tLN:4992\n@SQ\tSN:KB710999.1\tLN:4992\n@SQ\tSN:APMT01219235.1\tLN:4992\n@SQ\tSN:KB710976.1\tLN:4991\n@SQ\tSN:APMT01219157.1\tLN:4991\n@SQ\tSN:APMT01219236.1\tLN:4989\n@SQ\tSN:APMT01219245.1\tLN:4988\n@SQ\tSN:KB710984.1\tLN:4987\n@SQ\tSN:APMT01219246.1\tLN:4986\n@SQ\tSN:APMT01219247.1\tLN:4986\n@SQ\tSN:APMT01219248.1\tLN:4986\n@SQ\tSN:KB711257.1\tLN:4986\n@SQ\tSN:KB710140.1\tLN:4985\n@SQ\tSN:KB710971.1\tLN:4984\n@SQ\tSN:KB710947.1\tLN:4982\n@SQ\tSN:APMT01219163.1\tLN:4981\n@SQ\tSN:APMT01219159.1\tLN:4980\n@SQ\tSN:APMT01219259.1\tLN:4980\n@SQ\tSN:APMT01219260.1\tLN:4980\n@SQ\tSN:APMT01219261.1\tLN:4980\n@SQ\tSN:APMT01219264.1\tLN:4979\n@SQ\tSN:APMT01219263.1\tLN:4977\n@SQ\tSN:APMT01219162.1\tLN:4976\n@SQ\tSN:KB712174.1\tLN:4976\n@SQ\tSN:APMT01219267.1\tLN:4975\n@SQ\tSN:KB711632.1\tLN:4973\n@SQ\tSN:APMT01219268.1\tLN:4972\n@SQ\tSN:APMT01219174.1\tLN:4971\n@SQ\tSN:KB710969.1\tLN:4970\n@SQ\tSN:KB710904.1\tLN:4969\n@SQ\tSN:APMT01219172.1\tLN:4969\n@SQ\tSN:APMT01219385.1\tLN:4969\n@SQ\tSN:KB712211.1\tLN:4965\n@SQ\tSN:KB711141.1\tLN:4964\n@SQ\tSN:KB711228.1\tLN:4964\n@SQ\tSN:APMT01219085.1\tLN:4962\n@SQ\tSN:APMT01219193.1\tLN:4960\n@SQ\tSN:APMT01219208.1\tLN:4959\n@SQ\tSN:APMT01219271.1\tLN:4958\n@SQ\tSN:APMT01219272.1\tLN:4957\n@SQ\tSN:APMT01219273.1\tLN:4956\n@SQ\tSN:KB711047.1\tLN:4956\n@SQ\tSN:APMT01219275.1\tLN:4955\n@SQ\tSN:APMT01219203.1\tLN:4954\n@SQ\tSN:APMT01219226.1\tLN:4954\n@SQ\tSN:APMT01219278.1\tLN:4954\n@SQ\tSN:KB710980.1\tLN:4953\n@SQ\tSN:APMT01219205.1\tLN:4953\n@SQ\tSN:KB710972.1\tLN:4947\n@SQ\tSN:APMT01219290.1\tLN:4947\n@SQ\tSN:KB711407.1\tLN:4947\n@SQ\tSN:KB711056.1\tLN:4946\n@SQ\tSN:KB711281.1\tLN:4946\n@SQ\tSN:APMT01219296.1\tLN:4945\n@SQ\tSN:APMT01219294.1\tLN:4944\n@SQ\tSN:APMT01219227.1\tLN:4943\n@SQ\tSN:APMT01219299.1\tLN:4943\n@SQ\tSN:KB711272.1\tLN:4943\n@SQ\tSN:KB711122.1\tLN:4942\n@SQ\tSN:APMT01219303.1\tLN:4941\n@SQ\tSN:APMT01219305.1\tLN:4940\n@SQ\tSN:APMT01219298.1\tLN:4939\n@SQ\tSN:KB711012.1\tLN:4939\n@SQ\tSN:APMT01219270.1\tLN:4938\n@SQ\tSN:APMT01219306.1\tLN:4938\n@SQ\tSN:APMT01219307.1\tLN:4938\n@SQ\tSN:KB712433.1\tLN:4938\n@SQ\tSN:KB710954.1\tLN:4936\n@SQ\tSN:APMT01219310.1\tLN:4934\n@SQ\tSN:APMT01219234.1\tLN:4933\n@SQ\tSN:APMT01219311.1\tLN:4933\n@SQ\tSN:APMT01219313.1\tLN:4932\n@SQ\tSN:APMT01219308.1\tLN:4931\n@SQ\tSN:APMT01219309.1\tLN:4931\n@SQ\tSN:APMT01219312.1\tLN:4931\n@SQ\tSN:APMT01219315.1\tLN:4930\n@SQ\tSN:KB710967.1\tLN:4929\n@SQ\tSN:KB711009.1\tLN:4929\n@SQ\tSN:APMT01219314.1\tLN:4929\n@SQ\tSN:KB711149.1\tLN:4929\n@SQ\tSN:APMT01219316.1\tLN:4928\n@SQ\tSN:KB711117.1\tLN:4927\n@SQ\tSN:KB711015.1\tLN:4925\n@SQ\tSN:APMT01219295.1\tLN:4924\n@SQ\tSN:KB712158.1\tLN:4923\n@SQ\tSN:KB712116.1\tLN:4922\n@SQ\tSN:APMT01219262.1\tLN:4921\n@SQ\tSN:APMT01219269.1\tLN:4919\n@SQ\tSN:APMT01219326.1\tLN:4919\n@SQ\tSN:APMT01219327.1\tLN:4919\n@SQ\tSN:APMT01219328.1\tLN:4918\n@SQ\tSN:APMT01219330.1\tLN:4916\n@SQ\tSN:KB712844.1\tLN:4914\n@SQ\tSN:KB711002.1\tLN:4911\n@SQ\tSN:APMT01219336.1\tLN:4909\n@SQ\tSN:KB710961.1\tLN:4908\n@SQ\tSN:KB711036.1\tLN:4908\n@SQ\tSN:KB711113.1\tLN:4907\n@SQ\tSN:APMT01219186.1\tLN:4906\n@SQ\tSN:KB712363.1\tLN:4905\n@SQ\tSN:KB711093.1\tLN:4904\n@SQ\tSN:APMT01219274.1\tLN:4903\n@SQ\tSN:APMT01219348.1\tLN:4903\n@SQ\tSN:APMT01219350.1\tLN:4902\n@SQ\tSN:APMT01219325.1\tLN:4901\n@SQ\tSN:KB710942.1\tLN:4900\n@SQ\tSN:APMT01219353.1\tLN:4899\n@SQ\tSN:APMT01219355.1\tLN:4897\n@SQ\tSN:APMT01219352.1\tLN:4896\n@SQ\tSN:APMT01219354.1\tLN:4896\n@SQ\tSN:APMT01219356.1\tLN:4896\n@SQ\tSN:APMT01219283.1\tLN:4895\n@SQ\tSN:APMT01219426.1\tLN:4895\n@SQ\tSN:KB710933.1\tLN:4892\n@SQ\tSN:APMT01219279.1\tLN:4892\n@SQ\tSN:APMT01219360.1\tLN:4892\n@SQ\tSN:APMT01219359.1\tLN:4891\n@SQ\tSN:APMT01219361.1\tLN:4891\n@SQ\tSN:KB710908.1\tLN:4890\n@SQ\tSN:KB710965.1\tLN:4890\n@SQ\tSN:APMT01219362.1\tLN:4890\n@SQ\tSN:APMT01219297.1\tLN:4888\n@SQ\tSN:APMT01219365.1\tLN:4888\n@SQ\tSN:APMT01219368.1\tLN:4887\n@SQ\tSN:APMT01219369.1\tLN:4887\n@SQ\tSN:APMT01219345.1\tLN:4883\n@SQ\tSN:APMT01219373.1\tLN:4883\n@SQ\tSN:KB710952.1\tLN:4882\n@SQ\tSN:KB710998.1\tLN:4882\n@SQ\tSN:APMT01219304.1\tLN:4882\n@SQ\tSN:APMT01219329.1\tLN:4882\n@SQ\tSN:APMT01219374.1\tLN:4882\n@SQ\tSN:APMT01219375.1\tLN:4882\n@SQ\tSN:APMT01219377.1\tLN:4881\n@SQ\tSN:KB712946.1\tLN:4881\n@SQ\tSN:APMT01219380.1\tLN:4880\n@SQ\tSN:APMT01219381.1\tLN:4879\n@SQ\tSN:APMT01219382.1\tLN:4879\n@SQ\tSN:APMT01219383.1\tLN:4879\n@SQ\tSN:KB711010.1\tLN:4877\n@SQ\tSN:APMT01219331.1\tLN:4876\n@SQ\tSN:APMT01219418.1\tLN:4876\n@SQ\tSN:APMT01219389.1\tLN:4875\n@SQ\tSN:APMT01219390.1\tLN:4875\n@SQ\tSN:KB712361.1\tLN:4875\n@SQ\tSN:APMT01219391.1\tLN:4874\n@SQ\tSN:APMT01219395.1\tLN:4873\n@SQ\tSN:KB711455.1\tLN:4871\n@SQ\tSN:KB710788.1\tLN:4870\n@SQ\tSN:APMT01219399.1\tLN:4870\n@SQ\tSN:APMT01219400.1\tLN:4869\n@SQ\tSN:APMT01219405.1\tLN:4866\n@SQ\tSN:APMT01219411.1\tLN:4863\n@SQ\tSN:KB711144.1\tLN:4863\n@SQ\tSN:KB711360.1\tLN:4863\n@SQ\tSN:KB710884.1\tLN:4862\n@SQ\tSN:APMT01219344.1\tLN:4862\n@SQ\tSN:APMT01219412.1\tLN:4862\n@SQ\tSN:APMT01219427.1\tLN:4862\n@SQ\tSN:APMT01219421.1\tLN:4861\n@SQ\tSN:KB711028.1\tLN:4860\n@SQ\tSN:APMT01219425.1\tLN:4859\n@SQ\tSN:KB710974.1\tLN:4858\n@SQ\tSN:APMT01219432.1\tLN:4858\n@SQ\tSN:KB711020.1\tLN:4857\n@SQ\tSN:APMT01219433.1\tLN:4857\n@SQ\tSN:KB711034.1\tLN:4856\n@SQ\tSN:APMT01219346.1\tLN:4853\n@SQ\tSN:KB711271.1\tLN:4852\n@SQ\tSN:KB711031.1\tLN:4851\n@SQ\tSN:APMT01219439.1\tLN:4851\n@SQ\tSN:KB711841.1\tLN:4851\n@SQ\tSN:KB712267.1\tLN:4851\n@SQ\tSN:APMT01219386.1\tLN:4850\n@SQ\tSN:APMT01219440.1\tLN:4850\n@SQ\tSN:APMT01219335.1\tLN:4849\n@SQ\tSN:APMT01219441.1\tLN:4849\n@SQ\tSN:APMT01219442.1\tLN:4849\n@SQ\tSN:KB711053.1\tLN:4849\n@SQ\tSN:APMT01219347.1\tLN:4848\n@SQ\tSN:APMT01219349.1\tLN:4848\n@SQ\tSN:KB710894.1\tLN:4845\n@SQ\tSN:APMT01219419.1\tLN:4845\n@SQ\tSN:APMT01219446.1\tLN:4845\n@SQ\tSN:APMT01219447.1\tLN:4845\n@SQ\tSN:APMT01219448.1\tLN:4845\n@SQ\tSN:APMT01219449.1\tLN:4844\n@SQ\tSN:APMT01219450.1\tLN:4842\n@SQ\tSN:APMT01219456.1\tLN:4842\n@SQ\tSN:APMT01219457.1\tLN:4842\n@SQ\tSN:APMT01219462.1\tLN:4841\n@SQ\tSN:APMT01219463.1\tLN:4841\n@SQ\tSN:KB711045.1\tLN:4841\n@SQ\tSN:APMT01219351.1\tLN:4839\n@SQ\tSN:KB711575.1\tLN:4839\n@SQ\tSN:APMT01219468.1\tLN:4837\n@SQ\tSN:KB711058.1\tLN:4837\n@SQ\tSN:KB711677.1\tLN:4837\n@SQ\tSN:APMT01219472.1\tLN:4836\n@SQ\tSN:KB711043.1\tLN:4834\n@SQ\tSN:APMT01219573.1\tLN:4832\n@SQ\tSN:KB712846.1\tLN:4832\n@SQ\tSN:APMT01219479.1\tLN:4830\n@SQ\tSN:KB711050.1\tLN:4830\n@SQ\tSN:KB711051.1\tLN:4830\n@SQ\tSN:APMT01219376.1\tLN:4829\n@SQ\tSN:APMT01219480.1\tLN:4829\n@SQ\tSN:KB711046.1\tLN:4829\n@SQ\tSN:KB712592.1\tLN:4829\n@SQ\tSN:KB711049.1\tLN:4828\n@SQ\tSN:APMT01219484.1\tLN:4827\n@SQ\tSN:APMT01219485.1\tLN:4827\n@SQ\tSN:APMT01219483.1\tLN:4826\n@SQ\tSN:APMT01219487.1\tLN:4826\n@SQ\tSN:KB711074.1\tLN:4826\n@SQ\tSN:KB710505.1\tLN:4825\n@SQ\tSN:KB710978.1\tLN:4825\n@SQ\tSN:APMT01219488.1\tLN:4825\n@SQ\tSN:KB712003.1\tLN:4825\n@SQ\tSN:KB713051.1\tLN:4823\n@SQ\tSN:APMT01219492.1\tLN:4822\n@SQ\tSN:APMT01219493.1\tLN:4822\n@SQ\tSN:APMT01219494.1\tLN:4822\n@SQ\tSN:APMT01219495.1\tLN:4821\n@SQ\tSN:KB712728.1\tLN:4821\n@SQ\tSN:APMT01219498.1\tLN:4820\n@SQ\tSN:APMT01219499.1\tLN:4820\n@SQ\tSN:APMT01219500.1\tLN:4820\n@SQ\tSN:KB711076.1\tLN:4820\n@SQ\tSN:APMT01219503.1\tLN:4819\n@SQ\tSN:KB711197.1\tLN:4818\n@SQ\tSN:APMT01219420.1\tLN:4817\n@SQ\tSN:APMT01219504.1\tLN:4817\n@SQ\tSN:APMT01219506.1\tLN:4817\n@SQ\tSN:APMT01219507.1\tLN:4816\n@SQ\tSN:APMT01219505.1\tLN:4814\n@SQ\tSN:KB711030.1\tLN:4813\n@SQ\tSN:APMT01219513.1\tLN:4813\n@SQ\tSN:APMT01219514.1\tLN:4813\n@SQ\tSN:KB711092.1\tLN:4811\n@SQ\tSN:APMT01219404.1\tLN:4810\n@SQ\tSN:KB711024.1\tLN:4809\n@SQ\tSN:APMT01219531.1\tLN:4808\n@SQ\tSN:APMT01219532.1\tLN:4807\n@SQ\tSN:KB711071.1\tLN:4807\n@SQ\tSN:APMT01219414.1\tLN:4806\n@SQ\tSN:APMT01219533.1\tLN:4806\n@SQ\tSN:APMT01219534.1\tLN:4806\n@SQ\tSN:KB710964.1\tLN:4805\n@SQ\tSN:APMT01219545.1\tLN:4804\n@SQ\tSN:APMT01219547.1\tLN:4803\n@SQ\tSN:APMT01219548.1\tLN:4803\n@SQ\tSN:APMT01219437.1\tLN:4801\n@SQ\tSN:APMT01219436.1\tLN:4798\n@SQ\tSN:APMT01219553.1\tLN:4797\n@SQ\tSN:APMT01219554.1\tLN:4796\n@SQ\tSN:APMT01219555.1\tLN:4796\n@SQ\tSN:APMT01219556.1\tLN:4796\n@SQ\tSN:APMT01219557.1\tLN:4794\n@SQ\tSN:KB711629.1\tLN:4794\n@SQ\tSN:APMT01219384.1\tLN:4793\n@SQ\tSN:APMT01219523.1\tLN:4793\n@SQ\tSN:APMT01219558.1\tLN:4793\n@SQ\tSN:APMT01219559.1\tLN:4793\n@SQ\tSN:KB711080.1\tLN:4792\n@SQ\tSN:APMT01219438.1\tLN:4791\n@SQ\tSN:KB711059.1\tLN:4790\n@SQ\tSN:APMT01219562.1\tLN:4790\n@SQ\tSN:APMT01219563.1\tLN:4790\n@SQ\tSN:KB710671.1\tLN:4789\n@SQ\tSN:APMT01219561.1\tLN:4789\n@SQ\tSN:APMT01219564.1\tLN:4789\n@SQ\tSN:KB711061.1\tLN:4788\n@SQ\tSN:APMT01219565.1\tLN:4787\n@SQ\tSN:APMT01219461.1\tLN:4786\n@SQ\tSN:APMT01219568.1\tLN:4786\n@SQ\tSN:APMT01219572.1\tLN:4785\n@SQ\tSN:APMT01219571.1\tLN:4783\n@SQ\tSN:KB712325.1\tLN:4783\n@SQ\tSN:APMT01219575.1\tLN:4782\n@SQ\tSN:APMT01219574.1\tLN:4780\n@SQ\tSN:APMT01219577.1\tLN:4780\n@SQ\tSN:APMT01219460.1\tLN:4779\n@SQ\tSN:KB711953.1\tLN:4778\n@SQ\tSN:APMT01219486.1\tLN:4777\n@SQ\tSN:KB711261.1\tLN:4774\n@SQ\tSN:KB711810.1\tLN:4773\n@SQ\tSN:KB711477.1\tLN:4772\n@SQ\tSN:APMT01219592.1\tLN:4771\n@SQ\tSN:APMT01219596.1\tLN:4770\n@SQ\tSN:APMT01219597.1\tLN:4770\n@SQ\tSN:APMT01219598.1\tLN:4770\n@SQ\tSN:KB711404.1\tLN:4770\n@SQ\tSN:KB711033.1\tLN:4769\n@SQ\tSN:APMT01219605.1\tLN:4768\n@SQ\tSN:KB712107.1\tLN:4768\n@SQ\tSN:KB710989.1\tLN:4767\n@SQ\tSN:KB711543.1\tLN:4766\n@SQ\tSN:APMT01219617.1\tLN:4765\n@SQ\tSN:KB713147.1\tLN:4765\n@SQ\tSN:KB711064.1\tLN:4764\n@SQ\tSN:APMT01219616.1\tLN:4763\n@SQ\tSN:APMT01219619.1\tLN:4763\n@SQ\tSN:APMT01219508.1\tLN:4762\n@SQ\tSN:KB711464.1\tLN:4762\n@SQ\tSN:APMT01219591.1\tLN:4761\n@SQ\tSN:APMT01219627.1\tLN:4761\n@SQ\tSN:KB711014.1\tLN:4760\n@SQ\tSN:KB710420.1\tLN:4759\n@SQ\tSN:KB711068.1\tLN:4759\n@SQ\tSN:KB711018.1\tLN:4758\n@SQ\tSN:APMT01219633.1\tLN:4757\n@SQ\tSN:KB711065.1\tLN:4756\n@SQ\tSN:APMT01219635.1\tLN:4756\n@SQ\tSN:APMT01219636.1\tLN:4755\n@SQ\tSN:KB711095.1\tLN:4755\n@SQ\tSN:KB711023.1\tLN:4754\n@SQ\tSN:APMT01219637.1\tLN:4754\n@SQ\tSN:APMT01219644.1\tLN:4753\n@SQ\tSN:APMT01219646.1\tLN:4752\n@SQ\tSN:KB710738.1\tLN:4751\n@SQ\tSN:KB711563.1\tLN:4750\n@SQ\tSN:APMT01219445.1\tLN:4747\n@SQ\tSN:APMT01219632.1\tLN:4747\n@SQ\tSN:APMT01219649.1\tLN:4746\n@SQ\tSN:APMT01219650.1\tLN:4746\n@SQ\tSN:APMT01219540.1\tLN:4745\n@SQ\tSN:APMT01219473.1\tLN:4744\n@SQ\tSN:APMT01219651.1\tLN:4743\n@SQ\tSN:APMT01219570.1\tLN:4742\n@SQ\tSN:APMT01219546.1\tLN:4741\n@SQ\tSN:APMT01219552.1\tLN:4739\n@SQ\tSN:APMT01219655.1\tLN:4739\n@SQ\tSN:APMT01219656.1\tLN:4739\n@SQ\tSN:APMT01219658.1\tLN:4738\n@SQ\tSN:APMT01219659.1\tLN:4738\n@SQ\tSN:APMT01219660.1\tLN:4738\n@SQ\tSN:APMT01219661.1\tLN:4738\n@SQ\tSN:APMT01219604.1\tLN:4736\n@SQ\tSN:KB711101.1\tLN:4735\n@SQ\tSN:KB711103.1\tLN:4735\n@SQ\tSN:KB711914.1\tLN:4735\n@SQ\tSN:APMT01219665.1\tLN:4734\n@SQ\tSN:KB711091.1\tLN:4734\n@SQ\tSN:APMT01219560.1\tLN:4731\n@SQ\tSN:APMT01219671.1\tLN:4731\n@SQ\tSN:APMT01219672.1\tLN:4731\n@SQ\tSN:APMT01219676.1\tLN:4731\n@SQ\tSN:APMT01219680.1\tLN:4730\n@SQ\tSN:KB711450.1\tLN:4730\n@SQ\tSN:KB711491.1\tLN:4730\n@SQ\tSN:APMT01219684.1\tLN:4729\n@SQ\tSN:APMT01219687.1\tLN:4728\n@SQ\tSN:APMT01219688.1\tLN:4728\n@SQ\tSN:APMT01219569.1\tLN:4727\n@SQ\tSN:APMT01219689.1\tLN:4727\n@SQ\tSN:APMT01219690.1\tLN:4727\n@SQ\tSN:KB713573.1\tLN:4726\n@SQ\tSN:APMT01219603.1\tLN:4725\n@SQ\tSN:APMT01219576.1\tLN:4724\n@SQ\tSN:APMT01219694.1\tLN:4723\n@SQ\tSN:APMT01219695.1\tLN:4723\n@SQ\tSN:APMT01219618.1\tLN:4722\n@SQ\tSN:KB714206.1\tLN:4722\n@SQ\tSN:KB711026.1\tLN:4720\n@SQ\tSN:APMT01219696.1\tLN:4720\n@SQ\tSN:APMT01219701.1\tLN:4720\n@SQ\tSN:APMT01219704.1\tLN:4719\n@SQ\tSN:KB711094.1\tLN:4719\n@SQ\tSN:APMT01219693.1\tLN:4718\n@SQ\tSN:APMT01219705.1\tLN:4717\n@SQ\tSN:APMT01219711.1\tLN:4717\n@SQ\tSN:KB711085.1\tLN:4716\n@SQ\tSN:KB711146.1\tLN:4716\n@SQ\tSN:KB711250.1\tLN:4716\n@SQ\tSN:APMT01219713.1\tLN:4714\n@SQ\tSN:APMT01219599.1\tLN:4713\n@SQ\tSN:APMT01219647.1\tLN:4713\n@SQ\tSN:APMT01219714.1\tLN:4713\n@SQ\tSN:KB711055.1\tLN:4712\n@SQ\tSN:KB711515.1\tLN:4712\n@SQ\tSN:APMT01219716.1\tLN:4711\n@SQ\tSN:APMT01219724.1\tLN:4710\n@SQ\tSN:KB711580.1\tLN:4710\n@SQ\tSN:KB711105.1\tLN:4709\n@SQ\tSN:KB711114.1\tLN:4709\n@SQ\tSN:APMT01219606.1\tLN:4708\n@SQ\tSN:APMT01219645.1\tLN:4707\n@SQ\tSN:KB712440.1\tLN:4707\n@SQ\tSN:KB711073.1\tLN:4706\n@SQ\tSN:APMT01219715.1\tLN:4706\n@SQ\tSN:APMT01219626.1\tLN:4705\n@SQ\tSN:KB710996.1\tLN:4703\n@SQ\tSN:APMT01219670.1\tLN:4703\n@SQ\tSN:APMT01219736.1\tLN:4703\n@SQ\tSN:APMT01219737.1\tLN:4703\n@SQ\tSN:APMT01219648.1\tLN:4702\n@SQ\tSN:APMT01219738.1\tLN:4702\n@SQ\tSN:APMT01219739.1\tLN:4700\n@SQ\tSN:APMT01219742.1\tLN:4699\n@SQ\tSN:KB710854.1\tLN:4698\n@SQ\tSN:KB711179.1\tLN:4698\n@SQ\tSN:KB710957.1\tLN:4697\n@SQ\tSN:KB710876.1\tLN:4695\n@SQ\tSN:KB711096.1\tLN:4693\n@SQ\tSN:KB711088.1\tLN:4692\n@SQ\tSN:APMT01219751.1\tLN:4691\n@SQ\tSN:KB712981.1\tLN:4691\n@SQ\tSN:APMT01219760.1\tLN:4690\n@SQ\tSN:APMT01219657.1\tLN:4689\n@SQ\tSN:APMT01219761.1\tLN:4689\n@SQ\tSN:APMT01219710.1\tLN:4688\n@SQ\tSN:APMT01219743.1\tLN:4688\n@SQ\tSN:KB713394.1\tLN:4688\n@SQ\tSN:KB710970.1\tLN:4687\n@SQ\tSN:APMT01219652.1\tLN:4687\n@SQ\tSN:APMT01219763.1\tLN:4686\n@SQ\tSN:APMT01219772.1\tLN:4686\n@SQ\tSN:KB712493.1\tLN:4686\n@SQ\tSN:KB711060.1\tLN:4685\n@SQ\tSN:APMT01219662.1\tLN:4685\n@SQ\tSN:KB711082.1\tLN:4684\n@SQ\tSN:APMT01219774.1\tLN:4684\n@SQ\tSN:APMT01219775.1\tLN:4684\n@SQ\tSN:KB711090.1\tLN:4683\n@SQ\tSN:APMT01219773.1\tLN:4683\n@SQ\tSN:KB710383.1\tLN:4682\n@SQ\tSN:APMT01219768.1\tLN:4682\n@SQ\tSN:APMT01219781.1\tLN:4682\n@SQ\tSN:KB711857.1\tLN:4682\n@SQ\tSN:KB713092.1\tLN:4680\n@SQ\tSN:APMT01219784.1\tLN:4679\n@SQ\tSN:APMT01219787.1\tLN:4678\n@SQ\tSN:KB711086.1\tLN:4677\n@SQ\tSN:APMT01219789.1\tLN:4676\n@SQ\tSN:KB711116.1\tLN:4676\n@SQ\tSN:KB711110.1\tLN:4675\n@SQ\tSN:KB711211.1\tLN:4675\n@SQ\tSN:KB711378.1\tLN:4674\n@SQ\tSN:KB711107.1\tLN:4673\n@SQ\tSN:APMT01219794.1\tLN:4673\n@SQ\tSN:APMT01219795.1\tLN:4673\n@SQ\tSN:APMT01219628.1\tLN:4672\n@SQ\tSN:APMT01219798.1\tLN:4672\n@SQ\tSN:APMT01219801.1\tLN:4671\n@SQ\tSN:APMT01219803.1\tLN:4670\n@SQ\tSN:APMT01219804.1\tLN:4670\n@SQ\tSN:APMT01219805.1\tLN:4670\n@SQ\tSN:KB711139.1\tLN:4670\n@SQ\tSN:KB710997.1\tLN:4669\n@SQ\tSN:APMT01219677.1\tLN:4669\n@SQ\tSN:APMT01219807.1\tLN:4668\n@SQ\tSN:KB711723.1\tLN:4668\n@SQ\tSN:KB711797.1\tLN:4668\n@SQ\tSN:APMT01219732.1\tLN:4667\n@SQ\tSN:APMT01219735.1\tLN:4667\n@SQ\tSN:APMT01219808.1\tLN:4667\n@SQ\tSN:APMT01219809.1\tLN:4664\n@SQ\tSN:APMT01219806.1\tLN:4663\n@SQ\tSN:APMT01219815.1\tLN:4663\n@SQ\tSN:APMT01219816.1\tLN:4662\n@SQ\tSN:APMT01219818.1\tLN:4660\n@SQ\tSN:APMT01219719.1\tLN:4659\n@SQ\tSN:APMT01219819.1\tLN:4659\n@SQ\tSN:APMT01219820.1\tLN:4659\n@SQ\tSN:APMT01219725.1\tLN:4658\n@SQ\tSN:APMT01219821.1\tLN:4658\n@SQ\tSN:APMT01219822.1\tLN:4657\n@SQ\tSN:APMT01219823.1\tLN:4657\n@SQ\tSN:APMT01219802.1\tLN:4656\n@SQ\tSN:APMT01219824.1\tLN:4656\n@SQ\tSN:APMT01219712.1\tLN:4653\n@SQ\tSN:APMT01219826.1\tLN:4653\n@SQ\tSN:KB711124.1\tLN:4653\n@SQ\tSN:KB711219.1\tLN:4653\n@SQ\tSN:KB711077.1\tLN:4652\n@SQ\tSN:APMT01219827.1\tLN:4652\n@SQ\tSN:APMT01219829.1\tLN:4651\n@SQ\tSN:APMT01219811.1\tLN:4650\n@SQ\tSN:APMT01219830.1\tLN:4650\n@SQ\tSN:KB711177.1\tLN:4650\n@SQ\tSN:KB711430.1\tLN:4650\n@SQ\tSN:KB711062.1\tLN:4649\n@SQ\tSN:APMT01219831.1\tLN:4649\n@SQ\tSN:APMT01219834.1\tLN:4649\n@SQ\tSN:APMT01219835.1\tLN:4649\n@SQ\tSN:KB712412.1\tLN:4649\n@SQ\tSN:APMT01219839.1\tLN:4648\n@SQ\tSN:APMT01219843.1\tLN:4646\n@SQ\tSN:APMT01219846.1\tLN:4645\n@SQ\tSN:KB711501.1\tLN:4645\n@SQ\tSN:APMT01219842.1\tLN:4644\n@SQ\tSN:APMT01219847.1\tLN:4644\n@SQ\tSN:APMT01219810.1\tLN:4643\n@SQ\tSN:APMT01219844.1\tLN:4643\n@SQ\tSN:APMT01219848.1\tLN:4643\n@SQ\tSN:KB712535.1\tLN:4642\n@SQ\tSN:APMT01219849.1\tLN:4641\n@SQ\tSN:APMT01219828.1\tLN:4639\n@SQ\tSN:APMT01219850.1\tLN:4639\n@SQ\tSN:APMT01219851.1\tLN:4638\n@SQ\tSN:KB711658.1\tLN:4638\n@SQ\tSN:APMT01219855.1\tLN:4637\n@SQ\tSN:APMT01219856.1\tLN:4637\n@SQ\tSN:APMT01219858.1\tLN:4637\n@SQ\tSN:APMT01219861.1\tLN:4636\n@SQ\tSN:APMT01219862.1\tLN:4636\n@SQ\tSN:APMT01219413.1\tLN:4634\n@SQ\tSN:APMT01219750.1\tLN:4634\n@SQ\tSN:APMT01219857.1\tLN:4634\n@SQ\tSN:APMT01219863.1\tLN:4634\n@SQ\tSN:APMT01219866.1\tLN:4633\n@SQ\tSN:APMT01219867.1\tLN:4633\n@SQ\tSN:APMT01219876.1\tLN:4629\n@SQ\tSN:APMT01219762.1\tLN:4628\n@SQ\tSN:KB711214.1\tLN:4628\n@SQ\tSN:APMT01219771.1\tLN:4625\n@SQ\tSN:KB711112.1\tLN:4625\n@SQ\tSN:APMT01219877.1\tLN:4625\n@SQ\tSN:APMT01219882.1\tLN:4625\n@SQ\tSN:APMT01219883.1\tLN:4625\n@SQ\tSN:KB711011.1\tLN:4624\n@SQ\tSN:APMT01219884.1\tLN:4624\n@SQ\tSN:KB711241.1\tLN:4624\n@SQ\tSN:KB711235.1\tLN:4622\n@SQ\tSN:APMT01219778.1\tLN:4620\n@SQ\tSN:APMT01219895.1\tLN:4619\n@SQ\tSN:KB712377.1\tLN:4618\n@SQ\tSN:APMT01219788.1\tLN:4617\n@SQ\tSN:APMT01219845.1\tLN:4617\n@SQ\tSN:APMT01219900.1\tLN:4616\n@SQ\tSN:APMT01219901.1\tLN:4615\n@SQ\tSN:APMT01219903.1\tLN:4615\n@SQ\tSN:KB711158.1\tLN:4614\n@SQ\tSN:APMT01219911.1\tLN:4613\n@SQ\tSN:APMT01219634.1\tLN:4612\n@SQ\tSN:APMT01219915.1\tLN:4612\n@SQ\tSN:KB713265.1\tLN:4611\n@SQ\tSN:KB711923.1\tLN:4607\n@SQ\tSN:KB713079.1\tLN:4605\n@SQ\tSN:APMT01219891.1\tLN:4604\n@SQ\tSN:KB711138.1\tLN:4604\n@SQ\tSN:APMT01219902.1\tLN:4602\n@SQ\tSN:KB711154.1\tLN:4602\n@SQ\tSN:KB711042.1\tLN:4601\n@SQ\tSN:APMT01219817.1\tLN:4601\n@SQ\tSN:KB711183.1\tLN:4601\n@SQ\tSN:APMT01219933.1\tLN:4600\n@SQ\tSN:APMT01219934.1\tLN:4600\n@SQ\tSN:APMT01219935.1\tLN:4600\n@SQ\tSN:APMT01219825.1\tLN:4599\n@SQ\tSN:KB711127.1\tLN:4599\n@SQ\tSN:APMT01219938.1\tLN:4599\n@SQ\tSN:APMT01219942.1\tLN:4598\n@SQ\tSN:APMT01219945.1\tLN:4596\n@SQ\tSN:KB711567.1\tLN:4596\n@SQ\tSN:APMT01219949.1\tLN:4594\n@SQ\tSN:KB710992.1\tLN:4591\n@SQ\tSN:APMT01219904.1\tLN:4591\n@SQ\tSN:APMT01219953.1\tLN:4591\n@SQ\tSN:APMT01219838.1\tLN:4590\n@SQ\tSN:APMT01219954.1\tLN:4590\n@SQ\tSN:KB713142.1\tLN:4590\n@SQ\tSN:APMT01219948.1\tLN:4588\n@SQ\tSN:KB710704.1\tLN:4586\n@SQ\tSN:APMT01219966.1\tLN:4586\n@SQ\tSN:APMT01219967.1\tLN:4585\n@SQ\tSN:APMT01219968.1\tLN:4585\n@SQ\tSN:APMT01219969.1\tLN:4585\n@SQ\tSN:APMT01219971.1\tLN:4584\n@SQ\tSN:APMT01219970.1\tLN:4583\n@SQ\tSN:APMT01219916.1\tLN:4582\n@SQ\tSN:APMT01219975.1\tLN:4582\n@SQ\tSN:KB711159.1\tLN:4582\n@SQ\tSN:APMT01219980.1\tLN:4580\n@SQ\tSN:KB712289.1\tLN:4580\n@SQ\tSN:KB711136.1\tLN:4578\n@SQ\tSN:APMT01219854.1\tLN:4577\n@SQ\tSN:APMT01219988.1\tLN:4576\n@SQ\tSN:APMT01219868.1\tLN:4574\n@SQ\tSN:APMT01219990.1\tLN:4574\n@SQ\tSN:KB711168.1\tLN:4573\n@SQ\tSN:KB711102.1\tLN:4572\n@SQ\tSN:KB711172.1\tLN:4572\n@SQ\tSN:APMT01219989.1\tLN:4571\n@SQ\tSN:APMT01220000.1\tLN:4571\n@SQ\tSN:APMT01220202.1\tLN:4571\n@SQ\tSN:APMT01220002.1\tLN:4570\n@SQ\tSN:APMT01219959.1\tLN:4569\n@SQ\tSN:APMT01220003.1\tLN:4568\n@SQ\tSN:APMT01220004.1\tLN:4568\n@SQ\tSN:APMT01220005.1\tLN:4568\n@SQ\tSN:APMT01220007.1\tLN:4567\n@SQ\tSN:KB711135.1\tLN:4566\n@SQ\tSN:KB712015.1\tLN:4566\n@SQ\tSN:APMT01219919.1\tLN:4565\n@SQ\tSN:APMT01220006.1\tLN:4563\n@SQ\tSN:APMT01220008.1\tLN:4563\n@SQ\tSN:APMT01220009.1\tLN:4563\n@SQ\tSN:KB711328.1\tLN:4563\n@SQ\tSN:APMT01220014.1\tLN:4562\n@SQ\tSN:APMT01220011.1\tLN:4561\n@SQ\tSN:KB711522.1\tLN:4561\n@SQ\tSN:KB711121.1\tLN:4560\n@SQ\tSN:APMT01220010.1\tLN:4560\n@SQ\tSN:APMT01220016.1\tLN:4560\n@SQ\tSN:KB711263.1\tLN:4560\n@SQ\tSN:APMT01219926.1\tLN:4559\n@SQ\tSN:APMT01220018.1\tLN:4559\n@SQ\tSN:APMT01220022.1\tLN:4558\n@SQ\tSN:KB711249.1\tLN:4558\n@SQ\tSN:APMT01220023.1\tLN:4557\n@SQ\tSN:APMT01220026.1\tLN:4557\n@SQ\tSN:APMT01220027.1\tLN:4557\n@SQ\tSN:KB711078.1\tLN:4556\n@SQ\tSN:APMT01219950.1\tLN:4554\n@SQ\tSN:APMT01220035.1\tLN:4554\n@SQ\tSN:KB710144.1\tLN:4553\n@SQ\tSN:KB711218.1\tLN:4552\n@SQ\tSN:KB711345.1\tLN:4552\n@SQ\tSN:APMT01219976.1\tLN:4551\n@SQ\tSN:APMT01220044.1\tLN:4551\n@SQ\tSN:APMT01220045.1\tLN:4550\n@SQ\tSN:KB711175.1\tLN:4550\n@SQ\tSN:APMT01220048.1\tLN:4549\n@SQ\tSN:KB711294.1\tLN:4548\n@SQ\tSN:KB711259.1\tLN:4546\n@SQ\tSN:APMT01220017.1\tLN:4545\n@SQ\tSN:APMT01220034.1\tLN:4545\n@SQ\tSN:APMT01220057.1\tLN:4544\n@SQ\tSN:APMT01220056.1\tLN:4543\n@SQ\tSN:APMT01220021.1\tLN:4542\n@SQ\tSN:APMT01220062.1\tLN:4542\n@SQ\tSN:KB711761.1\tLN:4542\n@SQ\tSN:APMT01220064.1\tLN:4541\n@SQ\tSN:KB713271.1\tLN:4541\n@SQ\tSN:APMT01219963.1\tLN:4540\n@SQ\tSN:APMT01220052.1\tLN:4540\n@SQ\tSN:KB712936.1\tLN:4540\n@SQ\tSN:KB711534.1\tLN:4539\n@SQ\tSN:APMT01219983.1\tLN:4538\n@SQ\tSN:APMT01220072.1\tLN:4538\n@SQ\tSN:APMT01220071.1\tLN:4537\n@SQ\tSN:APMT01220078.1\tLN:4536\n@SQ\tSN:APMT01220085.1\tLN:4535\n@SQ\tSN:APMT01220086.1\tLN:4535\n@SQ\tSN:APMT01220087.1\tLN:4533\n@SQ\tSN:APMT01219987.1\tLN:4532\n@SQ\tSN:APMT01219962.1\tLN:4530\n@SQ\tSN:KB711032.1\tLN:4529\n@SQ\tSN:KB711099.1\tLN:4529\n@SQ\tSN:APMT01220090.1\tLN:4529\n@SQ\tSN:APMT01220166.1\tLN:4529\n@SQ\tSN:KB711342.1\tLN:4529\n@SQ\tSN:KB711358.1\tLN:4529\n@SQ\tSN:APMT01220093.1\tLN:4528\n@SQ\tSN:APMT01220094.1\tLN:4527\n@SQ\tSN:APMT01219972.1\tLN:4526\n@SQ\tSN:APMT01220101.1\tLN:4526\n@SQ\tSN:KB711335.1\tLN:4526\n@SQ\tSN:APMT01220103.1\tLN:4525\n@SQ\tSN:APMT01220102.1\tLN:4524\n@SQ\tSN:APMT01220104.1\tLN:4522\n@SQ\tSN:APMT01220105.1\tLN:4522\n@SQ\tSN:APMT01220107.1\tLN:4522\n@SQ\tSN:KB711151.1\tLN:4520\n@SQ\tSN:APMT01219991.1\tLN:4520\n@SQ\tSN:APMT01220111.1\tLN:4520\n@SQ\tSN:KB712000.1\tLN:4520\n@SQ\tSN:KB711282.1\tLN:4518\n@SQ\tSN:APMT01220117.1\tLN:4517\n@SQ\tSN:KB711685.1\tLN:4517\n@SQ\tSN:APMT01220046.1\tLN:4515\n@SQ\tSN:KB711373.1\tLN:4515\n@SQ\tSN:APMT01220127.1\tLN:4514\n@SQ\tSN:KB711756.1\tLN:4513\n@SQ\tSN:APMT01220015.1\tLN:4512\n@SQ\tSN:APMT01220036.1\tLN:4512\n@SQ\tSN:APMT01220130.1\tLN:4512\n@SQ\tSN:APMT01220134.1\tLN:4512\n@SQ\tSN:KB711145.1\tLN:4511\n@SQ\tSN:APMT01220039.1\tLN:4511\n@SQ\tSN:APMT01220135.1\tLN:4511\n@SQ\tSN:KB711098.1\tLN:4510\n@SQ\tSN:APMT01220001.1\tLN:4510\n@SQ\tSN:KB710900.1\tLN:4509\n@SQ\tSN:KB710734.1\tLN:4508\n@SQ\tSN:APMT01220139.1\tLN:4508\n@SQ\tSN:KB710490.1\tLN:4507\n@SQ\tSN:KB711072.1\tLN:4507\n@SQ\tSN:KB710893.1\tLN:4506\n@SQ\tSN:APMT01220108.1\tLN:4506\n@SQ\tSN:APMT01220146.1\tLN:4506\n@SQ\tSN:APMT01220147.1\tLN:4506\n@SQ\tSN:APMT01220030.1\tLN:4505\n@SQ\tSN:APMT01220152.1\tLN:4505\n@SQ\tSN:APMT01220156.1\tLN:4504\n@SQ\tSN:KB711222.1\tLN:4504\n@SQ\tSN:KB711125.1\tLN:4503\n@SQ\tSN:APMT01220164.1\tLN:4503\n@SQ\tSN:KB713022.1\tLN:4503\n@SQ\tSN:KB711119.1\tLN:4502\n@SQ\tSN:KB711202.1\tLN:4502\n@SQ\tSN:APMT01220304.1\tLN:4502\n@SQ\tSN:KB711267.1\tLN:4502\n@SQ\tSN:KB711949.1\tLN:4501\n@SQ\tSN:KB711220.1\tLN:4500\n@SQ\tSN:APMT01220138.1\tLN:4499\n@SQ\tSN:KB711644.1\tLN:4499\n@SQ\tSN:KB711123.1\tLN:4498\n@SQ\tSN:KB711217.1\tLN:4498\n@SQ\tSN:APMT01220170.1\tLN:4497\n@SQ\tSN:KB712552.1\tLN:4497\n@SQ\tSN:APMT01220171.1\tLN:4496\n@SQ\tSN:APMT01220176.1\tLN:4496\n@SQ\tSN:KB711201.1\tLN:4496\n@SQ\tSN:KB711130.1\tLN:4495\n@SQ\tSN:KB711712.1\tLN:4495\n@SQ\tSN:KB712877.1\tLN:4495\n@SQ\tSN:APMT01220047.1\tLN:4493\n@SQ\tSN:APMT01220181.1\tLN:4492\n@SQ\tSN:APMT01220182.1\tLN:4492\n@SQ\tSN:APMT01220185.1\tLN:4490\n@SQ\tSN:APMT01220186.1\tLN:4489\n@SQ\tSN:APMT01220187.1\tLN:4489\n@SQ\tSN:APMT01220126.1\tLN:4488\n@SQ\tSN:APMT01220106.1\tLN:4487\n@SQ\tSN:APMT01220191.1\tLN:4487\n@SQ\tSN:APMT01220192.1\tLN:4487\n@SQ\tSN:APMT01220197.1\tLN:4486\n@SQ\tSN:KB711683.1\tLN:4486\n@SQ\tSN:APMT01220055.1\tLN:4485\n@SQ\tSN:KB711185.1\tLN:4484\n@SQ\tSN:APMT01220199.1\tLN:4483\n@SQ\tSN:APMT01220116.1\tLN:4482\n@SQ\tSN:KB711182.1\tLN:4482\n@SQ\tSN:APMT01220201.1\tLN:4482\n@SQ\tSN:APMT01220203.1\tLN:4481\n@SQ\tSN:APMT01220198.1\tLN:4480\n@SQ\tSN:APMT01220206.1\tLN:4480\n@SQ\tSN:APMT01220084.1\tLN:4478\n@SQ\tSN:KB711555.1\tLN:4478\n@SQ\tSN:APMT01220207.1\tLN:4476\n@SQ\tSN:APMT01220190.1\tLN:4475\n@SQ\tSN:APMT01220209.1\tLN:4475\n@SQ\tSN:APMT01220210.1\tLN:4475\n@SQ\tSN:KB711038.1\tLN:4474\n@SQ\tSN:APMT01220079.1\tLN:4474\n@SQ\tSN:APMT01220211.1\tLN:4474\n@SQ\tSN:KB711687.1\tLN:4473\n@SQ\tSN:KB711248.1\tLN:4472\n@SQ\tSN:KB711189.1\tLN:4469\n@SQ\tSN:KB711192.1\tLN:4469\n@SQ\tSN:KB713374.1\tLN:4469\n@SQ\tSN:APMT01220220.1\tLN:4468\n@SQ\tSN:APMT01220115.1\tLN:4467\n@SQ\tSN:APMT01220221.1\tLN:4467\n@SQ\tSN:APMT01220222.1\tLN:4467\n@SQ\tSN:APMT01220223.1\tLN:4467\n@SQ\tSN:KB713403.1\tLN:4467\n@SQ\tSN:KB711207.1\tLN:4466\n@SQ\tSN:KB711434.1\tLN:4466\n@SQ\tSN:KB711171.1\tLN:4465\n@SQ\tSN:APMT01220140.1\tLN:4465\n@SQ\tSN:KB711340.1\tLN:4465\n@SQ\tSN:APMT01220225.1\tLN:4464\n@SQ\tSN:APMT01220230.1\tLN:4464\n@SQ\tSN:KB711223.1\tLN:4464\n@SQ\tSN:KB711188.1\tLN:4463\n@SQ\tSN:APMT01220231.1\tLN:4463\n@SQ\tSN:KB711590.1\tLN:4463\n@SQ\tSN:APMT01220224.1\tLN:4460\n@SQ\tSN:APMT01220232.1\tLN:4460\n@SQ\tSN:KB711894.1\tLN:4460\n@SQ\tSN:KB712577.1\tLN:4460\n@SQ\tSN:KB710935.1\tLN:4459\n@SQ\tSN:APMT01220179.1\tLN:4459\n@SQ\tSN:APMT01220233.1\tLN:4459\n@SQ\tSN:APMT01220236.1\tLN:4459\n@SQ\tSN:APMT01220239.1\tLN:4458\n@SQ\tSN:KB711355.1\tLN:4458\n@SQ\tSN:KB711203.1\tLN:4457\n@SQ\tSN:APMT01220243.1\tLN:4457\n@SQ\tSN:APMT01220244.1\tLN:4457\n@SQ\tSN:KB711305.1\tLN:4457\n@SQ\tSN:KB711152.1\tLN:4456\n@SQ\tSN:APMT01220248.1\tLN:4456\n@SQ\tSN:KB712056.1\tLN:4455\n@SQ\tSN:APMT01220251.1\tLN:4454\n@SQ\tSN:APMT01220252.1\tLN:4454\n@SQ\tSN:APMT01220253.1\tLN:4454\n@SQ\tSN:APMT01220254.1\tLN:4454\n@SQ\tSN:KB711255.1\tLN:4453\n@SQ\tSN:KB711327.1\tLN:4453\n@SQ\tSN:APMT01220157.1\tLN:4452\n@SQ\tSN:APMT01220257.1\tLN:4452\n@SQ\tSN:KB711109.1\tLN:4451\n@SQ\tSN:APMT01220258.1\tLN:4451\n@SQ\tSN:APMT01220033.1\tLN:4450\n@SQ\tSN:APMT01220259.1\tLN:4450\n@SQ\tSN:KB712035.1\tLN:4450\n@SQ\tSN:APMT01220262.1\tLN:4449\n@SQ\tSN:APMT01220229.1\tLN:4448\n@SQ\tSN:APMT01220263.1\tLN:4448\n@SQ\tSN:APMT01220265.1\tLN:4447\n@SQ\tSN:APMT01220268.1\tLN:4446\n@SQ\tSN:KB711216.1\tLN:4445\n@SQ\tSN:KB711190.1\tLN:4444\n@SQ\tSN:APMT01220219.1\tLN:4444\n@SQ\tSN:APMT01220271.1\tLN:4444\n@SQ\tSN:APMT01220165.1\tLN:4443\n@SQ\tSN:APMT01220218.1\tLN:4443\n@SQ\tSN:APMT01220247.1\tLN:4443\n@SQ\tSN:APMT01220272.1\tLN:4443\n@SQ\tSN:APMT01220275.1\tLN:4443\n@SQ\tSN:KB712553.1\tLN:4443\n@SQ\tSN:APMT01220276.1\tLN:4442\n@SQ\tSN:APMT01220277.1\tLN:4442\n@SQ\tSN:APMT01220278.1\tLN:4442\n@SQ\tSN:APMT01220279.1\tLN:4442\n@SQ\tSN:APMT01220184.1\tLN:4441\n@SQ\tSN:APMT01220226.1\tLN:4441\n@SQ\tSN:APMT01220280.1\tLN:4441\n@SQ\tSN:KB711208.1\tLN:4440\n@SQ\tSN:APMT01220284.1\tLN:4440\n@SQ\tSN:APMT01220285.1\tLN:4440\n@SQ\tSN:KB711155.1\tLN:4439\n@SQ\tSN:APMT01220286.1\tLN:4439\n@SQ\tSN:APMT01220287.1\tLN:4439\n@SQ\tSN:APMT01220292.1\tLN:4439\n@SQ\tSN:APMT01220169.1\tLN:4438\n@SQ\tSN:APMT01220294.1\tLN:4438\n@SQ\tSN:KB711221.1\tLN:4438\n@SQ\tSN:APMT01220063.1\tLN:4434\n@SQ\tSN:APMT01220183.1\tLN:4434\n@SQ\tSN:APMT01220299.1\tLN:4434\n@SQ\tSN:APMT01220200.1\tLN:4433\n@SQ\tSN:APMT01220264.1\tLN:4433\n@SQ\tSN:APMT01220180.1\tLN:4431\n@SQ\tSN:APMT01220305.1\tLN:4431\n@SQ\tSN:KB712484.1\tLN:4430\n@SQ\tSN:APMT01220310.1\tLN:4429\n@SQ\tSN:APMT01220311.1\tLN:4429\n@SQ\tSN:APMT01220293.1\tLN:4428\n@SQ\tSN:APMT01220314.1\tLN:4428\n@SQ\tSN:APMT01220315.1\tLN:4428\n@SQ\tSN:KB711251.1\tLN:4428\n@SQ\tSN:APMT01220318.1\tLN:4427\n@SQ\tSN:KB712155.1\tLN:4427\n@SQ\tSN:APMT01220321.1\tLN:4426\n@SQ\tSN:APMT01220324.1\tLN:4425\n@SQ\tSN:APMT01220325.1\tLN:4425\n@SQ\tSN:APMT01220326.1\tLN:4425\n@SQ\tSN:APMT01220327.1\tLN:4425\n@SQ\tSN:APMT01220328.1\tLN:4424\n@SQ\tSN:APMT01220329.1\tLN:4424\n@SQ\tSN:KB711178.1\tLN:4423\n@SQ\tSN:APMT01220309.1\tLN:4423\n@SQ\tSN:KB711225.1\tLN:4423\n@SQ\tSN:APMT01220331.1\tLN:4423\n@SQ\tSN:APMT01220332.1\tLN:4423\n@SQ\tSN:APMT01220333.1\tLN:4423\n@SQ\tSN:APMT01220334.1\tLN:4423\n@SQ\tSN:APMT01220336.1\tLN:4422\n@SQ\tSN:APMT01220344.1\tLN:4421\n@SQ\tSN:APMT01220350.1\tLN:4420\n@SQ\tSN:APMT01220351.1\tLN:4420\n@SQ\tSN:APMT01220352.1\tLN:4420\n@SQ\tSN:KB711398.1\tLN:4420\n@SQ\tSN:KB711087.1\tLN:4418\n@SQ\tSN:KB711191.1\tLN:4418\n@SQ\tSN:APMT01220357.1\tLN:4418\n@SQ\tSN:APMT01220298.1\tLN:4417\n@SQ\tSN:APMT01220208.1\tLN:4415\n@SQ\tSN:KB710528.1\tLN:4414\n@SQ\tSN:KB711606.1\tLN:4414\n@SQ\tSN:APMT01220361.1\tLN:4413\n@SQ\tSN:APMT01220362.1\tLN:4413\n@SQ\tSN:KB711173.1\tLN:4408\n@SQ\tSN:KB711489.1\tLN:4408\n@SQ\tSN:APMT01220378.1\tLN:4407\n@SQ\tSN:KB711319.1\tLN:4407\n@SQ\tSN:KB712888.1\tLN:4407\n@SQ\tSN:APMT01220379.1\tLN:4406\n@SQ\tSN:APMT01220380.1\tLN:4406\n@SQ\tSN:KB711143.1\tLN:4405\n@SQ\tSN:KB712502.1\tLN:4405\n@SQ\tSN:KB711157.1\tLN:4403\n@SQ\tSN:APMT01220386.1\tLN:4403\n@SQ\tSN:APMT01220387.1\tLN:4403\n@SQ\tSN:APMT01220390.1\tLN:4402\n@SQ\tSN:APMT01220392.1\tLN:4401\n@SQ\tSN:APMT01220391.1\tLN:4399\n@SQ\tSN:APMT01220393.1\tLN:4399\n@SQ\tSN:KB711816.1\tLN:4399\n@SQ\tSN:APMT01220337.1\tLN:4397\n@SQ\tSN:APMT01220382.1\tLN:4397\n@SQ\tSN:KB713308.1\tLN:4397\n@SQ\tSN:APMT01220412.1\tLN:4395\n@SQ\tSN:KB711209.1\tLN:4392\n@SQ\tSN:APMT01220416.1\tLN:4392\n@SQ\tSN:KB711265.1\tLN:4391\n@SQ\tSN:APMT01220369.1\tLN:4388\n@SQ\tSN:KB711246.1\tLN:4388\n@SQ\tSN:APMT01220409.1\tLN:4388\n@SQ\tSN:APMT01220422.1\tLN:4388\n@SQ\tSN:APMT01220423.1\tLN:4388\n@SQ\tSN:KB711295.1\tLN:4388\n@SQ\tSN:APMT01220424.1\tLN:4387\n@SQ\tSN:APMT01220425.1\tLN:4387\n@SQ\tSN:APMT01220426.1\tLN:4387\n@SQ\tSN:KB711847.1\tLN:4386\n@SQ\tSN:KB713628.1\tLN:4386\n@SQ\tSN:KB711106.1\tLN:4385\n@SQ\tSN:APMT01220427.1\tLN:4385\n@SQ\tSN:KB711269.1\tLN:4385\n@SQ\tSN:KB711164.1\tLN:4384\n@SQ\tSN:APMT01220432.1\tLN:4384\n@SQ\tSN:KB711435.1\tLN:4384\n@SQ\tSN:KB711210.1\tLN:4383\n@SQ\tSN:KB711334.1\tLN:4383\n@SQ\tSN:APMT01220434.1\tLN:4381\n@SQ\tSN:APMT01220440.1\tLN:4381\n@SQ\tSN:KB712359.1\tLN:4381\n@SQ\tSN:APMT01220303.1\tLN:4380\n@SQ\tSN:APMT01220441.1\tLN:4380\n@SQ\tSN:KB711137.1\tLN:4379\n@SQ\tSN:APMT01220306.1\tLN:4377\n@SQ\tSN:APMT01220330.1\tLN:4377\n@SQ\tSN:APMT01220493.1\tLN:4377\n@SQ\tSN:KB711134.1\tLN:4376\n@SQ\tSN:APMT01220455.1\tLN:4376\n@SQ\tSN:APMT01220456.1\tLN:4376\n@SQ\tSN:APMT01220457.1\tLN:4376\n@SQ\tSN:APMT01220465.1\tLN:4375\n@SQ\tSN:APMT01220335.1\tLN:4374\n@SQ\tSN:APMT01220467.1\tLN:4374\n@SQ\tSN:APMT01220472.1\tLN:4374\n@SQ\tSN:APMT01220473.1\tLN:4374\n@SQ\tSN:KB711831.1\tLN:4372\n@SQ\tSN:KB711264.1\tLN:4371\n@SQ\tSN:KB711226.1\tLN:4369\n@SQ\tSN:APMT01220363.1\tLN:4369\n@SQ\tSN:APMT01220486.1\tLN:4369\n@SQ\tSN:KB711227.1\tLN:4368\n@SQ\tSN:APMT01220492.1\tLN:4368\n@SQ\tSN:APMT01220731.1\tLN:4368\n@SQ\tSN:KB712949.1\tLN:4368\n@SQ\tSN:APMT01220366.1\tLN:4367\n@SQ\tSN:APMT01220449.1\tLN:4367\n@SQ\tSN:APMT01220496.1\tLN:4367\n@SQ\tSN:KB711508.1\tLN:4367\n@SQ\tSN:APMT01220501.1\tLN:4366\n@SQ\tSN:APMT01220773.1\tLN:4366\n@SQ\tSN:APMT01220504.1\tLN:4364\n@SQ\tSN:KB711354.1\tLN:4364\n@SQ\tSN:APMT01220508.1\tLN:4363\n@SQ\tSN:APMT01220509.1\tLN:4363\n@SQ\tSN:KB711454.1\tLN:4363\n@SQ\tSN:APMT01220510.1\tLN:4360\n@SQ\tSN:KB711379.1\tLN:4360\n@SQ\tSN:KB711240.1\tLN:4359\n@SQ\tSN:APMT01220433.1\tLN:4359\n@SQ\tSN:KB711277.1\tLN:4358\n@SQ\tSN:KB711296.1\tLN:4358\n@SQ\tSN:KB711236.1\tLN:4357\n@SQ\tSN:KB712458.1\tLN:4357\n@SQ\tSN:APMT01220402.1\tLN:4356\n@SQ\tSN:KB711607.1\tLN:4356\n@SQ\tSN:APMT01220415.1\tLN:4355\n@SQ\tSN:KB711274.1\tLN:4355\n@SQ\tSN:KB711541.1\tLN:4354\n@SQ\tSN:KB713219.1\tLN:4353\n@SQ\tSN:KB711262.1\tLN:4352\n@SQ\tSN:APMT01220360.1\tLN:4351\n@SQ\tSN:KB711206.1\tLN:4350\n@SQ\tSN:APMT01220450.1\tLN:4349\n@SQ\tSN:KB711634.1\tLN:4349\n@SQ\tSN:KB711276.1\tLN:4348\n@SQ\tSN:KB711466.1\tLN:4348\n@SQ\tSN:KB711834.1\tLN:4348\n@SQ\tSN:KB711156.1\tLN:4347\n@SQ\tSN:APMT01220541.1\tLN:4347\n@SQ\tSN:KB711323.1\tLN:4347\n@SQ\tSN:KB711898.1\tLN:4347\n@SQ\tSN:APMT01220538.1\tLN:4345\n@SQ\tSN:KB711194.1\tLN:4344\n@SQ\tSN:KB710990.1\tLN:4343\n@SQ\tSN:APMT01220547.1\tLN:4343\n@SQ\tSN:KB711743.1\tLN:4343\n@SQ\tSN:APMT01220418.1\tLN:4342\n@SQ\tSN:APMT01220551.1\tLN:4341\n@SQ\tSN:APMT01220417.1\tLN:4339\n@SQ\tSN:APMT01220558.1\tLN:4339\n@SQ\tSN:KB712163.1\tLN:4339\n@SQ\tSN:KB710979.1\tLN:4338\n@SQ\tSN:KB711314.1\tLN:4338\n@SQ\tSN:KB713118.1\tLN:4338\n@SQ\tSN:APMT01220419.1\tLN:4337\n@SQ\tSN:APMT01220562.1\tLN:4337\n@SQ\tSN:APMT01220561.1\tLN:4336\n@SQ\tSN:APMT01220428.1\tLN:4335\n@SQ\tSN:KB711321.1\tLN:4335\n@SQ\tSN:KB711901.1\tLN:4335\n@SQ\tSN:APMT01220481.1\tLN:4334\n@SQ\tSN:KB711266.1\tLN:4334\n@SQ\tSN:KB711939.1\tLN:4334\n@SQ\tSN:KB711268.1\tLN:4333\n@SQ\tSN:KB711304.1\tLN:4333\n@SQ\tSN:KB711234.1\tLN:4332\n@SQ\tSN:KB711288.1\tLN:4332\n@SQ\tSN:KB711506.1\tLN:4332\n@SQ\tSN:KB711184.1\tLN:4330\n@SQ\tSN:APMT01220579.1\tLN:4330\n@SQ\tSN:APMT01220613.1\tLN:4329\n@SQ\tSN:APMT01220583.1\tLN:4328\n@SQ\tSN:KB712328.1\tLN:4328\n@SQ\tSN:KB712715.1\tLN:4328\n@SQ\tSN:APMT01220589.1\tLN:4327\n@SQ\tSN:KB711336.1\tLN:4327\n@SQ\tSN:KB711616.1\tLN:4327\n@SQ\tSN:KB711922.1\tLN:4327\n@SQ\tSN:APMT01220584.1\tLN:4326\n@SQ\tSN:KB711502.1\tLN:4325\n@SQ\tSN:KB712513.1\tLN:4324\n@SQ\tSN:APMT01220439.1\tLN:4323\n@SQ\tSN:APMT01220476.1\tLN:4323\n@SQ\tSN:APMT01220601.1\tLN:4323\n@SQ\tSN:APMT01220540.1\tLN:4322\n@SQ\tSN:KB711627.1\tLN:4322\n@SQ\tSN:KB711866.1\tLN:4322\n@SQ\tSN:APMT01220435.1\tLN:4321\n@SQ\tSN:APMT01220466.1\tLN:4321\n@SQ\tSN:APMT01220606.1\tLN:4319\n@SQ\tSN:KB711258.1\tLN:4318\n@SQ\tSN:KB711794.1\tLN:4318\n@SQ\tSN:APMT01220603.1\tLN:4317\n@SQ\tSN:APMT01220615.1\tLN:4316\n@SQ\tSN:APMT01220480.1\tLN:4315\n@SQ\tSN:APMT01220614.1\tLN:4315\n@SQ\tSN:APMT01220619.1\tLN:4313\n@SQ\tSN:APMT01220620.1\tLN:4313\n@SQ\tSN:APMT01220623.1\tLN:4313\n@SQ\tSN:KB711402.1\tLN:4313\n@SQ\tSN:KB711498.1\tLN:4313\n@SQ\tSN:APMT01220477.1\tLN:4311\n@SQ\tSN:APMT01220624.1\tLN:4311\n@SQ\tSN:APMT01220625.1\tLN:4311\n@SQ\tSN:APMT01220629.1\tLN:4311\n@SQ\tSN:APMT01220630.1\tLN:4311\n@SQ\tSN:APMT01220631.1\tLN:4310\n@SQ\tSN:APMT01220635.1\tLN:4310\n@SQ\tSN:KB711325.1\tLN:4310\n@SQ\tSN:KB711303.1\tLN:4309\n@SQ\tSN:APMT01220491.1\tLN:4308\n@SQ\tSN:APMT01220626.1\tLN:4308\n@SQ\tSN:KB711344.1\tLN:4307\n@SQ\tSN:APMT01220638.1\tLN:4306\n@SQ\tSN:APMT01220641.1\tLN:4306\n@SQ\tSN:KB711224.1\tLN:4305\n@SQ\tSN:APMT01220381.1\tLN:4305\n@SQ\tSN:APMT01220646.1\tLN:4305\n@SQ\tSN:APMT01220653.1\tLN:4304\n@SQ\tSN:KB711320.1\tLN:4304\n@SQ\tSN:APMT01220658.1\tLN:4301\n@SQ\tSN:KB713460.1\tLN:4300\n@SQ\tSN:KB711180.1\tLN:4299\n@SQ\tSN:KB711390.1\tLN:4299\n@SQ\tSN:KB711311.1\tLN:4298\n@SQ\tSN:APMT01220667.1\tLN:4298\n@SQ\tSN:APMT01220674.1\tLN:4298\n@SQ\tSN:KB711193.1\tLN:4297\n@SQ\tSN:APMT01220675.1\tLN:4297\n@SQ\tSN:KB711176.1\tLN:4296\n@SQ\tSN:KB711313.1\tLN:4295\n@SQ\tSN:APMT01220676.1\tLN:4295\n@SQ\tSN:APMT01220684.1\tLN:4295\n@SQ\tSN:APMT01220687.1\tLN:4294\n@SQ\tSN:KB710675.1\tLN:4293\n@SQ\tSN:APMT01220550.1\tLN:4292\n@SQ\tSN:APMT01220692.1\tLN:4292\n@SQ\tSN:APMT01220693.1\tLN:4291\n@SQ\tSN:KB711800.1\tLN:4291\n@SQ\tSN:APMT01220694.1\tLN:4290\n@SQ\tSN:APMT01220697.1\tLN:4290\n@SQ\tSN:KB711593.1\tLN:4290\n@SQ\tSN:KB712060.1\tLN:4290\n@SQ\tSN:APMT01220699.1\tLN:4289\n@SQ\tSN:APMT01220700.1\tLN:4289\n@SQ\tSN:APMT01220701.1\tLN:4289\n@SQ\tSN:KB711724.1\tLN:4289\n@SQ\tSN:APMT01220705.1\tLN:4287\n@SQ\tSN:KB711387.1\tLN:4287\n@SQ\tSN:APMT01220566.1\tLN:4286\n@SQ\tSN:APMT01220712.1\tLN:4286\n@SQ\tSN:APMT01220714.1\tLN:4285\n@SQ\tSN:APMT01220719.1\tLN:4284\n@SQ\tSN:KB713505.1\tLN:4284\n@SQ\tSN:APMT01220664.1\tLN:4283\n@SQ\tSN:APMT01220702.1\tLN:4283\n@SQ\tSN:APMT01220732.1\tLN:4281\n@SQ\tSN:KB711353.1\tLN:4281\n@SQ\tSN:KB713156.1\tLN:4281\n@SQ\tSN:APMT01220668.1\tLN:4280\n@SQ\tSN:APMT01220713.1\tLN:4280\n@SQ\tSN:APMT01220739.1\tLN:4280\n@SQ\tSN:KB711377.1\tLN:4280\n@SQ\tSN:APMT01220742.1\tLN:4279\n@SQ\tSN:KB711562.1\tLN:4279\n@SQ\tSN:KB711856.1\tLN:4278\n@SQ\tSN:APMT01220747.1\tLN:4277\n@SQ\tSN:APMT01220748.1\tLN:4277\n@SQ\tSN:APMT01220751.1\tLN:4277\n@SQ\tSN:KB711364.1\tLN:4277\n@SQ\tSN:KB711338.1\tLN:4276\n@SQ\tSN:APMT01220754.1\tLN:4276\n@SQ\tSN:APMT01220567.1\tLN:4275\n@SQ\tSN:APMT01220616.1\tLN:4275\n@SQ\tSN:APMT01220755.1\tLN:4275\n@SQ\tSN:APMT01220571.1\tLN:4273\n@SQ\tSN:APMT01220572.1\tLN:4273\n@SQ\tSN:APMT01220698.1\tLN:4273\n@SQ\tSN:KB711777.1\tLN:4273\n@SQ\tSN:APMT01220765.1\tLN:4272\n@SQ\tSN:APMT01220767.1\tLN:4272\n@SQ\tSN:APMT01220771.1\tLN:4271\n@SQ\tSN:APMT01220602.1\tLN:4270\n@SQ\tSN:APMT01220774.1\tLN:4270\n@SQ\tSN:APMT01220778.1\tLN:4270\n@SQ\tSN:KB711232.1\tLN:4269\n@SQ\tSN:KB711374.1\tLN:4269\n@SQ\tSN:KB711372.1\tLN:4268\n@SQ\tSN:KB711153.1\tLN:4267\n@SQ\tSN:APMT01220787.1\tLN:4267\n@SQ\tSN:KB711359.1\tLN:4266\n@SQ\tSN:KB711484.1\tLN:4266\n@SQ\tSN:APMT01220799.1\tLN:4265\n@SQ\tSN:KB713390.1\tLN:4265\n@SQ\tSN:KB711315.1\tLN:4264\n@SQ\tSN:APMT01220808.1\tLN:4264\n@SQ\tSN:APMT01220809.1\tLN:4263\n@SQ\tSN:APMT01220812.1\tLN:4263\n@SQ\tSN:APMT01220929.1\tLN:4262\n@SQ\tSN:KB711410.1\tLN:4262\n@SQ\tSN:KB711920.1\tLN:4262\n@SQ\tSN:KB712126.1\tLN:4262\n@SQ\tSN:KB711238.1\tLN:4261\n@SQ\tSN:KB711297.1\tLN:4261\n@SQ\tSN:APMT01220779.1\tLN:4261\n@SQ\tSN:KB711748.1\tLN:4261\n@SQ\tSN:APMT01220612.1\tLN:4260\n@SQ\tSN:KB711341.1\tLN:4260\n@SQ\tSN:KB712622.1\tLN:4260\n@SQ\tSN:APMT01220659.1\tLN:4259\n@SQ\tSN:APMT01220816.1\tLN:4259\n@SQ\tSN:APMT01220817.1\tLN:4259\n@SQ\tSN:APMT01220819.1\tLN:4259\n@SQ\tSN:KB711376.1\tLN:4259\n@SQ\tSN:APMT01221276.1\tLN:4259\n@SQ\tSN:APMT01220825.1\tLN:4258\n@SQ\tSN:KB711441.1\tLN:4258\n@SQ\tSN:APMT01220611.1\tLN:4257\n@SQ\tSN:APMT01220847.1\tLN:4257\n@SQ\tSN:KB711396.1\tLN:4257\n@SQ\tSN:APMT01220830.1\tLN:4255\n@SQ\tSN:APMT01220834.1\tLN:4253\n@SQ\tSN:KB711472.1\tLN:4253\n@SQ\tSN:APMT01220766.1\tLN:4252\n@SQ\tSN:KB711347.1\tLN:4251\n@SQ\tSN:APMT01220840.1\tLN:4251\n@SQ\tSN:APMT01221212.1\tLN:4251\n@SQ\tSN:KB711380.1\tLN:4249\n@SQ\tSN:KB711244.1\tLN:4248\n@SQ\tSN:APMT01220854.1\tLN:4248\n@SQ\tSN:APMT01220858.1\tLN:4248\n@SQ\tSN:KB711499.1\tLN:4248\n@SQ\tSN:KB711726.1\tLN:4248\n@SQ\tSN:KB711554.1\tLN:4247\n@SQ\tSN:KB714302.1\tLN:4245\n@SQ\tSN:APMT01220866.1\tLN:4244\n@SQ\tSN:APMT01220867.1\tLN:4244\n@SQ\tSN:KB711424.1\tLN:4244\n@SQ\tSN:KB711988.1\tLN:4244\n@SQ\tSN:KB711316.1\tLN:4243\n@SQ\tSN:APMT01220868.1\tLN:4243\n@SQ\tSN:APMT01220869.1\tLN:4243\n@SQ\tSN:KB711610.1\tLN:4242\n@SQ\tSN:APMT01220770.1\tLN:4241\n@SQ\tSN:APMT01220772.1\tLN:4241\n@SQ\tSN:KB711452.1\tLN:4241\n@SQ\tSN:KB711468.1\tLN:4241\n@SQ\tSN:KB711790.1\tLN:4241\n@SQ\tSN:KB713150.1\tLN:4240\n@SQ\tSN:KB713384.1\tLN:4240\n@SQ\tSN:APMT01220881.1\tLN:4239\n@SQ\tSN:KB711474.1\tLN:4239\n@SQ\tSN:APMT01220565.1\tLN:4238\n@SQ\tSN:APMT01220725.1\tLN:4238\n@SQ\tSN:KB711436.1\tLN:4238\n@SQ\tSN:APMT01220743.1\tLN:4237\n@SQ\tSN:APMT01220890.1\tLN:4237\n@SQ\tSN:KB711243.1\tLN:4235\n@SQ\tSN:APMT01220632.1\tLN:4235\n@SQ\tSN:APMT01220796.1\tLN:4235\n@SQ\tSN:KB711322.1\tLN:4234\n@SQ\tSN:KB711731.1\tLN:4234\n@SQ\tSN:KB711936.1\tLN:4234\n@SQ\tSN:KB712781.1\tLN:4234\n@SQ\tSN:KB711391.1\tLN:4233\n@SQ\tSN:APMT01220909.1\tLN:4233\n@SQ\tSN:APMT01220912.1\tLN:4232\n@SQ\tSN:KB711876.1\tLN:4232\n@SQ\tSN:APMT01220920.1\tLN:4231\n@SQ\tSN:KB711308.1\tLN:4230\n@SQ\tSN:KB711669.1\tLN:4229\n@SQ\tSN:APMT01220924.1\tLN:4228\n@SQ\tSN:APMT01220928.1\tLN:4228\n@SQ\tSN:KB711510.1\tLN:4228\n@SQ\tSN:APMT01220539.1\tLN:4227\n@SQ\tSN:APMT01220932.1\tLN:4227\n@SQ\tSN:KB711433.1\tLN:4227\n@SQ\tSN:KB711500.1\tLN:4227\n@SQ\tSN:KB711290.1\tLN:4225\n@SQ\tSN:APMT01220944.1\tLN:4224\n@SQ\tSN:KB712660.1\tLN:4224\n@SQ\tSN:KB711132.1\tLN:4223\n@SQ\tSN:KB711309.1\tLN:4223\n@SQ\tSN:APMT01220945.1\tLN:4223\n@SQ\tSN:APMT01220946.1\tLN:4223\n@SQ\tSN:APMT01220593.1\tLN:4222\n@SQ\tSN:APMT01220831.1\tLN:4222\n@SQ\tSN:KB711375.1\tLN:4222\n@SQ\tSN:APMT01220943.1\tLN:4222\n@SQ\tSN:KB711735.1\tLN:4222\n@SQ\tSN:KB711395.1\tLN:4221\n@SQ\tSN:KB711392.1\tLN:4220\n@SQ\tSN:APMT01220744.1\tLN:4218\n@SQ\tSN:APMT01220960.1\tLN:4218\n@SQ\tSN:KB711448.1\tLN:4218\n@SQ\tSN:KB711526.1\tLN:4217\n@SQ\tSN:APMT01220970.1\tLN:4214\n@SQ\tSN:KB711754.1\tLN:4214\n@SQ\tSN:KB711331.1\tLN:4213\n@SQ\tSN:APMT01220974.1\tLN:4213\n@SQ\tSN:KB712514.1\tLN:4213\n@SQ\tSN:KB711270.1\tLN:4212\n@SQ\tSN:KB711621.1\tLN:4212\n@SQ\tSN:KB711818.1\tLN:4212\n@SQ\tSN:KB713833.1\tLN:4212\n@SQ\tSN:APMT01220921.1\tLN:4211\n@SQ\tSN:APMT01220978.1\tLN:4211\n@SQ\tSN:KB711762.1\tLN:4211\n@SQ\tSN:KB711384.1\tLN:4210\n@SQ\tSN:KB711415.1\tLN:4210\n@SQ\tSN:KB711416.1\tLN:4210\n@SQ\tSN:KB711851.1\tLN:4210\n@SQ\tSN:APMT01220989.1\tLN:4209\n@SQ\tSN:KB711736.1\tLN:4209\n@SQ\tSN:APMT01220913.1\tLN:4207\n@SQ\tSN:APMT01220788.1\tLN:4206\n@SQ\tSN:APMT01220993.1\tLN:4206\n@SQ\tSN:KB711444.1\tLN:4206\n@SQ\tSN:KB711492.1\tLN:4206\n@SQ\tSN:APMT01220994.1\tLN:4205\n@SQ\tSN:APMT01220995.1\tLN:4205\n@SQ\tSN:APMT01220813.1\tLN:4204\n@SQ\tSN:KB711625.1\tLN:4204\n@SQ\tSN:KB711381.1\tLN:4202\n@SQ\tSN:KB711394.1\tLN:4202\n@SQ\tSN:KB711411.1\tLN:4202\n@SQ\tSN:KB711588.1\tLN:4202\n@SQ\tSN:APMT01221000.1\tLN:4201\n@SQ\tSN:APMT01221001.1\tLN:4201\n@SQ\tSN:KB711463.1\tLN:4201\n@SQ\tSN:KB711393.1\tLN:4200\n@SQ\tSN:KB711406.1\tLN:4200\n@SQ\tSN:APMT01221009.1\tLN:4199\n@SQ\tSN:KB711253.1\tLN:4198\n@SQ\tSN:APMT01220984.1\tLN:4198\n@SQ\tSN:KB711494.1\tLN:4198\n@SQ\tSN:KB713714.1\tLN:4198\n@SQ\tSN:KB711280.1\tLN:4197\n@SQ\tSN:KB711520.1\tLN:4197\n@SQ\tSN:KB711403.1\tLN:4196\n@SQ\tSN:APMT01221013.1\tLN:4196\n@SQ\tSN:KB711467.1\tLN:4196\n@SQ\tSN:KB711523.1\tLN:4196\n@SQ\tSN:APMT01220835.1\tLN:4195\n@SQ\tSN:APMT01221018.1\tLN:4195\n@SQ\tSN:APMT01221021.1\tLN:4195\n@SQ\tSN:KB711417.1\tLN:4194\n@SQ\tSN:APMT01221022.1\tLN:4194\n@SQ\tSN:KB713688.1\tLN:4194\n@SQ\tSN:KB711233.1\tLN:4193\n@SQ\tSN:APMT01220938.1\tLN:4193\n@SQ\tSN:APMT01220965.1\tLN:4193\n@SQ\tSN:KB711428.1\tLN:4193\n@SQ\tSN:KB711429.1\tLN:4192\n@SQ\tSN:KB711591.1\tLN:4192\n@SQ\tSN:KB711008.1\tLN:4190\n@SQ\tSN:APMT01220990.1\tLN:4190\n@SQ\tSN:APMT01220855.1\tLN:4189\n@SQ\tSN:APMT01221040.1\tLN:4189\n@SQ\tSN:APMT01221043.1\tLN:4189\n@SQ\tSN:KB711771.1\tLN:4189\n@SQ\tSN:APMT01221044.1\tLN:4188\n@SQ\tSN:APMT01221045.1\tLN:4188\n@SQ\tSN:APMT01221051.1\tLN:4187\n@SQ\tSN:KB711583.1\tLN:4187\n@SQ\tSN:APMT01220775.1\tLN:4186\n@SQ\tSN:KB712869.1\tLN:4186\n@SQ\tSN:KB710939.1\tLN:4185\n@SQ\tSN:APMT01221055.1\tLN:4185\n@SQ\tSN:APMT01221058.1\tLN:4185\n@SQ\tSN:APMT01221059.1\tLN:4185\n@SQ\tSN:APMT01221060.1\tLN:4185\n@SQ\tSN:APMT01221065.1\tLN:4185\n@SQ\tSN:KB711356.1\tLN:4184\n@SQ\tSN:KB711833.1\tLN:4184\n@SQ\tSN:APMT01220923.1\tLN:4183\n@SQ\tSN:KB711418.1\tLN:4183\n@SQ\tSN:KB711566.1\tLN:4183\n@SQ\tSN:APMT01221069.1\tLN:4182\n@SQ\tSN:KB711471.1\tLN:4182\n@SQ\tSN:APMT01220908.1\tLN:4181\n@SQ\tSN:APMT01221070.1\tLN:4181\n@SQ\tSN:APMT01221074.1\tLN:4181\n@SQ\tSN:KB711473.1\tLN:4181\n@SQ\tSN:KB711365.1\tLN:4180\n@SQ\tSN:APMT01221050.1\tLN:4180\n@SQ\tSN:APMT01221075.1\tLN:4180\n@SQ\tSN:KB711312.1\tLN:4179\n@SQ\tSN:KB711405.1\tLN:4179\n@SQ\tSN:APMT01221077.1\tLN:4179\n@SQ\tSN:APMT01220925.1\tLN:4178\n@SQ\tSN:APMT01221076.1\tLN:4178\n@SQ\tSN:APMT01221080.1\tLN:4178\n@SQ\tSN:KB711919.1\tLN:4177\n@SQ\tSN:KB711423.1\tLN:4176\n@SQ\tSN:APMT01221094.1\tLN:4176\n@SQ\tSN:KB711459.1\tLN:4175\n@SQ\tSN:KB711573.1\tLN:4175\n@SQ\tSN:KB711812.1\tLN:4175\n@SQ\tSN:APMT01221091.1\tLN:4174\n@SQ\tSN:APMT01221099.1\tLN:4174\n@SQ\tSN:KB711806.1\tLN:4173\n@SQ\tSN:KB711413.1\tLN:4171\n@SQ\tSN:APMT01221066.1\tLN:4171\n@SQ\tSN:KB713916.1\tLN:4171\n@SQ\tSN:KB711457.1\tLN:4170\n@SQ\tSN:APMT01221110.1\tLN:4170\n@SQ\tSN:KB711273.1\tLN:4169\n@SQ\tSN:KB711289.1\tLN:4169\n@SQ\tSN:KB711383.1\tLN:4169\n@SQ\tSN:APMT01221117.1\tLN:4169\n@SQ\tSN:APMT01221121.1\tLN:4169\n@SQ\tSN:KB711475.1\tLN:4169\n@SQ\tSN:APMT01221251.1\tLN:4169\n@SQ\tSN:KB711786.1\tLN:4169\n@SQ\tSN:APMT01221004.1\tLN:4168\n@SQ\tSN:KB711576.1\tLN:4168\n@SQ\tSN:KB711695.1\tLN:4168\n@SQ\tSN:KB712945.1\tLN:4168\n@SQ\tSN:APMT01220959.1\tLN:4167\n@SQ\tSN:APMT01221131.1\tLN:4167\n@SQ\tSN:APMT01221136.1\tLN:4167\n@SQ\tSN:APMT01220818.1\tLN:4165\n@SQ\tSN:KB711465.1\tLN:4165\n@SQ\tSN:KB711469.1\tLN:4165\n@SQ\tSN:KB711486.1\tLN:4165\n@SQ\tSN:APMT01220975.1\tLN:4163\n@SQ\tSN:APMT01220985.1\tLN:4163\n@SQ\tSN:APMT01221149.1\tLN:4163\n@SQ\tSN:KB711729.1\tLN:4163\n@SQ\tSN:KB713288.1\tLN:4163\n@SQ\tSN:APMT01221156.1\tLN:4162\n@SQ\tSN:APMT01221054.1\tLN:4161\n@SQ\tSN:APMT01221157.1\tLN:4161\n@SQ\tSN:KB711165.1\tLN:4160\n@SQ\tSN:APMT01221106.1\tLN:4160\n@SQ\tSN:APMT01221176.1\tLN:4159\n@SQ\tSN:KB711480.1\tLN:4159\n@SQ\tSN:APMT01221181.1\tLN:4159\n@SQ\tSN:APMT01221182.1\tLN:4159\n@SQ\tSN:APMT01221008.1\tLN:4158\n@SQ\tSN:APMT01221097.1\tLN:4158\n@SQ\tSN:APMT01221187.1\tLN:4158\n@SQ\tSN:APMT01221189.1\tLN:4158\n@SQ\tSN:KB711490.1\tLN:4158\n@SQ\tSN:APMT01221183.1\tLN:4157\n@SQ\tSN:APMT01221190.1\tLN:4157\n@SQ\tSN:KB711839.1\tLN:4157\n@SQ\tSN:KB711443.1\tLN:4156\n@SQ\tSN:KB711519.1\tLN:4156\n@SQ\tSN:APMT01220922.1\tLN:4155\n@SQ\tSN:KB711438.1\tLN:4155\n@SQ\tSN:KB711427.1\tLN:4154\n@SQ\tSN:APMT01221100.1\tLN:4154\n@SQ\tSN:KB712139.1\tLN:4154\n@SQ\tSN:KB710963.1\tLN:4153\n@SQ\tSN:APMT01221206.1\tLN:4151\n@SQ\tSN:KB711496.1\tLN:4150\n@SQ\tSN:KB711505.1\tLN:4150\n@SQ\tSN:KB711561.1\tLN:4150\n@SQ\tSN:KB713646.1\tLN:4149\n@SQ\tSN:APMT01221213.1\tLN:4148\n@SQ\tSN:APMT01221214.1\tLN:4148\n@SQ\tSN:APMT01221215.1\tLN:4148\n@SQ\tSN:KB711497.1\tLN:4148\n@SQ\tSN:KB711291.1\tLN:4147\n@SQ\tSN:APMT01221218.1\tLN:4147\n@SQ\tSN:APMT01221232.1\tLN:4145\n@SQ\tSN:APMT01221265.1\tLN:4145\n@SQ\tSN:KB713823.1\tLN:4145\n@SQ\tSN:APMT01221227.1\tLN:4144\n@SQ\tSN:APMT01221235.1\tLN:4144\n@SQ\tSN:APMT01221067.1\tLN:4143\n@SQ\tSN:APMT01221238.1\tLN:4143\n@SQ\tSN:APMT01221241.1\tLN:4143\n@SQ\tSN:KB711680.1\tLN:4143\n@SQ\tSN:APMT01221007.1\tLN:4142\n@SQ\tSN:APMT01221234.1\tLN:4142\n@SQ\tSN:APMT01221188.1\tLN:4141\n@SQ\tSN:APMT01221256.1\tLN:4141\n@SQ\tSN:KB711613.1\tLN:4141\n@SQ\tSN:KB711481.1\tLN:4140\n@SQ\tSN:APMT01221257.1\tLN:4140\n@SQ\tSN:KB711461.1\tLN:4139\n@SQ\tSN:APMT01221264.1\tLN:4139\n@SQ\tSN:KB711142.1\tLN:4138\n@SQ\tSN:APMT01221191.1\tLN:4138\n@SQ\tSN:APMT01221012.1\tLN:4137\n@SQ\tSN:KB711636.1\tLN:4137\n@SQ\tSN:KB711488.1\tLN:4135\n@SQ\tSN:APMT01221210.1\tLN:4135\n@SQ\tSN:KB711882.1\tLN:4135\n@SQ\tSN:KB710065.1\tLN:4134\n@SQ\tSN:KB711431.1\tLN:4133\n@SQ\tSN:APMT01221109.1\tLN:4133\n@SQ\tSN:KB711518.1\tLN:4133\n@SQ\tSN:KB711549.1\tLN:4133\n@SQ\tSN:KB711999.1\tLN:4133\n@SQ\tSN:APMT01221026.1\tLN:4132\n@SQ\tSN:KB711462.1\tLN:4132\n@SQ\tSN:KB713031.1\tLN:4132\n@SQ\tSN:APMT01221081.1\tLN:4131\n@SQ\tSN:KB713414.1\tLN:4131\n@SQ\tSN:APMT01221281.1\tLN:4130\n@SQ\tSN:KB711445.1\tLN:4129\n@SQ\tSN:APMT01221142.1\tLN:4129\n@SQ\tSN:APMT01221282.1\tLN:4129\n@SQ\tSN:KB711612.1\tLN:4129\n@SQ\tSN:KB712528.1\tLN:4129\n@SQ\tSN:APMT01221285.1\tLN:4128\n@SQ\tSN:APMT01221286.1\tLN:4128\n@SQ\tSN:APMT01221287.1\tLN:4128\n@SQ\tSN:KB711757.1\tLN:4128\n@SQ\tSN:APMT01221288.1\tLN:4127\n@SQ\tSN:APMT01221289.1\tLN:4127\n@SQ\tSN:APMT01221292.1\tLN:4127\n@SQ\tSN:KB710705.1\tLN:4125\n@SQ\tSN:KB711513.1\tLN:4125\n@SQ\tSN:APMT01221302.1\tLN:4125\n@SQ\tSN:KB711525.1\tLN:4125\n@SQ\tSN:APMT01221305.1\tLN:4124\n@SQ\tSN:APMT01221306.1\tLN:4124\n@SQ\tSN:APMT01221307.1\tLN:4124\n@SQ\tSN:KB711551.1\tLN:4124\n@SQ\tSN:KB711656.1\tLN:4124\n@SQ\tSN:KB711921.1\tLN:4124\n@SQ\tSN:KB711421.1\tLN:4123\n@SQ\tSN:KB711530.1\tLN:4121\n@SQ\tSN:APMT01221165.1\tLN:4120\n@SQ\tSN:APMT01221318.1\tLN:4120\n@SQ\tSN:APMT01221330.1\tLN:4119\n@SQ\tSN:APMT01221132.1\tLN:4118\n@SQ\tSN:APMT01221331.1\tLN:4118\n@SQ\tSN:APMT01221332.1\tLN:4118\n@SQ\tSN:KB711682.1\tLN:4118\n@SQ\tSN:KB711351.1\tLN:4117\n@SQ\tSN:APMT01221098.1\tLN:4117\n@SQ\tSN:KB711493.1\tLN:4117\n@SQ\tSN:APMT01221335.1\tLN:4117\n@SQ\tSN:KB711785.1\tLN:4117\n@SQ\tSN:KB711512.1\tLN:4116\n@SQ\tSN:KB711601.1\tLN:4116\n@SQ\tSN:KB711027.1\tLN:4115\n@SQ\tSN:APMT01221105.1\tLN:4115\n@SQ\tSN:APMT01221203.1\tLN:4115\n@SQ\tSN:APMT01221338.1\tLN:4115\n@SQ\tSN:KB711422.1\tLN:4114\n@SQ\tSN:APMT01221343.1\tLN:4114\n@SQ\tSN:KB711470.1\tLN:4112\n@SQ\tSN:APMT01221350.1\tLN:4112\n@SQ\tSN:APMT01221111.1\tLN:4111\n@SQ\tSN:APMT01221355.1\tLN:4111\n@SQ\tSN:APMT01221356.1\tLN:4111\n@SQ\tSN:KB711617.1\tLN:4111\n@SQ\tSN:KB713032.1\tLN:4111\n@SQ\tSN:KB711426.1\tLN:4110\n@SQ\tSN:KB711440.1\tLN:4110\n@SQ\tSN:KB711661.1\tLN:4110\n@SQ\tSN:KB713737.1\tLN:4110\n@SQ\tSN:KB711699.1\tLN:4109\n@SQ\tSN:KB713215.1\tLN:4109\n@SQ\tSN:KB713544.1\tLN:4109\n@SQ\tSN:KB711439.1\tLN:4108\n@SQ\tSN:APMT01221133.1\tLN:4108\n@SQ\tSN:KB711487.1\tLN:4108\n@SQ\tSN:APMT01221364.1\tLN:4108\n@SQ\tSN:KB711730.1\tLN:4108\n@SQ\tSN:KB714320.1\tLN:4107\n@SQ\tSN:APMT01221363.1\tLN:4106\n@SQ\tSN:KB711458.1\tLN:4104\n@SQ\tSN:KB711597.1\tLN:4104\n@SQ\tSN:APMT01221249.1\tLN:4103\n@SQ\tSN:APMT01221375.1\tLN:4103\n@SQ\tSN:APMT01221082.1\tLN:4102\n@SQ\tSN:KB711557.1\tLN:4102\n@SQ\tSN:APMT01221164.1\tLN:4101\n@SQ\tSN:APMT01221387.1\tLN:4101\n@SQ\tSN:KB713488.1\tLN:4101\n@SQ\tSN:KB711162.1\tLN:4100\n@SQ\tSN:KB712605.1\tLN:4100\n@SQ\tSN:APMT01221390.1\tLN:4099\n@SQ\tSN:KB711642.1\tLN:4099\n@SQ\tSN:KB711989.1\tLN:4099\n@SQ\tSN:KB711352.1\tLN:4098\n@SQ\tSN:APMT01221412.1\tLN:4098\n@SQ\tSN:APMT01221398.1\tLN:4097\n@SQ\tSN:APMT01221399.1\tLN:4097\n@SQ\tSN:KB711968.1\tLN:4097\n@SQ\tSN:APMT01221400.1\tLN:4096\n@SQ\tSN:KB711511.1\tLN:4095\n@SQ\tSN:APMT01221367.1\tLN:4095\n@SQ\tSN:KB711665.1\tLN:4095\n@SQ\tSN:KB711765.1\tLN:4095\n@SQ\tSN:KB712050.1\tLN:4095\n@SQ\tSN:APMT01221408.1\tLN:4094\n@SQ\tSN:KB714089.1\tLN:4094\n@SQ\tSN:KB711386.1\tLN:4093\n@SQ\tSN:KB711547.1\tLN:4093\n@SQ\tSN:APMT01220986.1\tLN:4092\n@SQ\tSN:APMT01221233.1\tLN:4092\n@SQ\tSN:APMT01221407.1\tLN:4092\n@SQ\tSN:APMT01221064.1\tLN:4091\n@SQ\tSN:APMT01221279.1\tLN:4091\n@SQ\tSN:KB711553.1\tLN:4091\n@SQ\tSN:APMT01221415.1\tLN:4091\n@SQ\tSN:KB711476.1\tLN:4090\n@SQ\tSN:KB711552.1\tLN:4090\n@SQ\tSN:KB711706.1\tLN:4090\n@SQ\tSN:APMT01221211.1\tLN:4089\n@SQ\tSN:KB711709.1\tLN:4089\n@SQ\tSN:KB711495.1\tLN:4088\n@SQ\tSN:KB712551.1\tLN:4088\n@SQ\tSN:KB713224.1\tLN:4088\n@SQ\tSN:APMT01221250.1\tLN:4087\n@SQ\tSN:APMT01221293.1\tLN:4087\n@SQ\tSN:APMT01221372.1\tLN:4087\n@SQ\tSN:APMT01221589.1\tLN:4087\n@SQ\tSN:KB711538.1\tLN:4085\n@SQ\tSN:APMT01221464.1\tLN:4084\n@SQ\tSN:KB711701.1\tLN:4083\n@SQ\tSN:KB711389.1\tLN:4082\n@SQ\tSN:KB711540.1\tLN:4081\n@SQ\tSN:APMT01221480.1\tLN:4080\n@SQ\tSN:APMT01221482.1\tLN:4080\n@SQ\tSN:KB711449.1\tLN:4079\n@SQ\tSN:APMT01221327.1\tLN:4079\n@SQ\tSN:APMT01221481.1\tLN:4079\n@SQ\tSN:APMT01221312.1\tLN:4078\n@SQ\tSN:KB711532.1\tLN:4078\n@SQ\tSN:APMT01221491.1\tLN:4078\n@SQ\tSN:KB711662.1\tLN:4078\n@SQ\tSN:KB711702.1\tLN:4078\n@SQ\tSN:APMT01221494.1\tLN:4077\n@SQ\tSN:APMT01221497.1\tLN:4077\n@SQ\tSN:KB711595.1\tLN:4077\n@SQ\tSN:KB711668.1\tLN:4077\n@SQ\tSN:KB711017.1\tLN:4076\n@SQ\tSN:APMT01221510.1\tLN:4075\n@SQ\tSN:KB712236.1\tLN:4075\n@SQ\tSN:KB713312.1\tLN:4075\n@SQ\tSN:APMT01221280.1\tLN:4074\n@SQ\tSN:APMT01221514.1\tLN:4074\n@SQ\tSN:KB711670.1\tLN:4074\n@SQ\tSN:APMT01221068.1\tLN:4072\n@SQ\tSN:KB711544.1\tLN:4072\n@SQ\tSN:KB711584.1\tLN:4072\n@SQ\tSN:KB711844.1\tLN:4072\n@SQ\tSN:KB711521.1\tLN:4071\n@SQ\tSN:KB711720.1\tLN:4071\n@SQ\tSN:KB712500.1\tLN:4071\n@SQ\tSN:KB711878.1\tLN:4070\n@SQ\tSN:KB713532.1\tLN:4070\n@SQ\tSN:APMT01221284.1\tLN:4069\n@SQ\tSN:KB711539.1\tLN:4069\n@SQ\tSN:KB711970.1\tLN:4069\n@SQ\tSN:KB712095.1\tLN:4069\n@SQ\tSN:KB712390.1\tLN:4069\n@SQ\tSN:APMT01221161.1\tLN:4068\n@SQ\tSN:APMT01221283.1\tLN:4068\n@SQ\tSN:APMT01221525.1\tLN:4068\n@SQ\tSN:KB711578.1\tLN:4067\n@SQ\tSN:KB711817.1\tLN:4067\n@SQ\tSN:KB712217.1\tLN:4067\n@SQ\tSN:APMT01221347.1\tLN:4066\n@SQ\tSN:APMT01221538.1\tLN:4065\n@SQ\tSN:APMT01221537.1\tLN:4064\n@SQ\tSN:APMT01221563.1\tLN:4064\n@SQ\tSN:KB711581.1\tLN:4063\n@SQ\tSN:APMT01221561.1\tLN:4063\n@SQ\tSN:APMT01221562.1\tLN:4063\n@SQ\tSN:KB711660.1\tLN:4063\n@SQ\tSN:KB711545.1\tLN:4062\n@SQ\tSN:APMT01221564.1\tLN:4062\n@SQ\tSN:APMT01221565.1\tLN:4062\n@SQ\tSN:KB711648.1\tLN:4062\n@SQ\tSN:KB711558.1\tLN:4061\n@SQ\tSN:APMT01221566.1\tLN:4061\n@SQ\tSN:APMT01221567.1\tLN:4061\n@SQ\tSN:KB711252.1\tLN:4060\n@SQ\tSN:KB711609.1\tLN:4060\n@SQ\tSN:APMT01221580.1\tLN:4060\n@SQ\tSN:KB711419.1\tLN:4057\n@SQ\tSN:KB711619.1\tLN:4057\n@SQ\tSN:APMT01221600.1\tLN:4057\n@SQ\tSN:KB711638.1\tLN:4055\n@SQ\tSN:KB711758.1\tLN:4055\n@SQ\tSN:KB711582.1\tLN:4054\n@SQ\tSN:APMT01221552.1\tLN:4054\n@SQ\tSN:APMT01221709.1\tLN:4054\n@SQ\tSN:KB711571.1\tLN:4053\n@SQ\tSN:APMT01221616.1\tLN:4053\n@SQ\tSN:KB711516.1\tLN:4051\n@SQ\tSN:KB711546.1\tLN:4051\n@SQ\tSN:KB711577.1\tLN:4051\n@SQ\tSN:APMT01221623.1\tLN:4051\n@SQ\tSN:KB711650.1\tLN:4051\n@SQ\tSN:APMT01221438.1\tLN:4050\n@SQ\tSN:KB711623.1\tLN:4050\n@SQ\tSN:KB711767.1\tLN:4050\n@SQ\tSN:APMT01221529.1\tLN:4048\n@SQ\tSN:KB711628.1\tLN:4048\n@SQ\tSN:APMT01221630.1\tLN:4048\n@SQ\tSN:APMT01221631.1\tLN:4048\n@SQ\tSN:KB711672.1\tLN:4048\n@SQ\tSN:KB711568.1\tLN:4047\n@SQ\tSN:APMT01221632.1\tLN:4047\n@SQ\tSN:APMT01221344.1\tLN:4046\n@SQ\tSN:KB711599.1\tLN:4046\n@SQ\tSN:KB711637.1\tLN:4045\n@SQ\tSN:KB711778.1\tLN:4045\n@SQ\tSN:APMT01221386.1\tLN:4044\n@SQ\tSN:KB711655.1\tLN:4044\n@SQ\tSN:APMT01221644.1\tLN:4043\n@SQ\tSN:APMT01221645.1\tLN:4043\n@SQ\tSN:APMT01221646.1\tLN:4043\n@SQ\tSN:APMT01221649.1\tLN:4042\n@SQ\tSN:APMT01221421.1\tLN:4041\n@SQ\tSN:APMT01221619.1\tLN:4041\n@SQ\tSN:APMT01221655.1\tLN:4040\n@SQ\tSN:APMT01221662.1\tLN:4040\n@SQ\tSN:APMT01221831.1\tLN:4040\n@SQ\tSN:KB711775.1\tLN:4040\n@SQ\tSN:KB711560.1\tLN:4039\n@SQ\tSN:KB711579.1\tLN:4039\n@SQ\tSN:APMT01221665.1\tLN:4039\n@SQ\tSN:KB711814.1\tLN:4039\n@SQ\tSN:KB713365.1\tLN:4039\n@SQ\tSN:APMT01221435.1\tLN:4037\n@SQ\tSN:APMT01221675.1\tLN:4036\n@SQ\tSN:APMT01221676.1\tLN:4036\n@SQ\tSN:KB711721.1\tLN:4036\n@SQ\tSN:KB711542.1\tLN:4035\n@SQ\tSN:APMT01221409.1\tLN:4034\n@SQ\tSN:KB711618.1\tLN:4034\n@SQ\tSN:KB711675.1\tLN:4034\n@SQ\tSN:APMT01221691.1\tLN:4033\n@SQ\tSN:KB711744.1\tLN:4032\n@SQ\tSN:KB712008.1\tLN:4032\n@SQ\tSN:APMT01221706.1\tLN:4030\n@SQ\tSN:APMT01221707.1\tLN:4030\n@SQ\tSN:APMT01221712.1\tLN:4029\n@SQ\tSN:KB711509.1\tLN:4028\n@SQ\tSN:KB711652.1\tLN:4028\n@SQ\tSN:APMT01221704.1\tLN:4027\n@SQ\tSN:APMT01221726.1\tLN:4027\n@SQ\tSN:KB711630.1\tLN:4026\n@SQ\tSN:KB711905.1\tLN:4026\n@SQ\tSN:KB712298.1\tLN:4025\n@SQ\tSN:KB711686.1\tLN:4024\n@SQ\tSN:KB711333.1\tLN:4022\n@SQ\tSN:KB711598.1\tLN:4022\n@SQ\tSN:KB711719.1\tLN:4022\n@SQ\tSN:KB711787.1\tLN:4022\n@SQ\tSN:APMT01221746.1\tLN:4021\n@SQ\tSN:APMT01221747.1\tLN:4021\n@SQ\tSN:APMT01221597.1\tLN:4020\n@SQ\tSN:APMT01221650.1\tLN:4020\n@SQ\tSN:APMT01221750.1\tLN:4019\n@SQ\tSN:APMT01221639.1\tLN:4018\n@SQ\tSN:APMT01221756.1\tLN:4018\n@SQ\tSN:KB711824.1\tLN:4018\n@SQ\tSN:APMT01221513.1\tLN:4017\n@SQ\tSN:APMT01221755.1\tLN:4017\n@SQ\tSN:APMT01221757.1\tLN:4017\n@SQ\tSN:APMT01221762.1\tLN:4016\n@SQ\tSN:APMT01221765.1\tLN:4016\n@SQ\tSN:KB711807.1\tLN:4016\n@SQ\tSN:KB711830.1\tLN:4016\n@SQ\tSN:KB711622.1\tLN:4015\n@SQ\tSN:APMT01221769.1\tLN:4015\n@SQ\tSN:APMT01221770.1\tLN:4015\n@SQ\tSN:KB711550.1\tLN:4014\n@SQ\tSN:APMT01221753.1\tLN:4014\n@SQ\tSN:KB711437.1\tLN:4013\n@SQ\tSN:APMT01221528.1\tLN:4013\n@SQ\tSN:KB711694.1\tLN:4013\n@SQ\tSN:KB711708.1\tLN:4013\n@SQ\tSN:KB711782.1\tLN:4013\n@SQ\tSN:APMT01221777.1\tLN:4011\n@SQ\tSN:APMT01221780.1\tLN:4011\n@SQ\tSN:APMT01221592.1\tLN:4010\n@SQ\tSN:KB713806.1\tLN:4010\n@SQ\tSN:APMT01221786.1\tLN:4009\n@SQ\tSN:APMT01221787.1\tLN:4009\n@SQ\tSN:KB711925.1\tLN:4009\n@SQ\tSN:KB711626.1\tLN:4007\n@SQ\tSN:KB711671.1\tLN:4007\n@SQ\tSN:APMT01221796.1\tLN:4007\n@SQ\tSN:APMT01221802.1\tLN:4006\n@SQ\tSN:KB713018.1\tLN:4006\n@SQ\tSN:KB711845.1\tLN:4005\n@SQ\tSN:KB711608.1\tLN:4004\n@SQ\tSN:KB711640.1\tLN:4004\n@SQ\tSN:APMT01221785.1\tLN:4004\n@SQ\tSN:APMT01221807.1\tLN:4004\n@SQ\tSN:APMT01221025.1\tLN:4003\n@SQ\tSN:KB711641.1\tLN:4003\n@SQ\tSN:APMT01221810.1\tLN:4003\n@SQ\tSN:APMT01221826.1\tLN:4001\n@SQ\tSN:KB712375.1\tLN:4001\n@SQ\tSN:KB711589.1\tLN:4000\n@SQ\tSN:APMT01221829.1\tLN:4000\n@SQ\tSN:APMT01221830.1\tLN:4000\n@SQ\tSN:KB711478.1\tLN:3999\n@SQ\tSN:KB713169.1\tLN:3999\n@SQ\tSN:KB711663.1\tLN:3998\n@SQ\tSN:APMT01221838.1\tLN:3998\n@SQ\tSN:APMT01221729.1\tLN:3997\n@SQ\tSN:APMT01221850.1\tLN:3997\n@SQ\tSN:APMT01221851.1\tLN:3997\n@SQ\tSN:APMT01221811.1\tLN:3996\n@SQ\tSN:APMT01221854.1\tLN:3996\n@SQ\tSN:APMT01221857.1\tLN:3995\n@SQ\tSN:APMT01221860.1\tLN:3995\n@SQ\tSN:APMT01221865.1\tLN:3995\n@SQ\tSN:APMT01221866.1\tLN:3995\n@SQ\tSN:APMT01221867.1\tLN:3995\n@SQ\tSN:KB711710.1\tLN:3994\n@SQ\tSN:APMT01222233.1\tLN:3994\n@SQ\tSN:KB711615.1\tLN:3993\n@SQ\tSN:APMT01221873.1\tLN:3993\n@SQ\tSN:KB711592.1\tLN:3992\n@SQ\tSN:KB711684.1\tLN:3992\n@SQ\tSN:APMT01221887.1\tLN:3992\n@SQ\tSN:KB711741.1\tLN:3992\n@SQ\tSN:KB711954.1\tLN:3992\n@SQ\tSN:KB711704.1\tLN:3991\n@SQ\tSN:APMT01221892.1\tLN:3991\n@SQ\tSN:APMT01221705.1\tLN:3990\n@SQ\tSN:APMT01221895.1\tLN:3990\n@SQ\tSN:KB711600.1\tLN:3989\n@SQ\tSN:APMT01221899.1\tLN:3989\n@SQ\tSN:APMT01221902.1\tLN:3989\n@SQ\tSN:APMT01221905.1\tLN:3989\n@SQ\tSN:APMT01221910.1\tLN:3989\n@SQ\tSN:KB711310.1\tLN:3988\n@SQ\tSN:APMT01221666.1\tLN:3988\n@SQ\tSN:KB711691.1\tLN:3988\n@SQ\tSN:APMT01221879.1\tLN:3988\n@SQ\tSN:APMT01221911.1\tLN:3988\n@SQ\tSN:APMT01221918.1\tLN:3988\n@SQ\tSN:APMT01222575.1\tLN:3987\n@SQ\tSN:APMT01221719.1\tLN:3986\n@SQ\tSN:APMT01221927.1\tLN:3986\n@SQ\tSN:APMT01221928.1\tLN:3986\n@SQ\tSN:KB711998.1\tLN:3986\n@SQ\tSN:KB711284.1\tLN:3985\n@SQ\tSN:KB711302.1\tLN:3985\n@SQ\tSN:APMT01221929.1\tLN:3985\n@SQ\tSN:APMT01221937.1\tLN:3985\n@SQ\tSN:APMT01221791.1\tLN:3984\n@SQ\tSN:KB711722.1\tLN:3984\n@SQ\tSN:KB713746.1\tLN:3984\n@SQ\tSN:APMT01221874.1\tLN:3983\n@SQ\tSN:APMT01221941.1\tLN:3983\n@SQ\tSN:APMT01221945.1\tLN:3983\n@SQ\tSN:APMT01221946.1\tLN:3983\n@SQ\tSN:KB711596.1\tLN:3982\n@SQ\tSN:KB711651.1\tLN:3982\n@SQ\tSN:APMT01221947.1\tLN:3982\n@SQ\tSN:APMT01221948.1\tLN:3982\n@SQ\tSN:KB711887.1\tLN:3982\n@SQ\tSN:KB711535.1\tLN:3981\n@SQ\tSN:KB711740.1\tLN:3981\n@SQ\tSN:APMT01221951.1\tLN:3981\n@SQ\tSN:APMT01221957.1\tLN:3981\n@SQ\tSN:KB711620.1\tLN:3980\n@SQ\tSN:APMT01221708.1\tLN:3980\n@SQ\tSN:APMT01221959.1\tLN:3980\n@SQ\tSN:KB711614.1\tLN:3978\n@SQ\tSN:APMT01221677.1\tLN:3978\n@SQ\tSN:APMT01221972.1\tLN:3977\n@SQ\tSN:KB711751.1\tLN:3977\n@SQ\tSN:KB711803.1\tLN:3977\n@SQ\tSN:APMT01221973.1\tLN:3976\n@SQ\tSN:APMT01221974.1\tLN:3976\n@SQ\tSN:KB711326.1\tLN:3975\n@SQ\tSN:APMT01221703.1\tLN:3975\n@SQ\tSN:APMT01221975.1\tLN:3975\n@SQ\tSN:APMT01221977.1\tLN:3975\n@SQ\tSN:KB711749.1\tLN:3975\n@SQ\tSN:KB711631.1\tLN:3974\n@SQ\tSN:APMT01221640.1\tLN:3974\n@SQ\tSN:APMT01221981.1\tLN:3974\n@SQ\tSN:APMT01221982.1\tLN:3974\n@SQ\tSN:APMT01221988.1\tLN:3974\n@SQ\tSN:APMT01221991.1\tLN:3974\n@SQ\tSN:KB711696.1\tLN:3972\n@SQ\tSN:KB711793.1\tLN:3972\n@SQ\tSN:KB711781.1\tLN:3971\n@SQ\tSN:KB711784.1\tLN:3971\n@SQ\tSN:KB711850.1\tLN:3971\n@SQ\tSN:APMT01221966.1\tLN:3970\n@SQ\tSN:APMT01221999.1\tLN:3970\n@SQ\tSN:KB712105.1\tLN:3970\n@SQ\tSN:KB711734.1\tLN:3969\n@SQ\tSN:APMT01221532.1\tLN:3968\n@SQ\tSN:KB711605.1\tLN:3968\n@SQ\tSN:APMT01221768.1\tLN:3968\n@SQ\tSN:KB712007.1\tLN:3968\n@SQ\tSN:KB711368.1\tLN:3967\n@SQ\tSN:KB711705.1\tLN:3967\n@SQ\tSN:KB711678.1\tLN:3965\n@SQ\tSN:APMT01222083.1\tLN:3965\n@SQ\tSN:KB711725.1\tLN:3964\n@SQ\tSN:APMT01221998.1\tLN:3964\n@SQ\tSN:APMT01222036.1\tLN:3964\n@SQ\tSN:KB712701.1\tLN:3963\n@SQ\tSN:APMT01221392.1\tLN:3962\n@SQ\tSN:APMT01222052.1\tLN:3962\n@SQ\tSN:APMT01222057.1\tLN:3961\n@SQ\tSN:APMT01222058.1\tLN:3961\n@SQ\tSN:KB711044.1\tLN:3960\n@SQ\tSN:KB711676.1\tLN:3960\n@SQ\tSN:APMT01222059.1\tLN:3960\n@SQ\tSN:KB711804.1\tLN:3960\n@SQ\tSN:KB711624.1\tLN:3959\n@SQ\tSN:KB711646.1\tLN:3959\n@SQ\tSN:KB711649.1\tLN:3959\n@SQ\tSN:KB711768.1\tLN:3959\n@SQ\tSN:APMT01222067.1\tLN:3959\n@SQ\tSN:APMT01222068.1\tLN:3959\n@SQ\tSN:APMT01222069.1\tLN:3959\n@SQ\tSN:APMT01221832.1\tLN:3958\n@SQ\tSN:APMT01222089.1\tLN:3958\n@SQ\tSN:KB711912.1\tLN:3958\n@SQ\tSN:KB712234.1\tLN:3958\n@SQ\tSN:KB711565.1\tLN:3957\n@SQ\tSN:APMT01221754.1\tLN:3957\n@SQ\tSN:KB713826.1\tLN:3956\n@SQ\tSN:KB711733.1\tLN:3955\n@SQ\tSN:APMT01222084.1\tLN:3955\n@SQ\tSN:APMT01222085.1\tLN:3955\n@SQ\tSN:KB711874.1\tLN:3955\n@SQ\tSN:KB711604.1\tLN:3954\n@SQ\tSN:KB711774.1\tLN:3954\n@SQ\tSN:APMT01222088.1\tLN:3954\n@SQ\tSN:KB711688.1\tLN:3953\n@SQ\tSN:KB711853.1\tLN:3953\n@SQ\tSN:APMT01221524.1\tLN:3952\n@SQ\tSN:KB711361.1\tLN:3950\n@SQ\tSN:KB711916.1\tLN:3950\n@SQ\tSN:KB711653.1\tLN:3949\n@SQ\tSN:APMT01222099.1\tLN:3949\n@SQ\tSN:KB711843.1\tLN:3949\n@SQ\tSN:KB712122.1\tLN:3949\n@SQ\tSN:APMT01221797.1\tLN:3948\n@SQ\tSN:KB711973.1\tLN:3948\n@SQ\tSN:KB711690.1\tLN:3947\n@SQ\tSN:APMT01221896.1\tLN:3947\n@SQ\tSN:KB711752.1\tLN:3946\n@SQ\tSN:KB711755.1\tLN:3946\n@SQ\tSN:KB712039.1\tLN:3946\n@SQ\tSN:KB711742.1\tLN:3944\n@SQ\tSN:APMT01222115.1\tLN:3944\n@SQ\tSN:APMT01221925.1\tLN:3943\n@SQ\tSN:APMT01222117.1\tLN:3943\n@SQ\tSN:APMT01222118.1\tLN:3943\n@SQ\tSN:KB712153.1\tLN:3943\n@SQ\tSN:APMT01216141.1\tLN:3942\n@SQ\tSN:APMT01222121.1\tLN:3942\n@SQ\tSN:APMT01222122.1\tLN:3942\n@SQ\tSN:APMT01222126.1\tLN:3942\n@SQ\tSN:APMT01222127.1\tLN:3941\n@SQ\tSN:APMT01222129.1\tLN:3941\n@SQ\tSN:KB712423.1\tLN:3941\n@SQ\tSN:KB711645.1\tLN:3940\n@SQ\tSN:APMT01221872.1\tLN:3940\n@SQ\tSN:APMT01222130.1\tLN:3940\n@SQ\tSN:APMT01222131.1\tLN:3940\n@SQ\tSN:APMT01222134.1\tLN:3940\n@SQ\tSN:APMT01221926.1\tLN:3939\n@SQ\tSN:APMT01222167.1\tLN:3939\n@SQ\tSN:KB712565.1\tLN:3939\n@SQ\tSN:APMT01222144.1\tLN:3937\n@SQ\tSN:KB711750.1\tLN:3936\n@SQ\tSN:APMT01221956.1\tLN:3935\n@SQ\tSN:APMT01221958.1\tLN:3934\n@SQ\tSN:KB711763.1\tLN:3934\n@SQ\tSN:KB711537.1\tLN:3933\n@SQ\tSN:KB711792.1\tLN:3933\n@SQ\tSN:APMT01222165.1\tLN:3932\n@SQ\tSN:APMT01222166.1\tLN:3932\n@SQ\tSN:APMT01222170.1\tLN:3931\n@SQ\tSN:APMT01222173.1\tLN:3930\n@SQ\tSN:APMT01222179.1\tLN:3930\n@SQ\tSN:KB711860.1\tLN:3930\n@SQ\tSN:KB711556.1\tLN:3929\n@SQ\tSN:APMT01222164.1\tLN:3929\n@SQ\tSN:APMT01221917.1\tLN:3928\n@SQ\tSN:APMT01222128.1\tLN:3928\n@SQ\tSN:APMT01222183.1\tLN:3928\n@SQ\tSN:KB710492.1\tLN:3927\n@SQ\tSN:APMT01221718.1\tLN:3926\n@SQ\tSN:APMT01222192.1\tLN:3926\n@SQ\tSN:KB711674.1\tLN:3925\n@SQ\tSN:KB711799.1\tLN:3925\n@SQ\tSN:KB711891.1\tLN:3925\n@SQ\tSN:KB712749.1\tLN:3925\n@SQ\tSN:KB714191.1\tLN:3924\n@SQ\tSN:KB711654.1\tLN:3923\n@SQ\tSN:KB711715.1\tLN:3923\n@SQ\tSN:KB711827.1\tLN:3923\n@SQ\tSN:APMT01222213.1\tLN:3922\n@SQ\tSN:APMT01222799.1\tLN:3922\n@SQ\tSN:KB711504.1\tLN:3921\n@SQ\tSN:APMT01221987.1\tLN:3921\n@SQ\tSN:APMT01222216.1\tLN:3921\n@SQ\tSN:KB711899.1\tLN:3921\n@SQ\tSN:APMT01222401.1\tLN:3920\n@SQ\tSN:KB711996.1\tLN:3920\n@SQ\tSN:KB711747.1\tLN:3919\n@SQ\tSN:APMT01222193.1\tLN:3919\n@SQ\tSN:APMT01222224.1\tLN:3919\n@SQ\tSN:APMT01222225.1\tLN:3919\n@SQ\tSN:APMT01222226.1\tLN:3919\n@SQ\tSN:KB711666.1\tLN:3918\n@SQ\tSN:KB711697.1\tLN:3918\n@SQ\tSN:APMT01222227.1\tLN:3918\n@SQ\tSN:KB710437.1\tLN:3917\n@SQ\tSN:APMT01222241.1\tLN:3917\n@SQ\tSN:KB711773.1\tLN:3916\n@SQ\tSN:KB711842.1\tLN:3916\n@SQ\tSN:KB711716.1\tLN:3915\n@SQ\tSN:KB711791.1\tLN:3914\n@SQ\tSN:APMT01222260.1\tLN:3914\n@SQ\tSN:KB714080.1\tLN:3914\n@SQ\tSN:KB711693.1\tLN:3913\n@SQ\tSN:KB711848.1\tLN:3913\n@SQ\tSN:APMT01222269.1\tLN:3913\n@SQ\tSN:KB711711.1\tLN:3912\n@SQ\tSN:KB711728.1\tLN:3912\n@SQ\tSN:APMT01222000.1\tLN:3912\n@SQ\tSN:APMT01222035.1\tLN:3912\n@SQ\tSN:APMT01222043.1\tLN:3912\n@SQ\tSN:APMT01222242.1\tLN:3912\n@SQ\tSN:APMT01222275.1\tLN:3911\n@SQ\tSN:APMT01222277.1\tLN:3911\n@SQ\tSN:APMT01222280.1\tLN:3910\n@SQ\tSN:KB711727.1\tLN:3909\n@SQ\tSN:APMT01222151.1\tLN:3909\n@SQ\tSN:APMT01222288.1\tLN:3909\n@SQ\tSN:KB711713.1\tLN:3908\n@SQ\tSN:APMT01221882.1\tLN:3908\n@SQ\tSN:APMT01222116.1\tLN:3908\n@SQ\tSN:APMT01222293.1\tLN:3908\n@SQ\tSN:APMT01222294.1\tLN:3908\n@SQ\tSN:KB711738.1\tLN:3907\n@SQ\tSN:APMT01222135.1\tLN:3907\n@SQ\tSN:APMT01222301.1\tLN:3907\n@SQ\tSN:KB712722.1\tLN:3907\n@SQ\tSN:APMT01222026.1\tLN:3906\n@SQ\tSN:APMT01222092.1\tLN:3906\n@SQ\tSN:KB711889.1\tLN:3906\n@SQ\tSN:KB713304.1\tLN:3906\n@SQ\tSN:KB711798.1\tLN:3905\n@SQ\tSN:APMT01222310.1\tLN:3905\n@SQ\tSN:KB711846.1\tLN:3904\n@SQ\tSN:APMT01222314.1\tLN:3904\n@SQ\tSN:APMT01222315.1\tLN:3904\n@SQ\tSN:APMT01222316.1\tLN:3904\n@SQ\tSN:KB712002.1\tLN:3904\n@SQ\tSN:KB712017.1\tLN:3904\n@SQ\tSN:KB711813.1\tLN:3903\n@SQ\tSN:KB711858.1\tLN:3903\n@SQ\tSN:APMT01222317.1\tLN:3903\n@SQ\tSN:APMT01222324.1\tLN:3902\n@SQ\tSN:KB711883.1\tLN:3902\n@SQ\tSN:APMT01222333.1\tLN:3901\n@SQ\tSN:APMT01222334.1\tLN:3901\n@SQ\tSN:KB711840.1\tLN:3900\n@SQ\tSN:APMT01222283.1\tLN:3900\n@SQ\tSN:KB710861.1\tLN:3899\n@SQ\tSN:APMT01222339.1\tLN:3899\n@SQ\tSN:KB711647.1\tLN:3898\n@SQ\tSN:APMT01222347.1\tLN:3897\n@SQ\tSN:KB712421.1\tLN:3897\n@SQ\tSN:APMT01221801.1\tLN:3896\n@SQ\tSN:APMT01222219.1\tLN:3896\n@SQ\tSN:KB713305.1\tLN:3896\n@SQ\tSN:KB714280.1\tLN:3896\n@SQ\tSN:APMT01222110.1\tLN:3895\n@SQ\tSN:KB711864.1\tLN:3894\n@SQ\tSN:APMT01222374.1\tLN:3894\n@SQ\tSN:APMT01222378.1\tLN:3894\n@SQ\tSN:KB711918.1\tLN:3894\n@SQ\tSN:KB712121.1\tLN:3894\n@SQ\tSN:KB711760.1\tLN:3893\n@SQ\tSN:APMT01222386.1\tLN:3893\n@SQ\tSN:APMT01222218.1\tLN:3892\n@SQ\tSN:APMT01222109.1\tLN:3891\n@SQ\tSN:APMT01222180.1\tLN:3889\n@SQ\tSN:KB711603.1\tLN:3888\n@SQ\tSN:KB711859.1\tLN:3888\n@SQ\tSN:APMT01222402.1\tLN:3888\n@SQ\tSN:APMT01222403.1\tLN:3888\n@SQ\tSN:KB711928.1\tLN:3888\n@SQ\tSN:APMT01222410.1\tLN:3887\n@SQ\tSN:APMT01222161.1\tLN:3886\n@SQ\tSN:KB711895.1\tLN:3886\n@SQ\tSN:APMT01222418.1\tLN:3885\n@SQ\tSN:APMT01222419.1\tLN:3884\n@SQ\tSN:KB711900.1\tLN:3883\n@SQ\tSN:APMT01222432.1\tLN:3883\n@SQ\tSN:APMT01222428.1\tLN:3882\n@SQ\tSN:KB711903.1\tLN:3881\n@SQ\tSN:APMT01222433.1\tLN:3881\n@SQ\tSN:APMT01222434.1\tLN:3881\n@SQ\tSN:KB712224.1\tLN:3881\n@SQ\tSN:KB714344.1\tLN:3881\n@SQ\tSN:APMT01222304.1\tLN:3880\n@SQ\tSN:APMT01222394.1\tLN:3880\n@SQ\tSN:APMT01222420.1\tLN:3880\n@SQ\tSN:APMT01222435.1\tLN:3880\n@SQ\tSN:APMT01222442.1\tLN:3880\n@SQ\tSN:APMT01222443.1\tLN:3879\n@SQ\tSN:KB712054.1\tLN:3879\n@SQ\tSN:APMT01221976.1\tLN:3878\n@SQ\tSN:APMT01222359.1\tLN:3878\n@SQ\tSN:APMT01222449.1\tLN:3878\n@SQ\tSN:KB712515.1\tLN:3878\n@SQ\tSN:APMT01222397.1\tLN:3877\n@SQ\tSN:KB711902.1\tLN:3877\n@SQ\tSN:KB711940.1\tLN:3877\n@SQ\tSN:KB711944.1\tLN:3877\n@SQ\tSN:APMT01221944.1\tLN:3875\n@SQ\tSN:APMT01222462.1\tLN:3875\n@SQ\tSN:APMT01222465.1\tLN:3875\n@SQ\tSN:APMT01222470.1\tLN:3875\n@SQ\tSN:KB711927.1\tLN:3875\n@SQ\tSN:APMT01222513.1\tLN:3875\n@SQ\tSN:KB711602.1\tLN:3874\n@SQ\tSN:APMT01222157.1\tLN:3874\n@SQ\tSN:APMT01222475.1\tLN:3874\n@SQ\tSN:KB711795.1\tLN:3873\n@SQ\tSN:APMT01222444.1\tLN:3873\n@SQ\tSN:APMT01222480.1\tLN:3873\n@SQ\tSN:KB712274.1\tLN:3873\n@SQ\tSN:KB712348.1\tLN:3873\n@SQ\tSN:APMT01222481.1\tLN:3872\n@SQ\tSN:APMT01222482.1\tLN:3872\n@SQ\tSN:KB711801.1\tLN:3870\n@SQ\tSN:APMT01222476.1\tLN:3870\n@SQ\tSN:KB714221.1\tLN:3870\n@SQ\tSN:APMT01222062.1\tLN:3868\n@SQ\tSN:KB711805.1\tLN:3868\n@SQ\tSN:KB712080.1\tLN:3868\n@SQ\tSN:KB712124.1\tLN:3867\n@SQ\tSN:APMT01222270.1\tLN:3866\n@SQ\tSN:APMT01222519.1\tLN:3866\n@SQ\tSN:APMT01222525.1\tLN:3866\n@SQ\tSN:KB711960.1\tLN:3866\n@SQ\tSN:KB712042.1\tLN:3866\n@SQ\tSN:KB711766.1\tLN:3865\n@SQ\tSN:APMT01222526.1\tLN:3865\n@SQ\tSN:APMT01222527.1\tLN:3864\n@SQ\tSN:KB711819.1\tLN:3863\n@SQ\tSN:APMT01222409.1\tLN:3863\n@SQ\tSN:APMT01222542.1\tLN:3863\n@SQ\tSN:APMT01222547.1\tLN:3862\n@SQ\tSN:APMT01222548.1\tLN:3862\n@SQ\tSN:APMT01222549.1\tLN:3862\n@SQ\tSN:APMT01222217.1\tLN:3861\n@SQ\tSN:KB711871.1\tLN:3861\n@SQ\tSN:APMT01222553.1\tLN:3861\n@SQ\tSN:KB712102.1\tLN:3861\n@SQ\tSN:KB712104.1\tLN:3861\n@SQ\tSN:APMT01222228.1\tLN:3860\n@SQ\tSN:APMT01222381.1\tLN:3860\n@SQ\tSN:APMT01222559.1\tLN:3860\n@SQ\tSN:KB711952.1\tLN:3860\n@SQ\tSN:KB711770.1\tLN:3859\n@SQ\tSN:APMT01222311.1\tLN:3859\n@SQ\tSN:KB711930.1\tLN:3859\n@SQ\tSN:KB711753.1\tLN:3858\n@SQ\tSN:APMT01222604.1\tLN:3858\n@SQ\tSN:KB711967.1\tLN:3858\n@SQ\tSN:APMT01222328.1\tLN:3857\n@SQ\tSN:APMT01222554.1\tLN:3857\n@SQ\tSN:APMT01222583.1\tLN:3857\n@SQ\tSN:KB712814.1\tLN:3856\n@SQ\tSN:APMT01222346.1\tLN:3855\n@SQ\tSN:KB712046.1\tLN:3855\n@SQ\tSN:KB711893.1\tLN:3853\n@SQ\tSN:APMT01222595.1\tLN:3853\n@SQ\tSN:KB711976.1\tLN:3853\n@SQ\tSN:KB712043.1\tLN:3853\n@SQ\tSN:KB711822.1\tLN:3852\n@SQ\tSN:KB711829.1\tLN:3852\n@SQ\tSN:KB711869.1\tLN:3852\n@SQ\tSN:KB711897.1\tLN:3852\n@SQ\tSN:KB711745.1\tLN:3851\n@SQ\tSN:KB711879.1\tLN:3850\n@SQ\tSN:APMT01222607.1\tLN:3850\n@SQ\tSN:APMT01222608.1\tLN:3850\n@SQ\tSN:KB712091.1\tLN:3849\n@SQ\tSN:KB711873.1\tLN:3848\n@SQ\tSN:APMT01222617.1\tLN:3848\n@SQ\tSN:KB711961.1\tLN:3847\n@SQ\tSN:APMT01222618.1\tLN:3847\n@SQ\tSN:APMT01222621.1\tLN:3847\n@SQ\tSN:KB711924.1\tLN:3846\n@SQ\tSN:APMT01222596.1\tLN:3845\n@SQ\tSN:KB711966.1\tLN:3845\n@SQ\tSN:APMT01222629.1\tLN:3845\n@SQ\tSN:KB712085.1\tLN:3845\n@SQ\tSN:APMT01222632.1\tLN:3844\n@SQ\tSN:APMT01222635.1\tLN:3844\n@SQ\tSN:APMT01222636.1\tLN:3844\n@SQ\tSN:KB712009.1\tLN:3844\n@SQ\tSN:APMT01222287.1\tLN:3843\n@SQ\tSN:KB711913.1\tLN:3842\n@SQ\tSN:APMT01222645.1\tLN:3842\n@SQ\tSN:KB713987.1\tLN:3842\n@SQ\tSN:KB711926.1\tLN:3841\n@SQ\tSN:KB711956.1\tLN:3841\n@SQ\tSN:APMT01222647.1\tLN:3841\n@SQ\tSN:KB712074.1\tLN:3841\n@SQ\tSN:KB712103.1\tLN:3841\n@SQ\tSN:KB711906.1\tLN:3840\n@SQ\tSN:KB711972.1\tLN:3840\n@SQ\tSN:APMT01222646.1\tLN:3840\n@SQ\tSN:APMT01222654.1\tLN:3840\n@SQ\tSN:KB711772.1\tLN:3839\n@SQ\tSN:KB711826.1\tLN:3839\n@SQ\tSN:KB711865.1\tLN:3839\n@SQ\tSN:KB711877.1\tLN:3839\n@SQ\tSN:KB711995.1\tLN:3839\n@SQ\tSN:KB712755.1\tLN:3839\n@SQ\tSN:KB711681.1\tLN:3838\n@SQ\tSN:APMT01222398.1\tLN:3838\n@SQ\tSN:APMT01222664.1\tLN:3838\n@SQ\tSN:APMT01222666.1\tLN:3838\n@SQ\tSN:APMT01222669.1\tLN:3838\n@SQ\tSN:APMT01221479.1\tLN:3837\n@SQ\tSN:KB711783.1\tLN:3837\n@SQ\tSN:APMT01222670.1\tLN:3837\n@SQ\tSN:KB713942.1\tLN:3837\n@SQ\tSN:KB711880.1\tLN:3836\n@SQ\tSN:KB711980.1\tLN:3836\n@SQ\tSN:APMT01222674.1\tLN:3836\n@SQ\tSN:APMT01222679.1\tLN:3836\n@SQ\tSN:KB712004.1\tLN:3836\n@SQ\tSN:KB713106.1\tLN:3836\n@SQ\tSN:APMT01222518.1\tLN:3835\n@SQ\tSN:KB711997.1\tLN:3835\n@SQ\tSN:KB711835.1\tLN:3834\n@SQ\tSN:APMT01222276.1\tLN:3834\n@SQ\tSN:APMT01222673.1\tLN:3834\n@SQ\tSN:KB711910.1\tLN:3833\n@SQ\tSN:APMT01222477.1\tLN:3833\n@SQ\tSN:APMT01222688.1\tLN:3833\n@SQ\tSN:APMT01222689.1\tLN:3833\n@SQ\tSN:KB711838.1\tLN:3832\n@SQ\tSN:APMT01222391.1\tLN:3831\n@SQ\tSN:APMT01222456.1\tLN:3831\n@SQ\tSN:KB711987.1\tLN:3831\n@SQ\tSN:APMT01222705.1\tLN:3831\n@SQ\tSN:APMT01222108.1\tLN:3830\n@SQ\tSN:APMT01222709.1\tLN:3830\n@SQ\tSN:APMT01222712.1\tLN:3830\n@SQ\tSN:KB711808.1\tLN:3829\n@SQ\tSN:APMT01222721.1\tLN:3829\n@SQ\tSN:KB711911.1\tLN:3828\n@SQ\tSN:APMT01222724.1\tLN:3828\n@SQ\tSN:KB712128.1\tLN:3827\n@SQ\tSN:APMT01222417.1\tLN:3826\n@SQ\tSN:KB711904.1\tLN:3826\n@SQ\tSN:APMT01222697.1\tLN:3826\n@SQ\tSN:APMT01222732.1\tLN:3825\n@SQ\tSN:APMT01222733.1\tLN:3825\n@SQ\tSN:APMT01222734.1\tLN:3825\n@SQ\tSN:APMT01222735.1\tLN:3825\n@SQ\tSN:KB712052.1\tLN:3825\n@SQ\tSN:APMT01222520.1\tLN:3823\n@SQ\tSN:KB712014.1\tLN:3823\n@SQ\tSN:APMT01223306.1\tLN:3823\n@SQ\tSN:KB711861.1\tLN:3822\n@SQ\tSN:KB711934.1\tLN:3822\n@SQ\tSN:APMT01222738.1\tLN:3822\n@SQ\tSN:APMT01222539.1\tLN:3821\n@SQ\tSN:APMT01222761.1\tLN:3821\n@SQ\tSN:APMT01222763.1\tLN:3821\n@SQ\tSN:KB712057.1\tLN:3821\n@SQ\tSN:APMT01222762.1\tLN:3820\n@SQ\tSN:KB711832.1\tLN:3819\n@SQ\tSN:KB712006.1\tLN:3819\n@SQ\tSN:APMT01222773.1\tLN:3819\n@SQ\tSN:KB712028.1\tLN:3819\n@SQ\tSN:KB712494.1\tLN:3819\n@SQ\tSN:APMT01222776.1\tLN:3818\n@SQ\tSN:KB712422.1\tLN:3818\n@SQ\tSN:KB711875.1\tLN:3817\n@SQ\tSN:APMT01222459.1\tLN:3817\n@SQ\tSN:KB711982.1\tLN:3817\n@SQ\tSN:APMT01222696.1\tLN:3817\n@SQ\tSN:APMT01222768.1\tLN:3817\n@SQ\tSN:APMT01222781.1\tLN:3817\n@SQ\tSN:KB711868.1\tLN:3816\n@SQ\tSN:KB712064.1\tLN:3816\n@SQ\tSN:KB712583.1\tLN:3816\n@SQ\tSN:KB711836.1\tLN:3815\n@SQ\tSN:KB711888.1\tLN:3815\n@SQ\tSN:APMT01222782.1\tLN:3815\n@SQ\tSN:KB712051.1\tLN:3815\n@SQ\tSN:KB712023.1\tLN:3814\n@SQ\tSN:KB711657.1\tLN:3813\n@SQ\tSN:KB711837.1\tLN:3813\n@SQ\tSN:KB712055.1\tLN:3813\n@SQ\tSN:KB714057.1\tLN:3813\n@SQ\tSN:KB711993.1\tLN:3812\n@SQ\tSN:APMT01222814.1\tLN:3812\n@SQ\tSN:APMT01222492.1\tLN:3811\n@SQ\tSN:APMT01222820.1\tLN:3811\n@SQ\tSN:KB712016.1\tLN:3810\n@SQ\tSN:APMT01222815.1\tLN:3810\n@SQ\tSN:KB712059.1\tLN:3810\n@SQ\tSN:KB713877.1\tLN:3810\n@SQ\tSN:KB711892.1\tLN:3809\n@SQ\tSN:APMT01222828.1\tLN:3809\n@SQ\tSN:APMT01222829.1\tLN:3809\n@SQ\tSN:KB711890.1\tLN:3808\n@SQ\tSN:KB711985.1\tLN:3808\n@SQ\tSN:KB712109.1\tLN:3808\n@SQ\tSN:KB712901.1\tLN:3808\n@SQ\tSN:APMT01222431.1\tLN:3807\n@SQ\tSN:APMT01222838.1\tLN:3807\n@SQ\tSN:APMT01222842.1\tLN:3806\n@SQ\tSN:KB712073.1\tLN:3806\n@SQ\tSN:APMT01222845.1\tLN:3805\n@SQ\tSN:APMT01222550.1\tLN:3804\n@SQ\tSN:KB712044.1\tLN:3804\n@SQ\tSN:APMT01222284.1\tLN:3803\n@SQ\tSN:APMT01222657.1\tLN:3803\n@SQ\tSN:KB711983.1\tLN:3803\n@SQ\tSN:APMT01222852.1\tLN:3803\n@SQ\tSN:APMT01222861.1\tLN:3803\n@SQ\tSN:KB712005.1\tLN:3802\n@SQ\tSN:KB711667.1\tLN:3801\n@SQ\tSN:KB712058.1\tLN:3801\n@SQ\tSN:KB712111.1\tLN:3801\n@SQ\tSN:APMT01222682.1\tLN:3800\n@SQ\tSN:APMT01222869.1\tLN:3800\n@SQ\tSN:APMT01222589.1\tLN:3799\n@SQ\tSN:KB711992.1\tLN:3799\n@SQ\tSN:APMT01222881.1\tLN:3799\n@SQ\tSN:APMT01222567.1\tLN:3798\n@SQ\tSN:APMT01222570.1\tLN:3798\n@SQ\tSN:APMT01222887.1\tLN:3797\n@SQ\tSN:APMT01222888.1\tLN:3797\n@SQ\tSN:APMT01222534.1\tLN:3796\n@SQ\tSN:KB713211.1\tLN:3796\n@SQ\tSN:KB711917.1\tLN:3795\n@SQ\tSN:APMT01222586.1\tLN:3795\n@SQ\tSN:KB712025.1\tLN:3795\n@SQ\tSN:KB712089.1\tLN:3795\n@SQ\tSN:KB714047.1\tLN:3795\n@SQ\tSN:KB711886.1\tLN:3794\n@SQ\tSN:KB711937.1\tLN:3794\n@SQ\tSN:KB711978.1\tLN:3794\n@SQ\tSN:KB712021.1\tLN:3793\n@SQ\tSN:APMT01222902.1\tLN:3793\n@SQ\tSN:APMT01222989.1\tLN:3793\n@SQ\tSN:KB711855.1\tLN:3792\n@SQ\tSN:KB711990.1\tLN:3792\n@SQ\tSN:APMT01222720.1\tLN:3791\n@SQ\tSN:APMT01222920.1\tLN:3791\n@SQ\tSN:KB712146.1\tLN:3791\n@SQ\tSN:KB712152.1\tLN:3791\n@SQ\tSN:KB712026.1\tLN:3790\n@SQ\tSN:APMT01222922.1\tLN:3789\n@SQ\tSN:KB712129.1\tLN:3788\n@SQ\tSN:KB712209.1\tLN:3788\n@SQ\tSN:KB711909.1\tLN:3787\n@SQ\tSN:KB712012.1\tLN:3786\n@SQ\tSN:KB712037.1\tLN:3786\n@SQ\tSN:KB711828.1\tLN:3785\n@SQ\tSN:KB711965.1\tLN:3785\n@SQ\tSN:KB712108.1\tLN:3785\n@SQ\tSN:APMT01222949.1\tLN:3784\n@SQ\tSN:KB712138.1\tLN:3784\n@SQ\tSN:APMT01222626.1\tLN:3783\n@SQ\tSN:APMT01222954.1\tLN:3783\n@SQ\tSN:APMT01222955.1\tLN:3783\n@SQ\tSN:APMT01222921.1\tLN:3782\n@SQ\tSN:KB711825.1\tLN:3781\n@SQ\tSN:KB711929.1\tLN:3781\n@SQ\tSN:KB711947.1\tLN:3781\n@SQ\tSN:APMT01222582.1\tLN:3781\n@SQ\tSN:APMT01222665.1\tLN:3781\n@SQ\tSN:KB711994.1\tLN:3781\n@SQ\tSN:APMT01222961.1\tLN:3781\n@SQ\tSN:APMT01222962.1\tLN:3781\n@SQ\tSN:APMT01222963.1\tLN:3781\n@SQ\tSN:KB712077.1\tLN:3780\n@SQ\tSN:APMT01222965.1\tLN:3780\n@SQ\tSN:KB712206.1\tLN:3780\n@SQ\tSN:KB712061.1\tLN:3779\n@SQ\tSN:KB711485.1\tLN:3778\n@SQ\tSN:KB711969.1\tLN:3778\n@SQ\tSN:APMT01222979.1\tLN:3778\n@SQ\tSN:KB711932.1\tLN:3777\n@SQ\tSN:APMT01222974.1\tLN:3777\n@SQ\tSN:APMT01222992.1\tLN:3777\n@SQ\tSN:APMT01222694.1\tLN:3776\n@SQ\tSN:APMT01222730.1\tLN:3776\n@SQ\tSN:KB712092.1\tLN:3776\n@SQ\tSN:KB712159.1\tLN:3776\n@SQ\tSN:KB711692.1\tLN:3775\n@SQ\tSN:KB712053.1\tLN:3775\n@SQ\tSN:APMT01222966.1\tLN:3775\n@SQ\tSN:APMT01222993.1\tLN:3775\n@SQ\tSN:APMT01222994.1\tLN:3775\n@SQ\tSN:KB712013.1\tLN:3774\n@SQ\tSN:KB712068.1\tLN:3774\n@SQ\tSN:KB712383.1\tLN:3774\n@SQ\tSN:KB711933.1\tLN:3773\n@SQ\tSN:KB711942.1\tLN:3773\n@SQ\tSN:APMT01222811.1\tLN:3773\n@SQ\tSN:APMT01223008.1\tLN:3773\n@SQ\tSN:KB712038.1\tLN:3772\n@SQ\tSN:APMT01222913.1\tLN:3772\n@SQ\tSN:APMT01222950.1\tLN:3772\n@SQ\tSN:APMT01223010.1\tLN:3772\n@SQ\tSN:KB712349.1\tLN:3772\n@SQ\tSN:KB713812.1\tLN:3772\n@SQ\tSN:KB711707.1\tLN:3771\n@SQ\tSN:APMT01222695.1\tLN:3771\n@SQ\tSN:APMT01223009.1\tLN:3771\n@SQ\tSN:APMT01223024.1\tLN:3771\n@SQ\tSN:KB712184.1\tLN:3771\n@SQ\tSN:KB712101.1\tLN:3770\n@SQ\tSN:APMT01223028.1\tLN:3770\n@SQ\tSN:KB712186.1\tLN:3770\n@SQ\tSN:APMT01223040.1\tLN:3769\n@SQ\tSN:KB712219.1\tLN:3769\n@SQ\tSN:KB712049.1\tLN:3768\n@SQ\tSN:APMT01223043.1\tLN:3768\n@SQ\tSN:KB713764.1\tLN:3768\n@SQ\tSN:KB711548.1\tLN:3767\n@SQ\tSN:KB712018.1\tLN:3767\n@SQ\tSN:KB712048.1\tLN:3767\n@SQ\tSN:APMT01223050.1\tLN:3767\n@SQ\tSN:KB712183.1\tLN:3767\n@SQ\tSN:KB712082.1\tLN:3766\n@SQ\tSN:APMT01223055.1\tLN:3766\n@SQ\tSN:APMT01223061.1\tLN:3766\n@SQ\tSN:APMT01223062.1\tLN:3766\n@SQ\tSN:APMT01223063.1\tLN:3766\n@SQ\tSN:APMT01223064.1\tLN:3766\n@SQ\tSN:KB711759.1\tLN:3765\n@SQ\tSN:KB711977.1\tLN:3765\n@SQ\tSN:APMT01223065.1\tLN:3765\n@SQ\tSN:KB712202.1\tLN:3765\n@SQ\tSN:APMT01223068.1\tLN:3764\n@SQ\tSN:APMT01223071.1\tLN:3764\n@SQ\tSN:KB712131.1\tLN:3764\n@SQ\tSN:APMT01221978.1\tLN:3763\n@SQ\tSN:KB712030.1\tLN:3763\n@SQ\tSN:KB712071.1\tLN:3763\n@SQ\tSN:APMT01222964.1\tLN:3763\n@SQ\tSN:KB711821.1\tLN:3762\n@SQ\tSN:KB712045.1\tLN:3761\n@SQ\tSN:KB712197.1\tLN:3761\n@SQ\tSN:KB712201.1\tLN:3761\n@SQ\tSN:KB711852.1\tLN:3760\n@SQ\tSN:APMT01222488.1\tLN:3760\n@SQ\tSN:KB712113.1\tLN:3760\n@SQ\tSN:KB712020.1\tLN:3758\n@SQ\tSN:KB712069.1\tLN:3758\n@SQ\tSN:KB712096.1\tLN:3758\n@SQ\tSN:APMT01223092.1\tLN:3758\n@SQ\tSN:KB712198.1\tLN:3758\n@SQ\tSN:APMT01223112.1\tLN:3757\n@SQ\tSN:KB712157.1\tLN:3757\n@SQ\tSN:KB711950.1\tLN:3756\n@SQ\tSN:APMT01222609.1\tLN:3756\n@SQ\tSN:APMT01223115.1\tLN:3756\n@SQ\tSN:APMT01223119.1\tLN:3756\n@SQ\tSN:APMT01223175.1\tLN:3756\n@SQ\tSN:KB712027.1\tLN:3755\n@SQ\tSN:KB712098.1\tLN:3755\n@SQ\tSN:KB712135.1\tLN:3755\n@SQ\tSN:KB712099.1\tLN:3754\n@SQ\tSN:KB712141.1\tLN:3754\n@SQ\tSN:KB712161.1\tLN:3754\n@SQ\tSN:KB713857.1\tLN:3754\n@SQ\tSN:APMT01223126.1\tLN:3753\n@SQ\tSN:APMT01223127.1\tLN:3753\n@SQ\tSN:APMT01223130.1\tLN:3753\n@SQ\tSN:KB711820.1\tLN:3752\n@SQ\tSN:KB712117.1\tLN:3752\n@SQ\tSN:APMT01223131.1\tLN:3752\n@SQ\tSN:APMT01223134.1\tLN:3752\n@SQ\tSN:KB712207.1\tLN:3752\n@SQ\tSN:APMT01222375.1\tLN:3751\n@SQ\tSN:APMT01223146.1\tLN:3751\n@SQ\tSN:APMT01222839.1\tLN:3750\n@SQ\tSN:KB712130.1\tLN:3750\n@SQ\tSN:APMT01223149.1\tLN:3750\n@SQ\tSN:APMT01223154.1\tLN:3750\n@SQ\tSN:KB712178.1\tLN:3750\n@SQ\tSN:KB711569.1\tLN:3749\n@SQ\tSN:APMT01222739.1\tLN:3749\n@SQ\tSN:APMT01223163.1\tLN:3749\n@SQ\tSN:KB711802.1\tLN:3748\n@SQ\tSN:KB711915.1\tLN:3748\n@SQ\tSN:KB711974.1\tLN:3748\n@SQ\tSN:KB711958.1\tLN:3747\n@SQ\tSN:APMT01222827.1\tLN:3747\n@SQ\tSN:APMT01223168.1\tLN:3747\n@SQ\tSN:KB711957.1\tLN:3746\n@SQ\tSN:APMT01223174.1\tLN:3746\n@SQ\tSN:APMT01223193.1\tLN:3746\n@SQ\tSN:KB711764.1\tLN:3745\n@SQ\tSN:APMT01223177.1\tLN:3745\n@SQ\tSN:APMT01223180.1\tLN:3745\n@SQ\tSN:KB711955.1\tLN:3744\n@SQ\tSN:APMT01223188.1\tLN:3744\n@SQ\tSN:KB712075.1\tLN:3743\n@SQ\tSN:KB712093.1\tLN:3743\n@SQ\tSN:APMT01222858.1\tLN:3742\n@SQ\tSN:APMT01223198.1\tLN:3742\n@SQ\tSN:APMT01223199.1\tLN:3742\n@SQ\tSN:APMT01223201.1\tLN:3742\n@SQ\tSN:KB712040.1\tLN:3741\n@SQ\tSN:APMT01223206.1\tLN:3741\n@SQ\tSN:APMT01223221.1\tLN:3740\n@SQ\tSN:KB711964.1\tLN:3739\n@SQ\tSN:KB712087.1\tLN:3739\n@SQ\tSN:KB712136.1\tLN:3739\n@SQ\tSN:APMT01223225.1\tLN:3739\n@SQ\tSN:KB712190.1\tLN:3739\n@SQ\tSN:KB712249.1\tLN:3739\n@SQ\tSN:KB712277.1\tLN:3739\n@SQ\tSN:KB712029.1\tLN:3738\n@SQ\tSN:KB712047.1\tLN:3738\n@SQ\tSN:APMT01222909.1\tLN:3738\n@SQ\tSN:APMT01222923.1\tLN:3737\n@SQ\tSN:KB712094.1\tLN:3737\n@SQ\tSN:APMT01223240.1\tLN:3737\n@SQ\tSN:KB712196.1\tLN:3737\n@SQ\tSN:KB712266.1\tLN:3737\n@SQ\tSN:APMT01222958.1\tLN:3736\n@SQ\tSN:KB712097.1\tLN:3736\n@SQ\tSN:KB712170.1\tLN:3736\n@SQ\tSN:KB712371.1\tLN:3736\n@SQ\tSN:KB712208.1\tLN:3734\n@SQ\tSN:KB711971.1\tLN:3733\n@SQ\tSN:APMT01223272.1\tLN:3733\n@SQ\tSN:APMT01223273.1\tLN:3733\n@SQ\tSN:KB712062.1\tLN:3732\n@SQ\tSN:APMT01222953.1\tLN:3732\n@SQ\tSN:KB712114.1\tLN:3732\n@SQ\tSN:KB712151.1\tLN:3732\n@SQ\tSN:KB712185.1\tLN:3732\n@SQ\tSN:KB712203.1\tLN:3732\n@SQ\tSN:KB711948.1\tLN:3731\n@SQ\tSN:APMT01223274.1\tLN:3731\n@SQ\tSN:KB713491.1\tLN:3731\n@SQ\tSN:KB712063.1\tLN:3730\n@SQ\tSN:APMT01223280.1\tLN:3730\n@SQ\tSN:APMT01223284.1\tLN:3730\n@SQ\tSN:APMT01223289.1\tLN:3730\n@SQ\tSN:KB712554.1\tLN:3730\n@SQ\tSN:KB712022.1\tLN:3729\n@SQ\tSN:APMT01223288.1\tLN:3729\n@SQ\tSN:KB712001.1\tLN:3728\n@SQ\tSN:KB712181.1\tLN:3728\n@SQ\tSN:APMT01223283.1\tLN:3728\n@SQ\tSN:KB712360.1\tLN:3728\n@SQ\tSN:KB711870.1\tLN:3727\n@SQ\tSN:KB711283.1\tLN:3726\n@SQ\tSN:APMT01223293.1\tLN:3726\n@SQ\tSN:APMT01223296.1\tLN:3726\n@SQ\tSN:APMT01223299.1\tLN:3726\n@SQ\tSN:APMT01223300.1\tLN:3726\n@SQ\tSN:KB712072.1\tLN:3724\n@SQ\tSN:KB712123.1\tLN:3724\n@SQ\tSN:KB712293.1\tLN:3724\n@SQ\tSN:KB712165.1\tLN:3723\n@SQ\tSN:APMT01223173.1\tLN:3723\n@SQ\tSN:APMT01223027.1\tLN:3722\n@SQ\tSN:APMT01223176.1\tLN:3722\n@SQ\tSN:KB712179.1\tLN:3722\n@SQ\tSN:KB712215.1\tLN:3722\n@SQ\tSN:APMT01223320.1\tLN:3722\n@SQ\tSN:KB711941.1\tLN:3721\n@SQ\tSN:KB712032.1\tLN:3721\n@SQ\tSN:APMT01223093.1\tLN:3721\n@SQ\tSN:KB712257.1\tLN:3721\n@SQ\tSN:KB712259.1\tLN:3721\n@SQ\tSN:KB712492.1\tLN:3721\n@SQ\tSN:KB712115.1\tLN:3720\n@SQ\tSN:APMT01223513.1\tLN:3720\n@SQ\tSN:APMT01223037.1\tLN:3719\n@SQ\tSN:APMT01223334.1\tLN:3719\n@SQ\tSN:APMT01223011.1\tLN:3718\n@SQ\tSN:KB712166.1\tLN:3718\n@SQ\tSN:APMT01223349.1\tLN:3718\n@SQ\tSN:APMT01223350.1\tLN:3718\n@SQ\tSN:APMT01222986.1\tLN:3717\n@SQ\tSN:KB712189.1\tLN:3716\n@SQ\tSN:KB712213.1\tLN:3716\n@SQ\tSN:KB712615.1\tLN:3716\n@SQ\tSN:KB712106.1\tLN:3715\n@SQ\tSN:APMT01222908.1\tLN:3714\n@SQ\tSN:APMT01223007.1\tLN:3714\n@SQ\tSN:KB712172.1\tLN:3714\n@SQ\tSN:APMT01223365.1\tLN:3714\n@SQ\tSN:KB712237.1\tLN:3714\n@SQ\tSN:KB712612.1\tLN:3714\n@SQ\tSN:APMT01223374.1\tLN:3713\n@SQ\tSN:APMT01223382.1\tLN:3712\n@SQ\tSN:APMT01223383.1\tLN:3712\n@SQ\tSN:APMT01223386.1\tLN:3711\n@SQ\tSN:APMT01223389.1\tLN:3711\n@SQ\tSN:KB712041.1\tLN:3710\n@SQ\tSN:KB712120.1\tLN:3710\n@SQ\tSN:KB712148.1\tLN:3710\n@SQ\tSN:KB712229.1\tLN:3710\n@SQ\tSN:APMT01223392.1\tLN:3710\n@SQ\tSN:KB712143.1\tLN:3709\n@SQ\tSN:APMT01223399.1\tLN:3709\n@SQ\tSN:APMT01223400.1\tLN:3709\n@SQ\tSN:KB712323.1\tLN:3709\n@SQ\tSN:APMT01223277.1\tLN:3708\n@SQ\tSN:APMT01223409.1\tLN:3708\n@SQ\tSN:KB711815.1\tLN:3707\n@SQ\tSN:KB712187.1\tLN:3707\n@SQ\tSN:KB712191.1\tLN:3707\n@SQ\tSN:APMT01223716.1\tLN:3707\n@SQ\tSN:APMT01223292.1\tLN:3706\n@SQ\tSN:APMT01223303.1\tLN:3706\n@SQ\tSN:KB712248.1\tLN:3706\n@SQ\tSN:APMT01223419.1\tLN:3706\n@SQ\tSN:APMT01223420.1\tLN:3706\n@SQ\tSN:KB714204.1\tLN:3706\n@SQ\tSN:KB712010.1\tLN:3705\n@SQ\tSN:KB712078.1\tLN:3705\n@SQ\tSN:KB712100.1\tLN:3705\n@SQ\tSN:APMT01223233.1\tLN:3705\n@SQ\tSN:KB712228.1\tLN:3705\n@SQ\tSN:APMT01223407.1\tLN:3705\n@SQ\tSN:APMT01223421.1\tLN:3705\n@SQ\tSN:APMT01223422.1\tLN:3705\n@SQ\tSN:KB712319.1\tLN:3705\n@SQ\tSN:APMT01223200.1\tLN:3704\n@SQ\tSN:KB712324.1\tLN:3704\n@SQ\tSN:KB711885.1\tLN:3703\n@SQ\tSN:APMT01223408.1\tLN:3703\n@SQ\tSN:KB714102.1\tLN:3703\n@SQ\tSN:KB712176.1\tLN:3702\n@SQ\tSN:KB712212.1\tLN:3702\n@SQ\tSN:KB712332.1\tLN:3702\n@SQ\tSN:APMT01223443.1\tLN:3701\n@SQ\tSN:APMT01223448.1\tLN:3701\n@SQ\tSN:KB712382.1\tLN:3701\n@SQ\tSN:KB712127.1\tLN:3700\n@SQ\tSN:KB712250.1\tLN:3700\n@SQ\tSN:KB714319.1\tLN:3700\n@SQ\tSN:APMT01223451.1\tLN:3699\n@SQ\tSN:APMT01223454.1\tLN:3699\n@SQ\tSN:KB712331.1\tLN:3699\n@SQ\tSN:APMT01223081.1\tLN:3698\n@SQ\tSN:APMT01223457.1\tLN:3698\n@SQ\tSN:APMT01223458.1\tLN:3698\n@SQ\tSN:KB712908.1\tLN:3698\n@SQ\tSN:KB712256.1\tLN:3697\n@SQ\tSN:APMT01223116.1\tLN:3696\n@SQ\tSN:KB712214.1\tLN:3696\n@SQ\tSN:KB712218.1\tLN:3696\n@SQ\tSN:APMT01223467.1\tLN:3696\n@SQ\tSN:APMT01223468.1\tLN:3696\n@SQ\tSN:KB713267.1\tLN:3696\n@SQ\tSN:APMT01223483.1\tLN:3694\n@SQ\tSN:APMT01223486.1\tLN:3694\n@SQ\tSN:APMT01223181.1\tLN:3693\n@SQ\tSN:KB712238.1\tLN:3693\n@SQ\tSN:APMT01223480.1\tLN:3693\n@SQ\tSN:KB712317.1\tLN:3693\n@SQ\tSN:KB712369.1\tLN:3693\n@SQ\tSN:KB712180.1\tLN:3691\n@SQ\tSN:KB712031.1\tLN:3690\n@SQ\tSN:APMT01223141.1\tLN:3690\n@SQ\tSN:APMT01223512.1\tLN:3690\n@SQ\tSN:APMT01223526.1\tLN:3690\n@SQ\tSN:KB712110.1\tLN:3689\n@SQ\tSN:APMT01223445.1\tLN:3689\n@SQ\tSN:KB712411.1\tLN:3689\n@SQ\tSN:APMT01223520.1\tLN:3688\n@SQ\tSN:APMT01223523.1\tLN:3688\n@SQ\tSN:KB712347.1\tLN:3688\n@SQ\tSN:KB711951.1\tLN:3687\n@SQ\tSN:APMT01223391.1\tLN:3687\n@SQ\tSN:KB712210.1\tLN:3686\n@SQ\tSN:KB712225.1\tLN:3686\n@SQ\tSN:KB712381.1\tLN:3686\n@SQ\tSN:KB712401.1\tLN:3686\n@SQ\tSN:KB712205.1\tLN:3685\n@SQ\tSN:APMT01223393.1\tLN:3685\n@SQ\tSN:APMT01223493.1\tLN:3685\n@SQ\tSN:KB712160.1\tLN:3684\n@SQ\tSN:APMT01223539.1\tLN:3684\n@SQ\tSN:KB712169.1\tLN:3683\n@SQ\tSN:KB712260.1\tLN:3683\n@SQ\tSN:APMT01223552.1\tLN:3683\n@SQ\tSN:KB711013.1\tLN:3682\n@SQ\tSN:APMT01223497.1\tLN:3682\n@SQ\tSN:APMT01223557.1\tLN:3682\n@SQ\tSN:KB712664.1\tLN:3682\n@SQ\tSN:APMT01222907.1\tLN:3681\n@SQ\tSN:KB712272.1\tLN:3681\n@SQ\tSN:APMT01224114.1\tLN:3681\n@SQ\tSN:APMT01223573.1\tLN:3680\n@SQ\tSN:KB712326.1\tLN:3680\n@SQ\tSN:KB712351.1\tLN:3680\n@SQ\tSN:KB712370.1\tLN:3680\n@SQ\tSN:KB712562.1\tLN:3680\n@SQ\tSN:KB712233.1\tLN:3679\n@SQ\tSN:APMT01223580.1\tLN:3679\n@SQ\tSN:KB712355.1\tLN:3679\n@SQ\tSN:KB712173.1\tLN:3678\n@SQ\tSN:KB712409.1\tLN:3678\n@SQ\tSN:APMT01223436.1\tLN:3677\n@SQ\tSN:APMT01223595.1\tLN:3677\n@SQ\tSN:APMT01223596.1\tLN:3677\n@SQ\tSN:KB711737.1\tLN:3676\n@SQ\tSN:KB712118.1\tLN:3676\n@SQ\tSN:APMT01223597.1\tLN:3676\n@SQ\tSN:APMT01222912.1\tLN:3675\n@SQ\tSN:APMT01223635.1\tLN:3675\n@SQ\tSN:KB712090.1\tLN:3674\n@SQ\tSN:KB712220.1\tLN:3674\n@SQ\tSN:KB712268.1\tLN:3674\n@SQ\tSN:KB712306.1\tLN:3674\n@SQ\tSN:APMT01223606.1\tLN:3674\n@SQ\tSN:KB712269.1\tLN:3673\n@SQ\tSN:KB712301.1\tLN:3672\n@SQ\tSN:APMT01223598.1\tLN:3672\n@SQ\tSN:APMT01223618.1\tLN:3672\n@SQ\tSN:KB712258.1\tLN:3671\n@SQ\tSN:KB712276.1\tLN:3670\n@SQ\tSN:APMT01223572.1\tLN:3670\n@SQ\tSN:APMT01223630.1\tLN:3670\n@SQ\tSN:KB711788.1\tLN:3669\n@SQ\tSN:KB712376.1\tLN:3669\n@SQ\tSN:KB712076.1\tLN:3668\n@SQ\tSN:APMT01223642.1\tLN:3668\n@SQ\tSN:APMT01223531.1\tLN:3667\n@SQ\tSN:APMT01223643.1\tLN:3667\n@SQ\tSN:KB712367.1\tLN:3667\n@SQ\tSN:KB712226.1\tLN:3666\n@SQ\tSN:KB712243.1\tLN:3666\n@SQ\tSN:APMT01223639.1\tLN:3666\n@SQ\tSN:APMT01223331.1\tLN:3665\n@SQ\tSN:KB712305.1\tLN:3665\n@SQ\tSN:KB712357.1\tLN:3665\n@SQ\tSN:KB712168.1\tLN:3664\n@SQ\tSN:APMT01223335.1\tLN:3664\n@SQ\tSN:KB712223.1\tLN:3664\n@SQ\tSN:APMT01223603.1\tLN:3664\n@SQ\tSN:APMT01223646.1\tLN:3664\n@SQ\tSN:APMT01223671.1\tLN:3664\n@SQ\tSN:KB712525.1\tLN:3664\n@SQ\tSN:APMT01222973.1\tLN:3663\n@SQ\tSN:APMT01223667.1\tLN:3663\n@SQ\tSN:KB712140.1\tLN:3662\n@SQ\tSN:KB712261.1\tLN:3662\n@SQ\tSN:KB712419.1\tLN:3662\n@SQ\tSN:APMT01223323.1\tLN:3661\n@SQ\tSN:APMT01223346.1\tLN:3661\n@SQ\tSN:APMT01223666.1\tLN:3661\n@SQ\tSN:APMT01223678.1\tLN:3661\n@SQ\tSN:KB712397.1\tLN:3661\n@SQ\tSN:KB712164.1\tLN:3660\n@SQ\tSN:KB712284.1\tLN:3660\n@SQ\tSN:APMT01223679.1\tLN:3660\n@SQ\tSN:KB712417.1\tLN:3660\n@SQ\tSN:KB712235.1\tLN:3659\n@SQ\tSN:KB712279.1\tLN:3659\n@SQ\tSN:APMT01223685.1\tLN:3659\n@SQ\tSN:APMT01223687.1\tLN:3658\n@SQ\tSN:KB712648.1\tLN:3658\n@SQ\tSN:KB712066.1\tLN:3657\n@SQ\tSN:KB712278.1\tLN:3657\n@SQ\tSN:APMT01223698.1\tLN:3657\n@SQ\tSN:KB712204.1\tLN:3656\n@SQ\tSN:KB712255.1\tLN:3656\n@SQ\tSN:KB712294.1\tLN:3656\n@SQ\tSN:KB712275.1\tLN:3655\n@SQ\tSN:APMT01223726.1\tLN:3655\n@SQ\tSN:KB712436.1\tLN:3655\n@SQ\tSN:KB712536.1\tLN:3655\n@SQ\tSN:APMT01223084.1\tLN:3654\n@SQ\tSN:KB712150.1\tLN:3654\n@SQ\tSN:APMT01223390.1\tLN:3653\n@SQ\tSN:KB712264.1\tLN:3653\n@SQ\tSN:KB712282.1\tLN:3653\n@SQ\tSN:APMT01223636.1\tLN:3653\n@SQ\tSN:APMT01223733.1\tLN:3653\n@SQ\tSN:KB712404.1\tLN:3653\n@SQ\tSN:KB711348.1\tLN:3652\n@SQ\tSN:KB711862.1\tLN:3652\n@SQ\tSN:KB712380.1\tLN:3652\n@SQ\tSN:KB712392.1\tLN:3652\n@SQ\tSN:APMT01223732.1\tLN:3651\n@SQ\tSN:KB712339.1\tLN:3650\n@SQ\tSN:APMT01223745.1\tLN:3650\n@SQ\tSN:KB711639.1\tLN:3649\n@SQ\tSN:KB712242.1\tLN:3649\n@SQ\tSN:KB712262.1\tLN:3649\n@SQ\tSN:KB712299.1\tLN:3649\n@SQ\tSN:APMT01223883.1\tLN:3648\n@SQ\tSN:KB712519.1\tLN:3648\n@SQ\tSN:KB712231.1\tLN:3647\n@SQ\tSN:APMT01223761.1\tLN:3647\n@SQ\tSN:APMT01223766.1\tLN:3646\n@SQ\tSN:APMT01223425.1\tLN:3645\n@SQ\tSN:KB712338.1\tLN:3645\n@SQ\tSN:APMT01223774.1\tLN:3645\n@SQ\tSN:KB713473.1\tLN:3645\n@SQ\tSN:KB712636.1\tLN:3644\n@SQ\tSN:APMT01223496.1\tLN:3643\n@SQ\tSN:KB712312.1\tLN:3642\n@SQ\tSN:KB712313.1\tLN:3642\n@SQ\tSN:KB712498.1\tLN:3642\n@SQ\tSN:KB712364.1\tLN:3641\n@SQ\tSN:APMT01223798.1\tLN:3641\n@SQ\tSN:KB712438.1\tLN:3641\n@SQ\tSN:KB712560.1\tLN:3641\n@SQ\tSN:APMT01223444.1\tLN:3640\n@SQ\tSN:APMT01223800.1\tLN:3640\n@SQ\tSN:APMT01223801.1\tLN:3640\n@SQ\tSN:APMT01223802.1\tLN:3640\n@SQ\tSN:KB713692.1\tLN:3640\n@SQ\tSN:APMT01223809.1\tLN:3639\n@SQ\tSN:KB713113.1\tLN:3639\n@SQ\tSN:APMT01223579.1\tLN:3638\n@SQ\tSN:KB712389.1\tLN:3638\n@SQ\tSN:APMT01223811.1\tLN:3638\n@SQ\tSN:APMT01223816.1\tLN:3638\n@SQ\tSN:KB712193.1\tLN:3637\n@SQ\tSN:KB712314.1\tLN:3637\n@SQ\tSN:APMT01223787.1\tLN:3637\n@SQ\tSN:APMT01223821.1\tLN:3637\n@SQ\tSN:KB712171.1\tLN:3636\n@SQ\tSN:APMT01223831.1\tLN:3635\n@SQ\tSN:APMT01223834.1\tLN:3635\n@SQ\tSN:APMT01223973.1\tLN:3635\n@SQ\tSN:KB712629.1\tLN:3635\n@SQ\tSN:KB712292.1\tLN:3634\n@SQ\tSN:APMT01223847.1\tLN:3634\n@SQ\tSN:APMT01223771.1\tLN:3633\n@SQ\tSN:APMT01223856.1\tLN:3633\n@SQ\tSN:KB712758.1\tLN:3633\n@SQ\tSN:APMT01223860.1\tLN:3632\n@SQ\tSN:KB712252.1\tLN:3631\n@SQ\tSN:APMT01223629.1\tLN:3631\n@SQ\tSN:APMT01223869.1\tLN:3630\n@SQ\tSN:APMT01223873.1\tLN:3630\n@SQ\tSN:APMT01223874.1\tLN:3630\n@SQ\tSN:KB712194.1\tLN:3629\n@SQ\tSN:APMT01223684.1\tLN:3629\n@SQ\tSN:APMT01223866.1\tLN:3629\n@SQ\tSN:APMT01223882.1\tLN:3629\n@SQ\tSN:KB712503.1\tLN:3629\n@SQ\tSN:KB709343.1\tLN:3628\n@SQ\tSN:APMT01223889.1\tLN:3627\n@SQ\tSN:APMT01223888.1\tLN:3626\n@SQ\tSN:APMT01223898.1\tLN:3626\n@SQ\tSN:KB712295.1\tLN:3625\n@SQ\tSN:APMT01223907.1\tLN:3625\n@SQ\tSN:APMT01223913.1\tLN:3625\n@SQ\tSN:APMT01222800.1\tLN:3624\n@SQ\tSN:APMT01223918.1\tLN:3624\n@SQ\tSN:APMT01223287.1\tLN:3622\n@SQ\tSN:KB712239.1\tLN:3622\n@SQ\tSN:APMT01223601.1\tLN:3622\n@SQ\tSN:KB712340.1\tLN:3622\n@SQ\tSN:APMT01223738.1\tLN:3622\n@SQ\tSN:APMT01224257.1\tLN:3622\n@SQ\tSN:KB712573.1\tLN:3622\n@SQ\tSN:APMT01224546.1\tLN:3622\n@SQ\tSN:KB712125.1\tLN:3621\n@SQ\tSN:KB712452.1\tLN:3621\n@SQ\tSN:KB712784.1\tLN:3621\n@SQ\tSN:APMT01223576.1\tLN:3619\n@SQ\tSN:APMT01223602.1\tLN:3619\n@SQ\tSN:APMT01223943.1\tLN:3619\n@SQ\tSN:KB712241.1\tLN:3618\n@SQ\tSN:KB712358.1\tLN:3618\n@SQ\tSN:KB712416.1\tLN:3617\n@SQ\tSN:APMT01223952.1\tLN:3617\n@SQ\tSN:KB712465.1\tLN:3617\n@SQ\tSN:KB712499.1\tLN:3617\n@SQ\tSN:KB712518.1\tLN:3617\n@SQ\tSN:KB712144.1\tLN:3616\n@SQ\tSN:APMT01223965.1\tLN:3616\n@SQ\tSN:APMT01223966.1\tLN:3616\n@SQ\tSN:APMT01223967.1\tLN:3616\n@SQ\tSN:APMT01224018.1\tLN:3616\n@SQ\tSN:KB712557.1\tLN:3616\n@SQ\tSN:KB712559.1\tLN:3616\n@SQ\tSN:APMT01223609.1\tLN:3615\n@SQ\tSN:KB712413.1\tLN:3615\n@SQ\tSN:KB712459.1\tLN:3614\n@SQ\tSN:KB712307.1\tLN:3613\n@SQ\tSN:KB712230.1\tLN:3611\n@SQ\tSN:APMT01223985.1\tLN:3611\n@SQ\tSN:APMT01223988.1\tLN:3611\n@SQ\tSN:KB712418.1\tLN:3610\n@SQ\tSN:KB712469.1\tLN:3610\n@SQ\tSN:APMT01223992.1\tLN:3610\n@SQ\tSN:APMT01223993.1\tLN:3610\n@SQ\tSN:KB711881.1\tLN:3609\n@SQ\tSN:APMT01223668.1\tLN:3609\n@SQ\tSN:KB712372.1\tLN:3609\n@SQ\tSN:KB714233.1\tLN:3609\n@SQ\tSN:KB712387.1\tLN:3608\n@SQ\tSN:APMT01224022.1\tLN:3607\n@SQ\tSN:APMT01224023.1\tLN:3607\n@SQ\tSN:APMT01224024.1\tLN:3606\n@SQ\tSN:APMT01223837.1\tLN:3605\n@SQ\tSN:APMT01224027.1\tLN:3605\n@SQ\tSN:APMT01223997.1\tLN:3604\n@SQ\tSN:APMT01224028.1\tLN:3604\n@SQ\tSN:KB711984.1\tLN:3603\n@SQ\tSN:APMT01223727.1\tLN:3603\n@SQ\tSN:KB712488.1\tLN:3603\n@SQ\tSN:KB712311.1\tLN:3602\n@SQ\tSN:APMT01224033.1\tLN:3602\n@SQ\tSN:KB712088.1\tLN:3601\n@SQ\tSN:APMT01223931.1\tLN:3601\n@SQ\tSN:APMT01224048.1\tLN:3601\n@SQ\tSN:APMT01224051.1\tLN:3601\n@SQ\tSN:APMT01224053.1\tLN:3601\n@SQ\tSN:KB712593.1\tLN:3601\n@SQ\tSN:KB711809.1\tLN:3600\n@SQ\tSN:KB712232.1\tLN:3600\n@SQ\tSN:KB712302.1\tLN:3600\n@SQ\tSN:APMT01223846.1\tLN:3600\n@SQ\tSN:APMT01224054.1\tLN:3600\n@SQ\tSN:KB712517.1\tLN:3600\n@SQ\tSN:KB712288.1\tLN:3599\n@SQ\tSN:KB712335.1\tLN:3599\n@SQ\tSN:APMT01223686.1\tLN:3599\n@SQ\tSN:APMT01224043.1\tLN:3599\n@SQ\tSN:KB712271.1\tLN:3598\n@SQ\tSN:KB712333.1\tLN:3598\n@SQ\tSN:KB712474.1\tLN:3598\n@SQ\tSN:KB712501.1\tLN:3598\n@SQ\tSN:APMT01224080.1\tLN:3597\n@SQ\tSN:KB712616.1\tLN:3596\n@SQ\tSN:KB711867.1\tLN:3595\n@SQ\tSN:KB712374.1\tLN:3595\n@SQ\tSN:APMT01224088.1\tLN:3595\n@SQ\tSN:KB712395.1\tLN:3594\n@SQ\tSN:KB712400.1\tLN:3594\n@SQ\tSN:APMT01224106.1\tLN:3594\n@SQ\tSN:KB712521.1\tLN:3594\n@SQ\tSN:KB712996.1\tLN:3594\n@SQ\tSN:APMT01224107.1\tLN:3593\n@SQ\tSN:APMT01224111.1\tLN:3593\n@SQ\tSN:KB712434.1\tLN:3592\n@SQ\tSN:APMT01224118.1\tLN:3592\n@SQ\tSN:KB713490.1\tLN:3592\n@SQ\tSN:KB712407.1\tLN:3591\n@SQ\tSN:KB712480.1\tLN:3591\n@SQ\tSN:APMT01223972.1\tLN:3590\n@SQ\tSN:APMT01224131.1\tLN:3590\n@SQ\tSN:APMT01224127.1\tLN:3589\n@SQ\tSN:APMT01224136.1\tLN:3589\n@SQ\tSN:APMT01224139.1\tLN:3589\n@SQ\tSN:KB712024.1\tLN:3588\n@SQ\tSN:KB712308.1\tLN:3588\n@SQ\tSN:APMT01223810.1\tLN:3588\n@SQ\tSN:APMT01224144.1\tLN:3588\n@SQ\tSN:APMT01224147.1\tLN:3588\n@SQ\tSN:APMT01224150.1\tLN:3588\n@SQ\tSN:KB712188.1\tLN:3587\n@SQ\tSN:KB712318.1\tLN:3587\n@SQ\tSN:KB712475.1\tLN:3587\n@SQ\tSN:APMT01224097.1\tLN:3587\n@SQ\tSN:APMT01224140.1\tLN:3587\n@SQ\tSN:KB712156.1\tLN:3586\n@SQ\tSN:KB712162.1\tLN:3586\n@SQ\tSN:KB712468.1\tLN:3586\n@SQ\tSN:APMT01224157.1\tLN:3586\n@SQ\tSN:APMT01224160.1\tLN:3586\n@SQ\tSN:APMT01224163.1\tLN:3586\n@SQ\tSN:KB712482.1\tLN:3585\n@SQ\tSN:KB712489.1\tLN:3585\n@SQ\tSN:KB712516.1\tLN:3585\n@SQ\tSN:APMT01223661.1\tLN:3584\n@SQ\tSN:KB712449.1\tLN:3584\n@SQ\tSN:KB712491.1\tLN:3584\n@SQ\tSN:APMT01224177.1\tLN:3584\n@SQ\tSN:APMT01224182.1\tLN:3584\n@SQ\tSN:KB712896.1\tLN:3584\n@SQ\tSN:KB712253.1\tLN:3583\n@SQ\tSN:KB712273.1\tLN:3583\n@SQ\tSN:KB712393.1\tLN:3583\n@SQ\tSN:APMT01224187.1\tLN:3583\n@SQ\tSN:APMT01224188.1\tLN:3583\n@SQ\tSN:APMT01224189.1\tLN:3583\n@SQ\tSN:APMT01224190.1\tLN:3583\n@SQ\tSN:APMT01224169.1\tLN:3582\n@SQ\tSN:APMT01224193.1\tLN:3582\n@SQ\tSN:APMT01224194.1\tLN:3582\n@SQ\tSN:APMT01223932.1\tLN:3581\n@SQ\tSN:APMT01224202.1\tLN:3581\n@SQ\tSN:APMT01224081.1\tLN:3580\n@SQ\tSN:APMT01224176.1\tLN:3580\n@SQ\tSN:APMT01224213.1\tLN:3580\n@SQ\tSN:KB713298.1\tLN:3580\n@SQ\tSN:APMT01223799.1\tLN:3579\n@SQ\tSN:KB712410.1\tLN:3579\n@SQ\tSN:KB712522.1\tLN:3579\n@SQ\tSN:APMT01224207.1\tLN:3579\n@SQ\tSN:APMT01224216.1\tLN:3579\n@SQ\tSN:KB712821.1\tLN:3579\n@SQ\tSN:KB711703.1\tLN:3578\n@SQ\tSN:KB712408.1\tLN:3578\n@SQ\tSN:KB712346.1\tLN:3577\n@SQ\tSN:KB712448.1\tLN:3577\n@SQ\tSN:KB712175.1\tLN:3576\n@SQ\tSN:APMT01223857.1\tLN:3576\n@SQ\tSN:APMT01224240.1\tLN:3576\n@SQ\tSN:KB712797.1\tLN:3575\n@SQ\tSN:APMT01223957.1\tLN:3574\n@SQ\tSN:APMT01224255.1\tLN:3574\n@SQ\tSN:APMT01224256.1\tLN:3574\n@SQ\tSN:KB712394.1\tLN:3573\n@SQ\tSN:KB712463.1\tLN:3573\n@SQ\tSN:KB712396.1\tLN:3572\n@SQ\tSN:KB712532.1\tLN:3572\n@SQ\tSN:APMT01224266.1\tLN:3572\n@SQ\tSN:KB712414.1\tLN:3570\n@SQ\tSN:APMT01224272.1\tLN:3570\n@SQ\tSN:APMT01224281.1\tLN:3570\n@SQ\tSN:APMT01224282.1\tLN:3570\n@SQ\tSN:KB712070.1\tLN:3569\n@SQ\tSN:APMT01224126.1\tLN:3569\n@SQ\tSN:APMT01224283.1\tLN:3569\n@SQ\tSN:APMT01224017.1\tLN:3568\n@SQ\tSN:KB712786.1\tLN:3568\n@SQ\tSN:KB712283.1\tLN:3567\n@SQ\tSN:KB712378.1\tLN:3567\n@SQ\tSN:KB712644.1\tLN:3567\n@SQ\tSN:KB712510.1\tLN:3566\n@SQ\tSN:APMT01224244.1\tLN:3566\n@SQ\tSN:APMT01224299.1\tLN:3566\n@SQ\tSN:APMT01224360.1\tLN:3566\n@SQ\tSN:KB712609.1\tLN:3566\n@SQ\tSN:KB712310.1\tLN:3565\n@SQ\tSN:APMT01224302.1\tLN:3565\n@SQ\tSN:APMT01224307.1\tLN:3565\n@SQ\tSN:KB712678.1\tLN:3565\n@SQ\tSN:KB712461.1\tLN:3564\n@SQ\tSN:KB712478.1\tLN:3564\n@SQ\tSN:KB712512.1\tLN:3564\n@SQ\tSN:KB712352.1\tLN:3563\n@SQ\tSN:KB712356.1\tLN:3563\n@SQ\tSN:APMT01223879.1\tLN:3563\n@SQ\tSN:KB712432.1\tLN:3563\n@SQ\tSN:APMT01224128.1\tLN:3563\n@SQ\tSN:APMT01224313.1\tLN:3563\n@SQ\tSN:APMT01224314.1\tLN:3563\n@SQ\tSN:APMT01222884.1\tLN:3562\n@SQ\tSN:KB712344.1\tLN:3562\n@SQ\tSN:APMT01224052.1\tLN:3562\n@SQ\tSN:APMT01224156.1\tLN:3562\n@SQ\tSN:KB712534.1\tLN:3562\n@SQ\tSN:APMT01224317.1\tLN:3562\n@SQ\tSN:KB712541.1\tLN:3561\n@SQ\tSN:APMT01224321.1\tLN:3561\n@SQ\tSN:APMT01224324.1\tLN:3561\n@SQ\tSN:KB712912.1\tLN:3561\n@SQ\tSN:KB712365.1\tLN:3560\n@SQ\tSN:KB712539.1\tLN:3560\n@SQ\tSN:KB712506.1\tLN:3559\n@SQ\tSN:APMT01224328.1\tLN:3559\n@SQ\tSN:APMT01224329.1\tLN:3559\n@SQ\tSN:APMT01224332.1\tLN:3559\n@SQ\tSN:APMT01224335.1\tLN:3559\n@SQ\tSN:APMT01224336.1\tLN:3559\n@SQ\tSN:KB712265.1\tLN:3558\n@SQ\tSN:KB712405.1\tLN:3558\n@SQ\tSN:KB712426.1\tLN:3558\n@SQ\tSN:APMT01224340.1\tLN:3557\n@SQ\tSN:APMT01224341.1\tLN:3557\n@SQ\tSN:KB712200.1\tLN:3556\n@SQ\tSN:APMT01224354.1\tLN:3556\n@SQ\tSN:KB712657.1\tLN:3556\n@SQ\tSN:APMT01224356.1\tLN:3555\n@SQ\tSN:APMT01224357.1\tLN:3555\n@SQ\tSN:APMT01224387.1\tLN:3555\n@SQ\tSN:KB712661.1\tLN:3555\n@SQ\tSN:KB713357.1\tLN:3555\n@SQ\tSN:KB712345.1\tLN:3554\n@SQ\tSN:KB712533.1\tLN:3554\n@SQ\tSN:APMT01224363.1\tLN:3554\n@SQ\tSN:APMT01224364.1\tLN:3554\n@SQ\tSN:KB712384.1\tLN:3553\n@SQ\tSN:KB712462.1\tLN:3553\n@SQ\tSN:APMT01224034.1\tLN:3553\n@SQ\tSN:KB712505.1\tLN:3553\n@SQ\tSN:APMT01224367.1\tLN:3553\n@SQ\tSN:KB712379.1\tLN:3552\n@SQ\tSN:KB712439.1\tLN:3552\n@SQ\tSN:KB712483.1\tLN:3552\n@SQ\tSN:APMT01224358.1\tLN:3552\n@SQ\tSN:APMT01224370.1\tLN:3552\n@SQ\tSN:APMT01224375.1\tLN:3552\n@SQ\tSN:APMT01223980.1\tLN:3551\n@SQ\tSN:APMT01224390.1\tLN:3551\n@SQ\tSN:KB712420.1\tLN:3550\n@SQ\tSN:KB712467.1\tLN:3550\n@SQ\tSN:APMT01224125.1\tLN:3550\n@SQ\tSN:KB712571.1\tLN:3550\n@SQ\tSN:KB712342.1\tLN:3549\n@SQ\tSN:APMT01223996.1\tLN:3549\n@SQ\tSN:APMT01224117.1\tLN:3549\n@SQ\tSN:KB713952.1\tLN:3549\n@SQ\tSN:KB712320.1\tLN:3548\n@SQ\tSN:APMT01224057.1\tLN:3548\n@SQ\tSN:KB712567.1\tLN:3548\n@SQ\tSN:APMT01224403.1\tLN:3548\n@SQ\tSN:KB712738.1\tLN:3548\n@SQ\tSN:KB712662.1\tLN:3547\n@SQ\tSN:KB712883.1\tLN:3547\n@SQ\tSN:KB712137.1\tLN:3546\n@SQ\tSN:KB712415.1\tLN:3546\n@SQ\tSN:APMT01224021.1\tLN:3546\n@SQ\tSN:KB712550.1\tLN:3546\n@SQ\tSN:KB712564.1\tLN:3546\n@SQ\tSN:KB712595.1\tLN:3546\n@SQ\tSN:APMT01224411.1\tLN:3546\n@SQ\tSN:APMT01224414.1\tLN:3546\n@SQ\tSN:KB712651.1\tLN:3546\n@SQ\tSN:KB712470.1\tLN:3545\n@SQ\tSN:APMT01224208.1\tLN:3545\n@SQ\tSN:KB714158.1\tLN:3545\n@SQ\tSN:KB712589.1\tLN:3544\n@SQ\tSN:APMT01224426.1\tLN:3543\n@SQ\tSN:APMT01224427.1\tLN:3543\n@SQ\tSN:KB713108.1\tLN:3543\n@SQ\tSN:KB712145.1\tLN:3542\n@SQ\tSN:APMT01224168.1\tLN:3542\n@SQ\tSN:APMT01224432.1\tLN:3542\n@SQ\tSN:APMT01224433.1\tLN:3542\n@SQ\tSN:KB712694.1\tLN:3542\n@SQ\tSN:APMT01223074.1\tLN:3541\n@SQ\tSN:APMT01224273.1\tLN:3541\n@SQ\tSN:KB712582.1\tLN:3541\n@SQ\tSN:APMT01224440.1\tLN:3540\n@SQ\tSN:APMT01224441.1\tLN:3540\n@SQ\tSN:APMT01224442.1\tLN:3540\n@SQ\tSN:KB712437.1\tLN:3539\n@SQ\tSN:KB712575.1\tLN:3539\n@SQ\tSN:APMT01224445.1\tLN:3539\n@SQ\tSN:APMT01224453.1\tLN:3538\n@SQ\tSN:APMT01224459.1\tLN:3538\n@SQ\tSN:KB712303.1\tLN:3537\n@SQ\tSN:KB712454.1\tLN:3537\n@SQ\tSN:APMT01224348.1\tLN:3537\n@SQ\tSN:KB712315.1\tLN:3536\n@SQ\tSN:KB712464.1\tLN:3536\n@SQ\tSN:KB712481.1\tLN:3536\n@SQ\tSN:KB712572.1\tLN:3536\n@SQ\tSN:APMT01224464.1\tLN:3536\n@SQ\tSN:KB712425.1\tLN:3535\n@SQ\tSN:APMT01224222.1\tLN:3535\n@SQ\tSN:KB712599.1\tLN:3535\n@SQ\tSN:APMT01224456.1\tLN:3535\n@SQ\tSN:APMT01224481.1\tLN:3534\n@SQ\tSN:APMT01224490.1\tLN:3534\n@SQ\tSN:KB712373.1\tLN:3533\n@SQ\tSN:KB712537.1\tLN:3533\n@SQ\tSN:APMT01224243.1\tLN:3533\n@SQ\tSN:KB712617.1\tLN:3533\n@SQ\tSN:KB712845.1\tLN:3533\n@SQ\tSN:KB712904.1\tLN:3533\n@SQ\tSN:KB711986.1\tLN:3532\n@SQ\tSN:APMT01223960.1\tLN:3532\n@SQ\tSN:KB712316.1\tLN:3531\n@SQ\tSN:KB712607.1\tLN:3531\n@SQ\tSN:APMT01224502.1\tLN:3531\n@SQ\tSN:APMT01224141.1\tLN:3530\n@SQ\tSN:KB712548.1\tLN:3530\n@SQ\tSN:APMT01224155.1\tLN:3529\n@SQ\tSN:KB712542.1\tLN:3529\n@SQ\tSN:KB712556.1\tLN:3529\n@SQ\tSN:KB712561.1\tLN:3529\n@SQ\tSN:APMT01224428.1\tLN:3529\n@SQ\tSN:APMT01224509.1\tLN:3529\n@SQ\tSN:APMT01224511.1\tLN:3529\n@SQ\tSN:APMT01224512.1\tLN:3529\n@SQ\tSN:APMT01224517.1\tLN:3529\n@SQ\tSN:KB714313.1\tLN:3529\n@SQ\tSN:KB712507.1\tLN:3528\n@SQ\tSN:APMT01224520.1\tLN:3528\n@SQ\tSN:APMT01224521.1\tLN:3528\n@SQ\tSN:APMT01224522.1\tLN:3528\n@SQ\tSN:KB712669.1\tLN:3528\n@SQ\tSN:KB712700.1\tLN:3528\n@SQ\tSN:KB712818.1\tLN:3528\n@SQ\tSN:KB713430.1\tLN:3528\n@SQ\tSN:KB712350.1\tLN:3527\n@SQ\tSN:KB712587.1\tLN:3527\n@SQ\tSN:KB712639.1\tLN:3527\n@SQ\tSN:KB712476.1\tLN:3526\n@SQ\tSN:KB712766.1\tLN:3526\n@SQ\tSN:APMT01224493.1\tLN:3525\n@SQ\tSN:APMT01224535.1\tLN:3525\n@SQ\tSN:KB712606.1\tLN:3524\n@SQ\tSN:KB712643.1\tLN:3524\n@SQ\tSN:KB712650.1\tLN:3524\n@SQ\tSN:APMT01224549.1\tLN:3524\n@SQ\tSN:APMT01224550.1\tLN:3524\n@SQ\tSN:KB712081.1\tLN:3523\n@SQ\tSN:KB712182.1\tLN:3523\n@SQ\tSN:KB712709.1\tLN:3523\n@SQ\tSN:KB712247.1\tLN:3522\n@SQ\tSN:KB712443.1\tLN:3522\n@SQ\tSN:APMT01224561.1\tLN:3522\n@SQ\tSN:APMT01224562.1\tLN:3522\n@SQ\tSN:APMT01224563.1\tLN:3522\n@SQ\tSN:APMT01224564.1\tLN:3522\n@SQ\tSN:KB712479.1\tLN:3521\n@SQ\tSN:KB712667.1\tLN:3521\n@SQ\tSN:APMT01224565.1\tLN:3521\n@SQ\tSN:KB712718.1\tLN:3521\n@SQ\tSN:KB713638.1\tLN:3521\n@SQ\tSN:KB712594.1\tLN:3520\n@SQ\tSN:APMT01224572.1\tLN:3520\n@SQ\tSN:APMT01224573.1\tLN:3520\n@SQ\tSN:KB712287.1\tLN:3519\n@SQ\tSN:APMT01224590.1\tLN:3518\n@SQ\tSN:APMT01224593.1\tLN:3518\n@SQ\tSN:KB712524.1\tLN:3517\n@SQ\tSN:APMT01224265.1\tLN:3517\n@SQ\tSN:APMT01224482.1\tLN:3517\n@SQ\tSN:APMT01224505.1\tLN:3517\n@SQ\tSN:APMT01224602.1\tLN:3517\n@SQ\tSN:KB712353.1\tLN:3516\n@SQ\tSN:KB712610.1\tLN:3516\n@SQ\tSN:APMT01224510.1\tLN:3516\n@SQ\tSN:APMT01225155.1\tLN:3516\n@SQ\tSN:KB712435.1\tLN:3515\n@SQ\tSN:KB712490.1\tLN:3515\n@SQ\tSN:APMT01224612.1\tLN:3515\n@SQ\tSN:APMT01224613.1\tLN:3515\n@SQ\tSN:KB712368.1\tLN:3514\n@SQ\tSN:APMT01224277.1\tLN:3514\n@SQ\tSN:APMT01224337.1\tLN:3514\n@SQ\tSN:APMT01224622.1\tLN:3514\n@SQ\tSN:KB712430.1\tLN:3513\n@SQ\tSN:KB712585.1\tLN:3513\n@SQ\tSN:KB712602.1\tLN:3513\n@SQ\tSN:KB712625.1\tLN:3513\n@SQ\tSN:APMT01224628.1\tLN:3513\n@SQ\tSN:APMT01224629.1\tLN:3513\n@SQ\tSN:APMT01224637.1\tLN:3512\n@SQ\tSN:KB713253.1\tLN:3512\n@SQ\tSN:KB712472.1\tLN:3511\n@SQ\tSN:APMT01224587.1\tLN:3511\n@SQ\tSN:APMT01224635.1\tLN:3511\n@SQ\tSN:APMT01224642.1\tLN:3511\n@SQ\tSN:APMT01224650.1\tLN:3511\n@SQ\tSN:KB712399.1\tLN:3510\n@SQ\tSN:KB712523.1\tLN:3510\n@SQ\tSN:APMT01224280.1\tLN:3510\n@SQ\tSN:APMT01224651.1\tLN:3510\n@SQ\tSN:KB712760.1\tLN:3510\n@SQ\tSN:KB713326.1\tLN:3510\n@SQ\tSN:KB711507.1\tLN:3509\n@SQ\tSN:APMT01224284.1\tLN:3509\n@SQ\tSN:APMT01224286.1\tLN:3509\n@SQ\tSN:KB712631.1\tLN:3509\n@SQ\tSN:APMT01224668.1\tLN:3509\n@SQ\tSN:APMT01224669.1\tLN:3509\n@SQ\tSN:APMT01224672.1\tLN:3509\n@SQ\tSN:KB712555.1\tLN:3508\n@SQ\tSN:KB712634.1\tLN:3508\n@SQ\tSN:KB712649.1\tLN:3508\n@SQ\tSN:KB712689.1\tLN:3508\n@SQ\tSN:KB712630.1\tLN:3507\n@SQ\tSN:APMT01224678.1\tLN:3507\n@SQ\tSN:KB712708.1\tLN:3507\n@SQ\tSN:KB712588.1\tLN:3506\n@SQ\tSN:APMT01224682.1\tLN:3506\n@SQ\tSN:APMT01224686.1\tLN:3505\n@SQ\tSN:APMT01224687.1\tLN:3505\n@SQ\tSN:KB713016.1\tLN:3505\n@SQ\tSN:KB712538.1\tLN:3504\n@SQ\tSN:KB712569.1\tLN:3504\n@SQ\tSN:APMT01224351.1\tLN:3504\n@SQ\tSN:KB712428.1\tLN:3503\n@SQ\tSN:KB712621.1\tLN:3503\n@SQ\tSN:KB712691.1\tLN:3503\n@SQ\tSN:APMT01224706.1\tLN:3503\n@SQ\tSN:KB712581.1\tLN:3502\n@SQ\tSN:APMT01224713.1\tLN:3502\n@SQ\tSN:APMT01224716.1\tLN:3501\n@SQ\tSN:APMT01224719.1\tLN:3501\n@SQ\tSN:KB713838.1\tLN:3501\n@SQ\tSN:KB712388.1\tLN:3500\n@SQ\tSN:KB712546.1\tLN:3500\n@SQ\tSN:APMT01224728.1\tLN:3500\n@SQ\tSN:APMT01224735.1\tLN:3500\n@SQ\tSN:KB714312.1\tLN:3500\n@SQ\tSN:KB712495.1\tLN:3499\n@SQ\tSN:APMT01224744.1\tLN:3499\n@SQ\tSN:KB712763.1\tLN:3499\n@SQ\tSN:KB711975.1\tLN:3498\n@SQ\tSN:KB712450.1\tLN:3498\n@SQ\tSN:APMT01224582.1\tLN:3498\n@SQ\tSN:APMT01224753.1\tLN:3498\n@SQ\tSN:KB712240.1\tLN:3497\n@SQ\tSN:KB712568.1\tLN:3497\n@SQ\tSN:KB712704.1\tLN:3497\n@SQ\tSN:APMT01224826.1\tLN:3497\n@SQ\tSN:KB713159.1\tLN:3497\n@SQ\tSN:KB712086.1\tLN:3496\n@SQ\tSN:APMT01224734.1\tLN:3496\n@SQ\tSN:APMT01224759.1\tLN:3495\n@SQ\tSN:APMT01224760.1\tLN:3495\n@SQ\tSN:APMT01224761.1\tLN:3495\n@SQ\tSN:KB712149.1\tLN:3494\n@SQ\tSN:KB712576.1\tLN:3494\n@SQ\tSN:APMT01224359.1\tLN:3494\n@SQ\tSN:APMT01224762.1\tLN:3494\n@SQ\tSN:APMT01224765.1\tLN:3494\n@SQ\tSN:APMT01224766.1\tLN:3494\n@SQ\tSN:KB713204.1\tLN:3494\n@SQ\tSN:KB712291.1\tLN:3493\n@SQ\tSN:KB712530.1\tLN:3493\n@SQ\tSN:APMT01224382.1\tLN:3493\n@SQ\tSN:APMT01224408.1\tLN:3493\n@SQ\tSN:KB712624.1\tLN:3493\n@SQ\tSN:APMT01224769.1\tLN:3493\n@SQ\tSN:APMT01224775.1\tLN:3493\n@SQ\tSN:KB712497.1\tLN:3492\n@SQ\tSN:APMT01224787.1\tLN:3491\n@SQ\tSN:APMT01224793.1\tLN:3491\n@SQ\tSN:APMT01224794.1\tLN:3491\n@SQ\tSN:APMT01224778.1\tLN:3490\n@SQ\tSN:KB712929.1\tLN:3490\n@SQ\tSN:KB713276.1\tLN:3490\n@SQ\tSN:KB712453.1\tLN:3489\n@SQ\tSN:APMT01224310.1\tLN:3489\n@SQ\tSN:APMT01224810.1\tLN:3489\n@SQ\tSN:KB712988.1\tLN:3489\n@SQ\tSN:APMT01224417.1\tLN:3488\n@SQ\tSN:KB712711.1\tLN:3488\n@SQ\tSN:APMT01224820.1\tLN:3488\n@SQ\tSN:APMT01224822.1\tLN:3488\n@SQ\tSN:KB712504.1\tLN:3487\n@SQ\tSN:KB712688.1\tLN:3487\n@SQ\tSN:APMT01224834.1\tLN:3487\n@SQ\tSN:KB712764.1\tLN:3487\n@SQ\tSN:KB712773.1\tLN:3487\n@SQ\tSN:APMT01224738.1\tLN:3486\n@SQ\tSN:APMT01224840.1\tLN:3486\n@SQ\tSN:APMT01224841.1\tLN:3485\n@SQ\tSN:KB712775.1\tLN:3485\n@SQ\tSN:KB712455.1\tLN:3484\n@SQ\tSN:KB712740.1\tLN:3484\n@SQ\tSN:KB711907.1\tLN:3483\n@SQ\tSN:APMT01224009.1\tLN:3483\n@SQ\tSN:KB712620.1\tLN:3483\n@SQ\tSN:APMT01224583.1\tLN:3483\n@SQ\tSN:APMT01224928.1\tLN:3483\n@SQ\tSN:KB712322.1\tLN:3482\n@SQ\tSN:KB712511.1\tLN:3482\n@SQ\tSN:APMT01224201.1\tLN:3482\n@SQ\tSN:KB712603.1\tLN:3482\n@SQ\tSN:APMT01224852.1\tLN:3482\n@SQ\tSN:APMT01224853.1\tLN:3482\n@SQ\tSN:KB714387.1\tLN:3482\n@SQ\tSN:KB712343.1\tLN:3481\n@SQ\tSN:KB712473.1\tLN:3481\n@SQ\tSN:KB712641.1\tLN:3481\n@SQ\tSN:APMT01224855.1\tLN:3481\n@SQ\tSN:APMT01224856.1\tLN:3481\n@SQ\tSN:APMT01224857.1\tLN:3481\n@SQ\tSN:APMT01224860.1\tLN:3481\n@SQ\tSN:APMT01224623.1\tLN:3480\n@SQ\tSN:KB712686.1\tLN:3480\n@SQ\tSN:KB712719.1\tLN:3480\n@SQ\tSN:KB712177.1\tLN:3479\n@SQ\tSN:KB712584.1\tLN:3479\n@SQ\tSN:KB712744.1\tLN:3479\n@SQ\tSN:APMT01224867.1\tLN:3479\n@SQ\tSN:APMT01224870.1\tLN:3479\n@SQ\tSN:KB712848.1\tLN:3479\n@SQ\tSN:KB712671.1\tLN:3478\n@SQ\tSN:APMT01224673.1\tLN:3478\n@SQ\tSN:APMT01224605.1\tLN:3477\n@SQ\tSN:KB712742.1\tLN:3477\n@SQ\tSN:APMT01224873.1\tLN:3477\n@SQ\tSN:APMT01224601.1\tLN:3476\n@SQ\tSN:KB712679.1\tLN:3476\n@SQ\tSN:APMT01224880.1\tLN:3476\n@SQ\tSN:APMT01224881.1\tLN:3476\n@SQ\tSN:APMT01224884.1\tLN:3476\n@SQ\tSN:APMT01225062.1\tLN:3476\n@SQ\tSN:KB712676.1\tLN:3475\n@SQ\tSN:APMT01224902.1\tLN:3475\n@SQ\tSN:KB712590.1\tLN:3474\n@SQ\tSN:KB712663.1\tLN:3474\n@SQ\tSN:KB712703.1\tLN:3474\n@SQ\tSN:KB712713.1\tLN:3473\n@SQ\tSN:APMT01224899.1\tLN:3473\n@SQ\tSN:KB714376.1\tLN:3473\n@SQ\tSN:APMT01224924.1\tLN:3472\n@SQ\tSN:KB712750.1\tLN:3471\n@SQ\tSN:APMT01224917.1\tLN:3471\n@SQ\tSN:APMT01224918.1\tLN:3471\n@SQ\tSN:APMT01224921.1\tLN:3471\n@SQ\tSN:KB712872.1\tLN:3471\n@SQ\tSN:APMT01224872.1\tLN:3470\n@SQ\tSN:APMT01224905.1\tLN:3470\n@SQ\tSN:APMT01224925.1\tLN:3470\n@SQ\tSN:KB712953.1\tLN:3470\n@SQ\tSN:KB712281.1\tLN:3469\n@SQ\tSN:APMT01224448.1\tLN:3469\n@SQ\tSN:APMT01224922.1\tLN:3469\n@SQ\tSN:APMT01224937.1\tLN:3469\n@SQ\tSN:APMT01225191.1\tLN:3469\n@SQ\tSN:APMT01224569.1\tLN:3468\n@SQ\tSN:APMT01224685.1\tLN:3468\n@SQ\tSN:KB712754.1\tLN:3468\n@SQ\tSN:KB712777.1\tLN:3468\n@SQ\tSN:APMT01224929.1\tLN:3468\n@SQ\tSN:APMT01224942.1\tLN:3468\n@SQ\tSN:APMT01224429.1\tLN:3467\n@SQ\tSN:KB712698.1\tLN:3467\n@SQ\tSN:APMT01224885.1\tLN:3467\n@SQ\tSN:APMT01224934.1\tLN:3467\n@SQ\tSN:APMT01224947.1\tLN:3467\n@SQ\tSN:APMT01225028.1\tLN:3467\n@SQ\tSN:KB712966.1\tLN:3467\n@SQ\tSN:APMT01224355.1\tLN:3466\n@SQ\tSN:KB712627.1\tLN:3466\n@SQ\tSN:APMT01224632.1\tLN:3466\n@SQ\tSN:KB712729.1\tLN:3466\n@SQ\tSN:APMT01224770.1\tLN:3466\n@SQ\tSN:APMT01224908.1\tLN:3466\n@SQ\tSN:APMT01224952.1\tLN:3466\n@SQ\tSN:APMT01224960.1\tLN:3466\n@SQ\tSN:KB714586.1\tLN:3465\n@SQ\tSN:KB712672.1\tLN:3464\n@SQ\tSN:APMT01224970.1\tLN:3464\n@SQ\tSN:APMT01225045.1\tLN:3464\n@SQ\tSN:KB712574.1\tLN:3463\n@SQ\tSN:KB712666.1\tLN:3463\n@SQ\tSN:APMT01224591.1\tLN:3463\n@SQ\tSN:KB712286.1\tLN:3462\n@SQ\tSN:APMT01224681.1\tLN:3462\n@SQ\tSN:KB712721.1\tLN:3462\n@SQ\tSN:APMT01224985.1\tLN:3462\n@SQ\tSN:APMT01224986.1\tLN:3462\n@SQ\tSN:APMT01224987.1\tLN:3462\n@SQ\tSN:KB712724.1\tLN:3461\n@SQ\tSN:APMT01224829.1\tLN:3461\n@SQ\tSN:APMT01224994.1\tLN:3461\n@SQ\tSN:KB712586.1\tLN:3459\n@SQ\tSN:KB712741.1\tLN:3459\n@SQ\tSN:APMT01225004.1\tLN:3459\n@SQ\tSN:APMT01224584.1\tLN:3458\n@SQ\tSN:KB712752.1\tLN:3458\n@SQ\tSN:KB713161.1\tLN:3458\n@SQ\tSN:APMT01224249.1\tLN:3457\n@SQ\tSN:KB712790.1\tLN:3457\n@SQ\tSN:APMT01225014.1\tLN:3457\n@SQ\tSN:KB712997.1\tLN:3457\n@SQ\tSN:APMT01224285.1\tLN:3456\n@SQ\tSN:KB712608.1\tLN:3455\n@SQ\tSN:KB712757.1\tLN:3455\n@SQ\tSN:APMT01225019.1\tLN:3455\n@SQ\tSN:APMT01225022.1\tLN:3455\n@SQ\tSN:APMT01225023.1\tLN:3455\n@SQ\tSN:KB712897.1\tLN:3455\n@SQ\tSN:KB712943.1\tLN:3455\n@SQ\tSN:KB712578.1\tLN:3454\n@SQ\tSN:KB712619.1\tLN:3454\n@SQ\tSN:KB712637.1\tLN:3454\n@SQ\tSN:APMT01224662.1\tLN:3454\n@SQ\tSN:KB712739.1\tLN:3454\n@SQ\tSN:KB714479.1\tLN:3454\n@SQ\tSN:KB712570.1\tLN:3453\n@SQ\tSN:APMT01224614.1\tLN:3453\n@SQ\tSN:APMT01225035.1\tLN:3453\n@SQ\tSN:APMT01225036.1\tLN:3453\n@SQ\tSN:KB712604.1\tLN:3452\n@SQ\tSN:APMT01224536.1\tLN:3452\n@SQ\tSN:KB712745.1\tLN:3452\n@SQ\tSN:KB712820.1\tLN:3452\n@SQ\tSN:KB713042.1\tLN:3452\n@SQ\tSN:APMT01224636.1\tLN:3451\n@SQ\tSN:KB712873.1\tLN:3451\n@SQ\tSN:KB713332.1\tLN:3451\n@SQ\tSN:KB714301.1\tLN:3450\n@SQ\tSN:APMT01224592.1\tLN:3449\n@SQ\tSN:KB712726.1\tLN:3449\n@SQ\tSN:APMT01225048.1\tLN:3449\n@SQ\tSN:KB711863.1\tLN:3448\n@SQ\tSN:KB712635.1\tLN:3448\n@SQ\tSN:KB712712.1\tLN:3448\n@SQ\tSN:KB712796.1\tLN:3448\n@SQ\tSN:APMT01225049.1\tLN:3448\n@SQ\tSN:APMT01225430.1\tLN:3448\n@SQ\tSN:APMT01224615.1\tLN:3447\n@SQ\tSN:KB712717.1\tLN:3447\n@SQ\tSN:APMT01225056.1\tLN:3447\n@SQ\tSN:APMT01225059.1\tLN:3447\n@SQ\tSN:APMT01225160.1\tLN:3447\n@SQ\tSN:APMT01224710.1\tLN:3446\n@SQ\tSN:APMT01225066.1\tLN:3446\n@SQ\tSN:KB713000.1\tLN:3446\n@SQ\tSN:KB712645.1\tLN:3445\n@SQ\tSN:KB712697.1\tLN:3445\n@SQ\tSN:APMT01224959.1\tLN:3444\n@SQ\tSN:APMT01224995.1\tLN:3444\n@SQ\tSN:APMT01225085.1\tLN:3444\n@SQ\tSN:KB713057.1\tLN:3444\n@SQ\tSN:KB712591.1\tLN:3443\n@SQ\tSN:APMT01224923.1\tLN:3443\n@SQ\tSN:KB712811.1\tLN:3443\n@SQ\tSN:APMT01225089.1\tLN:3443\n@SQ\tSN:KB712563.1\tLN:3442\n@SQ\tSN:KB712628.1\tLN:3442\n@SQ\tSN:KB712668.1\tLN:3442\n@SQ\tSN:KB712731.1\tLN:3442\n@SQ\tSN:KB712798.1\tLN:3442\n@SQ\tSN:KB712831.1\tLN:3442\n@SQ\tSN:APMT01225090.1\tLN:3442\n@SQ\tSN:KB713068.1\tLN:3442\n@SQ\tSN:APMT01225104.1\tLN:3441\n@SQ\tSN:APMT01225129.1\tLN:3441\n@SQ\tSN:KB712951.1\tLN:3441\n@SQ\tSN:KB712487.1\tLN:3440\n@SQ\tSN:KB712600.1\tLN:3440\n@SQ\tSN:APMT01224854.1\tLN:3440\n@SQ\tSN:APMT01225109.1\tLN:3440\n@SQ\tSN:APMT01225110.1\tLN:3440\n@SQ\tSN:APMT01225111.1\tLN:3440\n@SQ\tSN:KB712297.1\tLN:3439\n@SQ\tSN:APMT01224506.1\tLN:3439\n@SQ\tSN:KB712865.1\tLN:3439\n@SQ\tSN:KB712655.1\tLN:3438\n@SQ\tSN:KB712680.1\tLN:3438\n@SQ\tSN:APMT01224758.1\tLN:3438\n@SQ\tSN:KB712751.1\tLN:3438\n@SQ\tSN:KB712833.1\tLN:3438\n@SQ\tSN:APMT01225082.1\tLN:3438\n@SQ\tSN:APMT01225105.1\tLN:3438\n@SQ\tSN:KB712813.1\tLN:3437\n@SQ\tSN:APMT01225133.1\tLN:3437\n@SQ\tSN:KB712222.1\tLN:3436\n@SQ\tSN:KB712596.1\tLN:3436\n@SQ\tSN:KB712710.1\tLN:3436\n@SQ\tSN:APMT01225108.1\tLN:3436\n@SQ\tSN:APMT01225130.1\tLN:3436\n@SQ\tSN:APMT01225136.1\tLN:3435\n@SQ\tSN:APMT01225142.1\tLN:3435\n@SQ\tSN:APMT01225143.1\tLN:3435\n@SQ\tSN:APMT01225145.1\tLN:3435\n@SQ\tSN:KB712891.1\tLN:3434\n@SQ\tSN:KB711001.1\tLN:3433\n@SQ\tSN:KB712809.1\tLN:3433\n@SQ\tSN:KB712309.1\tLN:3432\n@SQ\tSN:KB712647.1\tLN:3432\n@SQ\tSN:APMT01225154.1\tLN:3432\n@SQ\tSN:KB712793.1\tLN:3431\n@SQ\tSN:APMT01224941.1\tLN:3431\n@SQ\tSN:APMT01225161.1\tLN:3431\n@SQ\tSN:KB712547.1\tLN:3430\n@SQ\tSN:APMT01224835.1\tLN:3430\n@SQ\tSN:APMT01225166.1\tLN:3430\n@SQ\tSN:KB712626.1\tLN:3429\n@SQ\tSN:KB712706.1\tLN:3429\n@SQ\tSN:APMT01224731.1\tLN:3429\n@SQ\tSN:APMT01224821.1\tLN:3429\n@SQ\tSN:APMT01225088.1\tLN:3429\n@SQ\tSN:APMT01225173.1\tLN:3429\n@SQ\tSN:KB712613.1\tLN:3428\n@SQ\tSN:KB712723.1\tLN:3428\n@SQ\tSN:KB712783.1\tLN:3428\n@SQ\tSN:APMT01225179.1\tLN:3428\n@SQ\tSN:APMT01225184.1\tLN:3428\n@SQ\tSN:KB712456.1\tLN:3427\n@SQ\tSN:APMT01225189.1\tLN:3427\n@SQ\tSN:APMT01225190.1\tLN:3427\n@SQ\tSN:KB714331.1\tLN:3427\n@SQ\tSN:KB711963.1\tLN:3426\n@SQ\tSN:KB712747.1\tLN:3426\n@SQ\tSN:APMT01225192.1\tLN:3426\n@SQ\tSN:APMT01225194.1\tLN:3426\n@SQ\tSN:KB712385.1\tLN:3425\n@SQ\tSN:APMT01225168.1\tLN:3425\n@SQ\tSN:APMT01225202.1\tLN:3425\n@SQ\tSN:APMT01225207.1\tLN:3425\n@SQ\tSN:APMT01225214.1\tLN:3425\n@SQ\tSN:KB713075.1\tLN:3425\n@SQ\tSN:KB712133.1\tLN:3424\n@SQ\tSN:KB712683.1\tLN:3424\n@SQ\tSN:KB712765.1\tLN:3424\n@SQ\tSN:KB712780.1\tLN:3424\n@SQ\tSN:KB712792.1\tLN:3424\n@SQ\tSN:KB712806.1\tLN:3424\n@SQ\tSN:APMT01225013.1\tLN:3424\n@SQ\tSN:APMT01225217.1\tLN:3424\n@SQ\tSN:KB712843.1\tLN:3423\n@SQ\tSN:APMT01225216.1\tLN:3423\n@SQ\tSN:APMT01225223.1\tLN:3423\n@SQ\tSN:APMT01225224.1\tLN:3423\n@SQ\tSN:KB712441.1\tLN:3422\n@SQ\tSN:APMT01224896.1\tLN:3422\n@SQ\tSN:KB712816.1\tLN:3422\n@SQ\tSN:KB712558.1\tLN:3421\n@SQ\tSN:KB712642.1\tLN:3421\n@SQ\tSN:KB712725.1\tLN:3421\n@SQ\tSN:APMT01225167.1\tLN:3421\n@SQ\tSN:APMT01225215.1\tLN:3421\n@SQ\tSN:APMT01225372.1\tLN:3421\n@SQ\tSN:APMT01225246.1\tLN:3420\n@SQ\tSN:APMT01225247.1\tLN:3420\n@SQ\tSN:APMT01225283.1\tLN:3420\n@SQ\tSN:KB712300.1\tLN:3419\n@SQ\tSN:KB712509.1\tLN:3419\n@SQ\tSN:APMT01225001.1\tLN:3419\n@SQ\tSN:KB712866.1\tLN:3419\n@SQ\tSN:APMT01224871.1\tLN:3418\n@SQ\tSN:APMT01224961.1\tLN:3418\n@SQ\tSN:KB712803.1\tLN:3418\n@SQ\tSN:APMT01225270.1\tLN:3418\n@SQ\tSN:KB712914.1\tLN:3418\n@SQ\tSN:APMT01225271.1\tLN:3417\n@SQ\tSN:KB713392.1\tLN:3417\n@SQ\tSN:KB712460.1\tLN:3416\n@SQ\tSN:KB712785.1\tLN:3416\n@SQ\tSN:KB712826.1\tLN:3416\n@SQ\tSN:APMT01225280.1\tLN:3416\n@SQ\tSN:KB713250.1\tLN:3416\n@SQ\tSN:KB712653.1\tLN:3415\n@SQ\tSN:KB712913.1\tLN:3415\n@SQ\tSN:APMT01225289.1\tLN:3415\n@SQ\tSN:APMT01224221.1\tLN:3414\n@SQ\tSN:APMT01224581.1\tLN:3414\n@SQ\tSN:KB712705.1\tLN:3413\n@SQ\tSN:KB712810.1\tLN:3413\n@SQ\tSN:APMT01225302.1\tLN:3413\n@SQ\tSN:KB712540.1\tLN:3412\n@SQ\tSN:KB712730.1\tLN:3412\n@SQ\tSN:KB712863.1\tLN:3412\n@SQ\tSN:APMT01225306.1\tLN:3412\n@SQ\tSN:APMT01225253.1\tLN:3411\n@SQ\tSN:APMT01225307.1\tLN:3411\n@SQ\tSN:KB714435.1\tLN:3411\n@SQ\tSN:APMT01223989.1\tLN:3410\n@SQ\tSN:KB712789.1\tLN:3410\n@SQ\tSN:APMT01225239.1\tLN:3410\n@SQ\tSN:KB712906.1\tLN:3410\n@SQ\tSN:APMT01225319.1\tLN:3410\n@SQ\tSN:KB711746.1\tLN:3409\n@SQ\tSN:KB712638.1\tLN:3409\n@SQ\tSN:KB713475.1\tLN:3409\n@SQ\tSN:KB712681.1\tLN:3408\n@SQ\tSN:KB712909.1\tLN:3408\n@SQ\tSN:APMT01225303.1\tLN:3408\n@SQ\tSN:APMT01225329.1\tLN:3408\n@SQ\tSN:KB714409.1\tLN:3408\n@SQ\tSN:APMT01225337.1\tLN:3407\n@SQ\tSN:APMT01225338.1\tLN:3407\n@SQ\tSN:KB712941.1\tLN:3407\n@SQ\tSN:KB712329.1\tLN:3406\n@SQ\tSN:APMT01224743.1\tLN:3406\n@SQ\tSN:KB712800.1\tLN:3406\n@SQ\tSN:APMT01225342.1\tLN:3406\n@SQ\tSN:KB712910.1\tLN:3405\n@SQ\tSN:KB713019.1\tLN:3404\n@SQ\tSN:APMT01224911.1\tLN:3403\n@SQ\tSN:APMT01225352.1\tLN:3403\n@SQ\tSN:APMT01225354.1\tLN:3403\n@SQ\tSN:KB712520.1\tLN:3402\n@SQ\tSN:KB712732.1\tLN:3402\n@SQ\tSN:KB712900.1\tLN:3402\n@SQ\tSN:APMT01225355.1\tLN:3402\n@SQ\tSN:APMT01225356.1\tLN:3402\n@SQ\tSN:APMT01225358.1\tLN:3402\n@SQ\tSN:KB712702.1\tLN:3401\n@SQ\tSN:KB712759.1\tLN:3401\n@SQ\tSN:KB712881.1\tLN:3401\n@SQ\tSN:APMT01225361.1\tLN:3401\n@SQ\tSN:APMT01225362.1\tLN:3401\n@SQ\tSN:KB713782.1\tLN:3401\n@SQ\tSN:APMT01225365.1\tLN:3400\n@SQ\tSN:APMT01225366.1\tLN:3400\n@SQ\tSN:KB712968.1\tLN:3400\n@SQ\tSN:KB713017.1\tLN:3400\n@SQ\tSN:KB712774.1\tLN:3399\n@SQ\tSN:KB713010.1\tLN:3399\n@SQ\tSN:KB713136.1\tLN:3399\n@SQ\tSN:KB712851.1\tLN:3398\n@SQ\tSN:KB712447.1\tLN:3397\n@SQ\tSN:APMT01225260.1\tLN:3397\n@SQ\tSN:KB712927.1\tLN:3397\n@SQ\tSN:KB712457.1\tLN:3395\n@SQ\tSN:KB712932.1\tLN:3395\n@SQ\tSN:KB714439.1\tLN:3395\n@SQ\tSN:KB712882.1\tLN:3394\n@SQ\tSN:APMT01225369.1\tLN:3394\n@SQ\tSN:APMT01225399.1\tLN:3394\n@SQ\tSN:APMT01225412.1\tLN:3394\n@SQ\tSN:KB713980.1\tLN:3394\n@SQ\tSN:KB712761.1\tLN:3393\n@SQ\tSN:KB712769.1\tLN:3393\n@SQ\tSN:KB712839.1\tLN:3393\n@SQ\tSN:APMT01225408.1\tLN:3393\n@SQ\tSN:APMT01225409.1\tLN:3393\n@SQ\tSN:KB714053.1\tLN:3393\n@SQ\tSN:APMT01224327.1\tLN:3392\n@SQ\tSN:APMT01225037.1\tLN:3392\n@SQ\tSN:APMT01225417.1\tLN:3392\n@SQ\tSN:APMT01224998.1\tLN:3391\n@SQ\tSN:APMT01225069.1\tLN:3391\n@SQ\tSN:KB712893.1\tLN:3391\n@SQ\tSN:APMT01225418.1\tLN:3391\n@SQ\tSN:KB713140.1\tLN:3391\n@SQ\tSN:KB712496.1\tLN:3390\n@SQ\tSN:KB712727.1\tLN:3390\n@SQ\tSN:KB712795.1\tLN:3390\n@SQ\tSN:KB712817.1\tLN:3390\n@SQ\tSN:APMT01225038.1\tLN:3390\n@SQ\tSN:KB712853.1\tLN:3390\n@SQ\tSN:KB712549.1\tLN:3389\n@SQ\tSN:APMT01225423.1\tLN:3389\n@SQ\tSN:KB714447.1\tLN:3389\n@SQ\tSN:KB712446.1\tLN:3388\n@SQ\tSN:KB712670.1\tLN:3388\n@SQ\tSN:KB712880.1\tLN:3388\n@SQ\tSN:APMT01225222.1\tLN:3388\n@SQ\tSN:KB713058.1\tLN:3388\n@SQ\tSN:APMT01225055.1\tLN:3387\n@SQ\tSN:KB712858.1\tLN:3387\n@SQ\tSN:APMT01225447.1\tLN:3387\n@SQ\tSN:KB712801.1\tLN:3386\n@SQ\tSN:KB712854.1\tLN:3386\n@SQ\tSN:APMT01225322.1\tLN:3386\n@SQ\tSN:APMT01225453.1\tLN:3386\n@SQ\tSN:APMT01225462.1\tLN:3385\n@SQ\tSN:APMT01225463.1\tLN:3385\n@SQ\tSN:KB712391.1\tLN:3384\n@SQ\tSN:KB712884.1\tLN:3384\n@SQ\tSN:KB712902.1\tLN:3384\n@SQ\tSN:APMT01225288.1\tLN:3384\n@SQ\tSN:APMT01225452.1\tLN:3384\n@SQ\tSN:KB712974.1\tLN:3384\n@SQ\tSN:APMT01225464.1\tLN:3384\n@SQ\tSN:APMT01225465.1\tLN:3384\n@SQ\tSN:KB712983.1\tLN:3384\n@SQ\tSN:KB713247.1\tLN:3384\n@SQ\tSN:APMT01225478.1\tLN:3383\n@SQ\tSN:APMT01225481.1\tLN:3383\n@SQ\tSN:APMT01225482.1\tLN:3383\n@SQ\tSN:KB713378.1\tLN:3383\n@SQ\tSN:KB713915.1\tLN:3383\n@SQ\tSN:KB714525.1\tLN:3383\n@SQ\tSN:APMT01225486.1\tLN:3382\n@SQ\tSN:APMT01225489.1\tLN:3382\n@SQ\tSN:KB713085.1\tLN:3382\n@SQ\tSN:KB714468.1\tLN:3382\n@SQ\tSN:APMT01225448.1\tLN:3381\n@SQ\tSN:APMT01225492.1\tLN:3381\n@SQ\tSN:APMT01225495.1\tLN:3381\n@SQ\tSN:APMT01225496.1\tLN:3381\n@SQ\tSN:APMT01225651.1\tLN:3381\n@SQ\tSN:KB713062.1\tLN:3381\n@SQ\tSN:APMT01225501.1\tLN:3380\n@SQ\tSN:KB713243.1\tLN:3380\n@SQ\tSN:KB712658.1\tLN:3379\n@SQ\tSN:KB712716.1\tLN:3379\n@SQ\tSN:KB712935.1\tLN:3379\n@SQ\tSN:APMT01225438.1\tLN:3379\n@SQ\tSN:KB712989.1\tLN:3379\n@SQ\tSN:KB712695.1\tLN:3378\n@SQ\tSN:KB712733.1\tLN:3378\n@SQ\tSN:APMT01225516.1\tLN:3378\n@SQ\tSN:KB713141.1\tLN:3378\n@SQ\tSN:KB712835.1\tLN:3377\n@SQ\tSN:APMT01225353.1\tLN:3377\n@SQ\tSN:APMT01225524.1\tLN:3377\n@SQ\tSN:APMT01225526.1\tLN:3377\n@SQ\tSN:KB713005.1\tLN:3377\n@SQ\tSN:KB712431.1\tLN:3376\n@SQ\tSN:APMT01225599.1\tLN:3376\n@SQ\tSN:KB712776.1\tLN:3375\n@SQ\tSN:APMT01225139.1\tLN:3375\n@SQ\tSN:KB712919.1\tLN:3375\n@SQ\tSN:KB713133.1\tLN:3375\n@SQ\tSN:KB712611.1\tLN:3374\n@SQ\tSN:KB712633.1\tLN:3374\n@SQ\tSN:APMT01225201.1\tLN:3374\n@SQ\tSN:APMT01225238.1\tLN:3374\n@SQ\tSN:KB712930.1\tLN:3374\n@SQ\tSN:APMT01225550.1\tLN:3374\n@SQ\tSN:APMT01225553.1\tLN:3374\n@SQ\tSN:KB712354.1\tLN:3373\n@SQ\tSN:KB711572.1\tLN:3372\n@SQ\tSN:KB712362.1\tLN:3372\n@SQ\tSN:KB712770.1\tLN:3372\n@SQ\tSN:APMT01225193.1\tLN:3372\n@SQ\tSN:KB712995.1\tLN:3372\n@SQ\tSN:APMT01225560.1\tLN:3372\n@SQ\tSN:KB712665.1\tLN:3371\n@SQ\tSN:APMT01225114.1\tLN:3371\n@SQ\tSN:APMT01225564.1\tLN:3371\n@SQ\tSN:APMT01225567.1\tLN:3371\n@SQ\tSN:KB713785.1\tLN:3371\n@SQ\tSN:APMT01225580.1\tLN:3370\n@SQ\tSN:APMT01225583.1\tLN:3370\n@SQ\tSN:KB712961.1\tLN:3369\n@SQ\tSN:APMT01225584.1\tLN:3369\n@SQ\tSN:KB713932.1\tLN:3369\n@SQ\tSN:KB712779.1\tLN:3368\n@SQ\tSN:APMT01225178.1\tLN:3368\n@SQ\tSN:KB712871.1\tLN:3367\n@SQ\tSN:KB712907.1\tLN:3367\n@SQ\tSN:APMT01225334.1\tLN:3367\n@SQ\tSN:APMT01225604.1\tLN:3367\n@SQ\tSN:KB713063.1\tLN:3367\n@SQ\tSN:KB710724.1\tLN:3366\n@SQ\tSN:KB712819.1\tLN:3366\n@SQ\tSN:KB712958.1\tLN:3366\n@SQ\tSN:KB712969.1\tLN:3366\n@SQ\tSN:KB712977.1\tLN:3366\n@SQ\tSN:KB712828.1\tLN:3365\n@SQ\tSN:KB712887.1\tLN:3365\n@SQ\tSN:APMT01225234.1\tLN:3365\n@SQ\tSN:APMT01225261.1\tLN:3365\n@SQ\tSN:KB714058.1\tLN:3365\n@SQ\tSN:APMT01225616.1\tLN:3364\n@SQ\tSN:KB714218.1\tLN:3364\n@SQ\tSN:KB712692.1\tLN:3363\n@SQ\tSN:APMT01224940.1\tLN:3363\n@SQ\tSN:KB712875.1\tLN:3363\n@SQ\tSN:KB712975.1\tLN:3363\n@SQ\tSN:KB712531.1\tLN:3362\n@SQ\tSN:KB712931.1\tLN:3362\n@SQ\tSN:KB713024.1\tLN:3362\n@SQ\tSN:KB712543.1\tLN:3361\n@SQ\tSN:APMT01224912.1\tLN:3361\n@SQ\tSN:APMT01225638.1\tLN:3361\n@SQ\tSN:KB712964.1\tLN:3360\n@SQ\tSN:APMT01225645.1\tLN:3360\n@SQ\tSN:APMT01225743.1\tLN:3360\n@SQ\tSN:KB712824.1\tLN:3359\n@SQ\tSN:KB712296.1\tLN:3358\n@SQ\tSN:KB712898.1\tLN:3358\n@SQ\tSN:KB712940.1\tLN:3358\n@SQ\tSN:APMT01225654.1\tLN:3358\n@SQ\tSN:KB712808.1\tLN:3357\n@SQ\tSN:KB712829.1\tLN:3357\n@SQ\tSN:KB712860.1\tLN:3357\n@SQ\tSN:APMT01225658.1\tLN:3357\n@SQ\tSN:KB712978.1\tLN:3356\n@SQ\tSN:KB714024.1\tLN:3356\n@SQ\tSN:KB712834.1\tLN:3355\n@SQ\tSN:KB712928.1\tLN:3355\n@SQ\tSN:APMT01225675.1\tLN:3355\n@SQ\tSN:KB712870.1\tLN:3354\n@SQ\tSN:APMT01225688.1\tLN:3354\n@SQ\tSN:KB713144.1\tLN:3354\n@SQ\tSN:APMT01224975.1\tLN:3353\n@SQ\tSN:KB712971.1\tLN:3353\n@SQ\tSN:KB713249.1\tLN:3353\n@SQ\tSN:APMT01224271.1\tLN:3352\n@SQ\tSN:KB712654.1\tLN:3352\n@SQ\tSN:KB712772.1\tLN:3352\n@SQ\tSN:KB712973.1\tLN:3352\n@SQ\tSN:APMT01225708.1\tLN:3352\n@SQ\tSN:KB712659.1\tLN:3351\n@SQ\tSN:APMT01225259.1\tLN:3351\n@SQ\tSN:KB713038.1\tLN:3351\n@SQ\tSN:KB712527.1\tLN:3350\n@SQ\tSN:KB712794.1\tLN:3350\n@SQ\tSN:KB712855.1\tLN:3350\n@SQ\tSN:KB712874.1\tLN:3350\n@SQ\tSN:KB712948.1\tLN:3350\n@SQ\tSN:APMT01225712.1\tLN:3350\n@SQ\tSN:APMT01225713.1\tLN:3350\n@SQ\tSN:KB713158.1\tLN:3350\n@SQ\tSN:APMT01225357.1\tLN:3349\n@SQ\tSN:APMT01225488.1\tLN:3349\n@SQ\tSN:APMT01225715.1\tLN:3349\n@SQ\tSN:KB712864.1\tLN:3348\n@SQ\tSN:KB712938.1\tLN:3348\n@SQ\tSN:APMT01225386.1\tLN:3348\n@SQ\tSN:KB712687.1\tLN:3347\n@SQ\tSN:APMT01225095.1\tLN:3347\n@SQ\tSN:APMT01225719.1\tLN:3347\n@SQ\tSN:APMT01224254.1\tLN:3346\n@SQ\tSN:KB712656.1\tLN:3346\n@SQ\tSN:KB712967.1\tLN:3346\n@SQ\tSN:APMT01225667.1\tLN:3346\n@SQ\tSN:APMT01225716.1\tLN:3346\n@SQ\tSN:APMT01225746.1\tLN:3346\n@SQ\tSN:KB712618.1\tLN:3345\n@SQ\tSN:KB713027.1\tLN:3345\n@SQ\tSN:KB713056.1\tLN:3345\n@SQ\tSN:APMT01225726.1\tLN:3345\n@SQ\tSN:APMT01225734.1\tLN:3345\n@SQ\tSN:KB712254.1\tLN:3344\n@SQ\tSN:KB712924.1\tLN:3344\n@SQ\tSN:KB713192.1\tLN:3344\n@SQ\tSN:APMT01224260.1\tLN:3343\n@SQ\tSN:KB712849.1\tLN:3343\n@SQ\tSN:APMT01225741.1\tLN:3343\n@SQ\tSN:KB713264.1\tLN:3343\n@SQ\tSN:KB712922.1\tLN:3342\n@SQ\tSN:KB712939.1\tLN:3342\n@SQ\tSN:APMT01225749.1\tLN:3342\n@SQ\tSN:APMT01226022.1\tLN:3342\n@SQ\tSN:KB712696.1\tLN:3341\n@SQ\tSN:APMT01225754.1\tLN:3341\n@SQ\tSN:APMT01225755.1\tLN:3341\n@SQ\tSN:KB713059.1\tLN:3340\n@SQ\tSN:APMT01225769.1\tLN:3340\n@SQ\tSN:KB713184.1\tLN:3340\n@SQ\tSN:KB713550.1\tLN:3340\n@SQ\tSN:KB712245.1\tLN:3339\n@SQ\tSN:APMT01225762.1\tLN:3339\n@SQ\tSN:APMT01226212.1\tLN:3339\n@SQ\tSN:KB712837.1\tLN:3338\n@SQ\tSN:APMT01225231.1\tLN:3338\n@SQ\tSN:KB712986.1\tLN:3338\n@SQ\tSN:APMT01225742.1\tLN:3338\n@SQ\tSN:KB713167.1\tLN:3338\n@SQ\tSN:KB712905.1\tLN:3337\n@SQ\tSN:KB713008.1\tLN:3337\n@SQ\tSN:APMT01225789.1\tLN:3337\n@SQ\tSN:KB712917.1\tLN:3336\n@SQ\tSN:KB713035.1\tLN:3336\n@SQ\tSN:APMT01225796.1\tLN:3336\n@SQ\tSN:KB713769.1\tLN:3336\n@SQ\tSN:KB714037.1\tLN:3336\n@SQ\tSN:KB714362.1\tLN:3336\n@SQ\tSN:KB712601.1\tLN:3335\n@SQ\tSN:KB712623.1\tLN:3335\n@SQ\tSN:KB712903.1\tLN:3335\n@SQ\tSN:KB712920.1\tLN:3335\n@SQ\tSN:APMT01225456.1\tLN:3335\n@SQ\tSN:APMT01225799.1\tLN:3335\n@SQ\tSN:KB713260.1\tLN:3335\n@SQ\tSN:KB712815.1\tLN:3334\n@SQ\tSN:KB712942.1\tLN:3334\n@SQ\tSN:APMT01225494.1\tLN:3334\n@SQ\tSN:APMT01225807.1\tLN:3334\n@SQ\tSN:KB712321.1\tLN:3333\n@SQ\tSN:APMT01225542.1\tLN:3333\n@SQ\tSN:APMT01225808.1\tLN:3333\n@SQ\tSN:KB712778.1\tLN:3332\n@SQ\tSN:KB712885.1\tLN:3332\n@SQ\tSN:APMT01225252.1\tLN:3332\n@SQ\tSN:APMT01225541.1\tLN:3332\n@SQ\tSN:KB712799.1\tLN:3331\n@SQ\tSN:KB712890.1\tLN:3331\n@SQ\tSN:APMT01225451.1\tLN:3331\n@SQ\tSN:APMT01225824.1\tLN:3331\n@SQ\tSN:KB712933.1\tLN:3330\n@SQ\tSN:KB713023.1\tLN:3330\n@SQ\tSN:APMT01226232.1\tLN:3330\n@SQ\tSN:KB712827.1\tLN:3329\n@SQ\tSN:KB712962.1\tLN:3329\n@SQ\tSN:APMT01225828.1\tLN:3329\n@SQ\tSN:KB712334.1\tLN:3328\n@SQ\tSN:APMT01225431.1\tLN:3328\n@SQ\tSN:APMT01225443.1\tLN:3328\n@SQ\tSN:APMT01225830.1\tLN:3328\n@SQ\tSN:APMT01225834.1\tLN:3328\n@SQ\tSN:APMT01225837.1\tLN:3328\n@SQ\tSN:APMT01225850.1\tLN:3328\n@SQ\tSN:KB712579.1\tLN:3327\n@SQ\tSN:KB712993.1\tLN:3327\n@SQ\tSN:APMT01225839.1\tLN:3327\n@SQ\tSN:APMT01225840.1\tLN:3327\n@SQ\tSN:APMT01225444.1\tLN:3326\n@SQ\tSN:APMT01225823.1\tLN:3326\n@SQ\tSN:APMT01225847.1\tLN:3326\n@SQ\tSN:KB712782.1\tLN:3325\n@SQ\tSN:KB712805.1\tLN:3325\n@SQ\tSN:KB712984.1\tLN:3325\n@SQ\tSN:APMT01225829.1\tLN:3325\n@SQ\tSN:APMT01225854.1\tLN:3325\n@SQ\tSN:KB713157.1\tLN:3325\n@SQ\tSN:KB713226.1\tLN:3325\n@SQ\tSN:KB712985.1\tLN:3324\n@SQ\tSN:APMT01225510.1\tLN:3324\n@SQ\tSN:KB713020.1\tLN:3324\n@SQ\tSN:KB713066.1\tLN:3324\n@SQ\tSN:APMT01225858.1\tLN:3324\n@SQ\tSN:KB712466.1\tLN:3323\n@SQ\tSN:KB712707.1\tLN:3323\n@SQ\tSN:APMT01225825.1\tLN:3323\n@SQ\tSN:APMT01225857.1\tLN:3323\n@SQ\tSN:APMT01225867.1\tLN:3323\n@SQ\tSN:APMT01225971.1\tLN:3323\n@SQ\tSN:KB713976.1\tLN:3323\n@SQ\tSN:KB712734.1\tLN:3321\n@SQ\tSN:KB712916.1\tLN:3321\n@SQ\tSN:APMT01225878.1\tLN:3321\n@SQ\tSN:APMT01225882.1\tLN:3321\n@SQ\tSN:APMT01225459.1\tLN:3320\n@SQ\tSN:KB713067.1\tLN:3320\n@SQ\tSN:KB712597.1\tLN:3319\n@SQ\tSN:KB712918.1\tLN:3319\n@SQ\tSN:KB712955.1\tLN:3319\n@SQ\tSN:APMT01225888.1\tLN:3319\n@SQ\tSN:KB714434.1\tLN:3319\n@SQ\tSN:KB712768.1\tLN:3318\n@SQ\tSN:KB713109.1\tLN:3318\n@SQ\tSN:APMT01225343.1\tLN:3317\n@SQ\tSN:KB713122.1\tLN:3317\n@SQ\tSN:APMT01225907.1\tLN:3317\n@SQ\tSN:APMT01225698.1\tLN:3316\n@SQ\tSN:KB713097.1\tLN:3316\n@SQ\tSN:KB713087.1\tLN:3315\n@SQ\tSN:APMT01225917.1\tLN:3315\n@SQ\tSN:KB713450.1\tLN:3315\n@SQ\tSN:KB712836.1\tLN:3314\n@SQ\tSN:KB712899.1\tLN:3313\n@SQ\tSN:APMT01225554.1\tLN:3313\n@SQ\tSN:APMT01225931.1\tLN:3313\n@SQ\tSN:KB713003.1\tLN:3312\n@SQ\tSN:APMT01225932.1\tLN:3312\n@SQ\tSN:APMT01225934.1\tLN:3312\n@SQ\tSN:KB712822.1\tLN:3311\n@SQ\tSN:APMT01225933.1\tLN:3311\n@SQ\tSN:KB713354.1\tLN:3311\n@SQ\tSN:KB712921.1\tLN:3310\n@SQ\tSN:KB712957.1\tLN:3310\n@SQ\tSN:KB713004.1\tLN:3310\n@SQ\tSN:KB713102.1\tLN:3310\n@SQ\tSN:KB714364.1\tLN:3310\n@SQ\tSN:KB712952.1\tLN:3309\n@SQ\tSN:APMT01226046.1\tLN:3309\n@SQ\tSN:KB712970.1\tLN:3308\n@SQ\tSN:KB713045.1\tLN:3308\n@SQ\tSN:APMT01225926.1\tLN:3308\n@SQ\tSN:KB713152.1\tLN:3308\n@SQ\tSN:APMT01225957.1\tLN:3308\n@SQ\tSN:APMT01225958.1\tLN:3308\n@SQ\tSN:KB712990.1\tLN:3307\n@SQ\tSN:KB713055.1\tLN:3307\n@SQ\tSN:KB713072.1\tLN:3307\n@SQ\tSN:KB711594.1\tLN:3306\n@SQ\tSN:APMT01225970.1\tLN:3306\n@SQ\tSN:APMT01225976.1\tLN:3305\n@SQ\tSN:APMT01225979.1\tLN:3305\n@SQ\tSN:KB712925.1\tLN:3304\n@SQ\tSN:KB713077.1\tLN:3304\n@SQ\tSN:APMT01225982.1\tLN:3304\n@SQ\tSN:KB711823.1\tLN:3303\n@SQ\tSN:APMT01225619.1\tLN:3303\n@SQ\tSN:APMT01225986.1\tLN:3303\n@SQ\tSN:APMT01225987.1\tLN:3303\n@SQ\tSN:KB712937.1\tLN:3302\n@SQ\tSN:APMT01225714.1\tLN:3302\n@SQ\tSN:APMT01225991.1\tLN:3302\n@SQ\tSN:APMT01225998.1\tLN:3302\n@SQ\tSN:KB713206.1\tLN:3302\n@SQ\tSN:APMT01225144.1\tLN:3301\n@SQ\tSN:KB712980.1\tLN:3301\n@SQ\tSN:APMT01225727.1\tLN:3301\n@SQ\tSN:KB713155.1\tLN:3301\n@SQ\tSN:APMT01225975.1\tLN:3301\n@SQ\tSN:APMT01226001.1\tLN:3301\n@SQ\tSN:APMT01226006.1\tLN:3301\n@SQ\tSN:KB713198.1\tLN:3301\n@SQ\tSN:KB713445.1\tLN:3301\n@SQ\tSN:APMT01226007.1\tLN:3300\n@SQ\tSN:APMT01225511.1\tLN:3299\n@SQ\tSN:APMT01225538.1\tLN:3299\n@SQ\tSN:APMT01225646.1\tLN:3299\n@SQ\tSN:KB712674.1\tLN:3298\n@SQ\tSN:KB712830.1\tLN:3298\n@SQ\tSN:APMT01225341.1\tLN:3298\n@SQ\tSN:APMT01225655.1\tLN:3298\n@SQ\tSN:APMT01226015.1\tLN:3298\n@SQ\tSN:APMT01226019.1\tLN:3298\n@SQ\tSN:APMT01225525.1\tLN:3297\n@SQ\tSN:APMT01226026.1\tLN:3297\n@SQ\tSN:KB713245.1\tLN:3297\n@SQ\tSN:KB713492.1\tLN:3297\n@SQ\tSN:KB712673.1\tLN:3296\n@SQ\tSN:APMT01226027.1\tLN:3296\n@SQ\tSN:APMT01226028.1\tLN:3296\n@SQ\tSN:KB713173.1\tLN:3295\n@SQ\tSN:APMT01226029.1\tLN:3295\n@SQ\tSN:APMT01226030.1\tLN:3295\n@SQ\tSN:APMT01226031.1\tLN:3295\n@SQ\tSN:APMT01226032.1\tLN:3295\n@SQ\tSN:KB714421.1\tLN:3295\n@SQ\tSN:APMT01226033.1\tLN:3294\n@SQ\tSN:APMT01226036.1\tLN:3294\n@SQ\tSN:KB712850.1\tLN:3293\n@SQ\tSN:APMT01226014.1\tLN:3293\n@SQ\tSN:APMT01226037.1\tLN:3293\n@SQ\tSN:APMT01226038.1\tLN:3293\n@SQ\tSN:APMT01226039.1\tLN:3293\n@SQ\tSN:KB712406.1\tLN:3292\n@SQ\tSN:KB712580.1\tLN:3292\n@SQ\tSN:KB713012.1\tLN:3292\n@SQ\tSN:KB713131.1\tLN:3292\n@SQ\tSN:APMT01226041.1\tLN:3292\n@SQ\tSN:KB713054.1\tLN:3291\n@SQ\tSN:KB713164.1\tLN:3291\n@SQ\tSN:APMT01226048.1\tLN:3291\n@SQ\tSN:KB713788.1\tLN:3290\n@SQ\tSN:KB714427.1\tLN:3290\n@SQ\tSN:KB712857.1\tLN:3289\n@SQ\tSN:KB713041.1\tLN:3289\n@SQ\tSN:APMT01226061.1\tLN:3289\n@SQ\tSN:APMT01226063.1\tLN:3289\n@SQ\tSN:APMT01226066.1\tLN:3289\n@SQ\tSN:KB712736.1\tLN:3288\n@SQ\tSN:KB712972.1\tLN:3288\n@SQ\tSN:KB713039.1\tLN:3288\n@SQ\tSN:KB713071.1\tLN:3288\n@SQ\tSN:KB713145.1\tLN:3288\n@SQ\tSN:APMT01226074.1\tLN:3288\n@SQ\tSN:KB713014.1\tLN:3287\n@SQ\tSN:APMT01226073.1\tLN:3287\n@SQ\tSN:APMT01226077.1\tLN:3287\n@SQ\tSN:KB713186.1\tLN:3286\n@SQ\tSN:APMT01226087.1\tLN:3286\n@SQ\tSN:KB713043.1\tLN:3285\n@SQ\tSN:APMT01226092.1\tLN:3285\n@SQ\tSN:APMT01226101.1\tLN:3284\n@SQ\tSN:KB713202.1\tLN:3284\n@SQ\tSN:APMT01224489.1\tLN:3283\n@SQ\tSN:APMT01225493.1\tLN:3283\n@SQ\tSN:KB712427.1\tLN:3282\n@SQ\tSN:KB712685.1\tLN:3282\n@SQ\tSN:KB713069.1\tLN:3282\n@SQ\tSN:KB713149.1\tLN:3282\n@SQ\tSN:APMT01226053.1\tLN:3282\n@SQ\tSN:APMT01226110.1\tLN:3282\n@SQ\tSN:APMT01226111.1\tLN:3282\n@SQ\tSN:KB712336.1\tLN:3281\n@SQ\tSN:KB713006.1\tLN:3281\n@SQ\tSN:KB713007.1\tLN:3281\n@SQ\tSN:APMT01225770.1\tLN:3281\n@SQ\tSN:APMT01225898.1\tLN:3281\n@SQ\tSN:KB713162.1\tLN:3281\n@SQ\tSN:APMT01226114.1\tLN:3281\n@SQ\tSN:KB713343.1\tLN:3281\n@SQ\tSN:APMT01226768.1\tLN:3281\n@SQ\tSN:KB713001.1\tLN:3280\n@SQ\tSN:KB713034.1\tLN:3280\n@SQ\tSN:KB713128.1\tLN:3280\n@SQ\tSN:KB713179.1\tLN:3280\n@SQ\tSN:KB713193.1\tLN:3280\n@SQ\tSN:APMT01226119.1\tLN:3280\n@SQ\tSN:KB713210.1\tLN:3280\n@SQ\tSN:KB712832.1\tLN:3279\n@SQ\tSN:KB712991.1\tLN:3279\n@SQ\tSN:KB712998.1\tLN:3279\n@SQ\tSN:KB713153.1\tLN:3279\n@SQ\tSN:APMT01226058.1\tLN:3279\n@SQ\tSN:KB712614.1\tLN:3278\n@SQ\tSN:APMT01224537.1\tLN:3278\n@SQ\tSN:KB712944.1\tLN:3278\n@SQ\tSN:KB713002.1\tLN:3278\n@SQ\tSN:APMT01225607.1\tLN:3278\n@SQ\tSN:KB713028.1\tLN:3277\n@SQ\tSN:APMT01226140.1\tLN:3277\n@SQ\tSN:APMT01226141.1\tLN:3277\n@SQ\tSN:APMT01225563.1\tLN:3276\n@SQ\tSN:APMT01225859.1\tLN:3276\n@SQ\tSN:APMT01225920.1\tLN:3276\n@SQ\tSN:KB714378.1\tLN:3276\n@SQ\tSN:APMT01225838.1\tLN:3275\n@SQ\tSN:APMT01226148.1\tLN:3275\n@SQ\tSN:APMT01226151.1\tLN:3275\n@SQ\tSN:APMT01226155.1\tLN:3275\n@SQ\tSN:APMT01226161.1\tLN:3274\n@SQ\tSN:APMT01226162.1\tLN:3274\n@SQ\tSN:KB714007.1\tLN:3274\n@SQ\tSN:APMT01225809.1\tLN:3273\n@SQ\tSN:APMT01226174.1\tLN:3273\n@SQ\tSN:KB713331.1\tLN:3273\n@SQ\tSN:KB712950.1\tLN:3272\n@SQ\tSN:APMT01225487.1\tLN:3272\n@SQ\tSN:APMT01226186.1\tLN:3272\n@SQ\tSN:KB714195.1\tLN:3272\n@SQ\tSN:KB712791.1\tLN:3271\n@SQ\tSN:KB712841.1\tLN:3271\n@SQ\tSN:KB712956.1\tLN:3271\n@SQ\tSN:KB713098.1\tLN:3271\n@SQ\tSN:APMT01226176.1\tLN:3271\n@SQ\tSN:APMT01226179.1\tLN:3271\n@SQ\tSN:APMT01226185.1\tLN:3271\n@SQ\tSN:KB713236.1\tLN:3271\n@SQ\tSN:KB712788.1\tLN:3270\n@SQ\tSN:KB712840.1\tLN:3270\n@SQ\tSN:KB713036.1\tLN:3270\n@SQ\tSN:KB712444.1\tLN:3269\n@SQ\tSN:KB713100.1\tLN:3269\n@SQ\tSN:APMT01225831.1\tLN:3269\n@SQ\tSN:KB713112.1\tLN:3269\n@SQ\tSN:APMT01226043.1\tLN:3269\n@SQ\tSN:KB713203.1\tLN:3269\n@SQ\tSN:KB712632.1\tLN:3268\n@SQ\tSN:KB712979.1\tLN:3268\n@SQ\tSN:KB713064.1\tLN:3268\n@SQ\tSN:APMT01226203.1\tLN:3268\n@SQ\tSN:KB713105.1\tLN:3267\n@SQ\tSN:KB713148.1\tLN:3267\n@SQ\tSN:APMT01225947.1\tLN:3267\n@SQ\tSN:KB713231.1\tLN:3267\n@SQ\tSN:KB713404.1\tLN:3267\n@SQ\tSN:KB713677.1\tLN:3267\n@SQ\tSN:KB712868.1\tLN:3266\n@SQ\tSN:KB712926.1\tLN:3266\n@SQ\tSN:APMT01225559.1\tLN:3266\n@SQ\tSN:APMT01225950.1\tLN:3266\n@SQ\tSN:APMT01226219.1\tLN:3265\n@SQ\tSN:KB713037.1\tLN:3264\n@SQ\tSN:APMT01226228.1\tLN:3264\n@SQ\tSN:KB712652.1\tLN:3263\n@SQ\tSN:KB712842.1\tLN:3263\n@SQ\tSN:KB712987.1\tLN:3263\n@SQ\tSN:APMT01225870.1\tLN:3263\n@SQ\tSN:APMT01226236.1\tLN:3263\n@SQ\tSN:APMT01226237.1\tLN:3263\n@SQ\tSN:APMT01226238.1\tLN:3263\n@SQ\tSN:APMT01225963.1\tLN:3262\n@SQ\tSN:APMT01226241.1\tLN:3262\n@SQ\tSN:APMT01226251.1\tLN:3261\n@SQ\tSN:KB713095.1\tLN:3260\n@SQ\tSN:APMT01226040.1\tLN:3260\n@SQ\tSN:APMT01226254.1\tLN:3260\n@SQ\tSN:KB713370.1\tLN:3260\n@SQ\tSN:APMT01225398.1\tLN:3259\n@SQ\tSN:APMT01225547.1\tLN:3259\n@SQ\tSN:KB713080.1\tLN:3259\n@SQ\tSN:APMT01226259.1\tLN:3259\n@SQ\tSN:KB713093.1\tLN:3258\n@SQ\tSN:KB713213.1\tLN:3258\n@SQ\tSN:KB713248.1\tLN:3258\n@SQ\tSN:KB711896.1\tLN:3257\n@SQ\tSN:KB713021.1\tLN:3257\n@SQ\tSN:KB713049.1\tLN:3257\n@SQ\tSN:KB713047.1\tLN:3256\n@SQ\tSN:APMT01226016.1\tLN:3256\n@SQ\tSN:KB711962.1\tLN:3255\n@SQ\tSN:KB713084.1\tLN:3255\n@SQ\tSN:KB713120.1\tLN:3255\n@SQ\tSN:KB713121.1\tLN:3255\n@SQ\tSN:APMT01226284.1\tLN:3255\n@SQ\tSN:APMT01226285.1\tLN:3255\n@SQ\tSN:APMT01226286.1\tLN:3255\n@SQ\tSN:KB713033.1\tLN:3254\n@SQ\tSN:APMT01226042.1\tLN:3254\n@SQ\tSN:APMT01226296.1\tLN:3254\n@SQ\tSN:KB712693.1\tLN:3253\n@SQ\tSN:KB712852.1\tLN:3253\n@SQ\tSN:APMT01226109.1\tLN:3253\n@SQ\tSN:APMT01226294.1\tLN:3253\n@SQ\tSN:APMT01226303.1\tLN:3253\n@SQ\tSN:KB713760.1\tLN:3253\n@SQ\tSN:KB712847.1\tLN:3252\n@SQ\tSN:KB712954.1\tLN:3252\n@SQ\tSN:KB713090.1\tLN:3252\n@SQ\tSN:KB713125.1\tLN:3252\n@SQ\tSN:APMT01226158.1\tLN:3252\n@SQ\tSN:KB713053.1\tLN:3251\n@SQ\tSN:KB713081.1\tLN:3251\n@SQ\tSN:KB713220.1\tLN:3251\n@SQ\tSN:APMT01226309.1\tLN:3251\n@SQ\tSN:KB713356.1\tLN:3251\n@SQ\tSN:KB712802.1\tLN:3250\n@SQ\tSN:APMT01225983.1\tLN:3250\n@SQ\tSN:APMT01226279.1\tLN:3250\n@SQ\tSN:KB712963.1\tLN:3249\n@SQ\tSN:KB713025.1\tLN:3249\n@SQ\tSN:APMT01226325.1\tLN:3249\n@SQ\tSN:KB713134.1\tLN:3248\n@SQ\tSN:APMT01225992.1\tLN:3248\n@SQ\tSN:KB712934.1\tLN:3247\n@SQ\tSN:KB713259.1\tLN:3247\n@SQ\tSN:APMT01226332.1\tLN:3247\n@SQ\tSN:APMT01226335.1\tLN:3247\n@SQ\tSN:APMT01226341.1\tLN:3247\n@SQ\tSN:KB713359.1\tLN:3247\n@SQ\tSN:KB714575.1\tLN:3247\n@SQ\tSN:KB712699.1\tLN:3246\n@SQ\tSN:KB713083.1\tLN:3246\n@SQ\tSN:APMT01226347.1\tLN:3246\n@SQ\tSN:APMT01226348.1\tLN:3245\n@SQ\tSN:KB713009.1\tLN:3244\n@SQ\tSN:APMT01225972.1\tLN:3244\n@SQ\tSN:KB713227.1\tLN:3244\n@SQ\tSN:KB713809.1\tLN:3244\n@SQ\tSN:KB713029.1\tLN:3243\n@SQ\tSN:APMT01225887.1\tLN:3243\n@SQ\tSN:KB713135.1\tLN:3243\n@SQ\tSN:KB713325.1\tLN:3243\n@SQ\tSN:APMT01225993.1\tLN:3242\n@SQ\tSN:KB713190.1\tLN:3242\n@SQ\tSN:APMT01226368.1\tLN:3242\n@SQ\tSN:KB713321.1\tLN:3242\n@SQ\tSN:KB712221.1\tLN:3241\n@SQ\tSN:KB713052.1\tLN:3241\n@SQ\tSN:KB713060.1\tLN:3241\n@SQ\tSN:KB713078.1\tLN:3241\n@SQ\tSN:APMT01226365.1\tLN:3241\n@SQ\tSN:APMT01226377.1\tLN:3241\n@SQ\tSN:KB714249.1\tLN:3241\n@SQ\tSN:KB713130.1\tLN:3239\n@SQ\tSN:APMT01226124.1\tLN:3239\n@SQ\tSN:APMT01226180.1\tLN:3239\n@SQ\tSN:APMT01226384.1\tLN:3239\n@SQ\tSN:KB712753.1\tLN:3238\n@SQ\tSN:KB712959.1\tLN:3238\n@SQ\tSN:APMT01225864.1\tLN:3238\n@SQ\tSN:KB713126.1\tLN:3238\n@SQ\tSN:APMT01226206.1\tLN:3238\n@SQ\tSN:APMT01226388.1\tLN:3238\n@SQ\tSN:APMT01226361.1\tLN:3237\n@SQ\tSN:APMT01226364.1\tLN:3237\n@SQ\tSN:KB713551.1\tLN:3237\n@SQ\tSN:KB713015.1\tLN:3236\n@SQ\tSN:APMT01226397.1\tLN:3236\n@SQ\tSN:KB713447.1\tLN:3236\n@SQ\tSN:KB713091.1\tLN:3235\n@SQ\tSN:KB713188.1\tLN:3235\n@SQ\tSN:APMT01226227.1\tLN:3235\n@SQ\tSN:APMT01226416.1\tLN:3235\n@SQ\tSN:APMT01226417.1\tLN:3235\n@SQ\tSN:APMT01226420.1\tLN:3235\n@SQ\tSN:APMT01226421.1\tLN:3235\n@SQ\tSN:APMT01226422.1\tLN:3235\n@SQ\tSN:KB714464.1\tLN:3235\n@SQ\tSN:KB713189.1\tLN:3234\n@SQ\tSN:KB713197.1\tLN:3234\n@SQ\tSN:APMT01226222.1\tLN:3234\n@SQ\tSN:APMT01226423.1\tLN:3234\n@SQ\tSN:APMT01226424.1\tLN:3234\n@SQ\tSN:APMT01226428.1\tLN:3234\n@SQ\tSN:KB712947.1\tLN:3233\n@SQ\tSN:APMT01226429.1\tLN:3233\n@SQ\tSN:KB712859.1\tLN:3232\n@SQ\tSN:KB713048.1\tLN:3232\n@SQ\tSN:KB713116.1\tLN:3232\n@SQ\tSN:APMT01226431.1\tLN:3232\n@SQ\tSN:APMT01226432.1\tLN:3232\n@SQ\tSN:APMT01226433.1\tLN:3232\n@SQ\tSN:KB712545.1\tLN:3231\n@SQ\tSN:KB713110.1\tLN:3231\n@SQ\tSN:KB713232.1\tLN:3231\n@SQ\tSN:APMT01226450.1\tLN:3230\n@SQ\tSN:KB713234.1\tLN:3229\n@SQ\tSN:KB712486.1\tLN:3228\n@SQ\tSN:KB713103.1\tLN:3228\n@SQ\tSN:APMT01226078.1\tLN:3228\n@SQ\tSN:APMT01226132.1\tLN:3228\n@SQ\tSN:KB713301.1\tLN:3228\n@SQ\tSN:APMT01225990.1\tLN:3226\n@SQ\tSN:APMT01226487.1\tLN:3226\n@SQ\tSN:APMT01226490.1\tLN:3225\n@SQ\tSN:KB713369.1\tLN:3225\n@SQ\tSN:KB713339.1\tLN:3224\n@SQ\tSN:APMT01226104.1\tLN:3223\n@SQ\tSN:APMT01226255.1\tLN:3223\n@SQ\tSN:APMT01226479.1\tLN:3223\n@SQ\tSN:APMT01226147.1\tLN:3222\n@SQ\tSN:APMT01226513.1\tLN:3222\n@SQ\tSN:APMT01226514.1\tLN:3222\n@SQ\tSN:APMT01226515.1\tLN:3222\n@SQ\tSN:KB712965.1\tLN:3221\n@SQ\tSN:KB713216.1\tLN:3221\n@SQ\tSN:APMT01226518.1\tLN:3221\n@SQ\tSN:KB713163.1\tLN:3220\n@SQ\tSN:KB713286.1\tLN:3220\n@SQ\tSN:KB713362.1\tLN:3220\n@SQ\tSN:KB713690.1\tLN:3220\n@SQ\tSN:KB714486.1\tLN:3220\n@SQ\tSN:KB713279.1\tLN:3219\n@SQ\tSN:APMT01226523.1\tLN:3219\n@SQ\tSN:APMT01226525.1\tLN:3219\n@SQ\tSN:KB712911.1\tLN:3218\n@SQ\tSN:KB713181.1\tLN:3218\n@SQ\tSN:KB712838.1\tLN:3217\n@SQ\tSN:KB713263.1\tLN:3217\n@SQ\tSN:KB713281.1\tLN:3217\n@SQ\tSN:APMT01226510.1\tLN:3217\n@SQ\tSN:APMT01226526.1\tLN:3217\n@SQ\tSN:APMT01226529.1\tLN:3217\n@SQ\tSN:APMT01226530.1\tLN:3217\n@SQ\tSN:KB712646.1\tLN:3216\n@SQ\tSN:KB713138.1\tLN:3216\n@SQ\tSN:KB713344.1\tLN:3216\n@SQ\tSN:APMT01226539.1\tLN:3216\n@SQ\tSN:APMT01226545.1\tLN:3216\n@SQ\tSN:APMT01226546.1\tLN:3216\n@SQ\tSN:KB713358.1\tLN:3216\n@SQ\tSN:KB713726.1\tLN:3216\n@SQ\tSN:KB712598.1\tLN:3215\n@SQ\tSN:APMT01226260.1\tLN:3215\n@SQ\tSN:APMT01226376.1\tLN:3215\n@SQ\tSN:KB713076.1\tLN:3214\n@SQ\tSN:APMT01226425.1\tLN:3214\n@SQ\tSN:APMT01226556.1\tLN:3214\n@SQ\tSN:APMT01226557.1\tLN:3214\n@SQ\tSN:APMT01226558.1\tLN:3214\n@SQ\tSN:KB712011.1\tLN:3213\n@SQ\tSN:APMT01226047.1\tLN:3213\n@SQ\tSN:APMT01226062.1\tLN:3213\n@SQ\tSN:APMT01226274.1\tLN:3213\n@SQ\tSN:APMT01226552.1\tLN:3213\n@SQ\tSN:APMT01226559.1\tLN:3213\n@SQ\tSN:KB713132.1\tLN:3212\n@SQ\tSN:KB713352.1\tLN:3212\n@SQ\tSN:APMT01226569.1\tLN:3212\n@SQ\tSN:KB712878.1\tLN:3211\n@SQ\tSN:KB712895.1\tLN:3211\n@SQ\tSN:APMT01226200.1\tLN:3211\n@SQ\tSN:KB713239.1\tLN:3211\n@SQ\tSN:KB713270.1\tLN:3211\n@SQ\tSN:KB713338.1\tLN:3211\n@SQ\tSN:KB714451.1\tLN:3211\n@SQ\tSN:KB713273.1\tLN:3210\n@SQ\tSN:APMT01226578.1\tLN:3210\n@SQ\tSN:APMT01226584.1\tLN:3210\n@SQ\tSN:KB713070.1\tLN:3209\n@SQ\tSN:APMT01226125.1\tLN:3209\n@SQ\tSN:APMT01226195.1\tLN:3208\n@SQ\tSN:APMT01226264.1\tLN:3208\n@SQ\tSN:APMT01226594.1\tLN:3208\n@SQ\tSN:KB713046.1\tLN:3207\n@SQ\tSN:APMT01226242.1\tLN:3207\n@SQ\tSN:KB711635.1\tLN:3206\n@SQ\tSN:KB713217.1\tLN:3206\n@SQ\tSN:APMT01226231.1\tLN:3206\n@SQ\tSN:KB713347.1\tLN:3206\n@SQ\tSN:APMT01226610.1\tLN:3206\n@SQ\tSN:KB713531.1\tLN:3206\n@SQ\tSN:KB713124.1\tLN:3205\n@SQ\tSN:KB713170.1\tLN:3205\n@SQ\tSN:APMT01226338.1\tLN:3205\n@SQ\tSN:KB713292.1\tLN:3205\n@SQ\tSN:KB713274.1\tLN:3204\n@SQ\tSN:APMT01226494.1\tLN:3204\n@SQ\tSN:APMT01226547.1\tLN:3204\n@SQ\tSN:APMT01226634.1\tLN:3204\n@SQ\tSN:KB713242.1\tLN:3203\n@SQ\tSN:APMT01226596.1\tLN:3203\n@SQ\tSN:APMT01226616.1\tLN:3203\n@SQ\tSN:APMT01226638.1\tLN:3203\n@SQ\tSN:APMT01225875.1\tLN:3202\n@SQ\tSN:APMT01226233.1\tLN:3202\n@SQ\tSN:APMT01226581.1\tLN:3202\n@SQ\tSN:APMT01226612.1\tLN:3202\n@SQ\tSN:KB713244.1\tLN:3200\n@SQ\tSN:APMT01226654.1\tLN:3200\n@SQ\tSN:APMT01226657.1\tLN:3200\n@SQ\tSN:KB713101.1\tLN:3199\n@SQ\tSN:KB713119.1\tLN:3199\n@SQ\tSN:KB713241.1\tLN:3199\n@SQ\tSN:APMT01226658.1\tLN:3199\n@SQ\tSN:KB713182.1\tLN:3198\n@SQ\tSN:KB713252.1\tLN:3198\n@SQ\tSN:APMT01226258.1\tLN:3198\n@SQ\tSN:APMT01226591.1\tLN:3198\n@SQ\tSN:KB714035.1\tLN:3198\n@SQ\tSN:KB714478.1\tLN:3198\n@SQ\tSN:APMT01225691.1\tLN:3197\n@SQ\tSN:APMT01226668.1\tLN:3197\n@SQ\tSN:APMT01226669.1\tLN:3197\n@SQ\tSN:APMT01226273.1\tLN:3196\n@SQ\tSN:APMT01226670.1\tLN:3196\n@SQ\tSN:APMT01226671.1\tLN:3196\n@SQ\tSN:KB713212.1\tLN:3195\n@SQ\tSN:APMT01226680.1\tLN:3195\n@SQ\tSN:KB713620.1\tLN:3195\n@SQ\tSN:KB713175.1\tLN:3194\n@SQ\tSN:KB713323.1\tLN:3194\n@SQ\tSN:APMT01226689.1\tLN:3194\n@SQ\tSN:APMT01226690.1\tLN:3194\n@SQ\tSN:APMT01226696.1\tLN:3194\n@SQ\tSN:KB713089.1\tLN:3193\n@SQ\tSN:KB713201.1\tLN:3193\n@SQ\tSN:KB713387.1\tLN:3193\n@SQ\tSN:APMT01226699.1\tLN:3193\n@SQ\tSN:APMT01226700.1\tLN:3193\n@SQ\tSN:APMT01226704.1\tLN:3193\n@SQ\tSN:KB713465.1\tLN:3193\n@SQ\tSN:APMT01227095.1\tLN:3193\n@SQ\tSN:KB713606.1\tLN:3193\n@SQ\tSN:APMT01224817.1\tLN:3192\n@SQ\tSN:KB713405.1\tLN:3192\n@SQ\tSN:APMT01226716.1\tLN:3192\n@SQ\tSN:KB713466.1\tLN:3192\n@SQ\tSN:KB712856.1\tLN:3191\n@SQ\tSN:APMT01226306.1\tLN:3191\n@SQ\tSN:APMT01226725.1\tLN:3191\n@SQ\tSN:APMT01226728.1\tLN:3191\n@SQ\tSN:KB713608.1\tLN:3191\n@SQ\tSN:KB713168.1\tLN:3190\n@SQ\tSN:APMT01226691.1\tLN:3190\n@SQ\tSN:APMT01226732.1\tLN:3190\n@SQ\tSN:APMT01226733.1\tLN:3190\n@SQ\tSN:KB713335.1\tLN:3189\n@SQ\tSN:APMT01226734.1\tLN:3189\n@SQ\tSN:APMT01226737.1\tLN:3189\n@SQ\tSN:APMT01226740.1\tLN:3189\n@SQ\tSN:APMT01226741.1\tLN:3189\n@SQ\tSN:APMT01226742.1\tLN:3189\n@SQ\tSN:APMT01226743.1\tLN:3189\n@SQ\tSN:KB713417.1\tLN:3189\n@SQ\tSN:KB713214.1\tLN:3188\n@SQ\tSN:APMT01226317.1\tLN:3188\n@SQ\tSN:APMT01226744.1\tLN:3188\n@SQ\tSN:KB713449.1\tLN:3188\n@SQ\tSN:KB713166.1\tLN:3187\n@SQ\tSN:KB713311.1\tLN:3187\n@SQ\tSN:APMT01226757.1\tLN:3187\n@SQ\tSN:KB713280.1\tLN:3186\n@SQ\tSN:APMT01226346.1\tLN:3186\n@SQ\tSN:APMT01226356.1\tLN:3186\n@SQ\tSN:KB713333.1\tLN:3186\n@SQ\tSN:APMT01226761.1\tLN:3186\n@SQ\tSN:APMT01226951.1\tLN:3186\n@SQ\tSN:KB713689.1\tLN:3186\n@SQ\tSN:KB712526.1\tLN:3185\n@SQ\tSN:KB712812.1\tLN:3185\n@SQ\tSN:APMT01226375.1\tLN:3185\n@SQ\tSN:KB713330.1\tLN:3185\n@SQ\tSN:APMT01226767.1\tLN:3185\n@SQ\tSN:KB713208.1\tLN:3184\n@SQ\tSN:APMT01226873.1\tLN:3184\n@SQ\tSN:APMT01226410.1\tLN:3183\n@SQ\tSN:APMT01226617.1\tLN:3183\n@SQ\tSN:KB713409.1\tLN:3183\n@SQ\tSN:APMT01226771.1\tLN:3183\n@SQ\tSN:KB712876.1\tLN:3182\n@SQ\tSN:KB713290.1\tLN:3182\n@SQ\tSN:KB713433.1\tLN:3182\n@SQ\tSN:KB712737.1\tLN:3181\n@SQ\tSN:KB713160.1\tLN:3181\n@SQ\tSN:KB713391.1\tLN:3181\n@SQ\tSN:APMT01226785.1\tLN:3181\n@SQ\tSN:KB714262.1\tLN:3181\n@SQ\tSN:KB712807.1\tLN:3180\n@SQ\tSN:KB713088.1\tLN:3180\n@SQ\tSN:KB713099.1\tLN:3180\n@SQ\tSN:APMT01226794.1\tLN:3180\n@SQ\tSN:APMT01226797.1\tLN:3180\n@SQ\tSN:APMT01226800.1\tLN:3180\n@SQ\tSN:APMT01226808.1\tLN:3180\n@SQ\tSN:APMT01226476.1\tLN:3179\n@SQ\tSN:KB713376.1\tLN:3179\n@SQ\tSN:APMT01226809.1\tLN:3179\n@SQ\tSN:KB713783.1\tLN:3179\n@SQ\tSN:APMT01226023.1\tLN:3178\n@SQ\tSN:APMT01226413.1\tLN:3178\n@SQ\tSN:APMT01226519.1\tLN:3178\n@SQ\tSN:KB713470.1\tLN:3178\n@SQ\tSN:KB713705.1\tLN:3178\n@SQ\tSN:APMT01226824.1\tLN:3177\n@SQ\tSN:KB713476.1\tLN:3177\n@SQ\tSN:KB713013.1\tLN:3176\n@SQ\tSN:KB713237.1\tLN:3176\n@SQ\tSN:APMT01226436.1\tLN:3176\n@SQ\tSN:KB713395.1\tLN:3176\n@SQ\tSN:APMT01226828.1\tLN:3176\n@SQ\tSN:APMT01226837.1\tLN:3175\n@SQ\tSN:KB713180.1\tLN:3174\n@SQ\tSN:APMT01226295.1\tLN:3174\n@SQ\tSN:KB713011.1\tLN:3173\n@SQ\tSN:KB713030.1\tLN:3173\n@SQ\tSN:KB713096.1\tLN:3173\n@SQ\tSN:KB713117.1\tLN:3173\n@SQ\tSN:KB713299.1\tLN:3173\n@SQ\tSN:APMT01226845.1\tLN:3173\n@SQ\tSN:APMT01226848.1\tLN:3173\n@SQ\tSN:APMT01226851.1\tLN:3173\n@SQ\tSN:KB713171.1\tLN:3172\n@SQ\tSN:KB713375.1\tLN:3172\n@SQ\tSN:KB713334.1\tLN:3171\n@SQ\tSN:APMT01226856.1\tLN:3171\n@SQ\tSN:APMT01226859.1\tLN:3171\n@SQ\tSN:APMT01226866.1\tLN:3171\n@SQ\tSN:APMT01226867.1\tLN:3171\n@SQ\tSN:KB713861.1\tLN:3171\n@SQ\tSN:KB713172.1\tLN:3170\n@SQ\tSN:APMT01226146.1\tLN:3170\n@SQ\tSN:KB713261.1\tLN:3170\n@SQ\tSN:APMT01226870.1\tLN:3170\n@SQ\tSN:KB713082.1\tLN:3169\n@SQ\tSN:KB713337.1\tLN:3169\n@SQ\tSN:APMT01226874.1\tLN:3169\n@SQ\tSN:APMT01226881.1\tLN:3169\n@SQ\tSN:KB713178.1\tLN:3168\n@SQ\tSN:APMT01226560.1\tLN:3168\n@SQ\tSN:APMT01226886.1\tLN:3168\n@SQ\tSN:APMT01227027.1\tLN:3168\n@SQ\tSN:KB713177.1\tLN:3167\n@SQ\tSN:KB713328.1\tLN:3167\n@SQ\tSN:KB713419.1\tLN:3167\n@SQ\tSN:APMT01226887.1\tLN:3167\n@SQ\tSN:APMT01226912.1\tLN:3167\n@SQ\tSN:KB713187.1\tLN:3166\n@SQ\tSN:APMT01226482.1\tLN:3166\n@SQ\tSN:APMT01226542.1\tLN:3166\n@SQ\tSN:KB713379.1\tLN:3166\n@SQ\tSN:APMT01226900.1\tLN:3166\n@SQ\tSN:APMT01226901.1\tLN:3166\n@SQ\tSN:APMT01226904.1\tLN:3166\n@SQ\tSN:APMT01226760.1\tLN:3165\n@SQ\tSN:APMT01226910.1\tLN:3165\n@SQ\tSN:KB713483.1\tLN:3165\n@SQ\tSN:APMT01226953.1\tLN:3165\n@SQ\tSN:KB713240.1\tLN:3164\n@SQ\tSN:APMT01226495.1\tLN:3164\n@SQ\tSN:APMT01226613.1\tLN:3164\n@SQ\tSN:KB712019.1\tLN:3163\n@SQ\tSN:KB713205.1\tLN:3163\n@SQ\tSN:KB713581.1\tLN:3163\n@SQ\tSN:KB713307.1\tLN:3162\n@SQ\tSN:APMT01226561.1\tLN:3162\n@SQ\tSN:APMT01226651.1\tLN:3161\n@SQ\tSN:APMT01226880.1\tLN:3161\n@SQ\tSN:APMT01226930.1\tLN:3161\n@SQ\tSN:APMT01226940.1\tLN:3161\n@SQ\tSN:KB713233.1\tLN:3160\n@SQ\tSN:APMT01226611.1\tLN:3160\n@SQ\tSN:KB713381.1\tLN:3160\n@SQ\tSN:APMT01226688.1\tLN:3160\n@SQ\tSN:APMT01226722.1\tLN:3160\n@SQ\tSN:APMT01226731.1\tLN:3160\n@SQ\tSN:APMT01226780.1\tLN:3160\n@SQ\tSN:APMT01226941.1\tLN:3160\n@SQ\tSN:KB712386.1\tLN:3159\n@SQ\tSN:KB713143.1\tLN:3159\n@SQ\tSN:KB713269.1\tLN:3159\n@SQ\tSN:KB713313.1\tLN:3159\n@SQ\tSN:APMT01226524.1\tLN:3159\n@SQ\tSN:APMT01226952.1\tLN:3159\n@SQ\tSN:KB714474.1\tLN:3159\n@SQ\tSN:KB712982.1\tLN:3158\n@SQ\tSN:APMT01226945.1\tLN:3158\n@SQ\tSN:APMT01226954.1\tLN:3158\n@SQ\tSN:APMT01226955.1\tLN:3158\n@SQ\tSN:APMT01226959.1\tLN:3158\n@SQ\tSN:APMT01226962.1\tLN:3158\n@SQ\tSN:APMT01226963.1\tLN:3158\n@SQ\tSN:KB713497.1\tLN:3158\n@SQ\tSN:APMT01227960.1\tLN:3158\n@SQ\tSN:KB713287.1\tLN:3157\n@SQ\tSN:APMT01226437.1\tLN:3157\n@SQ\tSN:KB713320.1\tLN:3157\n@SQ\tSN:KB713422.1\tLN:3157\n@SQ\tSN:KB713423.1\tLN:3157\n@SQ\tSN:APMT01226966.1\tLN:3157\n@SQ\tSN:APMT01226972.1\tLN:3156\n@SQ\tSN:APMT01226974.1\tLN:3156\n@SQ\tSN:APMT01226685.1\tLN:3155\n@SQ\tSN:APMT01226975.1\tLN:3155\n@SQ\tSN:KB713805.1\tLN:3155\n@SQ\tSN:APMT01226976.1\tLN:3154\n@SQ\tSN:APMT01226977.1\tLN:3154\n@SQ\tSN:KB713557.1\tLN:3154\n@SQ\tSN:APMT01227544.1\tLN:3154\n@SQ\tSN:KB713065.1\tLN:3153\n@SQ\tSN:KB713257.1\tLN:3153\n@SQ\tSN:KB713350.1\tLN:3153\n@SQ\tSN:APMT01226555.1\tLN:3153\n@SQ\tSN:APMT01226985.1\tLN:3153\n@SQ\tSN:KB713412.1\tLN:3151\n@SQ\tSN:APMT01226992.1\tLN:3151\n@SQ\tSN:APMT01226993.1\tLN:3151\n@SQ\tSN:APMT01226994.1\tLN:3151\n@SQ\tSN:KB713151.1\tLN:3150\n@SQ\tSN:APMT01227000.1\tLN:3150\n@SQ\tSN:APMT01227003.1\tLN:3150\n@SQ\tSN:APMT01227006.1\tLN:3150\n@SQ\tSN:KB713373.1\tLN:3149\n@SQ\tSN:APMT01226762.1\tLN:3149\n@SQ\tSN:APMT01227010.1\tLN:3149\n@SQ\tSN:APMT01227013.1\tLN:3149\n@SQ\tSN:KB713104.1\tLN:3148\n@SQ\tSN:KB713289.1\tLN:3148\n@SQ\tSN:KB713297.1\tLN:3148\n@SQ\tSN:APMT01226572.1\tLN:3148\n@SQ\tSN:KB713364.1\tLN:3148\n@SQ\tSN:KB713416.1\tLN:3148\n@SQ\tSN:APMT01227015.1\tLN:3148\n@SQ\tSN:KB712862.1\tLN:3147\n@SQ\tSN:KB713256.1\tLN:3147\n@SQ\tSN:KB713284.1\tLN:3147\n@SQ\tSN:APMT01226659.1\tLN:3147\n@SQ\tSN:APMT01227019.1\tLN:3147\n@SQ\tSN:APMT01227020.1\tLN:3147\n@SQ\tSN:KB713582.1\tLN:3147\n@SQ\tSN:KB713185.1\tLN:3146\n@SQ\tSN:KB713418.1\tLN:3146\n@SQ\tSN:APMT01226825.1\tLN:3146\n@SQ\tSN:APMT01227021.1\tLN:3146\n@SQ\tSN:APMT01227024.1\tLN:3146\n@SQ\tSN:KB713388.1\tLN:3145\n@SQ\tSN:APMT01227028.1\tLN:3145\n@SQ\tSN:KB713539.1\tLN:3145\n@SQ\tSN:KB713254.1\tLN:3144\n@SQ\tSN:APMT01227029.1\tLN:3144\n@SQ\tSN:KB713282.1\tLN:3143\n@SQ\tSN:APMT01226631.1\tLN:3143\n@SQ\tSN:APMT01226823.1\tLN:3143\n@SQ\tSN:APMT01227030.1\tLN:3143\n@SQ\tSN:APMT01227692.1\tLN:3143\n@SQ\tSN:KB713174.1\tLN:3142\n@SQ\tSN:APMT01226637.1\tLN:3142\n@SQ\tSN:KB713402.1\tLN:3142\n@SQ\tSN:APMT01227041.1\tLN:3142\n@SQ\tSN:APMT01227042.1\tLN:3142\n@SQ\tSN:APMT01227043.1\tLN:3142\n@SQ\tSN:KB713822.1\tLN:3142\n@SQ\tSN:APMT01227046.1\tLN:3141\n@SQ\tSN:APMT01227047.1\tLN:3141\n@SQ\tSN:APMT01227052.1\tLN:3141\n@SQ\tSN:APMT01226763.1\tLN:3140\n@SQ\tSN:KB713456.1\tLN:3140\n@SQ\tSN:APMT01227057.1\tLN:3140\n@SQ\tSN:KB713593.1\tLN:3140\n@SQ\tSN:KB712762.1\tLN:3139\n@SQ\tSN:KB713383.1\tLN:3139\n@SQ\tSN:KB713094.1\tLN:3138\n@SQ\tSN:KB713262.1\tLN:3138\n@SQ\tSN:APMT01226660.1\tLN:3138\n@SQ\tSN:APMT01226766.1\tLN:3138\n@SQ\tSN:KB713458.1\tLN:3138\n@SQ\tSN:APMT01227064.1\tLN:3138\n@SQ\tSN:APMT01227067.1\tLN:3138\n@SQ\tSN:APMT01227068.1\tLN:3138\n@SQ\tSN:KB712976.1\tLN:3137\n@SQ\tSN:KB713278.1\tLN:3137\n@SQ\tSN:KB713524.1\tLN:3137\n@SQ\tSN:KB714282.1\tLN:3137\n@SQ\tSN:KB713322.1\tLN:3136\n@SQ\tSN:APMT01227075.1\tLN:3135\n@SQ\tSN:KB713625.1\tLN:3135\n@SQ\tSN:KB713277.1\tLN:3134\n@SQ\tSN:KB713345.1\tLN:3134\n@SQ\tSN:KB712894.1\tLN:3133\n@SQ\tSN:APMT01227084.1\tLN:3133\n@SQ\tSN:APMT01227089.1\tLN:3133\n@SQ\tSN:APMT01227091.1\tLN:3133\n@SQ\tSN:APMT01227092.1\tLN:3133\n@SQ\tSN:APMT01227093.1\tLN:3133\n@SQ\tSN:KB713398.1\tLN:3132\n@SQ\tSN:APMT01226905.1\tLN:3132\n@SQ\tSN:KB713477.1\tLN:3131\n@SQ\tSN:APMT01227094.1\tLN:3131\n@SQ\tSN:KB713191.1\tLN:3130\n@SQ\tSN:APMT01226777.1\tLN:3130\n@SQ\tSN:KB713486.1\tLN:3130\n@SQ\tSN:KB709575.1\tLN:3129\n@SQ\tSN:KB712960.1\tLN:3129\n@SQ\tSN:KB713114.1\tLN:3129\n@SQ\tSN:KB713452.1\tLN:3129\n@SQ\tSN:KB713293.1\tLN:3128\n@SQ\tSN:APMT01227112.1\tLN:3128\n@SQ\tSN:APMT01227113.1\tLN:3128\n@SQ\tSN:APMT01227116.1\tLN:3128\n@SQ\tSN:KB713086.1\tLN:3127\n@SQ\tSN:KB713209.1\tLN:3127\n@SQ\tSN:KB713446.1\tLN:3127\n@SQ\tSN:APMT01227117.1\tLN:3127\n@SQ\tSN:KB713195.1\tLN:3126\n@SQ\tSN:APMT01226451.1\tLN:3126\n@SQ\tSN:KB713372.1\tLN:3126\n@SQ\tSN:KB713676.1\tLN:3126\n@SQ\tSN:APMT01227121.1\tLN:3125\n@SQ\tSN:APMT01227129.1\tLN:3124\n@SQ\tSN:KB713600.1\tLN:3124\n@SQ\tSN:KB713645.1\tLN:3124\n@SQ\tSN:APMT01227510.1\tLN:3124\n@SQ\tSN:KB711230.1\tLN:3123\n@SQ\tSN:APMT01226774.1\tLN:3123\n@SQ\tSN:APMT01227120.1\tLN:3123\n@SQ\tSN:APMT01227130.1\tLN:3123\n@SQ\tSN:APMT01227134.1\tLN:3123\n@SQ\tSN:APMT01227135.1\tLN:3123\n@SQ\tSN:KB713129.1\tLN:3122\n@SQ\tSN:KB713154.1\tLN:3122\n@SQ\tSN:KB713218.1\tLN:3122\n@SQ\tSN:KB713413.1\tLN:3122\n@SQ\tSN:APMT01227136.1\tLN:3122\n@SQ\tSN:APMT01226667.1\tLN:3121\n@SQ\tSN:KB713482.1\tLN:3121\n@SQ\tSN:APMT01227143.1\tLN:3121\n@SQ\tSN:APMT01227144.1\tLN:3121\n@SQ\tSN:APMT01227150.1\tLN:3121\n@SQ\tSN:KB713382.1\tLN:3120\n@SQ\tSN:APMT01227018.1\tLN:3120\n@SQ\tSN:APMT01227147.1\tLN:3119\n@SQ\tSN:KB713266.1\tLN:3118\n@SQ\tSN:APMT01226703.1\tLN:3118\n@SQ\tSN:KB713441.1\tLN:3118\n@SQ\tSN:APMT01226835.1\tLN:3118\n@SQ\tSN:KB713454.1\tLN:3117\n@SQ\tSN:APMT01226942.1\tLN:3117\n@SQ\tSN:KB713496.1\tLN:3117\n@SQ\tSN:APMT01227156.1\tLN:3117\n@SQ\tSN:APMT01227157.1\tLN:3117\n@SQ\tSN:APMT01226973.1\tLN:3116\n@SQ\tSN:APMT01226717.1\tLN:3115\n@SQ\tSN:KB713504.1\tLN:3115\n@SQ\tSN:KB713512.1\tLN:3115\n@SQ\tSN:KB713421.1\tLN:3114\n@SQ\tSN:KB713429.1\tLN:3114\n@SQ\tSN:KB713431.1\tLN:3114\n@SQ\tSN:KB713436.1\tLN:3114\n@SQ\tSN:APMT01227181.1\tLN:3114\n@SQ\tSN:KB713251.1\tLN:3113\n@SQ\tSN:KB713434.1\tLN:3113\n@SQ\tSN:APMT01226879.1\tLN:3113\n@SQ\tSN:APMT01226933.1\tLN:3113\n@SQ\tSN:APMT01227186.1\tLN:3113\n@SQ\tSN:KB713455.1\tLN:3112\n@SQ\tSN:APMT01226956.1\tLN:3112\n@SQ\tSN:APMT01227194.1\tLN:3112\n@SQ\tSN:APMT01227195.1\tLN:3112\n@SQ\tSN:APMT01227200.1\tLN:3112\n@SQ\tSN:APMT01227202.1\tLN:3112\n@SQ\tSN:KB714438.1\tLN:3112\n@SQ\tSN:KB713462.1\tLN:3111\n@SQ\tSN:KB713534.1\tLN:3111\n@SQ\tSN:APMT01227207.1\tLN:3111\n@SQ\tSN:APMT01226860.1\tLN:3110\n@SQ\tSN:KB712337.1\tLN:3109\n@SQ\tSN:KB713396.1\tLN:3109\n@SQ\tSN:APMT01227208.1\tLN:3109\n@SQ\tSN:KB713346.1\tLN:3108\n@SQ\tSN:KB713469.1\tLN:3108\n@SQ\tSN:APMT01227209.1\tLN:3108\n@SQ\tSN:APMT01227222.1\tLN:3108\n@SQ\tSN:APMT01227223.1\tLN:3108\n@SQ\tSN:KB713407.1\tLN:3107\n@SQ\tSN:APMT01226928.1\tLN:3107\n@SQ\tSN:APMT01227224.1\tLN:3107\n@SQ\tSN:APMT01225707.1\tLN:3106\n@SQ\tSN:KB713073.1\tLN:3106\n@SQ\tSN:APMT01227216.1\tLN:3106\n@SQ\tSN:APMT01227227.1\tLN:3106\n@SQ\tSN:APMT01227230.1\tLN:3106\n@SQ\tSN:APMT01227231.1\tLN:3106\n@SQ\tSN:APMT01227232.1\tLN:3106\n@SQ\tSN:APMT01227233.1\tLN:3106\n@SQ\tSN:APMT01227234.1\tLN:3106\n@SQ\tSN:KB713424.1\tLN:3105\n@SQ\tSN:APMT01227235.1\tLN:3105\n@SQ\tSN:APMT01227240.1\tLN:3105\n@SQ\tSN:KB713580.1\tLN:3105\n@SQ\tSN:KB713438.1\tLN:3104\n@SQ\tSN:APMT01226911.1\tLN:3104\n@SQ\tSN:KB713522.1\tLN:3104\n@SQ\tSN:APMT01227244.1\tLN:3104\n@SQ\tSN:APMT01227333.1\tLN:3104\n@SQ\tSN:APMT01227723.1\tLN:3104\n@SQ\tSN:APMT01226946.1\tLN:3103\n@SQ\tSN:APMT01227009.1\tLN:3103\n@SQ\tSN:KB713525.1\tLN:3103\n@SQ\tSN:APMT01227250.1\tLN:3103\n@SQ\tSN:KB713165.1\tLN:3102\n@SQ\tSN:KB713487.1\tLN:3102\n@SQ\tSN:APMT01227256.1\tLN:3102\n@SQ\tSN:APMT01227259.1\tLN:3102\n@SQ\tSN:APMT01227264.1\tLN:3102\n@SQ\tSN:KB713275.1\tLN:3101\n@SQ\tSN:KB713315.1\tLN:3101\n@SQ\tSN:APMT01227268.1\tLN:3101\n@SQ\tSN:APMT01227271.1\tLN:3101\n@SQ\tSN:APMT01227272.1\tLN:3101\n@SQ\tSN:KB713199.1\tLN:3100\n@SQ\tSN:APMT01226980.1\tLN:3100\n@SQ\tSN:KB713509.1\tLN:3100\n@SQ\tSN:KB713511.1\tLN:3100\n@SQ\tSN:KB713348.1\tLN:3099\n@SQ\tSN:KB713443.1\tLN:3099\n@SQ\tSN:APMT01226995.1\tLN:3099\n@SQ\tSN:APMT01227288.1\tLN:3099\n@SQ\tSN:APMT01227291.1\tLN:3099\n@SQ\tSN:APMT01227292.1\tLN:3099\n@SQ\tSN:KB713750.1\tLN:3099\n@SQ\tSN:APMT01226445.1\tLN:3097\n@SQ\tSN:KB713549.1\tLN:3097\n@SQ\tSN:KB713355.1\tLN:3096\n@SQ\tSN:APMT01227169.1\tLN:3096\n@SQ\tSN:APMT01227312.1\tLN:3096\n@SQ\tSN:KB713229.1\tLN:3095\n@SQ\tSN:KB713410.1\tLN:3095\n@SQ\tSN:KB713463.1\tLN:3095\n@SQ\tSN:APMT01227324.1\tLN:3095\n@SQ\tSN:KB713471.1\tLN:3094\n@SQ\tSN:APMT01227131.1\tLN:3094\n@SQ\tSN:APMT01227313.1\tLN:3094\n@SQ\tSN:APMT01227332.1\tLN:3094\n@SQ\tSN:KB713474.1\tLN:3093\n@SQ\tSN:KB713510.1\tLN:3093\n@SQ\tSN:KB713548.1\tLN:3093\n@SQ\tSN:KB713574.1\tLN:3093\n@SQ\tSN:KB713649.1\tLN:3093\n@SQ\tSN:KB713589.1\tLN:3092\n@SQ\tSN:APMT01227339.1\tLN:3092\n@SQ\tSN:APMT01227344.1\tLN:3092\n@SQ\tSN:KB713479.1\tLN:3091\n@SQ\tSN:APMT01227285.1\tLN:3091\n@SQ\tSN:APMT01227305.1\tLN:3090\n@SQ\tSN:APMT01226154.1\tLN:3089\n@SQ\tSN:KB713310.1\tLN:3089\n@SQ\tSN:KB713439.1\tLN:3089\n@SQ\tSN:APMT01227359.1\tLN:3088\n@SQ\tSN:APMT01227360.1\tLN:3088\n@SQ\tSN:APMT01227374.1\tLN:3088\n@SQ\tSN:KB713230.1\tLN:3087\n@SQ\tSN:KB713435.1\tLN:3087\n@SQ\tSN:KB713448.1\tLN:3087\n@SQ\tSN:KB713503.1\tLN:3087\n@SQ\tSN:APMT01227014.1\tLN:3087\n@SQ\tSN:APMT01227369.1\tLN:3087\n@SQ\tSN:APMT01227377.1\tLN:3087\n@SQ\tSN:KB713660.1\tLN:3087\n@SQ\tSN:KB713543.1\tLN:3086\n@SQ\tSN:KB713630.1\tLN:3086\n@SQ\tSN:KB713411.1\tLN:3085\n@SQ\tSN:KB713495.1\tLN:3085\n@SQ\tSN:KB713546.1\tLN:3085\n@SQ\tSN:APMT01225711.1\tLN:3084\n@SQ\tSN:KB713530.1\tLN:3084\n@SQ\tSN:KB713562.1\tLN:3084\n@SQ\tSN:APMT01227387.1\tLN:3084\n@SQ\tSN:APMT01227390.1\tLN:3084\n@SQ\tSN:APMT01227397.1\tLN:3084\n@SQ\tSN:APMT01227398.1\tLN:3084\n@SQ\tSN:KB713255.1\tLN:3083\n@SQ\tSN:KB713258.1\tLN:3083\n@SQ\tSN:APMT01227403.1\tLN:3083\n@SQ\tSN:APMT01227406.1\tLN:3083\n@SQ\tSN:KB713368.1\tLN:3082\n@SQ\tSN:KB713397.1\tLN:3082\n@SQ\tSN:APMT01227178.1\tLN:3082\n@SQ\tSN:APMT01227351.1\tLN:3082\n@SQ\tSN:APMT01227408.1\tLN:3082\n@SQ\tSN:APMT01227409.1\tLN:3082\n@SQ\tSN:KB713222.1\tLN:3081\n@SQ\tSN:KB713457.1\tLN:3081\n@SQ\tSN:APMT01227411.1\tLN:3081\n@SQ\tSN:KB713272.1\tLN:3080\n@SQ\tSN:KB713560.1\tLN:3080\n@SQ\tSN:APMT01227424.1\tLN:3080\n@SQ\tSN:KB713730.1\tLN:3080\n@SQ\tSN:APMT01228482.1\tLN:3080\n@SQ\tSN:APMT01226493.1\tLN:3079\n@SQ\tSN:APMT01226927.1\tLN:3079\n@SQ\tSN:KB713516.1\tLN:3079\n@SQ\tSN:APMT01227427.1\tLN:3079\n@SQ\tSN:KB712886.1\tLN:3078\n@SQ\tSN:KB712915.1\tLN:3078\n@SQ\tSN:APMT01227105.1\tLN:3078\n@SQ\tSN:APMT01227430.1\tLN:3078\n@SQ\tSN:APMT01227433.1\tLN:3078\n@SQ\tSN:APMT01227435.1\tLN:3078\n@SQ\tSN:APMT01227467.1\tLN:3078\n@SQ\tSN:KB713671.1\tLN:3078\n@SQ\tSN:APMT01227440.1\tLN:3077\n@SQ\tSN:APMT01227441.1\tLN:3077\n@SQ\tSN:KB714009.1\tLN:3077\n@SQ\tSN:APMT01227442.1\tLN:3076\n@SQ\tSN:KB714111.1\tLN:3076\n@SQ\tSN:KB714192.1\tLN:3076\n@SQ\tSN:APMT01227452.1\tLN:3075\n@SQ\tSN:APMT01227461.1\tLN:3075\n@SQ\tSN:KB713139.1\tLN:3074\n@SQ\tSN:KB713324.1\tLN:3074\n@SQ\tSN:APMT01227449.1\tLN:3074\n@SQ\tSN:APMT01227455.1\tLN:3074\n@SQ\tSN:KB713340.1\tLN:3073\n@SQ\tSN:APMT01227465.1\tLN:3073\n@SQ\tSN:APMT01227466.1\tLN:3073\n@SQ\tSN:KB713533.1\tLN:3072\n@SQ\tSN:KB713576.1\tLN:3072\n@SQ\tSN:KB713629.1\tLN:3072\n@SQ\tSN:APMT01227102.1\tLN:3071\n@SQ\tSN:KB713614.1\tLN:3071\n@SQ\tSN:APMT01227482.1\tLN:3071\n@SQ\tSN:KB713554.1\tLN:3070\n@SQ\tSN:KB713587.1\tLN:3070\n@SQ\tSN:KB713618.1\tLN:3070\n@SQ\tSN:APMT01227492.1\tLN:3070\n@SQ\tSN:APMT01227450.1\tLN:3069\n@SQ\tSN:APMT01227497.1\tLN:3069\n@SQ\tSN:APMT01227502.1\tLN:3069\n@SQ\tSN:KB713377.1\tLN:3068\n@SQ\tSN:KB713664.1\tLN:3068\n@SQ\tSN:APMT01227504.1\tLN:3068\n@SQ\tSN:KB713480.1\tLN:3067\n@SQ\tSN:KB713519.1\tLN:3067\n@SQ\tSN:APMT01227506.1\tLN:3067\n@SQ\tSN:KB713501.1\tLN:3066\n@SQ\tSN:APMT01227517.1\tLN:3066\n@SQ\tSN:APMT01227520.1\tLN:3066\n@SQ\tSN:KB713794.1\tLN:3066\n@SQ\tSN:KB713639.1\tLN:3065\n@SQ\tSN:KB712771.1\tLN:3064\n@SQ\tSN:KB713506.1\tLN:3064\n@SQ\tSN:KB713632.1\tLN:3064\n@SQ\tSN:KB713367.1\tLN:3063\n@SQ\tSN:APMT01227128.1\tLN:3063\n@SQ\tSN:KB713586.1\tLN:3063\n@SQ\tSN:APMT01227531.1\tLN:3063\n@SQ\tSN:KB713739.1\tLN:3063\n@SQ\tSN:KB713542.1\tLN:3062\n@SQ\tSN:KB713115.1\tLN:3061\n@SQ\tSN:KB713200.1\tLN:3061\n@SQ\tSN:APMT01227540.1\tLN:3061\n@SQ\tSN:APMT01227548.1\tLN:3061\n@SQ\tSN:KB713283.1\tLN:3060\n@SQ\tSN:APMT01226430.1\tLN:3060\n@SQ\tSN:KB713360.1\tLN:3060\n@SQ\tSN:KB713547.1\tLN:3060\n@SQ\tSN:KB713617.1\tLN:3060\n@SQ\tSN:APMT01227549.1\tLN:3059\n@SQ\tSN:APMT01227553.1\tLN:3059\n@SQ\tSN:APMT01227911.1\tLN:3059\n@SQ\tSN:KB713669.1\tLN:3058\n@SQ\tSN:APMT01227555.1\tLN:3058\n@SQ\tSN:APMT01227558.1\tLN:3058\n@SQ\tSN:APMT01227561.1\tLN:3058\n@SQ\tSN:KB713341.1\tLN:3057\n@SQ\tSN:KB713541.1\tLN:3057\n@SQ\tSN:APMT01227505.1\tLN:3057\n@SQ\tSN:APMT01227556.1\tLN:3057\n@SQ\tSN:APMT01227258.1\tLN:3056\n@SQ\tSN:APMT01227302.1\tLN:3056\n@SQ\tSN:KB713650.1\tLN:3056\n@SQ\tSN:APMT01227569.1\tLN:3056\n@SQ\tSN:APMT01227570.1\tLN:3056\n@SQ\tSN:APMT01227573.1\tLN:3056\n@SQ\tSN:KB713401.1\tLN:3055\n@SQ\tSN:APMT01227241.1\tLN:3055\n@SQ\tSN:KB713609.1\tLN:3055\n@SQ\tSN:APMT01227574.1\tLN:3055\n@SQ\tSN:APMT01226929.1\tLN:3054\n@SQ\tSN:KB713556.1\tLN:3054\n@SQ\tSN:APMT01227201.1\tLN:3054\n@SQ\tSN:APMT01227575.1\tLN:3054\n@SQ\tSN:KB713500.1\tLN:3053\n@SQ\tSN:KB713507.1\tLN:3053\n@SQ\tSN:APMT01227585.1\tLN:3053\n@SQ\tSN:APMT01227586.1\tLN:3053\n@SQ\tSN:KB713604.1\tLN:3052\n@SQ\tSN:APMT01227593.1\tLN:3052\n@SQ\tSN:APMT01227594.1\tLN:3052\n@SQ\tSN:KB711503.1\tLN:3051\n@SQ\tSN:KB712684.1\tLN:3051\n@SQ\tSN:KB713107.1\tLN:3051\n@SQ\tSN:KB713380.1\tLN:3051\n@SQ\tSN:KB713633.1\tLN:3051\n@SQ\tSN:APMT01227507.1\tLN:3051\n@SQ\tSN:APMT01227554.1\tLN:3051\n@SQ\tSN:APMT01227595.1\tLN:3051\n@SQ\tSN:APMT01227596.1\tLN:3051\n@SQ\tSN:KB713513.1\tLN:3050\n@SQ\tSN:APMT01227257.1\tLN:3050\n@SQ\tSN:KB713674.1\tLN:3050\n@SQ\tSN:APMT01227602.1\tLN:3050\n@SQ\tSN:APMT01227603.1\tLN:3050\n@SQ\tSN:KB713703.1\tLN:3050\n@SQ\tSN:KB714156.1\tLN:3050\n@SQ\tSN:KB713221.1\tLN:3049\n@SQ\tSN:APMT01226175.1\tLN:3049\n@SQ\tSN:KB713527.1\tLN:3049\n@SQ\tSN:KB713296.1\tLN:3048\n@SQ\tSN:APMT01227613.1\tLN:3048\n@SQ\tSN:APMT01227616.1\tLN:3048\n@SQ\tSN:APMT01227623.1\tLN:3048\n@SQ\tSN:KB713302.1\tLN:3047\n@SQ\tSN:KB713314.1\tLN:3047\n@SQ\tSN:APMT01226820.1\tLN:3047\n@SQ\tSN:KB713578.1\tLN:3047\n@SQ\tSN:APMT01227407.1\tLN:3047\n@SQ\tSN:APMT01227626.1\tLN:3047\n@SQ\tSN:KB713585.1\tLN:3045\n@SQ\tSN:APMT01227349.1\tLN:3045\n@SQ\tSN:APMT01227635.1\tLN:3045\n@SQ\tSN:APMT01227636.1\tLN:3045\n@SQ\tSN:APMT01227640.1\tLN:3045\n@SQ\tSN:KB713440.1\tLN:3044\n@SQ\tSN:APMT01227421.1\tLN:3044\n@SQ\tSN:KB713663.1\tLN:3044\n@SQ\tSN:APMT01227644.1\tLN:3044\n@SQ\tSN:KB713821.1\tLN:3044\n@SQ\tSN:KB713420.1\tLN:3042\n@SQ\tSN:KB713588.1\tLN:3042\n@SQ\tSN:KB713595.1\tLN:3042\n@SQ\tSN:APMT01227655.1\tLN:3042\n@SQ\tSN:APMT01227664.1\tLN:3042\n@SQ\tSN:KB713342.1\tLN:3041\n@SQ\tSN:KB713400.1\tLN:3041\n@SQ\tSN:APMT01227550.1\tLN:3041\n@SQ\tSN:KB713444.1\tLN:3040\n@SQ\tSN:KB713685.1\tLN:3040\n@SQ\tSN:APMT01227645.1\tLN:3040\n@SQ\tSN:KB711329.1\tLN:3039\n@SQ\tSN:KB713526.1\tLN:3039\n@SQ\tSN:APMT01227681.1\tLN:3039\n@SQ\tSN:KB713207.1\tLN:3038\n@SQ\tSN:KB713523.1\tLN:3038\n@SQ\tSN:APMT01227301.1\tLN:3038\n@SQ\tSN:APMT01227677.1\tLN:3038\n@SQ\tSN:APMT01227678.1\tLN:3038\n@SQ\tSN:APMT01227684.1\tLN:3038\n@SQ\tSN:KB713729.1\tLN:3038\n@SQ\tSN:KB713389.1\tLN:3037\n@SQ\tSN:KB713442.1\tLN:3037\n@SQ\tSN:KB713555.1\tLN:3037\n@SQ\tSN:APMT01227191.1\tLN:3037\n@SQ\tSN:APMT01227629.1\tLN:3037\n@SQ\tSN:APMT01227693.1\tLN:3037\n@SQ\tSN:KB713050.1\tLN:3036\n@SQ\tSN:APMT01227451.1\tLN:3036\n@SQ\tSN:APMT01227691.1\tLN:3036\n@SQ\tSN:APMT01227694.1\tLN:3036\n@SQ\tSN:APMT01227696.1\tLN:3036\n@SQ\tSN:KB713228.1\tLN:3035\n@SQ\tSN:APMT01227334.1\tLN:3035\n@SQ\tSN:APMT01227699.1\tLN:3035\n@SQ\tSN:KB713695.1\tLN:3034\n@SQ\tSN:KB713246.1\tLN:3032\n@SQ\tSN:KB713613.1\tLN:3032\n@SQ\tSN:APMT01227532.1\tLN:3032\n@SQ\tSN:APMT01227718.1\tLN:3032\n@SQ\tSN:APMT01227710.1\tLN:3031\n@SQ\tSN:KB713796.1\tLN:3031\n@SQ\tSN:KB714023.1\tLN:3031\n@SQ\tSN:KB713468.1\tLN:3030\n@SQ\tSN:KB713515.1\tLN:3030\n@SQ\tSN:APMT01227729.1\tLN:3030\n@SQ\tSN:APMT01227732.1\tLN:3030\n@SQ\tSN:KB713385.1\tLN:3029\n@SQ\tSN:APMT01226836.1\tLN:3029\n@SQ\tSN:KB713552.1\tLN:3029\n@SQ\tSN:KB713634.1\tLN:3029\n@SQ\tSN:APMT01227733.1\tLN:3029\n@SQ\tSN:KB712825.1\tLN:3028\n@SQ\tSN:KB713123.1\tLN:3028\n@SQ\tSN:APMT01227746.1\tLN:3028\n@SQ\tSN:APMT01227758.1\tLN:3028\n@SQ\tSN:APMT01228820.1\tLN:3028\n@SQ\tSN:KB713194.1\tLN:3027\n@SQ\tSN:KB713351.1\tLN:3027\n@SQ\tSN:KB713393.1\tLN:3027\n@SQ\tSN:APMT01227753.1\tLN:3027\n@SQ\tSN:APMT01227754.1\tLN:3027\n@SQ\tSN:KB713508.1\tLN:3026\n@SQ\tSN:KB713565.1\tLN:3026\n@SQ\tSN:KB713648.1\tLN:3026\n@SQ\tSN:APMT01227755.1\tLN:3026\n@SQ\tSN:KB713903.1\tLN:3026\n@SQ\tSN:KB713948.1\tLN:3026\n@SQ\tSN:APMT01227391.1\tLN:3025\n@SQ\tSN:KB713641.1\tLN:3025\n@SQ\tSN:KB713656.1\tLN:3025\n@SQ\tSN:APMT01227771.1\tLN:3025\n@SQ\tSN:APMT01227772.1\tLN:3025\n@SQ\tSN:APMT01227773.1\tLN:3025\n@SQ\tSN:KB713349.1\tLN:3024\n@SQ\tSN:APMT01227392.1\tLN:3024\n@SQ\tSN:KB713643.1\tLN:3024\n@SQ\tSN:APMT01227543.1\tLN:3024\n@SQ\tSN:APMT01227777.1\tLN:3024\n@SQ\tSN:KB713564.1\tLN:3023\n@SQ\tSN:KB713640.1\tLN:3023\n@SQ\tSN:KB713759.1\tLN:3023\n@SQ\tSN:KB713484.1\tLN:3022\n@SQ\tSN:APMT01227481.1\tLN:3022\n@SQ\tSN:KB713303.1\tLN:3021\n@SQ\tSN:KB713553.1\tLN:3021\n@SQ\tSN:KB713570.1\tLN:3021\n@SQ\tSN:APMT01227766.1\tLN:3021\n@SQ\tSN:APMT01226842.1\tLN:3020\n@SQ\tSN:KB713502.1\tLN:3020\n@SQ\tSN:KB713597.1\tLN:3020\n@SQ\tSN:KB713686.1\tLN:3020\n@SQ\tSN:APMT01227783.1\tLN:3020\n@SQ\tSN:KB713427.1\tLN:3019\n@SQ\tSN:APMT01227790.1\tLN:3019\n@SQ\tSN:KB713584.1\tLN:3018\n@SQ\tSN:KB713642.1\tLN:3018\n@SQ\tSN:APMT01227434.1\tLN:3018\n@SQ\tSN:APMT01227793.1\tLN:3018\n@SQ\tSN:APMT01227796.1\tLN:3018\n@SQ\tSN:APMT01227797.1\tLN:3018\n@SQ\tSN:APMT01227436.1\tLN:3017\n@SQ\tSN:APMT01227792.1\tLN:3017\n@SQ\tSN:APMT01227812.1\tLN:3017\n@SQ\tSN:APMT01227815.1\tLN:3016\n@SQ\tSN:KB713432.1\tLN:3015\n@SQ\tSN:KB713481.1\tLN:3015\n@SQ\tSN:APMT01227791.1\tLN:3015\n@SQ\tSN:APMT01227806.1\tLN:3015\n@SQ\tSN:APMT01227820.1\tLN:3015\n@SQ\tSN:APMT01227821.1\tLN:3015\n@SQ\tSN:APMT01227824.1\tLN:3015\n@SQ\tSN:APMT01227825.1\tLN:3015\n@SQ\tSN:KB713637.1\tLN:3014\n@SQ\tSN:APMT01227827.1\tLN:3014\n@SQ\tSN:KB713784.1\tLN:3014\n@SQ\tSN:KB713577.1\tLN:3013\n@SQ\tSN:APMT01227672.1\tLN:3013\n@SQ\tSN:KB713724.1\tLN:3013\n@SQ\tSN:APMT01227828.1\tLN:3013\n@SQ\tSN:KB713798.1\tLN:3013\n@SQ\tSN:APMT01227835.1\tLN:3012\n@SQ\tSN:APMT01227478.1\tLN:3011\n@SQ\tSN:APMT01227533.1\tLN:3011\n@SQ\tSN:KB713478.1\tLN:3010\n@SQ\tSN:KB713651.1\tLN:3010\n@SQ\tSN:APMT01227562.1\tLN:3010\n@SQ\tSN:APMT01227703.1\tLN:3010\n@SQ\tSN:APMT01227849.1\tLN:3010\n@SQ\tSN:APMT01227090.1\tLN:3009\n@SQ\tSN:APMT01227714.1\tLN:3009\n@SQ\tSN:KB713074.1\tLN:3008\n@SQ\tSN:APMT01227571.1\tLN:3008\n@SQ\tSN:APMT01227643.1\tLN:3008\n@SQ\tSN:APMT01227717.1\tLN:3008\n@SQ\tSN:APMT01227865.1\tLN:3008\n@SQ\tSN:APMT01227265.1\tLN:3007\n@SQ\tSN:KB713655.1\tLN:3006\n@SQ\tSN:KB713682.1\tLN:3006\n@SQ\tSN:KB713694.1\tLN:3006\n@SQ\tSN:KB711204.1\tLN:3005\n@SQ\tSN:KB713300.1\tLN:3005\n@SQ\tSN:KB713723.1\tLN:3005\n@SQ\tSN:APMT01227877.1\tLN:3005\n@SQ\tSN:APMT01227878.1\tLN:3005\n@SQ\tSN:KB714405.1\tLN:3005\n@SQ\tSN:APMT01227882.1\tLN:3004\n@SQ\tSN:APMT01227883.1\tLN:3004\n@SQ\tSN:APMT01227884.1\tLN:3004\n@SQ\tSN:KB713493.1\tLN:3003\n@SQ\tSN:APMT01228097.1\tLN:3003\n@SQ\tSN:KB713683.1\tLN:3002\n@SQ\tSN:APMT01227879.1\tLN:3002\n@SQ\tSN:KB713528.1\tLN:3001\n@SQ\tSN:KB713612.1\tLN:3001\n@SQ\tSN:APMT01227892.1\tLN:3001\n@SQ\tSN:KB713792.1\tLN:3001\n@SQ\tSN:KB713235.1\tLN:3000\n@SQ\tSN:APMT01227895.1\tLN:3000\n@SQ\tSN:KB713635.1\tLN:2999\n@SQ\tSN:KB713670.1\tLN:2999\n@SQ\tSN:APMT01227900.1\tLN:2999\n@SQ\tSN:APMT01227906.1\tLN:2999\n@SQ\tSN:KB713317.1\tLN:2998\n@SQ\tSN:KB713498.1\tLN:2998\n@SQ\tSN:APMT01227557.1\tLN:2998\n@SQ\tSN:APMT01227912.1\tLN:2998\n@SQ\tSN:KB713291.1\tLN:2997\n@SQ\tSN:KB713747.1\tLN:2997\n@SQ\tSN:APMT01227889.1\tLN:2997\n@SQ\tSN:APMT01227918.1\tLN:2997\n@SQ\tSN:APMT01227919.1\tLN:2997\n@SQ\tSN:APMT01227921.1\tLN:2997\n@SQ\tSN:KB713579.1\tLN:2996\n@SQ\tSN:KB713691.1\tLN:2996\n@SQ\tSN:APMT01227920.1\tLN:2996\n@SQ\tSN:APMT01227930.1\tLN:2996\n@SQ\tSN:APMT01227932.1\tLN:2996\n@SQ\tSN:APMT01227582.1\tLN:2995\n@SQ\tSN:APMT01227937.1\tLN:2995\n@SQ\tSN:APMT01227942.1\tLN:2995\n@SQ\tSN:KB712451.1\tLN:2994\n@SQ\tSN:KB713603.1\tLN:2994\n@SQ\tSN:KB713610.1\tLN:2994\n@SQ\tSN:KB713696.1\tLN:2994\n@SQ\tSN:KB713715.1\tLN:2994\n@SQ\tSN:APMT01227943.1\tLN:2994\n@SQ\tSN:APMT01227944.1\tLN:2994\n@SQ\tSN:APMT01227945.1\tLN:2994\n@SQ\tSN:KB713601.1\tLN:2993\n@SQ\tSN:APMT01227331.1\tLN:2993\n@SQ\tSN:APMT01227917.1\tLN:2993\n@SQ\tSN:KB713540.1\tLN:2992\n@SQ\tSN:KB713622.1\tLN:2992\n@SQ\tSN:APMT01227963.1\tLN:2992\n@SQ\tSN:KB713408.1\tLN:2991\n@SQ\tSN:APMT01227597.1\tLN:2991\n@SQ\tSN:KB713704.1\tLN:2991\n@SQ\tSN:APMT01227765.1\tLN:2991\n@SQ\tSN:APMT01227965.1\tLN:2991\n@SQ\tSN:APMT01227969.1\tLN:2991\n@SQ\tSN:KB713426.1\tLN:2990\n@SQ\tSN:KB713673.1\tLN:2990\n@SQ\tSN:APMT01227601.1\tLN:2990\n@SQ\tSN:APMT01227610.1\tLN:2990\n@SQ\tSN:APMT01227669.1\tLN:2990\n@SQ\tSN:APMT01227728.1\tLN:2990\n@SQ\tSN:APMT01227971.1\tLN:2990\n@SQ\tSN:KB713428.1\tLN:2989\n@SQ\tSN:KB713718.1\tLN:2989\n@SQ\tSN:KB713733.1\tLN:2989\n@SQ\tSN:APMT01227972.1\tLN:2989\n@SQ\tSN:APMT01227975.1\tLN:2989\n@SQ\tSN:KB713366.1\tLN:2988\n@SQ\tSN:APMT01227687.1\tLN:2988\n@SQ\tSN:KB713775.1\tLN:2988\n@SQ\tSN:APMT01227976.1\tLN:2988\n@SQ\tSN:KB713567.1\tLN:2987\n@SQ\tSN:KB713667.1\tLN:2987\n@SQ\tSN:APMT01227695.1\tLN:2987\n@SQ\tSN:KB713899.1\tLN:2987\n@SQ\tSN:APMT01227979.1\tLN:2986\n@SQ\tSN:APMT01227378.1\tLN:2985\n@SQ\tSN:APMT01227776.1\tLN:2985\n@SQ\tSN:APMT01227982.1\tLN:2985\n@SQ\tSN:APMT01227990.1\tLN:2985\n@SQ\tSN:KB713878.1\tLN:2985\n@SQ\tSN:KB713627.1\tLN:2984\n@SQ\tSN:KB713719.1\tLN:2984\n@SQ\tSN:APMT01227991.1\tLN:2984\n@SQ\tSN:APMT01227993.1\tLN:2984\n@SQ\tSN:APMT01226595.1\tLN:2983\n@SQ\tSN:KB713594.1\tLN:2983\n@SQ\tSN:KB713558.1\tLN:2982\n@SQ\tSN:APMT01227545.1\tLN:2982\n@SQ\tSN:KB713697.1\tLN:2982\n@SQ\tSN:KB713568.1\tLN:2981\n@SQ\tSN:KB713599.1\tLN:2981\n@SQ\tSN:APMT01228002.1\tLN:2981\n@SQ\tSN:KB713623.1\tLN:2980\n@SQ\tSN:APMT01228006.1\tLN:2980\n@SQ\tSN:APMT01228007.1\tLN:2980\n@SQ\tSN:APMT01228008.1\tLN:2980\n@SQ\tSN:APMT01227688.1\tLN:2979\n@SQ\tSN:KB713836.1\tLN:2978\n@SQ\tSN:APMT01227968.1\tLN:2977\n@SQ\tSN:APMT01228016.1\tLN:2977\n@SQ\tSN:APMT01228017.1\tLN:2977\n@SQ\tSN:APMT01228019.1\tLN:2977\n@SQ\tSN:KB713489.1\tLN:2976\n@SQ\tSN:APMT01228018.1\tLN:2976\n@SQ\tSN:KB713761.1\tLN:2975\n@SQ\tSN:APMT01228030.1\tLN:2975\n@SQ\tSN:APMT01228039.1\tLN:2974\n@SQ\tSN:APMT01228043.1\tLN:2974\n@SQ\tSN:APMT01228287.1\tLN:2974\n@SQ\tSN:KB713914.1\tLN:2974\n@SQ\tSN:KB713996.1\tLN:2974\n@SQ\tSN:KB713845.1\tLN:2973\n@SQ\tSN:KB713734.1\tLN:2972\n@SQ\tSN:KB713738.1\tLN:2972\n@SQ\tSN:APMT01228071.1\tLN:2971\n@SQ\tSN:APMT01228072.1\tLN:2971\n@SQ\tSN:KB713849.1\tLN:2971\n@SQ\tSN:KB713907.1\tLN:2971\n@SQ\tSN:KB713399.1\tLN:2970\n@SQ\tSN:KB713571.1\tLN:2970\n@SQ\tSN:KB713658.1\tLN:2970\n@SQ\tSN:APMT01227782.1\tLN:2970\n@SQ\tSN:APMT01228070.1\tLN:2970\n@SQ\tSN:APMT01228073.1\tLN:2970\n@SQ\tSN:APMT01228083.1\tLN:2970\n@SQ\tSN:KB713892.1\tLN:2970\n@SQ\tSN:APMT01228074.1\tLN:2969\n@SQ\tSN:APMT01228160.1\tLN:2969\n@SQ\tSN:KB714101.1\tLN:2969\n@SQ\tSN:KB713662.1\tLN:2968\n@SQ\tSN:APMT01227800.1\tLN:2968\n@SQ\tSN:APMT01228084.1\tLN:2968\n@SQ\tSN:APMT01228088.1\tLN:2968\n@SQ\tSN:KB713706.1\tLN:2967\n@SQ\tSN:KB713799.1\tLN:2967\n@SQ\tSN:APMT01228087.1\tLN:2967\n@SQ\tSN:APMT01228093.1\tLN:2967\n@SQ\tSN:APMT01228094.1\tLN:2967\n@SQ\tSN:APMT01228095.1\tLN:2967\n@SQ\tSN:APMT01228096.1\tLN:2967\n@SQ\tSN:APMT01227456.1\tLN:2966\n@SQ\tSN:KB713710.1\tLN:2966\n@SQ\tSN:KB713755.1\tLN:2966\n@SQ\tSN:APMT01228100.1\tLN:2966\n@SQ\tSN:APMT01227253.1\tLN:2965\n@SQ\tSN:KB713602.1\tLN:2965\n@SQ\tSN:APMT01228101.1\tLN:2965\n@SQ\tSN:APMT01228106.1\tLN:2965\n@SQ\tSN:APMT01228107.1\tLN:2965\n@SQ\tSN:KB713891.1\tLN:2965\n@SQ\tSN:KB713982.1\tLN:2965\n@SQ\tSN:KB713464.1\tLN:2964\n@SQ\tSN:APMT01227572.1\tLN:2964\n@SQ\tSN:APMT01228108.1\tLN:2964\n@SQ\tSN:APMT01228113.1\tLN:2964\n@SQ\tSN:KB713309.1\tLN:2963\n@SQ\tSN:APMT01227711.1\tLN:2963\n@SQ\tSN:KB713757.1\tLN:2963\n@SQ\tSN:KB713762.1\tLN:2963\n@SQ\tSN:KB713647.1\tLN:2962\n@SQ\tSN:KB713681.1\tLN:2962\n@SQ\tSN:APMT01228116.1\tLN:2962\n@SQ\tSN:APMT01228123.1\tLN:2962\n@SQ\tSN:KB713472.1\tLN:2961\n@SQ\tSN:KB713776.1\tLN:2961\n@SQ\tSN:KB713781.1\tLN:2961\n@SQ\tSN:APMT01227887.1\tLN:2961\n@SQ\tSN:APMT01228128.1\tLN:2961\n@SQ\tSN:KB712804.1\tLN:2960\n@SQ\tSN:APMT01227516.1\tLN:2960\n@SQ\tSN:APMT01227801.1\tLN:2960\n@SQ\tSN:APMT01227860.1\tLN:2960\n@SQ\tSN:APMT01228117.1\tLN:2960\n@SQ\tSN:APMT01228137.1\tLN:2960\n@SQ\tSN:KB713521.1\tLN:2959\n@SQ\tSN:KB713668.1\tLN:2959\n@SQ\tSN:APMT01227836.1\tLN:2959\n@SQ\tSN:KB713815.1\tLN:2959\n@SQ\tSN:APMT01228144.1\tLN:2959\n@SQ\tSN:KB713425.1\tLN:2958\n@SQ\tSN:APMT01228145.1\tLN:2958\n@SQ\tSN:APMT01228150.1\tLN:2958\n@SQ\tSN:APMT01228151.1\tLN:2958\n@SQ\tSN:KB713684.1\tLN:2957\n@SQ\tSN:APMT01228173.1\tLN:2957\n@SQ\tSN:APMT01227809.1\tLN:2956\n@SQ\tSN:APMT01228153.1\tLN:2956\n@SQ\tSN:KB713876.1\tLN:2956\n@SQ\tSN:KB713713.1\tLN:2955\n@SQ\tSN:KB713736.1\tLN:2955\n@SQ\tSN:APMT01227826.1\tLN:2955\n@SQ\tSN:APMT01228156.1\tLN:2955\n@SQ\tSN:APMT01228157.1\tLN:2955\n@SQ\tSN:APMT01228163.1\tLN:2955\n@SQ\tSN:KB713536.1\tLN:2954\n@SQ\tSN:APMT01228165.1\tLN:2954\n@SQ\tSN:APMT01228168.1\tLN:2954\n@SQ\tSN:APMT01226385.1\tLN:2953\n@SQ\tSN:KB713624.1\tLN:2953\n@SQ\tSN:KB713722.1\tLN:2953\n@SQ\tSN:KB713598.1\tLN:2952\n@SQ\tSN:KB713851.1\tLN:2952\n@SQ\tSN:APMT01227632.1\tLN:2951\n@SQ\tSN:KB713716.1\tLN:2951\n@SQ\tSN:APMT01228183.1\tLN:2951\n@SQ\tSN:KB712992.1\tLN:2950\n@SQ\tSN:KB713825.1\tLN:2950\n@SQ\tSN:APMT01228189.1\tLN:2950\n@SQ\tSN:KB711698.1\tLN:2949\n@SQ\tSN:KB713591.1\tLN:2949\n@SQ\tSN:APMT01227503.1\tLN:2949\n@SQ\tSN:APMT01227700.1\tLN:2949\n@SQ\tSN:KB713268.1\tLN:2948\n@SQ\tSN:APMT01228020.1\tLN:2948\n@SQ\tSN:APMT01228191.1\tLN:2948\n@SQ\tSN:APMT01228192.1\tLN:2948\n@SQ\tSN:KB713766.1\tLN:2946\n@SQ\tSN:KB713779.1\tLN:2946\n@SQ\tSN:APMT01228198.1\tLN:2946\n@SQ\tSN:APMT01227462.1\tLN:2945\n@SQ\tSN:APMT01228201.1\tLN:2945\n@SQ\tSN:APMT01227155.1\tLN:2944\n@SQ\tSN:KB713611.1\tLN:2944\n@SQ\tSN:KB713702.1\tLN:2944\n@SQ\tSN:KB713756.1\tLN:2944\n@SQ\tSN:APMT01227871.1\tLN:2944\n@SQ\tSN:KB713787.1\tLN:2944\n@SQ\tSN:APMT01228207.1\tLN:2944\n@SQ\tSN:APMT01228210.1\tLN:2944\n@SQ\tSN:KB712199.1\tLN:2943\n@SQ\tSN:APMT01227888.1\tLN:2943\n@SQ\tSN:APMT01228218.1\tLN:2942\n@SQ\tSN:KB711979.1\tLN:2941\n@SQ\tSN:KB712861.1\tLN:2941\n@SQ\tSN:APMT01228184.1\tLN:2941\n@SQ\tSN:APMT01228221.1\tLN:2941\n@SQ\tSN:APMT01228222.1\tLN:2941\n@SQ\tSN:APMT01228225.1\tLN:2941\n@SQ\tSN:KB713520.1\tLN:2939\n@SQ\tSN:KB713566.1\tLN:2939\n@SQ\tSN:KB713615.1\tLN:2939\n@SQ\tSN:KB713665.1\tLN:2939\n@SQ\tSN:APMT01228233.1\tLN:2939\n@SQ\tSN:APMT01228234.1\tLN:2939\n@SQ\tSN:APMT01228235.1\tLN:2939\n@SQ\tSN:APMT01227931.1\tLN:2938\n@SQ\tSN:APMT01228236.1\tLN:2938\n@SQ\tSN:KB713844.1\tLN:2937\n@SQ\tSN:APMT01228239.1\tLN:2937\n@SQ\tSN:APMT01228241.1\tLN:2936\n@SQ\tSN:KB713636.1\tLN:2935\n@SQ\tSN:KB713644.1\tLN:2935\n@SQ\tSN:KB713693.1\tLN:2935\n@SQ\tSN:KB713712.1\tLN:2934\n@SQ\tSN:KB713743.1\tLN:2934\n@SQ\tSN:APMT01228258.1\tLN:2933\n@SQ\tSN:APMT01228259.1\tLN:2933\n@SQ\tSN:APMT01228260.1\tLN:2933\n@SQ\tSN:APMT01228261.1\tLN:2933\n@SQ\tSN:APMT01228262.1\tLN:2933\n@SQ\tSN:APMT01228837.1\tLN:2933\n@SQ\tSN:APMT01227974.1\tLN:2932\n@SQ\tSN:APMT01228247.1\tLN:2932\n@SQ\tSN:APMT01228753.1\tLN:2932\n@SQ\tSN:KB711022.1\tLN:2931\n@SQ\tSN:APMT01227356.1\tLN:2931\n@SQ\tSN:APMT01227992.1\tLN:2931\n@SQ\tSN:KB713850.1\tLN:2931\n@SQ\tSN:APMT01228269.1\tLN:2931\n@SQ\tSN:APMT01228272.1\tLN:2931\n@SQ\tSN:KB713679.1\tLN:2930\n@SQ\tSN:APMT01228277.1\tLN:2930\n@SQ\tSN:KB713744.1\tLN:2929\n@SQ\tSN:APMT01227970.1\tLN:2929\n@SQ\tSN:APMT01227973.1\tLN:2929\n@SQ\tSN:APMT01228012.1\tLN:2929\n@SQ\tSN:APMT01228204.1\tLN:2929\n@SQ\tSN:APMT01228288.1\tLN:2929\n@SQ\tSN:APMT01228289.1\tLN:2929\n@SQ\tSN:APMT01228290.1\tLN:2929\n@SQ\tSN:KB713535.1\tLN:2928\n@SQ\tSN:APMT01228298.1\tLN:2928\n@SQ\tSN:APMT01228299.1\tLN:2928\n@SQ\tSN:APMT01228300.1\tLN:2928\n@SQ\tSN:KB712036.1\tLN:2926\n@SQ\tSN:KB713732.1\tLN:2926\n@SQ\tSN:KB713811.1\tLN:2926\n@SQ\tSN:APMT01228309.1\tLN:2926\n@SQ\tSN:APMT01228310.1\tLN:2926\n@SQ\tSN:APMT01228311.1\tLN:2926\n@SQ\tSN:APMT01228172.1\tLN:2925\n@SQ\tSN:KB713904.1\tLN:2925\n@SQ\tSN:APMT01228315.1\tLN:2925\n@SQ\tSN:APMT01228317.1\tLN:2925\n@SQ\tSN:KB713485.1\tLN:2924\n@SQ\tSN:KB713871.1\tLN:2924\n@SQ\tSN:KB713698.1\tLN:2922\n@SQ\tSN:KB713748.1\tLN:2922\n@SQ\tSN:APMT01228326.1\tLN:2922\n@SQ\tSN:APMT01228011.1\tLN:2920\n@SQ\tSN:KB713864.1\tLN:2920\n@SQ\tSN:KB713882.1\tLN:2920\n@SQ\tSN:APMT01228334.1\tLN:2920\n@SQ\tSN:KB714130.1\tLN:2920\n@SQ\tSN:KB713653.1\tLN:2919\n@SQ\tSN:APMT01227666.1\tLN:2919\n@SQ\tSN:APMT01228013.1\tLN:2919\n@SQ\tSN:APMT01228164.1\tLN:2919\n@SQ\tSN:APMT01228337.1\tLN:2919\n@SQ\tSN:APMT01228670.1\tLN:2919\n@SQ\tSN:KB713386.1\tLN:2918\n@SQ\tSN:APMT01228322.1\tLN:2918\n@SQ\tSN:APMT01228338.1\tLN:2918\n@SQ\tSN:KB711872.1\tLN:2917\n@SQ\tSN:APMT01227350.1\tLN:2917\n@SQ\tSN:KB713735.1\tLN:2917\n@SQ\tSN:KB713800.1\tLN:2917\n@SQ\tSN:KB713911.1\tLN:2917\n@SQ\tSN:APMT01228341.1\tLN:2917\n@SQ\tSN:APMT01227977.1\tLN:2916\n@SQ\tSN:APMT01228042.1\tLN:2916\n@SQ\tSN:KB713657.1\tLN:2915\n@SQ\tSN:APMT01227665.1\tLN:2915\n@SQ\tSN:KB713720.1\tLN:2915\n@SQ\tSN:KB713731.1\tLN:2915\n@SQ\tSN:APMT01228348.1\tLN:2915\n@SQ\tSN:APMT01228349.1\tLN:2915\n@SQ\tSN:APMT01228350.1\tLN:2915\n@SQ\tSN:APMT01228351.1\tLN:2915\n@SQ\tSN:KB713853.1\tLN:2914\n@SQ\tSN:KB713874.1\tLN:2914\n@SQ\tSN:KB713921.1\tLN:2914\n@SQ\tSN:APMT01228352.1\tLN:2914\n@SQ\tSN:APMT01228050.1\tLN:2913\n@SQ\tSN:APMT01228211.1\tLN:2913\n@SQ\tSN:APMT01228357.1\tLN:2913\n@SQ\tSN:KB713514.1\tLN:2912\n@SQ\tSN:APMT01228021.1\tLN:2912\n@SQ\tSN:APMT01228065.1\tLN:2911\n@SQ\tSN:KB713885.1\tLN:2911\n@SQ\tSN:APMT01228371.1\tLN:2911\n@SQ\tSN:APMT01228374.1\tLN:2911\n@SQ\tSN:KB713830.1\tLN:2910\n@SQ\tSN:APMT01228103.1\tLN:2910\n@SQ\tSN:KB712442.1\tLN:2909\n@SQ\tSN:KB713499.1\tLN:2909\n@SQ\tSN:KB713537.1\tLN:2909\n@SQ\tSN:KB713538.1\tLN:2909\n@SQ\tSN:KB713890.1\tLN:2909\n@SQ\tSN:APMT01228302.1\tLN:2909\n@SQ\tSN:APMT01228383.1\tLN:2909\n@SQ\tSN:KB713939.1\tLN:2909\n@SQ\tSN:APMT01227485.1\tLN:2908\n@SQ\tSN:KB713917.1\tLN:2908\n@SQ\tSN:APMT01228356.1\tLN:2908\n@SQ\tSN:APMT01228390.1\tLN:2908\n@SQ\tSN:KB713467.1\tLN:2907\n@SQ\tSN:KB713596.1\tLN:2907\n@SQ\tSN:APMT01228058.1\tLN:2907\n@SQ\tSN:KB713880.1\tLN:2906\n@SQ\tSN:KB713909.1\tLN:2906\n@SQ\tSN:APMT01228308.1\tLN:2906\n@SQ\tSN:APMT01228396.1\tLN:2906\n@SQ\tSN:KB713363.1\tLN:2904\n@SQ\tSN:KB713631.1\tLN:2904\n@SQ\tSN:KB713680.1\tLN:2904\n@SQ\tSN:APMT01228149.1\tLN:2904\n@SQ\tSN:KB713943.1\tLN:2904\n@SQ\tSN:APMT01228407.1\tLN:2904\n@SQ\tSN:APMT01228408.1\tLN:2904\n@SQ\tSN:APMT01228409.1\tLN:2904\n@SQ\tSN:KB713061.1\tLN:2903\n@SQ\tSN:KB713740.1\tLN:2903\n@SQ\tSN:APMT01228391.1\tLN:2903\n@SQ\tSN:APMT01228410.1\tLN:2903\n@SQ\tSN:APMT01228416.1\tLN:2902\n@SQ\tSN:KB713971.1\tLN:2902\n@SQ\tSN:KB713728.1\tLN:2901\n@SQ\tSN:APMT01228419.1\tLN:2901\n@SQ\tSN:APMT01228420.1\tLN:2901\n@SQ\tSN:APMT01228421.1\tLN:2901\n@SQ\tSN:KB713758.1\tLN:2900\n@SQ\tSN:KB713816.1\tLN:2900\n@SQ\tSN:APMT01228146.1\tLN:2899\n@SQ\tSN:APMT01228232.1\tLN:2899\n@SQ\tSN:APMT01228434.1\tLN:2899\n@SQ\tSN:APMT01228435.1\tLN:2899\n@SQ\tSN:KB711849.1\tLN:2898\n@SQ\tSN:KB712735.1\tLN:2898\n@SQ\tSN:APMT01228362.1\tLN:2898\n@SQ\tSN:APMT01228439.1\tLN:2898\n@SQ\tSN:APMT01228450.1\tLN:2897\n@SQ\tSN:KB713998.1\tLN:2897\n@SQ\tSN:KB712424.1\tLN:2896\n@SQ\tSN:KB713789.1\tLN:2896\n@SQ\tSN:APMT01228312.1\tLN:2896\n@SQ\tSN:KB713928.1\tLN:2896\n@SQ\tSN:APMT01228413.1\tLN:2896\n@SQ\tSN:APMT01228456.1\tLN:2896\n@SQ\tSN:APMT01228457.1\tLN:2896\n@SQ\tSN:APMT01228460.1\tLN:2896\n@SQ\tSN:KB713494.1\tLN:2895\n@SQ\tSN:KB713701.1\tLN:2895\n@SQ\tSN:KB713887.1\tLN:2895\n@SQ\tSN:APMT01228286.1\tLN:2895\n@SQ\tSN:KB713767.1\tLN:2894\n@SQ\tSN:APMT01228005.1\tLN:2894\n@SQ\tSN:KB713827.1\tLN:2894\n@SQ\tSN:APMT01228190.1\tLN:2894\n@SQ\tSN:APMT01228307.1\tLN:2894\n@SQ\tSN:APMT01228325.1\tLN:2894\n@SQ\tSN:APMT01228465.1\tLN:2894\n@SQ\tSN:APMT01228468.1\tLN:2894\n@SQ\tSN:APMT01228469.1\tLN:2894\n@SQ\tSN:KB713461.1\tLN:2893\n@SQ\tSN:APMT01228171.1\tLN:2893\n@SQ\tSN:KB713925.1\tLN:2893\n@SQ\tSN:KB713926.1\tLN:2893\n@SQ\tSN:KB713902.1\tLN:2892\n@SQ\tSN:APMT01228301.1\tLN:2892\n@SQ\tSN:KB713749.1\tLN:2891\n@SQ\tSN:KB713817.1\tLN:2891\n@SQ\tSN:APMT01228182.1\tLN:2891\n@SQ\tSN:KB713954.1\tLN:2891\n@SQ\tSN:KB713981.1\tLN:2891\n@SQ\tSN:APMT01228485.1\tLN:2890\n@SQ\tSN:APMT01228487.1\tLN:2890\n@SQ\tSN:KB713802.1\tLN:2889\n@SQ\tSN:KB713837.1\tLN:2889\n@SQ\tSN:APMT01228488.1\tLN:2889\n@SQ\tSN:APMT01227953.1\tLN:2888\n@SQ\tSN:APMT01228476.1\tLN:2888\n@SQ\tSN:APMT01228491.1\tLN:2888\n@SQ\tSN:APMT01228494.1\tLN:2888\n@SQ\tSN:KB713707.1\tLN:2886\n@SQ\tSN:APMT01228197.1\tLN:2886\n@SQ\tSN:APMT01228507.1\tLN:2886\n@SQ\tSN:APMT01228508.1\tLN:2886\n@SQ\tSN:KB713316.1\tLN:2885\n@SQ\tSN:KB713777.1\tLN:2885\n@SQ\tSN:APMT01228370.1\tLN:2885\n@SQ\tSN:KB712251.1\tLN:2884\n@SQ\tSN:KB713790.1\tLN:2884\n@SQ\tSN:APMT01228492.1\tLN:2884\n@SQ\tSN:APMT01228772.1\tLN:2884\n@SQ\tSN:KB713751.1\tLN:2883\n@SQ\tSN:KB713946.1\tLN:2883\n@SQ\tSN:APMT01228518.1\tLN:2883\n@SQ\tSN:KB713919.1\tLN:2882\n@SQ\tSN:APMT01228523.1\tLN:2882\n@SQ\tSN:APMT01228524.1\tLN:2882\n@SQ\tSN:KB714004.1\tLN:2882\n@SQ\tSN:KB714020.1\tLN:2882\n@SQ\tSN:KB713575.1\tLN:2881\n@SQ\tSN:KB713898.1\tLN:2880\n@SQ\tSN:APMT01228475.1\tLN:2880\n@SQ\tSN:APMT01228538.1\tLN:2880\n@SQ\tSN:APMT01228539.1\tLN:2880\n@SQ\tSN:KB713753.1\tLN:2879\n@SQ\tSN:KB713839.1\tLN:2879\n@SQ\tSN:KB713855.1\tLN:2879\n@SQ\tSN:APMT01228541.1\tLN:2879\n@SQ\tSN:KB713607.1\tLN:2878\n@SQ\tSN:KB713727.1\tLN:2878\n@SQ\tSN:KB713832.1\tLN:2878\n@SQ\tSN:KB713870.1\tLN:2878\n@SQ\tSN:APMT01228455.1\tLN:2878\n@SQ\tSN:APMT01228540.1\tLN:2878\n@SQ\tSN:APMT01227950.1\tLN:2877\n@SQ\tSN:APMT01228544.1\tLN:2877\n@SQ\tSN:KB713770.1\tLN:2876\n@SQ\tSN:KB713941.1\tLN:2876\n@SQ\tSN:APMT01228484.1\tLN:2876\n@SQ\tSN:APMT01228522.1\tLN:2876\n@SQ\tSN:APMT01228550.1\tLN:2876\n@SQ\tSN:KB713687.1\tLN:2875\n@SQ\tSN:KB713824.1\tLN:2875\n@SQ\tSN:APMT01228551.1\tLN:2875\n@SQ\tSN:APMT01228554.1\tLN:2875\n@SQ\tSN:KB714048.1\tLN:2875\n@SQ\tSN:KB713863.1\tLN:2874\n@SQ\tSN:APMT01228562.1\tLN:2874\n@SQ\tSN:KB713992.1\tLN:2874\n@SQ\tSN:APMT01228950.1\tLN:2874\n@SQ\tSN:KB712471.1\tLN:2873\n@SQ\tSN:KB713867.1\tLN:2873\n@SQ\tSN:APMT01227964.1\tLN:2872\n@SQ\tSN:KB713913.1\tLN:2872\n@SQ\tSN:APMT01228564.1\tLN:2872\n@SQ\tSN:APMT01228571.1\tLN:2872\n@SQ\tSN:APMT01228577.1\tLN:2872\n@SQ\tSN:KB713306.1\tLN:2871\n@SQ\tSN:KB713843.1\tLN:2871\n@SQ\tSN:KB713960.1\tLN:2871\n@SQ\tSN:APMT01228534.1\tLN:2871\n@SQ\tSN:APMT01228563.1\tLN:2871\n@SQ\tSN:APMT01228579.1\tLN:2871\n@SQ\tSN:APMT01228580.1\tLN:2871\n@SQ\tSN:APMT01228583.1\tLN:2871\n@SQ\tSN:APMT01228375.1\tLN:2870\n@SQ\tSN:APMT01228590.1\tLN:2870\n@SQ\tSN:APMT01229335.1\tLN:2870\n@SQ\tSN:APMT01228217.1\tLN:2869\n@SQ\tSN:KB713897.1\tLN:2869\n@SQ\tSN:APMT01228594.1\tLN:2869\n@SQ\tSN:APMT01228597.1\tLN:2869\n@SQ\tSN:APMT01228598.1\tLN:2869\n@SQ\tSN:KB713804.1\tLN:2868\n@SQ\tSN:APMT01227978.1\tLN:2868\n@SQ\tSN:APMT01228552.1\tLN:2868\n@SQ\tSN:APMT01228605.1\tLN:2868\n@SQ\tSN:APMT01228606.1\tLN:2868\n@SQ\tSN:APMT01228760.1\tLN:2868\n@SQ\tSN:APMT01228295.1\tLN:2867\n@SQ\tSN:KB713949.1\tLN:2867\n@SQ\tSN:APMT01228497.1\tLN:2867\n@SQ\tSN:APMT01228610.1\tLN:2867\n@SQ\tSN:APMT01228613.1\tLN:2867\n@SQ\tSN:APMT01228353.1\tLN:2866\n@SQ\tSN:APMT01228599.1\tLN:2866\n@SQ\tSN:APMT01228609.1\tLN:2866\n@SQ\tSN:APMT01228321.1\tLN:2865\n@SQ\tSN:KB713953.1\tLN:2865\n@SQ\tSN:KB713741.1\tLN:2864\n@SQ\tSN:KB713772.1\tLN:2864\n@SQ\tSN:KB713910.1\tLN:2864\n@SQ\tSN:KB713951.1\tLN:2863\n@SQ\tSN:APMT01228593.1\tLN:2863\n@SQ\tSN:APMT01228633.1\tLN:2863\n@SQ\tSN:APMT01228635.1\tLN:2863\n@SQ\tSN:APMT01228638.1\tLN:2863\n@SQ\tSN:KB713223.1\tLN:2862\n@SQ\tSN:APMT01228624.1\tLN:2862\n@SQ\tSN:APMT01228645.1\tLN:2861\n@SQ\tSN:APMT01228646.1\tLN:2861\n@SQ\tSN:KB713947.1\tLN:2860\n@SQ\tSN:APMT01228565.1\tLN:2860\n@SQ\tSN:APMT01228647.1\tLN:2860\n@SQ\tSN:KB713353.1\tLN:2859\n@SQ\tSN:KB713847.1\tLN:2859\n@SQ\tSN:APMT01228372.1\tLN:2859\n@SQ\tSN:KB714555.1\tLN:2859\n@SQ\tSN:KB713808.1\tLN:2858\n@SQ\tSN:KB713881.1\tLN:2858\n@SQ\tSN:KB713791.1\tLN:2857\n@SQ\tSN:KB714000.1\tLN:2857\n@SQ\tSN:APMT01228614.1\tLN:2857\n@SQ\tSN:APMT01228659.1\tLN:2857\n@SQ\tSN:KB713807.1\tLN:2856\n@SQ\tSN:KB713040.1\tLN:2855\n@SQ\tSN:KB713327.1\tLN:2855\n@SQ\tSN:KB713774.1\tLN:2855\n@SQ\tSN:KB713780.1\tLN:2855\n@SQ\tSN:APMT01228382.1\tLN:2855\n@SQ\tSN:APMT01228648.1\tLN:2855\n@SQ\tSN:APMT01228661.1\tLN:2855\n@SQ\tSN:KB713963.1\tLN:2854\n@SQ\tSN:KB714241.1\tLN:2854\n@SQ\tSN:KB713721.1\tLN:2853\n@SQ\tSN:KB713773.1\tLN:2853\n@SQ\tSN:APMT01228373.1\tLN:2853\n@SQ\tSN:APMT01228660.1\tLN:2853\n@SQ\tSN:APMT01228672.1\tLN:2853\n@SQ\tSN:KB714021.1\tLN:2853\n@SQ\tSN:KB714073.1\tLN:2853\n@SQ\tSN:APMT01228483.1\tLN:2852\n@SQ\tSN:APMT01228674.1\tLN:2852\n@SQ\tSN:KB713561.1\tLN:2851\n@SQ\tSN:APMT01228678.1\tLN:2851\n@SQ\tSN:APMT01228679.1\tLN:2851\n@SQ\tSN:APMT01228680.1\tLN:2851\n@SQ\tSN:APMT01228789.1\tLN:2851\n@SQ\tSN:KB713810.1\tLN:2850\n@SQ\tSN:KB713835.1\tLN:2850\n@SQ\tSN:APMT01228477.1\tLN:2850\n@SQ\tSN:KB713970.1\tLN:2850\n@SQ\tSN:KB714006.1\tLN:2850\n@SQ\tSN:KB713989.1\tLN:2849\n@SQ\tSN:APMT01228677.1\tLN:2849\n@SQ\tSN:APMT01228684.1\tLN:2849\n@SQ\tSN:APMT01228685.1\tLN:2849\n@SQ\tSN:KB713865.1\tLN:2848\n@SQ\tSN:KB713883.1\tLN:2848\n@SQ\tSN:KB713959.1\tLN:2848\n@SQ\tSN:APMT01228470.1\tLN:2848\n@SQ\tSN:APMT01228689.1\tLN:2848\n@SQ\tSN:APMT01228729.1\tLN:2848\n@SQ\tSN:KB713699.1\tLN:2847\n@SQ\tSN:APMT01228512.1\tLN:2847\n@SQ\tSN:APMT01228568.1\tLN:2847\n@SQ\tSN:APMT01228637.1\tLN:2847\n@SQ\tSN:APMT01228691.1\tLN:2847\n@SQ\tSN:KB713529.1\tLN:2846\n@SQ\tSN:KB713619.1\tLN:2846\n@SQ\tSN:APMT01228662.1\tLN:2846\n@SQ\tSN:APMT01228696.1\tLN:2846\n@SQ\tSN:KB713945.1\tLN:2845\n@SQ\tSN:APMT01228695.1\tLN:2845\n@SQ\tSN:APMT01228698.1\tLN:2845\n@SQ\tSN:APMT01227905.1\tLN:2844\n@SQ\tSN:KB713818.1\tLN:2844\n@SQ\tSN:APMT01228701.1\tLN:2844\n@SQ\tSN:APMT01228713.1\tLN:2844\n@SQ\tSN:KB713616.1\tLN:2843\n@SQ\tSN:KB713848.1\tLN:2843\n@SQ\tSN:APMT01228716.1\tLN:2843\n@SQ\tSN:APMT01228719.1\tLN:2843\n@SQ\tSN:APMT01228720.1\tLN:2843\n@SQ\tSN:KB713518.1\tLN:2842\n@SQ\tSN:APMT01228721.1\tLN:2842\n@SQ\tSN:APMT01227989.1\tLN:2841\n@SQ\tSN:APMT01228493.1\tLN:2841\n@SQ\tSN:KB714017.1\tLN:2841\n@SQ\tSN:APMT01228438.1\tLN:2840\n@SQ\tSN:APMT01228574.1\tLN:2840\n@SQ\tSN:APMT01228733.1\tLN:2840\n@SQ\tSN:APMT01229113.1\tLN:2839\n@SQ\tSN:APMT01228761.1\tLN:2838\n@SQ\tSN:APMT01228736.1\tLN:2837\n@SQ\tSN:APMT01228743.1\tLN:2837\n@SQ\tSN:APMT01228744.1\tLN:2837\n@SQ\tSN:APMT01228333.1\tLN:2836\n@SQ\tSN:APMT01228754.1\tLN:2836\n@SQ\tSN:KB712119.1\tLN:2835\n@SQ\tSN:KB713999.1\tLN:2835\n@SQ\tSN:APMT01228600.1\tLN:2835\n@SQ\tSN:APMT01228634.1\tLN:2835\n@SQ\tSN:APMT01228755.1\tLN:2835\n@SQ\tSN:KB714045.1\tLN:2835\n@SQ\tSN:KB713590.1\tLN:2834\n@SQ\tSN:KB713745.1\tLN:2834\n@SQ\tSN:APMT01228758.1\tLN:2834\n@SQ\tSN:KB713834.1\tLN:2833\n@SQ\tSN:KB713991.1\tLN:2833\n@SQ\tSN:APMT01228763.1\tLN:2833\n@SQ\tSN:APMT01228764.1\tLN:2833\n@SQ\tSN:KB712403.1\tLN:2832\n@SQ\tSN:KB713901.1\tLN:2832\n@SQ\tSN:APMT01228750.1\tLN:2832\n@SQ\tSN:APMT01228751.1\tLN:2832\n@SQ\tSN:APMT01228766.1\tLN:2832\n@SQ\tSN:APMT01228513.1\tLN:2831\n@SQ\tSN:APMT01228769.1\tLN:2831\n@SQ\tSN:APMT01228553.1\tLN:2830\n@SQ\tSN:KB713801.1\tLN:2829\n@SQ\tSN:KB713840.1\tLN:2829\n@SQ\tSN:KB713678.1\tLN:2828\n@SQ\tSN:APMT01228498.1\tLN:2828\n@SQ\tSN:APMT01228519.1\tLN:2828\n@SQ\tSN:KB713988.1\tLN:2828\n@SQ\tSN:APMT01228782.1\tLN:2828\n@SQ\tSN:KB713708.1\tLN:2827\n@SQ\tSN:KB713884.1\tLN:2827\n@SQ\tSN:KB714043.1\tLN:2827\n@SQ\tSN:APMT01228783.1\tLN:2827\n@SQ\tSN:APMT01228786.1\tLN:2827\n@SQ\tSN:APMT01229217.1\tLN:2827\n@SQ\tSN:APMT01228212.1\tLN:2826\n@SQ\tSN:APMT01228486.1\tLN:2826\n@SQ\tSN:APMT01228521.1\tLN:2826\n@SQ\tSN:APMT01228787.1\tLN:2826\n@SQ\tSN:KB714177.1\tLN:2826\n@SQ\tSN:KB713912.1\tLN:2825\n@SQ\tSN:APMT01228790.1\tLN:2825\n@SQ\tSN:KB711908.1\tLN:2824\n@SQ\tSN:KB713176.1\tLN:2824\n@SQ\tSN:KB713990.1\tLN:2824\n@SQ\tSN:APMT01228732.1\tLN:2824\n@SQ\tSN:APMT01228752.1\tLN:2824\n@SQ\tSN:APMT01228765.1\tLN:2824\n@SQ\tSN:APMT01228797.1\tLN:2824\n@SQ\tSN:APMT01228802.1\tLN:2824\n@SQ\tSN:APMT01228803.1\tLN:2824\n@SQ\tSN:APMT01228804.1\tLN:2824\n@SQ\tSN:KB713754.1\tLN:2823\n@SQ\tSN:KB713933.1\tLN:2823\n@SQ\tSN:APMT01228810.1\tLN:2823\n@SQ\tSN:KB713763.1\tLN:2822\n@SQ\tSN:KB713931.1\tLN:2822\n@SQ\tSN:APMT01228779.1\tLN:2822\n@SQ\tSN:APMT01228819.1\tLN:2822\n@SQ\tSN:KB713888.1\tLN:2821\n@SQ\tSN:APMT01228816.1\tLN:2821\n@SQ\tSN:APMT01228817.1\tLN:2821\n@SQ\tSN:KB713873.1\tLN:2820\n@SQ\tSN:KB713983.1\tLN:2820\n@SQ\tSN:APMT01228818.1\tLN:2820\n@SQ\tSN:APMT01228821.1\tLN:2820\n@SQ\tSN:APMT01228824.1\tLN:2820\n@SQ\tSN:KB713793.1\tLN:2818\n@SQ\tSN:APMT01228428.1\tLN:2818\n@SQ\tSN:APMT01228834.1\tLN:2818\n@SQ\tSN:KB713967.1\tLN:2817\n@SQ\tSN:APMT01228813.1\tLN:2817\n@SQ\tSN:APMT01228838.1\tLN:2817\n@SQ\tSN:KB713860.1\tLN:2816\n@SQ\tSN:KB713875.1\tLN:2816\n@SQ\tSN:KB713900.1\tLN:2816\n@SQ\tSN:KB713936.1\tLN:2816\n@SQ\tSN:KB713956.1\tLN:2816\n@SQ\tSN:APMT01228549.1\tLN:2816\n@SQ\tSN:APMT01228842.1\tLN:2816\n@SQ\tSN:APMT01228850.1\tLN:2815\n@SQ\tSN:APMT01228857.1\tLN:2815\n@SQ\tSN:KB713984.1\tLN:2814\n@SQ\tSN:KB711739.1\tLN:2813\n@SQ\tSN:KB713922.1\tLN:2813\n@SQ\tSN:APMT01228636.1\tLN:2813\n@SQ\tSN:APMT01228853.1\tLN:2813\n@SQ\tSN:APMT01228854.1\tLN:2813\n@SQ\tSN:APMT01228855.1\tLN:2813\n@SQ\tSN:APMT01228856.1\tLN:2813\n@SQ\tSN:APMT01228862.1\tLN:2813\n@SQ\tSN:APMT01228578.1\tLN:2812\n@SQ\tSN:KB714032.1\tLN:2812\n@SQ\tSN:APMT01228795.1\tLN:2812\n@SQ\tSN:APMT01228864.1\tLN:2812\n@SQ\tSN:APMT01228866.1\tLN:2812\n@SQ\tSN:KB713415.1\tLN:2811\n@SQ\tSN:KB713672.1\tLN:2811\n@SQ\tSN:APMT01228868.1\tLN:2810\n@SQ\tSN:APMT01228869.1\tLN:2810\n@SQ\tSN:APMT01228870.1\tLN:2810\n@SQ\tSN:APMT01228871.1\tLN:2810\n@SQ\tSN:KB713965.1\tLN:2809\n@SQ\tSN:KB714008.1\tLN:2809\n@SQ\tSN:APMT01228875.1\tLN:2809\n@SQ\tSN:APMT01228876.1\tLN:2809\n@SQ\tSN:KB713958.1\tLN:2808\n@SQ\tSN:APMT01228879.1\tLN:2808\n@SQ\tSN:APMT01228880.1\tLN:2808\n@SQ\tSN:KB714077.1\tLN:2808\n@SQ\tSN:KB714011.1\tLN:2807\n@SQ\tSN:APMT01228671.1\tLN:2807\n@SQ\tSN:APMT01228882.1\tLN:2807\n@SQ\tSN:APMT01228888.1\tLN:2807\n@SQ\tSN:APMT01228891.1\tLN:2807\n@SQ\tSN:KB714113.1\tLN:2807\n@SQ\tSN:KB713950.1\tLN:2806\n@SQ\tSN:KB713966.1\tLN:2806\n@SQ\tSN:KB714018.1\tLN:2806\n@SQ\tSN:KB714027.1\tLN:2806\n@SQ\tSN:KB713711.1\tLN:2804\n@SQ\tSN:KB713924.1\tLN:2804\n@SQ\tSN:APMT01228623.1\tLN:2804\n@SQ\tSN:APMT01228712.1\tLN:2804\n@SQ\tSN:APMT01228852.1\tLN:2804\n@SQ\tSN:APMT01228894.1\tLN:2804\n@SQ\tSN:APMT01228895.1\tLN:2804\n@SQ\tSN:KB712714.1\tLN:2803\n@SQ\tSN:APMT01228102.1\tLN:2803\n@SQ\tSN:KB713934.1\tLN:2803\n@SQ\tSN:KB713974.1\tLN:2803\n@SQ\tSN:APMT01228683.1\tLN:2803\n@SQ\tSN:APMT01228899.1\tLN:2803\n@SQ\tSN:APMT01228902.1\tLN:2803\n@SQ\tSN:KB714178.1\tLN:2803\n@SQ\tSN:APMT01228673.1\tLN:2802\n@SQ\tSN:KB714067.1\tLN:2802\n@SQ\tSN:APMT01228905.1\tLN:2802\n@SQ\tSN:KB714095.1\tLN:2802\n@SQ\tSN:KB713742.1\tLN:2801\n@SQ\tSN:KB714061.1\tLN:2801\n@SQ\tSN:APMT01228908.1\tLN:2801\n@SQ\tSN:APMT01228912.1\tLN:2801\n@SQ\tSN:KB713858.1\tLN:2800\n@SQ\tSN:APMT01228690.1\tLN:2800\n@SQ\tSN:KB714042.1\tLN:2800\n@SQ\tSN:APMT01228913.1\tLN:2800\n@SQ\tSN:APMT01228914.1\tLN:2800\n@SQ\tSN:APMT01228915.1\tLN:2800\n@SQ\tSN:APMT01228921.1\tLN:2800\n@SQ\tSN:KB713563.1\tLN:2799\n@SQ\tSN:APMT01228928.1\tLN:2799\n@SQ\tSN:APMT01228929.1\tLN:2799\n@SQ\tSN:KB713459.1\tLN:2798\n@SQ\tSN:KB714031.1\tLN:2798\n@SQ\tSN:KB713814.1\tLN:2797\n@SQ\tSN:KB714033.1\tLN:2797\n@SQ\tSN:APMT01228941.1\tLN:2797\n@SQ\tSN:APMT01228943.1\tLN:2797\n@SQ\tSN:APMT01228944.1\tLN:2797\n@SQ\tSN:APMT01228945.1\tLN:2797\n@SQ\tSN:KB713319.1\tLN:2796\n@SQ\tSN:KB713675.1\tLN:2796\n@SQ\tSN:KB713973.1\tLN:2796\n@SQ\tSN:APMT01228942.1\tLN:2796\n@SQ\tSN:APMT01228949.1\tLN:2796\n@SQ\tSN:KB713979.1\tLN:2795\n@SQ\tSN:KB714003.1\tLN:2795\n@SQ\tSN:APMT01228951.1\tLN:2795\n@SQ\tSN:APMT01228952.1\tLN:2795\n@SQ\tSN:APMT01228953.1\tLN:2795\n@SQ\tSN:APMT01228954.1\tLN:2795\n@SQ\tSN:KB713569.1\tLN:2794\n@SQ\tSN:KB713572.1\tLN:2794\n@SQ\tSN:APMT01228841.1\tLN:2794\n@SQ\tSN:APMT01228957.1\tLN:2794\n@SQ\tSN:APMT01228958.1\tLN:2794\n@SQ\tSN:KB714040.1\tLN:2793\n@SQ\tSN:APMT01228962.1\tLN:2793\n@SQ\tSN:KB714389.1\tLN:2793\n@SQ\tSN:KB713930.1\tLN:2792\n@SQ\tSN:KB713994.1\tLN:2792\n@SQ\tSN:KB714056.1\tLN:2792\n@SQ\tSN:KB714078.1\tLN:2792\n@SQ\tSN:APMT01228971.1\tLN:2792\n@SQ\tSN:KB714026.1\tLN:2791\n@SQ\tSN:KB714071.1\tLN:2791\n@SQ\tSN:KB713583.1\tLN:2790\n@SQ\tSN:APMT01228655.1\tLN:2790\n@SQ\tSN:APMT01228972.1\tLN:2790\n@SQ\tSN:KB713666.1\tLN:2789\n@SQ\tSN:KB713955.1\tLN:2789\n@SQ\tSN:APMT01228979.1\tLN:2789\n@SQ\tSN:APMT01228561.1\tLN:2788\n@SQ\tSN:KB713846.1\tLN:2787\n@SQ\tSN:APMT01228809.1\tLN:2787\n@SQ\tSN:APMT01228983.1\tLN:2787\n@SQ\tSN:APMT01228986.1\tLN:2787\n@SQ\tSN:APMT01228990.1\tLN:2787\n@SQ\tSN:KB712142.1\tLN:2786\n@SQ\tSN:APMT01228799.1\tLN:2785\n@SQ\tSN:KB714083.1\tLN:2785\n@SQ\tSN:KB713918.1\tLN:2784\n@SQ\tSN:KB713986.1\tLN:2784\n@SQ\tSN:APMT01228982.1\tLN:2783\n@SQ\tSN:APMT01229010.1\tLN:2783\n@SQ\tSN:KB714272.1\tLN:2783\n@SQ\tSN:KB713937.1\tLN:2782\n@SQ\tSN:APMT01229015.1\tLN:2782\n@SQ\tSN:KB714267.1\tLN:2782\n@SQ\tSN:APMT01228730.1\tLN:2781\n@SQ\tSN:APMT01228998.1\tLN:2781\n@SQ\tSN:APMT01228731.1\tLN:2780\n@SQ\tSN:APMT01229020.1\tLN:2779\n@SQ\tSN:APMT01229021.1\tLN:2779\n@SQ\tSN:APMT01229022.1\tLN:2779\n@SQ\tSN:KB714228.1\tLN:2779\n@SQ\tSN:KB713868.1\tLN:2778\n@SQ\tSN:APMT01228740.1\tLN:2778\n@SQ\tSN:APMT01229028.1\tLN:2778\n@SQ\tSN:APMT01229029.1\tLN:2778\n@SQ\tSN:KB714074.1\tLN:2777\n@SQ\tSN:APMT01229042.1\tLN:2777\n@SQ\tSN:APMT01229043.1\tLN:2776\n@SQ\tSN:APMT01229044.1\tLN:2776\n@SQ\tSN:APMT01229047.1\tLN:2776\n@SQ\tSN:KB713795.1\tLN:2775\n@SQ\tSN:KB713854.1\tLN:2775\n@SQ\tSN:APMT01228242.1\tLN:2774\n@SQ\tSN:APMT01229054.1\tLN:2774\n@SQ\tSN:APMT01229055.1\tLN:2774\n@SQ\tSN:APMT01229060.1\tLN:2774\n@SQ\tSN:APMT01228747.1\tLN:2773\n@SQ\tSN:APMT01229061.1\tLN:2773\n@SQ\tSN:APMT01229063.1\tLN:2773\n@SQ\tSN:KB714160.1\tLN:2773\n@SQ\tSN:KB713451.1\tLN:2772\n@SQ\tSN:KB714012.1\tLN:2772\n@SQ\tSN:APMT01228762.1\tLN:2772\n@SQ\tSN:KB714317.1\tLN:2772\n@SQ\tSN:KB713803.1\tLN:2771\n@SQ\tSN:APMT01228863.1\tLN:2771\n@SQ\tSN:KB714081.1\tLN:2771\n@SQ\tSN:APMT01229068.1\tLN:2771\n@SQ\tSN:APMT01229073.1\tLN:2771\n@SQ\tSN:KB714129.1\tLN:2771\n@SQ\tSN:APMT01228839.1\tLN:2770\n@SQ\tSN:APMT01229070.1\tLN:2770\n@SQ\tSN:APMT01229083.1\tLN:2770\n@SQ\tSN:KB714030.1\tLN:2769\n@SQ\tSN:APMT01229080.1\tLN:2768\n@SQ\tSN:APMT01229082.1\tLN:2768\n@SQ\tSN:APMT01229085.1\tLN:2768\n@SQ\tSN:APMT01229086.1\tLN:2768\n@SQ\tSN:KB714516.1\tLN:2768\n@SQ\tSN:APMT01228688.1\tLN:2767\n@SQ\tSN:KB714127.1\tLN:2767\n@SQ\tSN:APMT01229092.1\tLN:2767\n@SQ\tSN:KB714271.1\tLN:2767\n@SQ\tSN:APMT01228788.1\tLN:2766\n@SQ\tSN:APMT01228840.1\tLN:2766\n@SQ\tSN:APMT01228316.1\tLN:2765\n@SQ\tSN:KB714041.1\tLN:2765\n@SQ\tSN:APMT01229084.1\tLN:2765\n@SQ\tSN:APMT01229096.1\tLN:2765\n@SQ\tSN:APMT01229099.1\tLN:2765\n@SQ\tSN:APMT01229100.1\tLN:2765\n@SQ\tSN:APMT01228697.1\tLN:2764\n@SQ\tSN:APMT01229104.1\tLN:2764\n@SQ\tSN:APMT01229108.1\tLN:2764\n@SQ\tSN:APMT01229109.1\tLN:2764\n@SQ\tSN:KB714143.1\tLN:2764\n@SQ\tSN:KB714149.1\tLN:2764\n@SQ\tSN:APMT01229638.1\tLN:2764\n@SQ\tSN:KB714052.1\tLN:2763\n@SQ\tSN:APMT01228826.1\tLN:2763\n@SQ\tSN:APMT01229101.1\tLN:2763\n@SQ\tSN:APMT01228847.1\tLN:2762\n@SQ\tSN:APMT01228985.1\tLN:2762\n@SQ\tSN:KB714131.1\tLN:2762\n@SQ\tSN:APMT01229112.1\tLN:2762\n@SQ\tSN:APMT01229062.1\tLN:2761\n@SQ\tSN:APMT01229119.1\tLN:2761\n@SQ\tSN:APMT01229122.1\tLN:2761\n@SQ\tSN:APMT01229123.1\tLN:2761\n@SQ\tSN:APMT01229124.1\tLN:2761\n@SQ\tSN:APMT01229127.1\tLN:2761\n@SQ\tSN:KB714157.1\tLN:2761\n@SQ\tSN:APMT01228651.1\tLN:2760\n@SQ\tSN:APMT01228825.1\tLN:2760\n@SQ\tSN:APMT01228867.1\tLN:2760\n@SQ\tSN:KB713905.1\tLN:2759\n@SQ\tSN:APMT01229133.1\tLN:2759\n@SQ\tSN:APMT01229134.1\tLN:2759\n@SQ\tSN:APMT01229135.1\tLN:2759\n@SQ\tSN:APMT01229136.1\tLN:2759\n@SQ\tSN:APMT01229137.1\tLN:2759\n@SQ\tSN:KB713621.1\tLN:2758\n@SQ\tSN:APMT01228652.1\tLN:2758\n@SQ\tSN:APMT01229142.1\tLN:2758\n@SQ\tSN:KB713978.1\tLN:2757\n@SQ\tSN:APMT01229144.1\tLN:2757\n@SQ\tSN:KB713977.1\tLN:2756\n@SQ\tSN:KB713985.1\tLN:2756\n@SQ\tSN:APMT01229149.1\tLN:2756\n@SQ\tSN:APMT01229150.1\tLN:2756\n@SQ\tSN:APMT01229151.1\tLN:2756\n@SQ\tSN:KB714190.1\tLN:2756\n@SQ\tSN:KB713831.1\tLN:2755\n@SQ\tSN:APMT01229152.1\tLN:2755\n@SQ\tSN:APMT01229153.1\tLN:2755\n@SQ\tSN:KB714165.1\tLN:2755\n@SQ\tSN:KB712756.1\tLN:2754\n@SQ\tSN:KB714049.1\tLN:2754\n@SQ\tSN:APMT01228851.1\tLN:2754\n@SQ\tSN:APMT01229143.1\tLN:2754\n@SQ\tSN:APMT01229158.1\tLN:2754\n@SQ\tSN:APMT01229159.1\tLN:2754\n@SQ\tSN:KB713997.1\tLN:2753\n@SQ\tSN:APMT01229161.1\tLN:2753\n@SQ\tSN:APMT01229162.1\tLN:2753\n@SQ\tSN:APMT01229166.1\tLN:2752\n@SQ\tSN:APMT01229167.1\tLN:2752\n@SQ\tSN:KB713819.1\tLN:2751\n@SQ\tSN:KB713993.1\tLN:2751\n@SQ\tSN:KB714044.1\tLN:2751\n@SQ\tSN:APMT01228932.1\tLN:2751\n@SQ\tSN:APMT01228956.1\tLN:2751\n@SQ\tSN:APMT01228987.1\tLN:2751\n@SQ\tSN:APMT01229178.1\tLN:2751\n@SQ\tSN:APMT01228865.1\tLN:2750\n@SQ\tSN:APMT01228911.1\tLN:2750\n@SQ\tSN:APMT01229179.1\tLN:2750\n@SQ\tSN:APMT01229183.1\tLN:2750\n@SQ\tSN:APMT01229184.1\tLN:2750\n@SQ\tSN:KB714144.1\tLN:2749\n@SQ\tSN:APMT01229182.1\tLN:2749\n@SQ\tSN:APMT01229187.1\tLN:2749\n@SQ\tSN:APMT01229188.1\tLN:2749\n@SQ\tSN:APMT01229195.1\tLN:2749\n@SQ\tSN:APMT01229194.1\tLN:2748\n@SQ\tSN:KB714163.1\tLN:2748\n@SQ\tSN:APMT01228896.1\tLN:2747\n@SQ\tSN:APMT01229201.1\tLN:2747\n@SQ\tSN:APMT01229265.1\tLN:2747\n@SQ\tSN:KB713146.1\tLN:2746\n@SQ\tSN:KB714133.1\tLN:2746\n@SQ\tSN:APMT01229204.1\tLN:2746\n@SQ\tSN:APMT01229205.1\tLN:2745\n@SQ\tSN:KB711700.1\tLN:2744\n@SQ\tSN:APMT01228796.1\tLN:2744\n@SQ\tSN:APMT01229211.1\tLN:2744\n@SQ\tSN:KB713700.1\tLN:2743\n@SQ\tSN:APMT01229215.1\tLN:2743\n@SQ\tSN:APMT01229212.1\tLN:2742\n@SQ\tSN:APMT01229216.1\tLN:2742\n@SQ\tSN:APMT01229219.1\tLN:2742\n@SQ\tSN:KB714134.1\tLN:2741\n@SQ\tSN:APMT01229223.1\tLN:2741\n@SQ\tSN:APMT01229224.1\tLN:2741\n@SQ\tSN:APMT01229227.1\tLN:2741\n@SQ\tSN:KB711531.1\tLN:2740\n@SQ\tSN:KB713879.1\tLN:2740\n@SQ\tSN:APMT01228973.1\tLN:2740\n@SQ\tSN:APMT01229232.1\tLN:2740\n@SQ\tSN:APMT01228920.1\tLN:2739\n@SQ\tSN:APMT01229222.1\tLN:2739\n@SQ\tSN:APMT01229233.1\tLN:2739\n@SQ\tSN:APMT01229237.1\tLN:2739\n@SQ\tSN:APMT01229240.1\tLN:2738\n@SQ\tSN:APMT01229241.1\tLN:2738\n@SQ\tSN:APMT01229244.1\tLN:2738\n@SQ\tSN:APMT01229245.1\tLN:2738\n@SQ\tSN:APMT01229248.1\tLN:2738\n@SQ\tSN:APMT01229246.1\tLN:2737\n@SQ\tSN:KB713813.1\tLN:2736\n@SQ\tSN:KB713927.1\tLN:2736\n@SQ\tSN:KB713961.1\tLN:2736\n@SQ\tSN:KB714016.1\tLN:2736\n@SQ\tSN:KB714072.1\tLN:2736\n@SQ\tSN:APMT01229019.1\tLN:2736\n@SQ\tSN:APMT01229146.1\tLN:2736\n@SQ\tSN:APMT01228961.1\tLN:2735\n@SQ\tSN:KB714141.1\tLN:2735\n@SQ\tSN:APMT01229154.1\tLN:2735\n@SQ\tSN:KB714105.1\tLN:2734\n@SQ\tSN:KB714138.1\tLN:2734\n@SQ\tSN:APMT01229252.1\tLN:2734\n@SQ\tSN:APMT01229255.1\tLN:2734\n@SQ\tSN:APMT01229258.1\tLN:2734\n@SQ\tSN:APMT01229259.1\tLN:2734\n@SQ\tSN:APMT01229260.1\tLN:2734\n@SQ\tSN:APMT01229264.1\tLN:2733\n@SQ\tSN:APMT01229266.1\tLN:2733\n@SQ\tSN:APMT01229267.1\tLN:2733\n@SQ\tSN:KB713938.1\tLN:2732\n@SQ\tSN:APMT01229270.1\tLN:2732\n@SQ\tSN:APMT01229276.1\tLN:2732\n@SQ\tSN:KB713920.1\tLN:2731\n@SQ\tSN:KB714063.1\tLN:2731\n@SQ\tSN:APMT01228997.1\tLN:2731\n@SQ\tSN:APMT01229023.1\tLN:2731\n@SQ\tSN:KB714123.1\tLN:2731\n@SQ\tSN:APMT01229014.1\tLN:2730\n@SQ\tSN:APMT01229285.1\tLN:2730\n@SQ\tSN:KB713294.1\tLN:2729\n@SQ\tSN:APMT01228984.1\tLN:2729\n@SQ\tSN:APMT01229128.1\tLN:2729\n@SQ\tSN:APMT01229247.1\tLN:2729\n@SQ\tSN:APMT01229288.1\tLN:2729\n@SQ\tSN:APMT01229289.1\tLN:2729\n@SQ\tSN:KB714098.1\tLN:2728\n@SQ\tSN:KB714125.1\tLN:2728\n@SQ\tSN:KB714166.1\tLN:2728\n@SQ\tSN:APMT01229290.1\tLN:2728\n@SQ\tSN:APMT01229291.1\tLN:2728\n@SQ\tSN:APMT01229292.1\tLN:2728\n@SQ\tSN:APMT01229293.1\tLN:2728\n@SQ\tSN:APMT01229294.1\tLN:2728\n@SQ\tSN:APMT01229295.1\tLN:2728\n@SQ\tSN:KB714179.1\tLN:2728\n@SQ\tSN:KB713559.1\tLN:2727\n@SQ\tSN:KB714062.1\tLN:2727\n@SQ\tSN:APMT01229001.1\tLN:2727\n@SQ\tSN:APMT01229165.1\tLN:2727\n@SQ\tSN:APMT01229296.1\tLN:2727\n@SQ\tSN:APMT01229297.1\tLN:2727\n@SQ\tSN:KB714343.1\tLN:2727\n@SQ\tSN:KB713786.1\tLN:2726\n@SQ\tSN:APMT01229011.1\tLN:2726\n@SQ\tSN:KB714142.1\tLN:2726\n@SQ\tSN:APMT01229189.1\tLN:2726\n@SQ\tSN:APMT01229302.1\tLN:2726\n@SQ\tSN:KB714038.1\tLN:2725\n@SQ\tSN:APMT01229002.1\tLN:2725\n@SQ\tSN:APMT01229299.1\tLN:2725\n@SQ\tSN:APMT01229306.1\tLN:2725\n@SQ\tSN:KB714229.1\tLN:2725\n@SQ\tSN:KB714118.1\tLN:2724\n@SQ\tSN:APMT01229307.1\tLN:2724\n@SQ\tSN:KB714065.1\tLN:2723\n@SQ\tSN:APMT01229009.1\tLN:2723\n@SQ\tSN:APMT01229308.1\tLN:2723\n@SQ\tSN:APMT01229309.1\tLN:2723\n@SQ\tSN:APMT01229069.1\tLN:2722\n@SQ\tSN:KB714150.1\tLN:2722\n@SQ\tSN:APMT01229303.1\tLN:2722\n@SQ\tSN:KB714348.1\tLN:2722\n@SQ\tSN:KB714087.1\tLN:2721\n@SQ\tSN:KB714103.1\tLN:2721\n@SQ\tSN:APMT01229089.1\tLN:2721\n@SQ\tSN:APMT01229318.1\tLN:2721\n@SQ\tSN:APMT01229320.1\tLN:2721\n@SQ\tSN:APMT01229323.1\tLN:2721\n@SQ\tSN:APMT01229325.1\tLN:2721\n@SQ\tSN:KB713828.1\tLN:2720\n@SQ\tSN:APMT01228240.1\tLN:2720\n@SQ\tSN:KB714094.1\tLN:2720\n@SQ\tSN:KB714112.1\tLN:2720\n@SQ\tSN:APMT01229254.1\tLN:2719\n@SQ\tSN:APMT01229324.1\tLN:2719\n@SQ\tSN:APMT01229333.1\tLN:2719\n@SQ\tSN:APMT01229334.1\tLN:2719\n@SQ\tSN:APMT01229336.1\tLN:2719\n@SQ\tSN:KB713893.1\tLN:2718\n@SQ\tSN:KB714010.1\tLN:2718\n@SQ\tSN:APMT01229018.1\tLN:2718\n@SQ\tSN:KB714079.1\tLN:2717\n@SQ\tSN:APMT01229319.1\tLN:2716\n@SQ\tSN:APMT01229342.1\tLN:2716\n@SQ\tSN:APMT01229343.1\tLN:2716\n@SQ\tSN:APMT01228152.1\tLN:2715\n@SQ\tSN:APMT01229271.1\tLN:2715\n@SQ\tSN:APMT01229344.1\tLN:2715\n@SQ\tSN:APMT01229160.1\tLN:2714\n@SQ\tSN:APMT01229346.1\tLN:2714\n@SQ\tSN:APMT01229351.1\tLN:2714\n@SQ\tSN:KB712079.1\tLN:2713\n@SQ\tSN:APMT01228798.1\tLN:2713\n@SQ\tSN:APMT01229352.1\tLN:2713\n@SQ\tSN:APMT01229361.1\tLN:2713\n@SQ\tSN:APMT01228658.1\tLN:2712\n@SQ\tSN:APMT01229348.1\tLN:2712\n@SQ\tSN:APMT01229355.1\tLN:2712\n@SQ\tSN:APMT01229356.1\tLN:2712\n@SQ\tSN:APMT01229357.1\tLN:2711\n@SQ\tSN:APMT01229360.1\tLN:2711\n@SQ\tSN:KB714275.1\tLN:2711\n@SQ\tSN:KB714093.1\tLN:2710\n@SQ\tSN:KB714121.1\tLN:2710\n@SQ\tSN:APMT01229145.1\tLN:2710\n@SQ\tSN:APMT01229363.1\tLN:2710\n@SQ\tSN:APMT01229364.1\tLN:2710\n@SQ\tSN:APMT01229365.1\tLN:2710\n@SQ\tSN:APMT01222731.1\tLN:2709\n@SQ\tSN:KB714119.1\tLN:2709\n@SQ\tSN:APMT01229377.1\tLN:2707\n@SQ\tSN:KB714100.1\tLN:2706\n@SQ\tSN:KB714169.1\tLN:2706\n@SQ\tSN:KB714172.1\tLN:2706\n@SQ\tSN:APMT01229386.1\tLN:2706\n@SQ\tSN:APMT01229190.1\tLN:2705\n@SQ\tSN:APMT01228883.1\tLN:2704\n@SQ\tSN:APMT01229116.1\tLN:2704\n@SQ\tSN:KB714117.1\tLN:2703\n@SQ\tSN:APMT01229105.1\tLN:2703\n@SQ\tSN:APMT01229279.1\tLN:2703\n@SQ\tSN:KB714175.1\tLN:2703\n@SQ\tSN:KB714146.1\tLN:2702\n@SQ\tSN:APMT01229400.1\tLN:2702\n@SQ\tSN:APMT01229401.1\tLN:2702\n@SQ\tSN:APMT01229155.1\tLN:2701\n@SQ\tSN:APMT01229404.1\tLN:2701\n@SQ\tSN:KB713592.1\tLN:2700\n@SQ\tSN:APMT01229411.1\tLN:2700\n@SQ\tSN:APMT01229412.1\tLN:2700\n@SQ\tSN:KB714207.1\tLN:2700\n@SQ\tSN:APMT01228535.1\tLN:2699\n@SQ\tSN:KB714059.1\tLN:2699\n@SQ\tSN:APMT01229328.1\tLN:2699\n@SQ\tSN:APMT01229415.1\tLN:2699\n@SQ\tSN:APMT01229420.1\tLN:2699\n@SQ\tSN:KB713238.1\tLN:2698\n@SQ\tSN:KB714099.1\tLN:2698\n@SQ\tSN:KB714148.1\tLN:2698\n@SQ\tSN:KB714153.1\tLN:2698\n@SQ\tSN:APMT01229421.1\tLN:2698\n@SQ\tSN:APMT01229423.1\tLN:2698\n@SQ\tSN:APMT01229424.1\tLN:2698\n@SQ\tSN:KB714266.1\tLN:2698\n@SQ\tSN:KB714287.1\tLN:2698\n@SQ\tSN:KB713935.1\tLN:2697\n@SQ\tSN:APMT01229425.1\tLN:2697\n@SQ\tSN:APMT01229429.1\tLN:2697\n@SQ\tSN:KB713894.1\tLN:2696\n@SQ\tSN:APMT01228955.1\tLN:2696\n@SQ\tSN:APMT01229432.1\tLN:2696\n@SQ\tSN:APMT01229433.1\tLN:2696\n@SQ\tSN:APMT01229439.1\tLN:2694\n@SQ\tSN:APMT01229441.1\tLN:2694\n@SQ\tSN:KB714060.1\tLN:2693\n@SQ\tSN:APMT01229426.1\tLN:2693\n@SQ\tSN:APMT01229444.1\tLN:2693\n@SQ\tSN:APMT01229445.1\tLN:2693\n@SQ\tSN:APMT01229446.1\tLN:2693\n@SQ\tSN:KB714107.1\tLN:2692\n@SQ\tSN:APMT01229434.1\tLN:2692\n@SQ\tSN:APMT01229451.1\tLN:2692\n@SQ\tSN:APMT01229452.1\tLN:2692\n@SQ\tSN:APMT01229253.1\tLN:2691\n@SQ\tSN:APMT01229455.1\tLN:2691\n@SQ\tSN:APMT01229456.1\tLN:2690\n@SQ\tSN:APMT01229457.1\tLN:2690\n@SQ\tSN:KB714223.1\tLN:2690\n@SQ\tSN:APMT01228976.1\tLN:2689\n@SQ\tSN:APMT01229228.1\tLN:2689\n@SQ\tSN:APMT01229440.1\tLN:2689\n@SQ\tSN:KB714036.1\tLN:2688\n@SQ\tSN:APMT01229515.1\tLN:2688\n@SQ\tSN:APMT01229466.1\tLN:2687\n@SQ\tSN:APMT01229471.1\tLN:2687\n@SQ\tSN:APMT01229514.1\tLN:2687\n@SQ\tSN:KB713862.1\tLN:2686\n@SQ\tSN:KB714126.1\tLN:2686\n@SQ\tSN:APMT01229095.1\tLN:2686\n@SQ\tSN:APMT01229475.1\tLN:2686\n@SQ\tSN:APMT01229916.1\tLN:2685\n@SQ\tSN:KB714388.1\tLN:2685\n@SQ\tSN:KB714096.1\tLN:2684\n@SQ\tSN:APMT01229236.1\tLN:2684\n@SQ\tSN:APMT01229347.1\tLN:2684\n@SQ\tSN:KB714197.1\tLN:2684\n@SQ\tSN:APMT01229481.1\tLN:2684\n@SQ\tSN:APMT01229482.1\tLN:2684\n@SQ\tSN:KB714054.1\tLN:2683\n@SQ\tSN:KB714132.1\tLN:2683\n@SQ\tSN:APMT01229208.1\tLN:2683\n@SQ\tSN:APMT01229490.1\tLN:2683\n@SQ\tSN:APMT01229492.1\tLN:2683\n@SQ\tSN:APMT01229493.1\tLN:2683\n@SQ\tSN:APMT01229494.1\tLN:2683\n@SQ\tSN:APMT01228759.1\tLN:2682\n@SQ\tSN:APMT01229485.1\tLN:2682\n@SQ\tSN:APMT01229498.1\tLN:2682\n@SQ\tSN:APMT01229218.1\tLN:2681\n@SQ\tSN:APMT01229231.1\tLN:2681\n@SQ\tSN:APMT01229251.1\tLN:2681\n@SQ\tSN:APMT01229284.1\tLN:2681\n@SQ\tSN:KB713923.1\tLN:2680\n@SQ\tSN:APMT01229502.1\tLN:2680\n@SQ\tSN:APMT01229503.1\tLN:2680\n@SQ\tSN:KB714227.1\tLN:2680\n@SQ\tSN:APMT01229511.1\tLN:2680\n@SQ\tSN:KB714075.1\tLN:2679\n@SQ\tSN:APMT01229513.1\tLN:2679\n@SQ\tSN:KB714120.1\tLN:2677\n@SQ\tSN:APMT01229298.1\tLN:2676\n@SQ\tSN:KB714147.1\tLN:2675\n@SQ\tSN:APMT01229525.1\tLN:2675\n@SQ\tSN:APMT01229528.1\tLN:2675\n@SQ\tSN:APMT01229529.1\tLN:2675\n@SQ\tSN:KB713820.1\tLN:2674\n@SQ\tSN:KB714088.1\tLN:2674\n@SQ\tSN:KB714209.1\tLN:2674\n@SQ\tSN:APMT01229534.1\tLN:2674\n@SQ\tSN:APMT01229539.1\tLN:2673\n@SQ\tSN:KB714002.1\tLN:2672\n@SQ\tSN:APMT01229543.1\tLN:2672\n@SQ\tSN:APMT01229546.1\tLN:2672\n@SQ\tSN:APMT01229389.1\tLN:2671\n@SQ\tSN:KB714253.1\tLN:2670\n@SQ\tSN:APMT01229383.1\tLN:2669\n@SQ\tSN:APMT01229553.1\tLN:2669\n@SQ\tSN:APMT01229339.1\tLN:2668\n@SQ\tSN:APMT01229378.1\tLN:2668\n@SQ\tSN:APMT01229395.1\tLN:2668\n@SQ\tSN:APMT01229556.1\tLN:2668\n@SQ\tSN:APMT01229558.1\tLN:2667\n@SQ\tSN:APMT01229559.1\tLN:2667\n@SQ\tSN:APMT01229560.1\tLN:2667\n@SQ\tSN:KB713652.1\tLN:2666\n@SQ\tSN:KB714164.1\tLN:2666\n@SQ\tSN:APMT01229561.1\tLN:2666\n@SQ\tSN:APMT01229564.1\tLN:2666\n@SQ\tSN:APMT01229571.1\tLN:2666\n@SQ\tSN:APMT01229579.1\tLN:2666\n@SQ\tSN:KB714159.1\tLN:2665\n@SQ\tSN:APMT01229959.1\tLN:2665\n@SQ\tSN:APMT01229581.1\tLN:2664\n@SQ\tSN:APMT01229582.1\tLN:2664\n@SQ\tSN:APMT01229583.1\tLN:2664\n@SQ\tSN:KB714224.1\tLN:2663\n@SQ\tSN:APMT01229588.1\tLN:2662\n@SQ\tSN:APMT01229589.1\tLN:2662\n@SQ\tSN:APMT01229592.1\tLN:2662\n@SQ\tSN:APMT01229593.1\tLN:2662\n@SQ\tSN:APMT01229341.1\tLN:2661\n@SQ\tSN:KB714202.1\tLN:2661\n@SQ\tSN:APMT01229594.1\tLN:2661\n@SQ\tSN:APMT01229597.1\tLN:2661\n@SQ\tSN:APMT01229598.1\tLN:2661\n@SQ\tSN:APMT01229599.1\tLN:2660\n@SQ\tSN:APMT01229601.1\tLN:2658\n@SQ\tSN:APMT01229604.1\tLN:2658\n@SQ\tSN:APMT01229605.1\tLN:2658\n@SQ\tSN:APMT01229606.1\tLN:2658\n@SQ\tSN:APMT01229607.1\tLN:2658\n@SQ\tSN:APMT01229611.1\tLN:2657\n@SQ\tSN:APMT01229612.1\tLN:2657\n@SQ\tSN:APMT01229613.1\tLN:2657\n@SQ\tSN:APMT01229614.1\tLN:2657\n@SQ\tSN:APMT01229480.1\tLN:2656\n@SQ\tSN:APMT01229600.1\tLN:2656\n@SQ\tSN:APMT01229615.1\tLN:2656\n@SQ\tSN:APMT01229340.1\tLN:2655\n@SQ\tSN:APMT01229396.1\tLN:2655\n@SQ\tSN:APMT01229501.1\tLN:2655\n@SQ\tSN:APMT01229616.1\tLN:2655\n@SQ\tSN:APMT01229617.1\tLN:2655\n@SQ\tSN:KB714135.1\tLN:2654\n@SQ\tSN:KB714231.1\tLN:2654\n@SQ\tSN:APMT01229621.1\tLN:2653\n@SQ\tSN:APMT01229624.1\tLN:2653\n@SQ\tSN:KB714082.1\tLN:2652\n@SQ\tSN:APMT01229625.1\tLN:2652\n@SQ\tSN:KB714122.1\tLN:2651\n@SQ\tSN:KB714161.1\tLN:2651\n@SQ\tSN:APMT01229626.1\tLN:2651\n@SQ\tSN:KB713872.1\tLN:2650\n@SQ\tSN:KB714106.1\tLN:2650\n@SQ\tSN:APMT01229633.1\tLN:2650\n@SQ\tSN:APMT01229636.1\tLN:2650\n@SQ\tSN:KB714110.1\tLN:2649\n@SQ\tSN:APMT01229491.1\tLN:2649\n@SQ\tSN:APMT01229637.1\tLN:2649\n@SQ\tSN:APMT01229639.1\tLN:2648\n@SQ\tSN:KB714196.1\tLN:2647\n@SQ\tSN:APMT01229474.1\tLN:2647\n@SQ\tSN:APMT01229644.1\tLN:2647\n@SQ\tSN:APMT01229645.1\tLN:2647\n@SQ\tSN:KB713852.1\tLN:2646\n@SQ\tSN:APMT01228320.1\tLN:2646\n@SQ\tSN:KB714069.1\tLN:2646\n@SQ\tSN:KB714239.1\tLN:2646\n@SQ\tSN:APMT01229646.1\tLN:2646\n@SQ\tSN:APMT01229647.1\tLN:2646\n@SQ\tSN:APMT01229649.1\tLN:2646\n@SQ\tSN:KB714171.1\tLN:2645\n@SQ\tSN:APMT01229620.1\tLN:2645\n@SQ\tSN:APMT01229654.1\tLN:2645\n@SQ\tSN:APMT01229666.1\tLN:2645\n@SQ\tSN:KB714180.1\tLN:2644\n@SQ\tSN:APMT01229390.1\tLN:2644\n@SQ\tSN:KB714205.1\tLN:2644\n@SQ\tSN:APMT01229548.1\tLN:2644\n@SQ\tSN:KB714258.1\tLN:2644\n@SQ\tSN:APMT01229660.1\tLN:2644\n@SQ\tSN:APMT01229661.1\tLN:2644\n@SQ\tSN:KB714167.1\tLN:2643\n@SQ\tSN:APMT01229407.1\tLN:2643\n@SQ\tSN:APMT01229659.1\tLN:2643\n@SQ\tSN:APMT01229662.1\tLN:2643\n@SQ\tSN:APMT01229663.1\tLN:2643\n@SQ\tSN:APMT01229664.1\tLN:2643\n@SQ\tSN:APMT01229665.1\tLN:2643\n@SQ\tSN:APMT01229672.1\tLN:2642\n@SQ\tSN:APMT01229673.1\tLN:2642\n@SQ\tSN:APMT01229674.1\tLN:2642\n@SQ\tSN:KB714085.1\tLN:2641\n@SQ\tSN:APMT01229408.1\tLN:2641\n@SQ\tSN:APMT01229675.1\tLN:2641\n@SQ\tSN:APMT01229678.1\tLN:2641\n@SQ\tSN:KB713869.1\tLN:2640\n@SQ\tSN:KB714034.1\tLN:2640\n@SQ\tSN:APMT01228874.1\tLN:2640\n@SQ\tSN:APMT01229679.1\tLN:2640\n@SQ\tSN:APMT01229680.1\tLN:2640\n@SQ\tSN:KB714109.1\tLN:2639\n@SQ\tSN:APMT01229422.1\tLN:2639\n@SQ\tSN:APMT01229687.1\tLN:2639\n@SQ\tSN:KB714188.1\tLN:2638\n@SQ\tSN:APMT01229692.1\tLN:2638\n@SQ\tSN:APMT01229693.1\tLN:2638\n@SQ\tSN:APMT01229694.1\tLN:2638\n@SQ\tSN:KB714174.1\tLN:2637\n@SQ\tSN:APMT01229462.1\tLN:2637\n@SQ\tSN:APMT01229698.1\tLN:2637\n@SQ\tSN:APMT01229701.1\tLN:2637\n@SQ\tSN:APMT01229708.1\tLN:2637\n@SQ\tSN:KB714314.1\tLN:2637\n@SQ\tSN:APMT01229703.1\tLN:2636\n@SQ\tSN:APMT01229707.1\tLN:2636\n@SQ\tSN:APMT01229518.1\tLN:2635\n@SQ\tSN:KB713975.1\tLN:2634\n@SQ\tSN:KB714140.1\tLN:2634\n@SQ\tSN:APMT01229681.1\tLN:2634\n@SQ\tSN:KB714379.1\tLN:2634\n@SQ\tSN:APMT01229709.1\tLN:2633\n@SQ\tSN:APMT01229712.1\tLN:2633\n@SQ\tSN:APMT01229717.1\tLN:2633\n@SQ\tSN:APMT01229497.1\tLN:2632\n@SQ\tSN:APMT01229721.1\tLN:2632\n@SQ\tSN:APMT01229671.1\tLN:2631\n@SQ\tSN:KB714263.1\tLN:2631\n@SQ\tSN:APMT01229704.1\tLN:2631\n@SQ\tSN:APMT01229727.1\tLN:2631\n@SQ\tSN:APMT01229728.1\tLN:2631\n@SQ\tSN:APMT01229729.1\tLN:2631\n@SQ\tSN:APMT01229732.1\tLN:2631\n@SQ\tSN:APMT01229734.1\tLN:2630\n@SQ\tSN:KB713995.1\tLN:2629\n@SQ\tSN:KB714064.1\tLN:2629\n@SQ\tSN:APMT01229200.1\tLN:2629\n@SQ\tSN:KB714232.1\tLN:2629\n@SQ\tSN:APMT01229739.1\tLN:2629\n@SQ\tSN:KB714208.1\tLN:2628\n@SQ\tSN:KB714217.1\tLN:2628\n@SQ\tSN:APMT01229551.1\tLN:2627\n@SQ\tSN:APMT01229744.1\tLN:2627\n@SQ\tSN:KB714390.1\tLN:2627\n@SQ\tSN:KB714029.1\tLN:2626\n@SQ\tSN:APMT01228833.1\tLN:2626\n@SQ\tSN:KB714183.1\tLN:2626\n@SQ\tSN:APMT01229754.1\tLN:2626\n@SQ\tSN:APMT01230087.1\tLN:2626\n@SQ\tSN:KB714246.1\tLN:2625\n@SQ\tSN:APMT01229762.1\tLN:2625\n@SQ\tSN:APMT01229370.1\tLN:2624\n@SQ\tSN:KB714201.1\tLN:2623\n@SQ\tSN:APMT01229764.1\tLN:2623\n@SQ\tSN:APMT01229765.1\tLN:2623\n@SQ\tSN:KB714315.1\tLN:2623\n@SQ\tSN:KB714152.1\tLN:2622\n@SQ\tSN:APMT01229595.1\tLN:2622\n@SQ\tSN:APMT01229770.1\tLN:2622\n@SQ\tSN:APMT01229773.1\tLN:2622\n@SQ\tSN:KB714219.1\tLN:2621\n@SQ\tSN:APMT01229523.1\tLN:2621\n@SQ\tSN:APMT01229542.1\tLN:2621\n@SQ\tSN:APMT01229776.1\tLN:2621\n@SQ\tSN:APMT01229777.1\tLN:2621\n@SQ\tSN:KB714216.1\tLN:2620\n@SQ\tSN:APMT01229781.1\tLN:2620\n@SQ\tSN:KB713957.1\tLN:2619\n@SQ\tSN:APMT01229524.1\tLN:2619\n@SQ\tSN:APMT01229547.1\tLN:2619\n@SQ\tSN:APMT01229557.1\tLN:2619\n@SQ\tSN:KB714137.1\tLN:2618\n@SQ\tSN:APMT01229512.1\tLN:2618\n@SQ\tSN:APMT01229787.1\tLN:2618\n@SQ\tSN:APMT01229790.1\tLN:2618\n@SQ\tSN:APMT01229791.1\tLN:2618\n@SQ\tSN:APMT01229796.1\tLN:2618\n@SQ\tSN:KB714028.1\tLN:2617\n@SQ\tSN:APMT01229250.1\tLN:2617\n@SQ\tSN:APMT01229567.1\tLN:2617\n@SQ\tSN:KB714086.1\tLN:2616\n@SQ\tSN:KB714145.1\tLN:2616\n@SQ\tSN:APMT01229465.1\tLN:2616\n@SQ\tSN:APMT01229574.1\tLN:2616\n@SQ\tSN:APMT01229788.1\tLN:2616\n@SQ\tSN:APMT01229802.1\tLN:2616\n@SQ\tSN:APMT01229803.1\tLN:2616\n@SQ\tSN:APMT01229807.1\tLN:2615\n@SQ\tSN:APMT01229808.1\tLN:2615\n@SQ\tSN:KB714284.1\tLN:2614\n@SQ\tSN:APMT01229815.1\tLN:2614\n@SQ\tSN:APMT01229818.1\tLN:2614\n@SQ\tSN:APMT01229821.1\tLN:2614\n@SQ\tSN:APMT01229575.1\tLN:2613\n@SQ\tSN:APMT01229824.1\tLN:2613\n@SQ\tSN:KB714051.1\tLN:2612\n@SQ\tSN:APMT01229825.1\tLN:2612\n@SQ\tSN:APMT01229826.1\tLN:2612\n@SQ\tSN:APMT01229827.1\tLN:2612\n@SQ\tSN:APMT01229828.1\tLN:2612\n@SQ\tSN:KB714185.1\tLN:2611\n@SQ\tSN:APMT01229801.1\tLN:2610\n@SQ\tSN:APMT01229836.1\tLN:2610\n@SQ\tSN:APMT01229837.1\tLN:2610\n@SQ\tSN:APMT01229838.1\tLN:2610\n@SQ\tSN:APMT01229839.1\tLN:2610\n@SQ\tSN:KB714237.1\tLN:2608\n@SQ\tSN:APMT01229840.1\tLN:2608\n@SQ\tSN:APMT01229844.1\tLN:2608\n@SQ\tSN:APMT01229554.1\tLN:2607\n@SQ\tSN:KB714248.1\tLN:2607\n@SQ\tSN:APMT01229738.1\tLN:2607\n@SQ\tSN:KB714276.1\tLN:2607\n@SQ\tSN:APMT01229845.1\tLN:2607\n@SQ\tSN:APMT01229846.1\tLN:2607\n@SQ\tSN:APMT01229849.1\tLN:2607\n@SQ\tSN:APMT01229851.1\tLN:2607\n@SQ\tSN:KB714234.1\tLN:2605\n@SQ\tSN:APMT01229858.1\tLN:2605\n@SQ\tSN:APMT01229859.1\tLN:2605\n@SQ\tSN:APMT01229860.1\tLN:2605\n@SQ\tSN:APMT01229578.1\tLN:2604\n@SQ\tSN:APMT01229596.1\tLN:2604\n@SQ\tSN:APMT01229830.1\tLN:2604\n@SQ\tSN:APMT01229861.1\tLN:2604\n@SQ\tSN:KB714136.1\tLN:2603\n@SQ\tSN:APMT01229789.1\tLN:2603\n@SQ\tSN:APMT01229806.1\tLN:2603\n@SQ\tSN:APMT01229809.1\tLN:2602\n@SQ\tSN:KB714292.1\tLN:2602\n@SQ\tSN:APMT01229850.1\tLN:2602\n@SQ\tSN:APMT01229866.1\tLN:2602\n@SQ\tSN:APMT01229871.1\tLN:2602\n@SQ\tSN:APMT01229875.1\tLN:2602\n@SQ\tSN:APMT01229761.1\tLN:2601\n@SQ\tSN:KB714092.1\tLN:2600\n@SQ\tSN:KB714187.1\tLN:2600\n@SQ\tSN:APMT01229874.1\tLN:2600\n@SQ\tSN:APMT01229882.1\tLN:2600\n@SQ\tSN:APMT01229883.1\tLN:2600\n@SQ\tSN:APMT01229886.1\tLN:2600\n@SQ\tSN:APMT01229887.1\tLN:2600\n@SQ\tSN:APMT01229897.1\tLN:2600\n@SQ\tSN:APMT01229894.1\tLN:2599\n@SQ\tSN:KB713336.1\tLN:2598\n@SQ\tSN:KB714194.1\tLN:2598\n@SQ\tSN:APMT01229899.1\tLN:2598\n@SQ\tSN:APMT01229902.1\tLN:2598\n@SQ\tSN:APMT01229629.1\tLN:2597\n@SQ\tSN:APMT01229632.1\tLN:2597\n@SQ\tSN:APMT01229904.1\tLN:2597\n@SQ\tSN:APMT01229907.1\tLN:2597\n@SQ\tSN:APMT01229908.1\tLN:2597\n@SQ\tSN:APMT01229901.1\tLN:2596\n@SQ\tSN:APMT01229909.1\tLN:2596\n@SQ\tSN:APMT01229911.1\tLN:2596\n@SQ\tSN:APMT01229920.1\tLN:2596\n@SQ\tSN:KB714193.1\tLN:2595\n@SQ\tSN:KB714212.1\tLN:2595\n@SQ\tSN:APMT01229580.1\tLN:2595\n@SQ\tSN:APMT01229653.1\tLN:2595\n@SQ\tSN:APMT01229914.1\tLN:2595\n@SQ\tSN:APMT01229915.1\tLN:2595\n@SQ\tSN:APMT01229917.1\tLN:2595\n@SQ\tSN:APMT01229922.1\tLN:2595\n@SQ\tSN:KB713856.1\tLN:2594\n@SQ\tSN:APMT01229650.1\tLN:2594\n@SQ\tSN:APMT01229921.1\tLN:2594\n@SQ\tSN:APMT01229923.1\tLN:2594\n@SQ\tSN:KB714321.1\tLN:2594\n@SQ\tSN:APMT01230075.1\tLN:2594\n@SQ\tSN:APMT01229670.1\tLN:2593\n@SQ\tSN:APMT01229833.1\tLN:2593\n@SQ\tSN:APMT01229933.1\tLN:2593\n@SQ\tSN:APMT01229934.1\tLN:2593\n@SQ\tSN:KB713968.1\tLN:2592\n@SQ\tSN:APMT01229937.1\tLN:2592\n@SQ\tSN:APMT01229942.1\tLN:2592\n@SQ\tSN:KB713841.1\tLN:2591\n@SQ\tSN:KB714155.1\tLN:2591\n@SQ\tSN:APMT01229261.1\tLN:2590\n@SQ\tSN:APMT01229945.1\tLN:2590\n@SQ\tSN:APMT01229946.1\tLN:2590\n@SQ\tSN:KB714116.1\tLN:2589\n@SQ\tSN:KB714290.1\tLN:2589\n@SQ\tSN:APMT01229648.1\tLN:2588\n@SQ\tSN:APMT01229779.1\tLN:2588\n@SQ\tSN:APMT01229900.1\tLN:2588\n@SQ\tSN:APMT01229955.1\tLN:2588\n@SQ\tSN:APMT01229956.1\tLN:2588\n@SQ\tSN:APMT01229957.1\tLN:2588\n@SQ\tSN:APMT01229960.1\tLN:2587\n@SQ\tSN:APMT01229961.1\tLN:2586\n@SQ\tSN:APMT01230013.1\tLN:2586\n@SQ\tSN:APMT01229965.1\tLN:2585\n@SQ\tSN:APMT01229968.1\tLN:2584\n@SQ\tSN:APMT01229884.1\tLN:2583\n@SQ\tSN:APMT01229974.1\tLN:2583\n@SQ\tSN:APMT01229379.1\tLN:2582\n@SQ\tSN:KB714306.1\tLN:2582\n@SQ\tSN:APMT01229976.1\tLN:2582\n@SQ\tSN:APMT01229980.1\tLN:2581\n@SQ\tSN:KB713842.1\tLN:2580\n@SQ\tSN:APMT01229983.1\tLN:2580\n@SQ\tSN:KB713361.1\tLN:2579\n@SQ\tSN:APMT01229910.1\tLN:2579\n@SQ\tSN:APMT01229984.1\tLN:2579\n@SQ\tSN:APMT01229985.1\tLN:2579\n@SQ\tSN:APMT01229986.1\tLN:2579\n@SQ\tSN:APMT01229989.1\tLN:2579\n@SQ\tSN:KB714257.1\tLN:2578\n@SQ\tSN:APMT01229979.1\tLN:2578\n@SQ\tSN:APMT01229990.1\tLN:2578\n@SQ\tSN:APMT01229991.1\tLN:2578\n@SQ\tSN:APMT01229992.1\tLN:2578\n@SQ\tSN:KB714162.1\tLN:2577\n@SQ\tSN:APMT01229994.1\tLN:2577\n@SQ\tSN:APMT01229995.1\tLN:2577\n@SQ\tSN:KB714114.1\tLN:2576\n@SQ\tSN:APMT01229081.1\tLN:2576\n@SQ\tSN:KB714251.1\tLN:2576\n@SQ\tSN:KB714236.1\tLN:2575\n@SQ\tSN:APMT01229702.1\tLN:2575\n@SQ\tSN:APMT01229716.1\tLN:2575\n@SQ\tSN:APMT01229841.1\tLN:2575\n@SQ\tSN:APMT01230001.1\tLN:2575\n@SQ\tSN:KB711664.1\tLN:2574\n@SQ\tSN:KB714055.1\tLN:2574\n@SQ\tSN:APMT01229711.1\tLN:2574\n@SQ\tSN:APMT01229713.1\tLN:2574\n@SQ\tSN:APMT01229735.1\tLN:2574\n@SQ\tSN:APMT01230007.1\tLN:2574\n@SQ\tSN:KB714349.1\tLN:2574\n@SQ\tSN:APMT01230180.1\tLN:2574\n@SQ\tSN:KB714423.1\tLN:2574\n@SQ\tSN:APMT01229988.1\tLN:2573\n@SQ\tSN:APMT01230012.1\tLN:2573\n@SQ\tSN:APMT01229756.1\tLN:2572\n@SQ\tSN:APMT01230014.1\tLN:2572\n@SQ\tSN:APMT01230015.1\tLN:2572\n@SQ\tSN:APMT01230016.1\tLN:2572\n@SQ\tSN:APMT01230017.1\tLN:2572\n@SQ\tSN:KB712429.1\tLN:2571\n@SQ\tSN:KB714013.1\tLN:2571\n@SQ\tSN:KB714128.1\tLN:2571\n@SQ\tSN:APMT01229724.1\tLN:2571\n@SQ\tSN:APMT01229780.1\tLN:2571\n@SQ\tSN:APMT01230022.1\tLN:2571\n@SQ\tSN:APMT01229745.1\tLN:2570\n@SQ\tSN:APMT01229193.1\tLN:2569\n@SQ\tSN:APMT01229610.1\tLN:2569\n@SQ\tSN:KB714316.1\tLN:2569\n@SQ\tSN:APMT01230025.1\tLN:2569\n@SQ\tSN:APMT01230029.1\tLN:2569\n@SQ\tSN:KB712923.1\tLN:2568\n@SQ\tSN:APMT01229996.1\tLN:2568\n@SQ\tSN:APMT01230002.1\tLN:2568\n@SQ\tSN:APMT01230031.1\tLN:2568\n@SQ\tSN:APMT01230032.1\tLN:2568\n@SQ\tSN:KB714293.1\tLN:2567\n@SQ\tSN:KB713896.1\tLN:2566\n@SQ\tSN:KB714259.1\tLN:2566\n@SQ\tSN:APMT01229755.1\tLN:2566\n@SQ\tSN:APMT01230037.1\tLN:2566\n@SQ\tSN:APMT01230040.1\tLN:2565\n@SQ\tSN:APMT01230041.1\tLN:2565\n@SQ\tSN:KB714022.1\tLN:2564\n@SQ\tSN:APMT01230050.1\tLN:2564\n@SQ\tSN:APMT01230057.1\tLN:2564\n@SQ\tSN:APMT01230058.1\tLN:2564\n@SQ\tSN:KB714243.1\tLN:2563\n@SQ\tSN:APMT01230183.1\tLN:2563\n@SQ\tSN:APMT01229552.1\tLN:2562\n@SQ\tSN:APMT01229786.1\tLN:2562\n@SQ\tSN:APMT01230062.1\tLN:2562\n@SQ\tSN:APMT01230063.1\tLN:2562\n@SQ\tSN:APMT01230064.1\tLN:2562\n@SQ\tSN:APMT01230065.1\tLN:2562\n@SQ\tSN:KB714459.1\tLN:2562\n@SQ\tSN:KB714176.1\tLN:2561\n@SQ\tSN:APMT01229718.1\tLN:2561\n@SQ\tSN:APMT01230068.1\tLN:2561\n@SQ\tSN:APMT01230069.1\tLN:2561\n@SQ\tSN:APMT01230070.1\tLN:2561\n@SQ\tSN:APMT01230071.1\tLN:2561\n@SQ\tSN:APMT01230072.1\tLN:2561\n@SQ\tSN:KB714247.1\tLN:2560\n@SQ\tSN:APMT01229669.1\tLN:2560\n@SQ\tSN:APMT01229829.1\tLN:2560\n@SQ\tSN:APMT01229958.1\tLN:2560\n@SQ\tSN:APMT01230076.1\tLN:2560\n@SQ\tSN:APMT01230080.1\tLN:2560\n@SQ\tSN:APMT01229766.1\tLN:2559\n@SQ\tSN:APMT01229782.1\tLN:2559\n@SQ\tSN:APMT01229885.1\tLN:2559\n@SQ\tSN:APMT01230081.1\tLN:2559\n@SQ\tSN:APMT01230083.1\tLN:2559\n@SQ\tSN:APMT01230085.1\tLN:2559\n@SQ\tSN:APMT01230086.1\tLN:2559\n@SQ\tSN:APMT01230131.1\tLN:2559\n@SQ\tSN:APMT01229249.1\tLN:2558\n@SQ\tSN:APMT01229769.1\tLN:2558\n@SQ\tSN:APMT01229800.1\tLN:2558\n@SQ\tSN:KB714308.1\tLN:2558\n@SQ\tSN:APMT01229797.1\tLN:2557\n@SQ\tSN:APMT01229898.1\tLN:2557\n@SQ\tSN:KB714329.1\tLN:2557\n@SQ\tSN:APMT01229733.1\tLN:2556\n@SQ\tSN:APMT01230091.1\tLN:2556\n@SQ\tSN:KB713972.1\tLN:2555\n@SQ\tSN:APMT01230000.1\tLN:2555\n@SQ\tSN:KB714115.1\tLN:2554\n@SQ\tSN:APMT01229810.1\tLN:2554\n@SQ\tSN:APMT01230102.1\tLN:2554\n@SQ\tSN:KB714046.1\tLN:2553\n@SQ\tSN:APMT01230098.1\tLN:2553\n@SQ\tSN:APMT01230099.1\tLN:2553\n@SQ\tSN:KB714386.1\tLN:2553\n@SQ\tSN:KB713771.1\tLN:2552\n@SQ\tSN:APMT01229778.1\tLN:2552\n@SQ\tSN:APMT01230101.1\tLN:2552\n@SQ\tSN:KB711000.1\tLN:2551\n@SQ\tSN:APMT01230096.1\tLN:2551\n@SQ\tSN:APMT01230097.1\tLN:2551\n@SQ\tSN:APMT01230103.1\tLN:2551\n@SQ\tSN:APMT01230105.1\tLN:2551\n@SQ\tSN:APMT01229938.1\tLN:2550\n@SQ\tSN:APMT01230106.1\tLN:2550\n@SQ\tSN:APMT01230107.1\tLN:2550\n@SQ\tSN:APMT01230108.1\tLN:2550\n@SQ\tSN:APMT01230109.1\tLN:2550\n@SQ\tSN:APMT01228881.1\tLN:2549\n@SQ\tSN:KB714305.1\tLN:2549\n@SQ\tSN:APMT01230079.1\tLN:2549\n@SQ\tSN:APMT01230112.1\tLN:2549\n@SQ\tSN:APMT01230114.1\tLN:2549\n@SQ\tSN:APMT01230115.1\tLN:2549\n@SQ\tSN:APMT01230116.1\tLN:2549\n@SQ\tSN:KB714270.1\tLN:2548\n@SQ\tSN:APMT01230059.1\tLN:2548\n@SQ\tSN:APMT01230100.1\tLN:2548\n@SQ\tSN:APMT01230117.1\tLN:2548\n@SQ\tSN:APMT01229510.1\tLN:2547\n@SQ\tSN:APMT01230120.1\tLN:2547\n@SQ\tSN:APMT01230122.1\tLN:2547\n@SQ\tSN:KB714170.1\tLN:2546\n@SQ\tSN:APMT01230088.1\tLN:2546\n@SQ\tSN:APMT01230124.1\tLN:2546\n@SQ\tSN:APMT01230129.1\tLN:2546\n@SQ\tSN:APMT01230130.1\tLN:2546\n@SQ\tSN:KB713895.1\tLN:2545\n@SQ\tSN:APMT01230133.1\tLN:2545\n@SQ\tSN:APMT01230134.1\tLN:2545\n@SQ\tSN:KB714104.1\tLN:2544\n@SQ\tSN:APMT01230139.1\tLN:2544\n@SQ\tSN:APMT01230140.1\tLN:2544\n@SQ\tSN:APMT01230141.1\tLN:2544\n@SQ\tSN:KB714296.1\tLN:2543\n@SQ\tSN:APMT01229862.1\tLN:2543\n@SQ\tSN:APMT01229997.1\tLN:2543\n@SQ\tSN:KB714334.1\tLN:2543\n@SQ\tSN:APMT01230125.1\tLN:2543\n@SQ\tSN:APMT01230132.1\tLN:2543\n@SQ\tSN:APMT01230142.1\tLN:2543\n@SQ\tSN:APMT01230145.1\tLN:2543\n@SQ\tSN:APMT01230146.1\tLN:2543\n@SQ\tSN:APMT01230148.1\tLN:2543\n@SQ\tSN:KB713517.1\tLN:2542\n@SQ\tSN:APMT01229930.1\tLN:2542\n@SQ\tSN:APMT01230147.1\tLN:2542\n@SQ\tSN:APMT01230178.1\tLN:2542\n@SQ\tSN:KB714245.1\tLN:2541\n@SQ\tSN:APMT01230150.1\tLN:2541\n@SQ\tSN:KB714252.1\tLN:2540\n@SQ\tSN:KB714277.1\tLN:2540\n@SQ\tSN:KB714288.1\tLN:2540\n@SQ\tSN:KB714295.1\tLN:2540\n@SQ\tSN:APMT01230149.1\tLN:2540\n@SQ\tSN:APMT01230152.1\tLN:2540\n@SQ\tSN:APMT01230158.1\tLN:2540\n@SQ\tSN:APMT01230221.1\tLN:2540\n@SQ\tSN:APMT01229964.1\tLN:2539\n@SQ\tSN:KB713285.1\tLN:2537\n@SQ\tSN:KB714015.1\tLN:2537\n@SQ\tSN:KB714213.1\tLN:2537\n@SQ\tSN:KB714255.1\tLN:2537\n@SQ\tSN:APMT01230165.1\tLN:2537\n@SQ\tSN:APMT01230170.1\tLN:2536\n@SQ\tSN:KB714173.1\tLN:2535\n@SQ\tSN:KB714278.1\tLN:2535\n@SQ\tSN:APMT01229981.1\tLN:2535\n@SQ\tSN:APMT01230173.1\tLN:2535\n@SQ\tSN:APMT01230179.1\tLN:2535\n@SQ\tSN:KB714340.1\tLN:2534\n@SQ\tSN:KB714184.1\tLN:2533\n@SQ\tSN:APMT01230191.1\tLN:2532\n@SQ\tSN:APMT01229555.1\tLN:2531\n@SQ\tSN:APMT01230190.1\tLN:2531\n@SQ\tSN:APMT01230192.1\tLN:2531\n@SQ\tSN:KB711811.1\tLN:2530\n@SQ\tSN:APMT01229975.1\tLN:2530\n@SQ\tSN:APMT01230198.1\tLN:2529\n@SQ\tSN:KB714337.1\tLN:2528\n@SQ\tSN:KB714281.1\tLN:2527\n@SQ\tSN:APMT01230205.1\tLN:2527\n@SQ\tSN:APMT01230199.1\tLN:2526\n@SQ\tSN:KB712263.1\tLN:2525\n@SQ\tSN:KB713225.1\tLN:2525\n@SQ\tSN:KB714273.1\tLN:2525\n@SQ\tSN:APMT01230206.1\tLN:2525\n@SQ\tSN:APMT01230212.1\tLN:2525\n@SQ\tSN:KB712529.1\tLN:2524\n@SQ\tSN:KB714346.1\tLN:2524\n@SQ\tSN:APMT01230214.1\tLN:2524\n@SQ\tSN:APMT01230215.1\tLN:2524\n@SQ\tSN:APMT01230216.1\tLN:2524\n@SQ\tSN:APMT01229969.1\tLN:2523\n@SQ\tSN:APMT01230028.1\tLN:2523\n@SQ\tSN:APMT01230219.1\tLN:2523\n@SQ\tSN:APMT01230220.1\tLN:2523\n@SQ\tSN:APMT01230222.1\tLN:2523\n@SQ\tSN:APMT01230606.1\tLN:2523\n@SQ\tSN:KB714214.1\tLN:2522\n@SQ\tSN:APMT01230226.1\tLN:2522\n@SQ\tSN:APMT01230209.1\tLN:2521\n@SQ\tSN:APMT01230225.1\tLN:2521\n@SQ\tSN:APMT01230228.1\tLN:2521\n@SQ\tSN:APMT01230231.1\tLN:2521\n@SQ\tSN:KB714539.1\tLN:2521\n@SQ\tSN:KB714299.1\tLN:2520\n@SQ\tSN:APMT01229863.1\tLN:2520\n@SQ\tSN:APMT01229987.1\tLN:2520\n@SQ\tSN:APMT01230046.1\tLN:2520\n@SQ\tSN:APMT01230615.1\tLN:2520\n@SQ\tSN:KB711048.1\tLN:2519\n@SQ\tSN:APMT01230237.1\tLN:2519\n@SQ\tSN:APMT01230238.1\tLN:2519\n@SQ\tSN:KB714304.1\tLN:2518\n@SQ\tSN:APMT01230240.1\tLN:2518\n@SQ\tSN:APMT01230241.1\tLN:2518\n@SQ\tSN:KB713886.1\tLN:2517\n@SQ\tSN:APMT01230239.1\tLN:2517\n@SQ\tSN:APMT01230242.1\tLN:2517\n@SQ\tSN:KB714014.1\tLN:2516\n@SQ\tSN:APMT01229697.1\tLN:2516\n@SQ\tSN:APMT01229993.1\tLN:2516\n@SQ\tSN:APMT01230047.1\tLN:2516\n@SQ\tSN:APMT01230196.1\tLN:2516\n@SQ\tSN:APMT01230227.1\tLN:2516\n@SQ\tSN:APMT01230243.1\tLN:2516\n@SQ\tSN:KB714225.1\tLN:2515\n@SQ\tSN:APMT01230082.1\tLN:2515\n@SQ\tSN:APMT01230245.1\tLN:2515\n@SQ\tSN:APMT01230246.1\tLN:2515\n@SQ\tSN:APMT01230247.1\tLN:2515\n@SQ\tSN:APMT01230250.1\tLN:2515\n@SQ\tSN:APMT01230234.1\tLN:2514\n@SQ\tSN:APMT01230251.1\tLN:2514\n@SQ\tSN:APMT01230252.1\tLN:2514\n@SQ\tSN:APMT01230253.1\tLN:2513\n@SQ\tSN:APMT01230256.1\tLN:2513\n@SQ\tSN:APMT01230257.1\tLN:2513\n@SQ\tSN:KB712065.1\tLN:2511\n@SQ\tSN:KB714256.1\tLN:2511\n@SQ\tSN:KB714265.1\tLN:2511\n@SQ\tSN:APMT01230259.1\tLN:2511\n@SQ\tSN:KB712154.1\tLN:2510\n@SQ\tSN:APMT01230258.1\tLN:2510\n@SQ\tSN:APMT01230262.1\tLN:2510\n@SQ\tSN:APMT01230263.1\tLN:2510\n@SQ\tSN:KB713318.1\tLN:2509\n@SQ\tSN:KB714454.1\tLN:2509\n@SQ\tSN:APMT01230264.1\tLN:2508\n@SQ\tSN:APMT01230267.1\tLN:2508\n@SQ\tSN:APMT01230268.1\tLN:2508\n@SQ\tSN:APMT01230272.1\tLN:2508\n@SQ\tSN:KB714333.1\tLN:2507\n@SQ\tSN:APMT01230273.1\tLN:2507\n@SQ\tSN:APMT01230275.1\tLN:2507\n@SQ\tSN:KB713944.1\tLN:2506\n@SQ\tSN:KB714339.1\tLN:2506\n@SQ\tSN:APMT01230163.1\tLN:2506\n@SQ\tSN:KB714510.1\tLN:2506\n@SQ\tSN:KB714291.1\tLN:2505\n@SQ\tSN:APMT01230254.1\tLN:2505\n@SQ\tSN:APMT01230284.1\tLN:2505\n@SQ\tSN:APMT01230285.1\tLN:2505\n@SQ\tSN:KB714380.1\tLN:2504\n@SQ\tSN:APMT01230286.1\tLN:2504\n@SQ\tSN:APMT01230287.1\tLN:2504\n@SQ\tSN:APMT01230236.1\tLN:2503\n@SQ\tSN:APMT01230281.1\tLN:2503\n@SQ\tSN:APMT01230289.1\tLN:2503\n@SQ\tSN:APMT01230290.1\tLN:2503\n@SQ\tSN:APMT01230271.1\tLN:2502\n@SQ\tSN:APMT01230294.1\tLN:2502\n@SQ\tSN:APMT01229763.1\tLN:2501\n@SQ\tSN:KB714345.1\tLN:2501\n@SQ\tSN:APMT01230297.1\tLN:2501\n@SQ\tSN:APMT01230298.1\tLN:2501\n@SQ\tSN:APMT01230018.1\tLN:2500\n@SQ\tSN:APMT01230299.1\tLN:2500\n@SQ\tSN:APMT01230300.1\tLN:2500\n@SQ\tSN:APMT01230293.1\tLN:2499\n@SQ\tSN:APMT01227410.1\tLN:2498\n@SQ\tSN:KB714341.1\tLN:2498\n@SQ\tSN:APMT01230084.1\tLN:2498\n@SQ\tSN:APMT01230113.1\tLN:2498\n@SQ\tSN:APMT01230306.1\tLN:2497\n@SQ\tSN:APMT01230307.1\tLN:2497\n@SQ\tSN:APMT01230308.1\tLN:2497\n@SQ\tSN:KB714254.1\tLN:2496\n@SQ\tSN:KB714335.1\tLN:2496\n@SQ\tSN:APMT01230312.1\tLN:2496\n@SQ\tSN:APMT01230313.1\tLN:2496\n@SQ\tSN:APMT01230317.1\tLN:2496\n@SQ\tSN:APMT01230318.1\tLN:2496\n@SQ\tSN:APMT01229362.1\tLN:2495\n@SQ\tSN:APMT01230274.1\tLN:2495\n@SQ\tSN:APMT01230319.1\tLN:2495\n@SQ\tSN:APMT01230321.1\tLN:2495\n@SQ\tSN:KB714154.1\tLN:2494\n@SQ\tSN:KB713371.1\tLN:2493\n@SQ\tSN:APMT01230327.1\tLN:2493\n@SQ\tSN:KB714307.1\tLN:2492\n@SQ\tSN:KB714338.1\tLN:2492\n@SQ\tSN:APMT01230104.1\tLN:2492\n@SQ\tSN:APMT01229903.1\tLN:2491\n@SQ\tSN:APMT01230135.1\tLN:2491\n@SQ\tSN:APMT01230331.1\tLN:2491\n@SQ\tSN:KB714377.1\tLN:2490\n@SQ\tSN:APMT01230334.1\tLN:2490\n@SQ\tSN:KB714240.1\tLN:2489\n@SQ\tSN:KB714274.1\tLN:2489\n@SQ\tSN:KB714327.1\tLN:2489\n@SQ\tSN:APMT01230136.1\tLN:2489\n@SQ\tSN:APMT01230336.1\tLN:2489\n@SQ\tSN:APMT01230337.1\tLN:2489\n@SQ\tSN:APMT01230338.1\tLN:2489\n@SQ\tSN:APMT01230123.1\tLN:2488\n@SQ\tSN:APMT01230224.1\tLN:2488\n@SQ\tSN:APMT01230343.1\tLN:2488\n@SQ\tSN:KB712192.1\tLN:2487\n@SQ\tSN:KB714323.1\tLN:2487\n@SQ\tSN:APMT01230197.1\tLN:2487\n@SQ\tSN:APMT01230344.1\tLN:2487\n@SQ\tSN:KB714410.1\tLN:2487\n@SQ\tSN:KB713962.1\tLN:2486\n@SQ\tSN:APMT01230347.1\tLN:2486\n@SQ\tSN:APMT01230348.1\tLN:2486\n@SQ\tSN:APMT01230351.1\tLN:2486\n@SQ\tSN:APMT01230223.1\tLN:2485\n@SQ\tSN:APMT01230354.1\tLN:2485\n@SQ\tSN:APMT01230357.1\tLN:2485\n@SQ\tSN:KB714450.1\tLN:2485\n@SQ\tSN:APMT01230361.1\tLN:2484\n@SQ\tSN:KB714210.1\tLN:2482\n@SQ\tSN:APMT01230369.1\tLN:2482\n@SQ\tSN:KB714353.1\tLN:2481\n@SQ\tSN:APMT01230121.1\tLN:2481\n@SQ\tSN:KB714368.1\tLN:2481\n@SQ\tSN:APMT01230372.1\tLN:2481\n@SQ\tSN:APMT01230380.1\tLN:2481\n@SQ\tSN:APMT01229939.1\tLN:2480\n@SQ\tSN:APMT01230202.1\tLN:2480\n@SQ\tSN:APMT01230378.1\tLN:2480\n@SQ\tSN:APMT01230164.1\tLN:2479\n@SQ\tSN:APMT01230508.1\tLN:2479\n@SQ\tSN:APMT01230261.1\tLN:2477\n@SQ\tSN:APMT01230375.1\tLN:2477\n@SQ\tSN:APMT01230381.1\tLN:2477\n@SQ\tSN:APMT01230384.1\tLN:2477\n@SQ\tSN:APMT01230385.1\tLN:2477\n@SQ\tSN:APMT01230386.1\tLN:2477\n@SQ\tSN:APMT01230387.1\tLN:2477\n@SQ\tSN:KB714350.1\tLN:2476\n@SQ\tSN:APMT01230266.1\tLN:2476\n@SQ\tSN:APMT01230391.1\tLN:2476\n@SQ\tSN:APMT01230392.1\tLN:2476\n@SQ\tSN:APMT01230398.1\tLN:2476\n@SQ\tSN:APMT01230399.1\tLN:2476\n@SQ\tSN:APMT01230400.1\tLN:2476\n@SQ\tSN:KB714215.1\tLN:2475\n@SQ\tSN:KB714354.1\tLN:2475\n@SQ\tSN:KB714369.1\tLN:2475\n@SQ\tSN:APMT01230255.1\tLN:2475\n@SQ\tSN:APMT01230340.1\tLN:2475\n@SQ\tSN:APMT01230401.1\tLN:2475\n@SQ\tSN:APMT01230402.1\tLN:2475\n@SQ\tSN:APMT01230403.1\tLN:2475\n@SQ\tSN:APMT01230404.1\tLN:2475\n@SQ\tSN:APMT01230407.1\tLN:2475\n@SQ\tSN:APMT01230408.1\tLN:2474\n@SQ\tSN:APMT01230279.1\tLN:2473\n@SQ\tSN:APMT01230397.1\tLN:2473\n@SQ\tSN:KB714449.1\tLN:2473\n@SQ\tSN:APMT01230412.1\tLN:2472\n@SQ\tSN:APMT01230613.1\tLN:2472\n@SQ\tSN:APMT01230415.1\tLN:2471\n@SQ\tSN:APMT01230417.1\tLN:2471\n@SQ\tSN:APMT01230416.1\tLN:2470\n@SQ\tSN:APMT01230420.1\tLN:2470\n@SQ\tSN:KB714198.1\tLN:2469\n@SQ\tSN:KB714342.1\tLN:2469\n@SQ\tSN:APMT01230426.1\tLN:2469\n@SQ\tSN:APMT01230427.1\tLN:2469\n@SQ\tSN:APMT01230429.1\tLN:2468\n@SQ\tSN:APMT01230430.1\tLN:2468\n@SQ\tSN:APMT01230431.1\tLN:2468\n@SQ\tSN:APMT01230432.1\tLN:2468\n@SQ\tSN:APMT01230265.1\tLN:2467\n@SQ\tSN:APMT01230370.1\tLN:2467\n@SQ\tSN:KB714365.1\tLN:2466\n@SQ\tSN:APMT01230428.1\tLN:2466\n@SQ\tSN:APMT01230434.1\tLN:2466\n@SQ\tSN:APMT01230435.1\tLN:2466\n@SQ\tSN:APMT01230436.1\tLN:2466\n@SQ\tSN:APMT01230438.1\tLN:2466\n@SQ\tSN:KB714318.1\tLN:2465\n@SQ\tSN:APMT01230193.1\tLN:2465\n@SQ\tSN:APMT01230442.1\tLN:2465\n@SQ\tSN:APMT01230443.1\tLN:2465\n@SQ\tSN:KB714269.1\tLN:2464\n@SQ\tSN:APMT01230446.1\tLN:2464\n@SQ\tSN:APMT01230448.1\tLN:2463\n@SQ\tSN:APMT01230451.1\tLN:2463\n@SQ\tSN:APMT01230453.1\tLN:2462\n@SQ\tSN:KB714310.1\tLN:2461\n@SQ\tSN:KB714355.1\tLN:2461\n@SQ\tSN:APMT01230151.1\tLN:2461\n@SQ\tSN:APMT01230456.1\tLN:2461\n@SQ\tSN:APMT01230457.1\tLN:2461\n@SQ\tSN:APMT01230458.1\tLN:2460\n@SQ\tSN:APMT01230463.1\tLN:2460\n@SQ\tSN:APMT01231416.1\tLN:2460\n@SQ\tSN:KB714242.1\tLN:2459\n@SQ\tSN:APMT01230235.1\tLN:2459\n@SQ\tSN:APMT01230464.1\tLN:2459\n@SQ\tSN:APMT01230465.1\tLN:2459\n@SQ\tSN:APMT01230466.1\tLN:2459\n@SQ\tSN:APMT01229345.1\tLN:2458\n@SQ\tSN:APMT01230376.1\tLN:2458\n@SQ\tSN:APMT01230470.1\tLN:2458\n@SQ\tSN:KB714203.1\tLN:2456\n@SQ\tSN:KB714352.1\tLN:2456\n@SQ\tSN:APMT01230472.1\tLN:2456\n@SQ\tSN:APMT01230475.1\tLN:2456\n@SQ\tSN:KB714336.1\tLN:2455\n@SQ\tSN:APMT01230476.1\tLN:2455\n@SQ\tSN:APMT01230479.1\tLN:2455\n@SQ\tSN:APMT01230480.1\tLN:2455\n@SQ\tSN:APMT01230326.1\tLN:2454\n@SQ\tSN:APMT01230481.1\tLN:2454\n@SQ\tSN:KB713829.1\tLN:2453\n@SQ\tSN:KB714182.1\tLN:2453\n@SQ\tSN:APMT01230244.1\tLN:2453\n@SQ\tSN:KB714396.1\tLN:2453\n@SQ\tSN:APMT01230491.1\tLN:2453\n@SQ\tSN:APMT01230532.1\tLN:2453\n@SQ\tSN:APMT01230646.1\tLN:2453\n@SQ\tSN:APMT01230471.1\tLN:2452\n@SQ\tSN:APMT01230488.1\tLN:2452\n@SQ\tSN:APMT01230494.1\tLN:2452\n@SQ\tSN:APMT01230495.1\tLN:2452\n@SQ\tSN:APMT01230499.1\tLN:2451\n@SQ\tSN:APMT01230500.1\tLN:2451\n@SQ\tSN:APMT01230501.1\tLN:2451\n@SQ\tSN:APMT01230502.1\tLN:2451\n@SQ\tSN:KB713626.1\tLN:2450\n@SQ\tSN:APMT01228694.1\tLN:2450\n@SQ\tSN:APMT01230213.1\tLN:2450\n@SQ\tSN:APMT01230506.1\tLN:2450\n@SQ\tSN:APMT01230507.1\tLN:2450\n@SQ\tSN:KB711528.1\tLN:2449\n@SQ\tSN:APMT01230277.1\tLN:2449\n@SQ\tSN:APMT01230511.1\tLN:2449\n@SQ\tSN:APMT01230514.1\tLN:2449\n@SQ\tSN:APMT01230515.1\tLN:2449\n@SQ\tSN:APMT01230516.1\tLN:2449\n@SQ\tSN:KB713964.1\tLN:2448\n@SQ\tSN:KB714397.1\tLN:2448\n@SQ\tSN:APMT01230517.1\tLN:2448\n@SQ\tSN:APMT01230519.1\tLN:2448\n@SQ\tSN:APMT01230520.1\tLN:2448\n@SQ\tSN:APMT01230521.1\tLN:2448\n@SQ\tSN:APMT01230522.1\tLN:2448\n@SQ\tSN:KB712034.1\tLN:2447\n@SQ\tSN:APMT01230276.1\tLN:2447\n@SQ\tSN:APMT01230339.1\tLN:2447\n@SQ\tSN:APMT01230360.1\tLN:2447\n@SQ\tSN:APMT01230523.1\tLN:2447\n@SQ\tSN:APMT01230526.1\tLN:2447\n@SQ\tSN:KB714472.1\tLN:2447\n@SQ\tSN:KB713906.1\tLN:2446\n@SQ\tSN:APMT01230288.1\tLN:2446\n@SQ\tSN:APMT01230441.1\tLN:2446\n@SQ\tSN:APMT01230527.1\tLN:2446\n@SQ\tSN:APMT01230528.1\tLN:2446\n@SQ\tSN:KB713969.1\tLN:2445\n@SQ\tSN:KB714076.1\tLN:2445\n@SQ\tSN:APMT01230531.1\tLN:2445\n@SQ\tSN:APMT01230533.1\tLN:2445\n@SQ\tSN:APMT01230536.1\tLN:2445\n@SQ\tSN:KB714005.1\tLN:2444\n@SQ\tSN:KB714366.1\tLN:2444\n@SQ\tSN:APMT01230537.1\tLN:2444\n@SQ\tSN:APMT01230538.1\tLN:2444\n@SQ\tSN:APMT01230539.1\tLN:2444\n@SQ\tSN:APMT01230541.1\tLN:2444\n@SQ\tSN:APMT01230518.1\tLN:2443\n@SQ\tSN:APMT01230544.1\tLN:2443\n@SQ\tSN:KB713026.1\tLN:2442\n@SQ\tSN:KB713929.1\tLN:2442\n@SQ\tSN:APMT01230547.1\tLN:2442\n@SQ\tSN:APMT01230548.1\tLN:2442\n@SQ\tSN:APMT01230549.1\tLN:2442\n@SQ\tSN:APMT01230550.1\tLN:2442\n@SQ\tSN:KB712746.1\tLN:2441\n@SQ\tSN:KB712999.1\tLN:2441\n@SQ\tSN:APMT01230126.1\tLN:2441\n@SQ\tSN:APMT01230447.1\tLN:2441\n@SQ\tSN:APMT01230551.1\tLN:2441\n@SQ\tSN:APMT01230552.1\tLN:2441\n@SQ\tSN:APMT01230553.1\tLN:2441\n@SQ\tSN:APMT01230322.1\tLN:2440\n@SQ\tSN:APMT01230554.1\tLN:2440\n@SQ\tSN:APMT01227168.1\tLN:2439\n@SQ\tSN:APMT01230302.1\tLN:2438\n@SQ\tSN:APMT01230587.1\tLN:2438\n@SQ\tSN:KB712867.1\tLN:2437\n@SQ\tSN:KB714326.1\tLN:2437\n@SQ\tSN:APMT01230570.1\tLN:2437\n@SQ\tSN:APMT01230379.1\tLN:2436\n@SQ\tSN:APMT01230388.1\tLN:2436\n@SQ\tSN:KB714440.1\tLN:2436\n@SQ\tSN:KB714186.1\tLN:2435\n@SQ\tSN:KB714268.1\tLN:2435\n@SQ\tSN:APMT01230335.1\tLN:2435\n@SQ\tSN:APMT01230579.1\tLN:2435\n@SQ\tSN:APMT01230580.1\tLN:2435\n@SQ\tSN:APMT01230581.1\tLN:2435\n@SQ\tSN:KB714381.1\tLN:2433\n@SQ\tSN:KB714399.1\tLN:2433\n@SQ\tSN:APMT01230584.1\tLN:2433\n@SQ\tSN:APMT01230589.1\tLN:2433\n@SQ\tSN:APMT01230590.1\tLN:2433\n@SQ\tSN:KB714324.1\tLN:2432\n@SQ\tSN:KB714375.1\tLN:2432\n@SQ\tSN:APMT01230296.1\tLN:2432\n@SQ\tSN:APMT01230325.1\tLN:2432\n@SQ\tSN:KB714414.1\tLN:2432\n@SQ\tSN:APMT01230592.1\tLN:2432\n@SQ\tSN:KB714039.1\tLN:2431\n@SQ\tSN:KB714261.1\tLN:2431\n@SQ\tSN:APMT01230595.1\tLN:2431\n@SQ\tSN:APMT01230598.1\tLN:2431\n@SQ\tSN:APMT01230599.1\tLN:2431\n@SQ\tSN:KB714070.1\tLN:2430\n@SQ\tSN:APMT01230594.1\tLN:2430\n@SQ\tSN:APMT01230602.1\tLN:2430\n@SQ\tSN:APMT01230603.1\tLN:2430\n@SQ\tSN:APMT01230605.1\tLN:2429\n@SQ\tSN:APMT01230607.1\tLN:2429\n@SQ\tSN:APMT01230608.1\tLN:2429\n@SQ\tSN:APMT01230611.1\tLN:2429\n@SQ\tSN:APMT01230571.1\tLN:2428\n@SQ\tSN:APMT01230612.1\tLN:2428\n@SQ\tSN:APMT01230614.1\tLN:2428\n@SQ\tSN:APMT01230616.1\tLN:2427\n@SQ\tSN:APMT01230377.1\tLN:2426\n@SQ\tSN:APMT01230621.1\tLN:2426\n@SQ\tSN:APMT01230622.1\tLN:2426\n@SQ\tSN:KB714298.1\tLN:2425\n@SQ\tSN:KB714357.1\tLN:2425\n@SQ\tSN:APMT01230425.1\tLN:2425\n@SQ\tSN:APMT01230583.1\tLN:2425\n@SQ\tSN:APMT01230623.1\tLN:2425\n@SQ\tSN:APMT01230624.1\tLN:2425\n@SQ\tSN:APMT01230627.1\tLN:2424\n@SQ\tSN:APMT01230628.1\tLN:2424\n@SQ\tSN:APMT01230630.1\tLN:2423\n@SQ\tSN:APMT01230642.1\tLN:2423\n@SQ\tSN:KB714286.1\tLN:2422\n@SQ\tSN:APMT01230573.1\tLN:2422\n@SQ\tSN:APMT01230631.1\tLN:2422\n@SQ\tSN:APMT01230632.1\tLN:2422\n@SQ\tSN:APMT01230636.1\tLN:2422\n@SQ\tSN:KB714297.1\tLN:2421\n@SQ\tSN:APMT01230368.1\tLN:2421\n@SQ\tSN:APMT01230409.1\tLN:2421\n@SQ\tSN:APMT01230637.1\tLN:2421\n@SQ\tSN:APMT01230328.1\tLN:2420\n@SQ\tSN:APMT01230433.1\tLN:2420\n@SQ\tSN:APMT01230153.1\tLN:2419\n@SQ\tSN:APMT01230648.1\tLN:2419\n@SQ\tSN:APMT01230639.1\tLN:2418\n@SQ\tSN:APMT01230651.1\tLN:2418\n@SQ\tSN:APMT01230652.1\tLN:2417\n@SQ\tSN:APMT01230653.1\tLN:2417\n@SQ\tSN:APMT01230309.1\tLN:2416\n@SQ\tSN:APMT01230654.1\tLN:2416\n@SQ\tSN:KB710271.1\tLN:2415\n@SQ\tSN:KB714398.1\tLN:2415\n@SQ\tSN:APMT01230657.1\tLN:2415\n@SQ\tSN:APMT01230658.1\tLN:2415\n@SQ\tSN:KB713768.1\tLN:2414\n@SQ\tSN:APMT01230661.1\tLN:2414\n@SQ\tSN:APMT01230662.1\tLN:2414\n@SQ\tSN:APMT01230663.1\tLN:2414\n@SQ\tSN:KB714383.1\tLN:2413\n@SQ\tSN:APMT01230664.1\tLN:2413\n@SQ\tSN:APMT01230665.1\tLN:2413\n@SQ\tSN:APMT01230666.1\tLN:2413\n@SQ\tSN:APMT01230667.1\tLN:2412\n@SQ\tSN:APMT01230668.1\tLN:2412\n@SQ\tSN:KB714300.1\tLN:2411\n@SQ\tSN:KB714393.1\tLN:2411\n@SQ\tSN:APMT01230670.1\tLN:2411\n@SQ\tSN:APMT01230672.1\tLN:2411\n@SQ\tSN:APMT01230677.1\tLN:2411\n@SQ\tSN:APMT01230863.1\tLN:2411\n@SQ\tSN:KB714406.1\tLN:2410\n@SQ\tSN:KB714431.1\tLN:2410\n@SQ\tSN:APMT01230678.1\tLN:2410\n@SQ\tSN:APMT01230680.1\tLN:2410\n@SQ\tSN:APMT01230681.1\tLN:2409\n@SQ\tSN:APMT01230682.1\tLN:2409\n@SQ\tSN:APMT01230896.1\tLN:2408\n@SQ\tSN:KB714374.1\tLN:2407\n@SQ\tSN:APMT01230638.1\tLN:2407\n@SQ\tSN:APMT01230693.1\tLN:2407\n@SQ\tSN:APMT01230696.1\tLN:2407\n@SQ\tSN:KB714283.1\tLN:2406\n@SQ\tSN:APMT01230698.1\tLN:2406\n@SQ\tSN:APMT01230699.1\tLN:2406\n@SQ\tSN:KB714220.1\tLN:2405\n@SQ\tSN:APMT01230705.1\tLN:2405\n@SQ\tSN:APMT01230706.1\tLN:2405\n@SQ\tSN:KB714476.1\tLN:2405\n@SQ\tSN:APMT01230707.1\tLN:2404\n@SQ\tSN:APMT01230708.1\tLN:2404\n@SQ\tSN:APMT01230710.1\tLN:2403\n@SQ\tSN:APMT01230711.1\tLN:2403\n@SQ\tSN:APMT01230712.1\tLN:2403\n@SQ\tSN:KB712270.1\tLN:2402\n@SQ\tSN:KB714289.1\tLN:2402\n@SQ\tSN:KB714322.1\tLN:2402\n@SQ\tSN:KB714372.1\tLN:2402\n@SQ\tSN:APMT01230714.1\tLN:2402\n@SQ\tSN:KB713752.1\tLN:2401\n@SQ\tSN:APMT01230718.1\tLN:2401\n@SQ\tSN:APMT01230719.1\tLN:2401\n@SQ\tSN:KB711529.1\tLN:2400\n@SQ\tSN:KB714385.1\tLN:2400\n@SQ\tSN:APMT01230713.1\tLN:2400\n@SQ\tSN:KB713778.1\tLN:2399\n@SQ\tSN:KB714392.1\tLN:2399\n@SQ\tSN:APMT01230725.1\tLN:2399\n@SQ\tSN:APMT01230729.1\tLN:2399\n@SQ\tSN:APMT01230730.1\tLN:2399\n@SQ\tSN:APMT01230731.1\tLN:2399\n@SQ\tSN:APMT01230732.1\tLN:2399\n@SQ\tSN:APMT01230437.1\tLN:2398\n@SQ\tSN:APMT01230588.1\tLN:2398\n@SQ\tSN:APMT01230735.1\tLN:2398\n@SQ\tSN:APMT01230738.1\tLN:2398\n@SQ\tSN:APMT01230739.1\tLN:2398\n@SQ\tSN:APMT01230742.1\tLN:2398\n@SQ\tSN:KB713725.1\tLN:2397\n@SQ\tSN:KB714416.1\tLN:2397\n@SQ\tSN:APMT01230469.1\tLN:2397\n@SQ\tSN:APMT01230492.1\tLN:2397\n@SQ\tSN:APMT01230728.1\tLN:2397\n@SQ\tSN:KB714543.1\tLN:2397\n@SQ\tSN:APMT01231396.1\tLN:2397\n@SQ\tSN:KB714325.1\tLN:2396\n@SQ\tSN:APMT01230660.1\tLN:2396\n@SQ\tSN:APMT01230743.1\tLN:2396\n@SQ\tSN:APMT01230744.1\tLN:2396\n@SQ\tSN:APMT01230604.1\tLN:2395\n@SQ\tSN:APMT01230733.1\tLN:2395\n@SQ\tSN:APMT01230745.1\tLN:2395\n@SQ\tSN:APMT01230747.1\tLN:2395\n@SQ\tSN:APMT01230750.1\tLN:2394\n@SQ\tSN:APMT01230751.1\tLN:2394\n@SQ\tSN:APMT01230754.1\tLN:2394\n@SQ\tSN:APMT01230493.1\tLN:2393\n@SQ\tSN:APMT01230752.1\tLN:2393\n@SQ\tSN:APMT01230753.1\tLN:2393\n@SQ\tSN:APMT01230280.1\tLN:2392\n@SQ\tSN:APMT01230758.1\tLN:2392\n@SQ\tSN:KB714496.1\tLN:2392\n@SQ\tSN:APMT01230659.1\tLN:2391\n@SQ\tSN:APMT01230760.1\tLN:2391\n@SQ\tSN:KB714235.1\tLN:2390\n@SQ\tSN:KB714448.1\tLN:2390\n@SQ\tSN:APMT01230764.1\tLN:2390\n@SQ\tSN:KB714328.1\tLN:2389\n@SQ\tSN:KB714363.1\tLN:2389\n@SQ\tSN:APMT01230759.1\tLN:2388\n@SQ\tSN:APMT01230768.1\tLN:2388\n@SQ\tSN:KB714303.1\tLN:2387\n@SQ\tSN:APMT01230769.1\tLN:2387\n@SQ\tSN:APMT01230771.1\tLN:2387\n@SQ\tSN:APMT01230772.1\tLN:2386\n@SQ\tSN:APMT01230774.1\tLN:2386\n@SQ\tSN:APMT01230775.1\tLN:2384\n@SQ\tSN:KB712889.1\tLN:2383\n@SQ\tSN:APMT01230671.1\tLN:2383\n@SQ\tSN:APMT01230780.1\tLN:2383\n@SQ\tSN:APMT01230773.1\tLN:2382\n@SQ\tSN:KB713044.1\tLN:2381\n@SQ\tSN:APMT01230563.1\tLN:2381\n@SQ\tSN:APMT01230794.1\tLN:2381\n@SQ\tSN:KB714285.1\tLN:2380\n@SQ\tSN:APMT01230767.1\tLN:2380\n@SQ\tSN:APMT01230795.1\tLN:2380\n@SQ\tSN:APMT01230796.1\tLN:2380\n@SQ\tSN:APMT01230800.1\tLN:2380\n@SQ\tSN:APMT01230578.1\tLN:2379\n@SQ\tSN:APMT01230801.1\tLN:2379\n@SQ\tSN:APMT01230804.1\tLN:2379\n@SQ\tSN:APMT01230806.1\tLN:2379\n@SQ\tSN:KB714436.1\tLN:2378\n@SQ\tSN:APMT01230810.1\tLN:2378\n@SQ\tSN:APMT01230559.1\tLN:2377\n@SQ\tSN:APMT01230746.1\tLN:2377\n@SQ\tSN:APMT01230812.1\tLN:2377\n@SQ\tSN:APMT01230813.1\tLN:2377\n@SQ\tSN:APMT01230815.1\tLN:2377\n@SQ\tSN:KB714411.1\tLN:2376\n@SQ\tSN:APMT01230582.1\tLN:2376\n@SQ\tSN:APMT01230816.1\tLN:2376\n@SQ\tSN:APMT01230818.1\tLN:2376\n@SQ\tSN:KB714514.1\tLN:2376\n@SQ\tSN:KB714211.1\tLN:2375\n@SQ\tSN:APMT01230821.1\tLN:2375\n@SQ\tSN:APMT01230822.1\tLN:2375\n@SQ\tSN:APMT01230823.1\tLN:2375\n@SQ\tSN:APMT01230720.1\tLN:2374\n@SQ\tSN:APMT01230826.1\tLN:2374\n@SQ\tSN:APMT01230827.1\tLN:2374\n@SQ\tSN:APMT01230829.1\tLN:2373\n@SQ\tSN:APMT01230831.1\tLN:2373\n@SQ\tSN:APMT01230832.1\tLN:2373\n@SQ\tSN:KB714226.1\tLN:2372\n@SQ\tSN:APMT01230834.1\tLN:2372\n@SQ\tSN:KB714407.1\tLN:2371\n@SQ\tSN:APMT01230593.1\tLN:2371\n@SQ\tSN:APMT01230840.1\tLN:2371\n@SQ\tSN:APMT01230841.1\tLN:2371\n@SQ\tSN:APMT01230842.1\tLN:2371\n@SQ\tSN:KB714244.1\tLN:2370\n@SQ\tSN:APMT01230560.1\tLN:2370\n@SQ\tSN:APMT01230845.1\tLN:2370\n@SQ\tSN:APMT01230846.1\tLN:2370\n@SQ\tSN:APMT01230848.1\tLN:2370\n@SQ\tSN:APMT01230853.1\tLN:2369\n@SQ\tSN:APMT01230854.1\tLN:2369\n@SQ\tSN:APMT01230855.1\tLN:2369\n@SQ\tSN:APMT01230856.1\tLN:2369\n@SQ\tSN:APMT01230857.1\tLN:2369\n@SQ\tSN:APMT01230858.1\tLN:2368\n@SQ\tSN:APMT01231129.1\tLN:2368\n@SQ\tSN:KB714463.1\tLN:2367\n@SQ\tSN:APMT01230860.1\tLN:2367\n@SQ\tSN:APMT01230629.1\tLN:2365\n@SQ\tSN:APMT01230647.1\tLN:2365\n@SQ\tSN:APMT01230861.1\tLN:2365\n@SQ\tSN:KB712566.1\tLN:2364\n@SQ\tSN:APMT01230709.1\tLN:2364\n@SQ\tSN:APMT01230770.1\tLN:2364\n@SQ\tSN:APMT01230865.1\tLN:2364\n@SQ\tSN:KB714452.1\tLN:2363\n@SQ\tSN:APMT01230791.1\tLN:2363\n@SQ\tSN:APMT01230303.1\tLN:2362\n@SQ\tSN:APMT01230868.1\tLN:2362\n@SQ\tSN:APMT01230869.1\tLN:2362\n@SQ\tSN:APMT01230870.1\tLN:2362\n@SQ\tSN:APMT01230872.1\tLN:2361\n@SQ\tSN:APMT01230873.1\tLN:2361\n@SQ\tSN:APMT01230726.1\tLN:2360\n@SQ\tSN:APMT01230805.1\tLN:2360\n@SQ\tSN:APMT01230874.1\tLN:2360\n@SQ\tSN:APMT01230877.1\tLN:2360\n@SQ\tSN:KB714495.1\tLN:2360\n@SQ\tSN:KB714359.1\tLN:2359\n@SQ\tSN:APMT01230880.1\tLN:2359\n@SQ\tSN:KB713866.1\tLN:2358\n@SQ\tSN:APMT01230727.1\tLN:2358\n@SQ\tSN:APMT01230833.1\tLN:2358\n@SQ\tSN:APMT01230884.1\tLN:2358\n@SQ\tSN:APMT01230591.1\tLN:2357\n@SQ\tSN:APMT01230690.1\tLN:2357\n@SQ\tSN:APMT01230885.1\tLN:2357\n@SQ\tSN:APMT01230887.1\tLN:2357\n@SQ\tSN:KB714311.1\tLN:2356\n@SQ\tSN:KB714446.1\tLN:2356\n@SQ\tSN:APMT01230888.1\tLN:2356\n@SQ\tSN:APMT01230889.1\tLN:2356\n@SQ\tSN:APMT01230890.1\tLN:2356\n@SQ\tSN:APMT01230891.1\tLN:2356\n@SQ\tSN:APMT01230892.1\tLN:2356\n@SQ\tSN:KB714417.1\tLN:2355\n@SQ\tSN:APMT01230893.1\tLN:2355\n@SQ\tSN:APMT01230894.1\tLN:2354\n@SQ\tSN:APMT01230895.1\tLN:2354\n@SQ\tSN:APMT01225923.1\tLN:2353\n@SQ\tSN:KB714084.1\tLN:2353\n@SQ\tSN:KB714264.1\tLN:2353\n@SQ\tSN:KB714420.1\tLN:2353\n@SQ\tSN:APMT01230897.1\tLN:2353\n@SQ\tSN:APMT01230898.1\tLN:2353\n@SQ\tSN:APMT01230899.1\tLN:2353\n@SQ\tSN:APMT01230900.1\tLN:2353\n@SQ\tSN:KB712787.1\tLN:2352\n@SQ\tSN:KB713859.1\tLN:2352\n@SQ\tSN:APMT01230901.1\tLN:2352\n@SQ\tSN:APMT01230903.1\tLN:2352\n@SQ\tSN:APMT01230669.1\tLN:2351\n@SQ\tSN:APMT01230679.1\tLN:2350\n@SQ\tSN:APMT01230734.1\tLN:2349\n@SQ\tSN:APMT01230797.1\tLN:2349\n@SQ\tSN:APMT01230905.1\tLN:2349\n@SQ\tSN:APMT01230685.1\tLN:2348\n@SQ\tSN:APMT01230755.1\tLN:2348\n@SQ\tSN:APMT01230907.1\tLN:2348\n@SQ\tSN:APMT01230912.1\tLN:2348\n@SQ\tSN:APMT01231267.1\tLN:2348\n@SQ\tSN:APMT01230704.1\tLN:2347\n@SQ\tSN:APMT01230914.1\tLN:2347\n@SQ\tSN:APMT01230915.1\tLN:2347\n@SQ\tSN:KB712823.1\tLN:2346\n@SQ\tSN:KB714356.1\tLN:2346\n@SQ\tSN:APMT01230918.1\tLN:2346\n@SQ\tSN:APMT01230919.1\tLN:2346\n@SQ\tSN:APMT01230916.1\tLN:2345\n@SQ\tSN:APMT01230921.1\tLN:2345\n@SQ\tSN:APMT01230922.1\tLN:2345\n@SQ\tSN:KB712304.1\tLN:2344\n@SQ\tSN:APMT01230924.1\tLN:2344\n@SQ\tSN:APMT01230847.1\tLN:2342\n@SQ\tSN:APMT01230929.1\tLN:2342\n@SQ\tSN:APMT01230790.1\tLN:2341\n@SQ\tSN:APMT01230930.1\tLN:2341\n@SQ\tSN:APMT01230931.1\tLN:2341\n@SQ\tSN:APMT01230934.1\tLN:2341\n@SQ\tSN:APMT01230935.1\tLN:2339\n@SQ\tSN:APMT01230936.1\tLN:2339\n@SQ\tSN:APMT01230937.1\tLN:2339\n@SQ\tSN:APMT01230940.1\tLN:2339\n@SQ\tSN:APMT01230920.1\tLN:2338\n@SQ\tSN:APMT01230942.1\tLN:2338\n@SQ\tSN:KB714222.1\tLN:2337\n@SQ\tSN:KB714462.1\tLN:2337\n@SQ\tSN:APMT01230762.1\tLN:2337\n@SQ\tSN:APMT01230941.1\tLN:2337\n@SQ\tSN:APMT01230946.1\tLN:2337\n@SQ\tSN:APMT01231303.1\tLN:2337\n@SQ\tSN:KB714189.1\tLN:2336\n@SQ\tSN:KB714402.1\tLN:2336\n@SQ\tSN:APMT01230917.1\tLN:2336\n@SQ\tSN:KB712690.1\tLN:2334\n@SQ\tSN:KB714424.1\tLN:2334\n@SQ\tSN:APMT01230948.1\tLN:2334\n@SQ\tSN:APMT01230953.1\tLN:2334\n@SQ\tSN:APMT01230954.1\tLN:2334\n@SQ\tSN:KB714418.1\tLN:2333\n@SQ\tSN:APMT01230906.1\tLN:2333\n@SQ\tSN:APMT01230959.1\tLN:2333\n@SQ\tSN:APMT01230960.1\tLN:2333\n@SQ\tSN:APMT01230961.1\tLN:2333\n@SQ\tSN:APMT01230962.1\tLN:2332\n@SQ\tSN:APMT01230964.1\tLN:2332\n@SQ\tSN:KB714382.1\tLN:2331\n@SQ\tSN:APMT01230965.1\tLN:2331\n@SQ\tSN:KB714151.1\tLN:2330\n@SQ\tSN:APMT01230970.1\tLN:2330\n@SQ\tSN:KB714361.1\tLN:2329\n@SQ\tSN:KB714441.1\tLN:2329\n@SQ\tSN:APMT01230763.1\tLN:2329\n@SQ\tSN:APMT01230824.1\tLN:2329\n@SQ\tSN:APMT01230975.1\tLN:2329\n@SQ\tSN:APMT01230697.1\tLN:2328\n@SQ\tSN:APMT01230981.1\tLN:2328\n@SQ\tSN:KB714466.1\tLN:2327\n@SQ\tSN:APMT01230985.1\tLN:2327\n@SQ\tSN:APMT01230923.1\tLN:2326\n@SQ\tSN:APMT01230987.1\tLN:2326\n@SQ\tSN:APMT01230988.1\tLN:2326\n@SQ\tSN:APMT01230989.1\tLN:2325\n@SQ\tSN:APMT01230991.1\tLN:2325\n@SQ\tSN:KB714453.1\tLN:2324\n@SQ\tSN:APMT01230761.1\tLN:2324\n@SQ\tSN:APMT01230992.1\tLN:2324\n@SQ\tSN:APMT01230997.1\tLN:2324\n@SQ\tSN:APMT01231518.1\tLN:2324\n@SQ\tSN:APMT01227437.1\tLN:2323\n@SQ\tSN:APMT01230572.1\tLN:2323\n@SQ\tSN:APMT01230886.1\tLN:2323\n@SQ\tSN:APMT01230998.1\tLN:2323\n@SQ\tSN:APMT01230999.1\tLN:2323\n@SQ\tSN:APMT01231000.1\tLN:2323\n@SQ\tSN:APMT01231045.1\tLN:2323\n@SQ\tSN:APMT01230990.1\tLN:2322\n@SQ\tSN:APMT01231003.1\tLN:2322\n@SQ\tSN:APMT01231007.1\tLN:2322\n@SQ\tSN:APMT01231008.1\tLN:2322\n@SQ\tSN:APMT01231009.1\tLN:2322\n@SQ\tSN:APMT01231010.1\tLN:2321\n@SQ\tSN:APMT01231011.1\tLN:2321\n@SQ\tSN:APMT01231013.1\tLN:2321\n@SQ\tSN:APMT01230830.1\tLN:2320\n@SQ\tSN:APMT01230881.1\tLN:2320\n@SQ\tSN:APMT01230955.1\tLN:2320\n@SQ\tSN:APMT01231015.1\tLN:2320\n@SQ\tSN:APMT01231016.1\tLN:2320\n@SQ\tSN:APMT01230862.1\tLN:2319\n@SQ\tSN:APMT01231025.1\tLN:2319\n@SQ\tSN:APMT01230814.1\tLN:2318\n@SQ\tSN:APMT01231018.1\tLN:2318\n@SQ\tSN:APMT01231027.1\tLN:2318\n@SQ\tSN:APMT01231123.1\tLN:2318\n@SQ\tSN:KB714569.1\tLN:2318\n@SQ\tSN:KB714294.1\tLN:2317\n@SQ\tSN:APMT01231031.1\tLN:2317\n@SQ\tSN:APMT01231032.1\tLN:2317\n@SQ\tSN:APMT01231033.1\tLN:2317\n@SQ\tSN:APMT01231035.1\tLN:2316\n@SQ\tSN:APMT01231036.1\tLN:2316\n@SQ\tSN:APMT01231037.1\tLN:2316\n@SQ\tSN:APMT01231038.1\tLN:2316\n@SQ\tSN:APMT01231042.1\tLN:2316\n@SQ\tSN:APMT01231034.1\tLN:2315\n@SQ\tSN:APMT01231046.1\tLN:2315\n@SQ\tSN:APMT01231047.1\tLN:2315\n@SQ\tSN:APMT01231051.1\tLN:2315\n@SQ\tSN:APMT01231052.1\tLN:2315\n@SQ\tSN:APMT01231053.1\tLN:2315\n@SQ\tSN:KB714437.1\tLN:2314\n@SQ\tSN:APMT01230828.1\tLN:2314\n@SQ\tSN:APMT01230859.1\tLN:2314\n@SQ\tSN:APMT01231028.1\tLN:2314\n@SQ\tSN:APMT01231055.1\tLN:2314\n@SQ\tSN:APMT01231056.1\tLN:2314\n@SQ\tSN:APMT01231057.1\tLN:2314\n@SQ\tSN:KB714467.1\tLN:2313\n@SQ\tSN:APMT01230825.1\tLN:2313\n@SQ\tSN:APMT01231048.1\tLN:2313\n@SQ\tSN:APMT01231058.1\tLN:2313\n@SQ\tSN:APMT01231061.1\tLN:2312\n@SQ\tSN:APMT01230505.1\tLN:2311\n@SQ\tSN:APMT01230837.1\tLN:2311\n@SQ\tSN:APMT01231064.1\tLN:2311\n@SQ\tSN:APMT01231065.1\tLN:2311\n@SQ\tSN:KB714408.1\tLN:2310\n@SQ\tSN:APMT01231062.1\tLN:2310\n@SQ\tSN:APMT01231067.1\tLN:2310\n@SQ\tSN:APMT01231068.1\tLN:2310\n@SQ\tSN:APMT01231069.1\tLN:2310\n@SQ\tSN:APMT01231070.1\tLN:2309\n@SQ\tSN:APMT01231075.1\tLN:2309\n@SQ\tSN:APMT01231076.1\tLN:2309\n@SQ\tSN:APMT01231077.1\tLN:2308\n@SQ\tSN:APMT01231078.1\tLN:2308\n@SQ\tSN:APMT01231079.1\tLN:2308\n@SQ\tSN:APMT01231080.1\tLN:2308\n@SQ\tSN:APMT01230030.1\tLN:2307\n@SQ\tSN:KB714497.1\tLN:2307\n@SQ\tSN:APMT01231081.1\tLN:2307\n@SQ\tSN:APMT01231082.1\tLN:2307\n@SQ\tSN:KB714494.1\tLN:2306\n@SQ\tSN:APMT01231084.1\tLN:2306\n@SQ\tSN:APMT01231086.1\tLN:2306\n@SQ\tSN:APMT01231091.1\tLN:2306\n@SQ\tSN:APMT01231092.1\tLN:2306\n@SQ\tSN:APMT01231041.1\tLN:2305\n@SQ\tSN:APMT01231093.1\tLN:2305\n@SQ\tSN:APMT01231094.1\tLN:2305\n@SQ\tSN:APMT01231095.1\tLN:2305\n@SQ\tSN:APMT01231101.1\tLN:2305\n@SQ\tSN:APMT01231102.1\tLN:2304\n@SQ\tSN:APMT01231103.1\tLN:2304\n@SQ\tSN:APMT01231104.1\tLN:2304\n@SQ\tSN:APMT01231105.1\tLN:2304\n@SQ\tSN:APMT01231106.1\tLN:2304\n@SQ\tSN:APMT01231107.1\tLN:2304\n@SQ\tSN:KB714401.1\tLN:2303\n@SQ\tSN:APMT01231108.1\tLN:2303\n@SQ\tSN:APMT01231109.1\tLN:2303\n@SQ\tSN:KB714412.1\tLN:2302\n@SQ\tSN:APMT01230643.1\tLN:2302\n@SQ\tSN:APMT01230452.1\tLN:2300\n@SQ\tSN:KB714469.1\tLN:2300\n@SQ\tSN:APMT01231115.1\tLN:2300\n@SQ\tSN:APMT01231128.1\tLN:2300\n@SQ\tSN:APMT01231127.1\tLN:2299\n@SQ\tSN:APMT01231014.1\tLN:2298\n@SQ\tSN:APMT01231074.1\tLN:2298\n@SQ\tSN:APMT01231130.1\tLN:2298\n@SQ\tSN:APMT01231131.1\tLN:2298\n@SQ\tSN:APMT01231132.1\tLN:2298\n@SQ\tSN:KB712767.1\tLN:2297\n@SQ\tSN:APMT01230689.1\tLN:2297\n@SQ\tSN:APMT01230799.1\tLN:2297\n@SQ\tSN:KB714481.1\tLN:2297\n@SQ\tSN:APMT01231133.1\tLN:2297\n@SQ\tSN:APMT01231126.1\tLN:2295\n@SQ\tSN:APMT01231136.1\tLN:2295\n@SQ\tSN:APMT01231203.1\tLN:2295\n@SQ\tSN:KB714404.1\tLN:2294\n@SQ\tSN:APMT01231141.1\tLN:2294\n@SQ\tSN:APMT01230295.1\tLN:2293\n@SQ\tSN:KB714500.1\tLN:2293\n@SQ\tSN:APMT01231142.1\tLN:2293\n@SQ\tSN:APMT01231144.1\tLN:2293\n@SQ\tSN:APMT01231145.1\tLN:2293\n@SQ\tSN:KB714445.1\tLN:2292\n@SQ\tSN:APMT01230715.1\tLN:2292\n@SQ\tSN:KB714465.1\tLN:2292\n@SQ\tSN:KB714503.1\tLN:2292\n@SQ\tSN:APMT01231012.1\tLN:2291\n@SQ\tSN:KB714432.1\tLN:2290\n@SQ\tSN:KB714442.1\tLN:2290\n@SQ\tSN:APMT01231001.1\tLN:2289\n@SQ\tSN:APMT01231151.1\tLN:2289\n@SQ\tSN:APMT01231153.1\tLN:2289\n@SQ\tSN:APMT01231156.1\tLN:2288\n@SQ\tSN:APMT01231157.1\tLN:2288\n@SQ\tSN:APMT01231159.1\tLN:2288\n@SQ\tSN:APMT01231164.1\tLN:2287\n@SQ\tSN:KB714384.1\tLN:2286\n@SQ\tSN:KB714520.1\tLN:2286\n@SQ\tSN:APMT01231165.1\tLN:2286\n@SQ\tSN:APMT01231166.1\tLN:2286\n@SQ\tSN:APMT01231167.1\tLN:2286\n@SQ\tSN:APMT01231168.1\tLN:2285\n@SQ\tSN:APMT01231170.1\tLN:2285\n@SQ\tSN:APMT01231026.1\tLN:2284\n@SQ\tSN:APMT01231169.1\tLN:2284\n@SQ\tSN:APMT01231171.1\tLN:2284\n@SQ\tSN:APMT01231172.1\tLN:2284\n@SQ\tSN:APMT01231173.1\tLN:2284\n@SQ\tSN:APMT01231112.1\tLN:2283\n@SQ\tSN:APMT01231139.1\tLN:2283\n@SQ\tSN:APMT01231175.1\tLN:2283\n@SQ\tSN:KB714493.1\tLN:2281\n@SQ\tSN:APMT01231096.1\tLN:2281\n@SQ\tSN:APMT01231143.1\tLN:2281\n@SQ\tSN:APMT01231190.1\tLN:2281\n@SQ\tSN:KB714395.1\tLN:2280\n@SQ\tSN:APMT01231178.1\tLN:2280\n@SQ\tSN:KB712508.1\tLN:2279\n@SQ\tSN:KB714419.1\tLN:2279\n@SQ\tSN:APMT01230958.1\tLN:2279\n@SQ\tSN:APMT01230976.1\tLN:2279\n@SQ\tSN:APMT01231146.1\tLN:2279\n@SQ\tSN:APMT01231187.1\tLN:2279\n@SQ\tSN:APMT01231188.1\tLN:2279\n@SQ\tSN:APMT01231189.1\tLN:2279\n@SQ\tSN:APMT01230301.1\tLN:2277\n@SQ\tSN:APMT01230781.1\tLN:2277\n@SQ\tSN:APMT01231193.1\tLN:2277\n@SQ\tSN:APMT01231199.1\tLN:2277\n@SQ\tSN:APMT01231235.1\tLN:2277\n@SQ\tSN:KB714230.1\tLN:2276\n@SQ\tSN:APMT01230947.1\tLN:2276\n@SQ\tSN:KB714526.1\tLN:2276\n@SQ\tSN:APMT01231204.1\tLN:2275\n@SQ\tSN:APMT01231211.1\tLN:2275\n@SQ\tSN:APMT01231212.1\tLN:2275\n@SQ\tSN:APMT01231213.1\tLN:2275\n@SQ\tSN:KB714552.1\tLN:2275\n@SQ\tSN:APMT01230811.1\tLN:2274\n@SQ\tSN:APMT01230966.1\tLN:2274\n@SQ\tSN:APMT01231215.1\tLN:2274\n@SQ\tSN:APMT01231218.1\tLN:2273\n@SQ\tSN:APMT01230963.1\tLN:2272\n@SQ\tSN:APMT01230967.1\tLN:2272\n@SQ\tSN:APMT01231214.1\tLN:2272\n@SQ\tSN:APMT01231221.1\tLN:2272\n@SQ\tSN:APMT01231222.1\tLN:2272\n@SQ\tSN:APMT01231224.1\tLN:2272\n@SQ\tSN:APMT01231225.1\tLN:2272\n@SQ\tSN:APMT01231226.1\tLN:2272\n@SQ\tSN:APMT01231227.1\tLN:2272\n@SQ\tSN:APMT01231230.1\tLN:2271\n@SQ\tSN:APMT01231234.1\tLN:2271\n@SQ\tSN:KB714391.1\tLN:2270\n@SQ\tSN:APMT01231240.1\tLN:2270\n@SQ\tSN:APMT01231241.1\tLN:2270\n@SQ\tSN:APMT01231243.1\tLN:2270\n@SQ\tSN:APMT01231244.1\tLN:2270\n@SQ\tSN:APMT01231002.1\tLN:2269\n@SQ\tSN:APMT01231220.1\tLN:2269\n@SQ\tSN:APMT01231223.1\tLN:2269\n@SQ\tSN:APMT01231248.1\tLN:2269\n@SQ\tSN:APMT01231249.1\tLN:2269\n@SQ\tSN:KB714422.1\tLN:2268\n@SQ\tSN:KB714475.1\tLN:2268\n@SQ\tSN:APMT01231219.1\tLN:2268\n@SQ\tSN:KB713453.1\tLN:2267\n@SQ\tSN:KB714485.1\tLN:2267\n@SQ\tSN:APMT01231177.1\tLN:2267\n@SQ\tSN:APMT01231253.1\tLN:2267\n@SQ\tSN:KB714470.1\tLN:2266\n@SQ\tSN:KB714490.1\tLN:2266\n@SQ\tSN:APMT01231247.1\tLN:2266\n@SQ\tSN:APMT01231256.1\tLN:2266\n@SQ\tSN:APMT01230871.1\tLN:2265\n@SQ\tSN:APMT01231258.1\tLN:2265\n@SQ\tSN:APMT01231260.1\tLN:2265\n@SQ\tSN:APMT01231261.1\tLN:2265\n@SQ\tSN:KB714502.1\tLN:2264\n@SQ\tSN:APMT01231268.1\tLN:2264\n@SQ\tSN:APMT01231269.1\tLN:2264\n@SQ\tSN:APMT01231270.1\tLN:2264\n@SQ\tSN:APMT01231017.1\tLN:2263\n@SQ\tSN:APMT01231198.1\tLN:2263\n@SQ\tSN:APMT01231271.1\tLN:2263\n@SQ\tSN:APMT01231272.1\tLN:2263\n@SQ\tSN:APMT01231273.1\tLN:2263\n@SQ\tSN:KB714480.1\tLN:2262\n@SQ\tSN:APMT01230882.1\tLN:2262\n@SQ\tSN:APMT01231278.1\tLN:2262\n@SQ\tSN:APMT01231279.1\tLN:2262\n@SQ\tSN:APMT01231281.1\tLN:2262\n@SQ\tSN:APMT01230986.1\tLN:2261\n@SQ\tSN:APMT01231276.1\tLN:2261\n@SQ\tSN:APMT01231280.1\tLN:2261\n@SQ\tSN:APMT01231284.1\tLN:2261\n@SQ\tSN:APMT01231285.1\tLN:2261\n@SQ\tSN:APMT01231286.1\tLN:2261\n@SQ\tSN:APMT01230902.1\tLN:2259\n@SQ\tSN:APMT01231287.1\tLN:2259\n@SQ\tSN:APMT01231288.1\tLN:2259\n@SQ\tSN:APMT01231290.1\tLN:2259\n@SQ\tSN:APMT01231291.1\tLN:2259\n@SQ\tSN:APMT01231292.1\tLN:2259\n@SQ\tSN:APMT01231293.1\tLN:2259\n@SQ\tSN:KB714498.1\tLN:2258\n@SQ\tSN:APMT01231083.1\tLN:2258\n@SQ\tSN:APMT01231242.1\tLN:2258\n@SQ\tSN:APMT01231296.1\tLN:2258\n@SQ\tSN:APMT01231297.1\tLN:2258\n@SQ\tSN:APMT01231298.1\tLN:2258\n@SQ\tSN:APMT01231205.1\tLN:2257\n@SQ\tSN:APMT01231255.1\tLN:2257\n@SQ\tSN:APMT01231300.1\tLN:2257\n@SQ\tSN:APMT01231302.1\tLN:2257\n@SQ\tSN:APMT01230688.1\tLN:2256\n@SQ\tSN:APMT01231305.1\tLN:2256\n@SQ\tSN:APMT01231306.1\tLN:2256\n@SQ\tSN:KB714456.1\tLN:2255\n@SQ\tSN:APMT01231307.1\tLN:2255\n@SQ\tSN:KB714367.1\tLN:2253\n@SQ\tSN:APMT01231116.1\tLN:2253\n@SQ\tSN:APMT01231122.1\tLN:2253\n@SQ\tSN:APMT01231194.1\tLN:2253\n@SQ\tSN:APMT01231277.1\tLN:2253\n@SQ\tSN:APMT01231312.1\tLN:2253\n@SQ\tSN:APMT01231088.1\tLN:2252\n@SQ\tSN:APMT01231315.1\tLN:2252\n@SQ\tSN:APMT01231316.1\tLN:2252\n@SQ\tSN:KB714444.1\tLN:2251\n@SQ\tSN:APMT01231317.1\tLN:2251\n@SQ\tSN:APMT01230635.1\tLN:2250\n@SQ\tSN:APMT01231063.1\tLN:2250\n@SQ\tSN:APMT01231087.1\tLN:2250\n@SQ\tSN:APMT01231275.1\tLN:2250\n@SQ\tSN:APMT01231319.1\tLN:2250\n@SQ\tSN:KB714360.1\tLN:2249\n@SQ\tSN:APMT01231073.1\tLN:2249\n@SQ\tSN:APMT01231085.1\tLN:2249\n@SQ\tSN:APMT01231320.1\tLN:2249\n@SQ\tSN:APMT01231323.1\tLN:2249\n@SQ\tSN:APMT01231324.1\tLN:2249\n@SQ\tSN:APMT01231325.1\tLN:2249\n@SQ\tSN:APMT01231326.1\tLN:2249\n@SQ\tSN:APMT01231259.1\tLN:2248\n@SQ\tSN:APMT01231330.1\tLN:2248\n@SQ\tSN:APMT01231331.1\tLN:2248\n@SQ\tSN:APMT01231332.1\tLN:2248\n@SQ\tSN:APMT01231335.1\tLN:2248\n@SQ\tSN:APMT01231336.1\tLN:2248\n@SQ\tSN:APMT01231089.1\tLN:2247\n@SQ\tSN:APMT01231121.1\tLN:2247\n@SQ\tSN:APMT01231138.1\tLN:2247\n@SQ\tSN:APMT01231337.1\tLN:2247\n@SQ\tSN:APMT01231090.1\tLN:2246\n@SQ\tSN:APMT01231342.1\tLN:2246\n@SQ\tSN:APMT01231344.1\tLN:2246\n@SQ\tSN:APMT01231345.1\tLN:2246\n@SQ\tSN:KB714515.1\tLN:2245\n@SQ\tSN:KB714521.1\tLN:2245\n@SQ\tSN:APMT01231346.1\tLN:2245\n@SQ\tSN:APMT01231347.1\tLN:2245\n@SQ\tSN:APMT01231158.1\tLN:2244\n@SQ\tSN:APMT01231191.1\tLN:2244\n@SQ\tSN:APMT01231349.1\tLN:2244\n@SQ\tSN:APMT01231350.1\tLN:2244\n@SQ\tSN:APMT01231368.1\tLN:2244\n@SQ\tSN:APMT01231137.1\tLN:2243\n@SQ\tSN:APMT01231351.1\tLN:2243\n@SQ\tSN:APMT01231352.1\tLN:2243\n@SQ\tSN:APMT01231356.1\tLN:2243\n@SQ\tSN:APMT01231358.1\tLN:2243\n@SQ\tSN:APMT01231359.1\tLN:2243\n@SQ\tSN:KB714332.1\tLN:2242\n@SQ\tSN:APMT01231365.1\tLN:2242\n@SQ\tSN:APMT01231134.1\tLN:2241\n@SQ\tSN:APMT01231362.1\tLN:2241\n@SQ\tSN:APMT01231364.1\tLN:2241\n@SQ\tSN:APMT01231200.1\tLN:2240\n@SQ\tSN:APMT01231363.1\tLN:2238\n@SQ\tSN:KB714524.1\tLN:2237\n@SQ\tSN:APMT01231376.1\tLN:2237\n@SQ\tSN:KB712290.1\tLN:2235\n@SQ\tSN:APMT01231378.1\tLN:2235\n@SQ\tSN:APMT01231379.1\tLN:2235\n@SQ\tSN:APMT01231380.1\tLN:2235\n@SQ\tSN:APMT01230817.1\tLN:2234\n@SQ\tSN:APMT01231372.1\tLN:2234\n@SQ\tSN:APMT01231373.1\tLN:2234\n@SQ\tSN:APMT01231382.1\tLN:2234\n@SQ\tSN:APMT01231383.1\tLN:2234\n@SQ\tSN:APMT01231384.1\tLN:2234\n@SQ\tSN:APMT01231386.1\tLN:2234\n@SQ\tSN:APMT01231252.1\tLN:2233\n@SQ\tSN:APMT01231388.1\tLN:2233\n@SQ\tSN:APMT01231391.1\tLN:2233\n@SQ\tSN:APMT01231420.1\tLN:2233\n@SQ\tSN:APMT01231152.1\tLN:2232\n@SQ\tSN:APMT01231393.1\tLN:2232\n@SQ\tSN:APMT01231394.1\tLN:2232\n@SQ\tSN:APMT01231395.1\tLN:2232\n@SQ\tSN:APMT01231179.1\tLN:2231\n@SQ\tSN:APMT01231233.1\tLN:2231\n@SQ\tSN:APMT01231397.1\tLN:2231\n@SQ\tSN:APMT01231400.1\tLN:2231\n@SQ\tSN:KB714471.1\tLN:2230\n@SQ\tSN:APMT01231401.1\tLN:2230\n@SQ\tSN:APMT01231402.1\tLN:2230\n@SQ\tSN:APMT01231406.1\tLN:2229\n@SQ\tSN:APMT01231407.1\tLN:2229\n@SQ\tSN:APMT01231408.1\tLN:2229\n@SQ\tSN:APMT01231409.1\tLN:2229\n@SQ\tSN:APMT01231410.1\tLN:2229\n@SQ\tSN:APMT01231411.1\tLN:2228\n@SQ\tSN:APMT01231417.1\tLN:2228\n@SQ\tSN:APMT01231418.1\tLN:2228\n@SQ\tSN:APMT01231004.1\tLN:2227\n@SQ\tSN:APMT01231282.1\tLN:2227\n@SQ\tSN:APMT01231304.1\tLN:2227\n@SQ\tSN:APMT01231348.1\tLN:2227\n@SQ\tSN:APMT01231419.1\tLN:2227\n@SQ\tSN:APMT01231421.1\tLN:2227\n@SQ\tSN:APMT01231424.1\tLN:2227\n@SQ\tSN:KB714351.1\tLN:2226\n@SQ\tSN:APMT01231422.1\tLN:2226\n@SQ\tSN:APMT01231425.1\tLN:2226\n@SQ\tSN:APMT01231426.1\tLN:2226\n@SQ\tSN:KB714001.1\tLN:2225\n@SQ\tSN:KB714371.1\tLN:2225\n@SQ\tSN:APMT01231135.1\tLN:2225\n@SQ\tSN:APMT01231427.1\tLN:2225\n@SQ\tSN:APMT01231428.1\tLN:2225\n@SQ\tSN:APMT01230982.1\tLN:2224\n@SQ\tSN:APMT01231174.1\tLN:2224\n@SQ\tSN:APMT01231176.1\tLN:2224\n@SQ\tSN:KB714544.1\tLN:2224\n@SQ\tSN:APMT01231429.1\tLN:2224\n@SQ\tSN:APMT01231430.1\tLN:2224\n@SQ\tSN:APMT01231431.1\tLN:2224\n@SQ\tSN:APMT01231432.1\tLN:2224\n@SQ\tSN:APMT01231433.1\tLN:2224\n@SQ\tSN:APMT01231434.1\tLN:2224\n@SQ\tSN:APMT01231435.1\tLN:2224\n@SQ\tSN:APMT01231274.1\tLN:2223\n@SQ\tSN:APMT01231437.1\tLN:2223\n@SQ\tSN:KB714455.1\tLN:2222\n@SQ\tSN:APMT01231442.1\tLN:2222\n@SQ\tSN:KB711186.1\tLN:2221\n@SQ\tSN:KB714373.1\tLN:2221\n@SQ\tSN:APMT01231266.1\tLN:2221\n@SQ\tSN:APMT01231311.1\tLN:2221\n@SQ\tSN:APMT01231443.1\tLN:2221\n@SQ\tSN:APMT01231445.1\tLN:2221\n@SQ\tSN:APMT01231184.1\tLN:2220\n@SQ\tSN:APMT01231206.1\tLN:2220\n@SQ\tSN:APMT01231446.1\tLN:2220\n@SQ\tSN:APMT01231447.1\tLN:2220\n@SQ\tSN:APMT01231448.1\tLN:2220\n@SQ\tSN:APMT01231449.1\tLN:2220\n@SQ\tSN:APMT01231140.1\tLN:2219\n@SQ\tSN:APMT01231202.1\tLN:2219\n@SQ\tSN:APMT01231450.1\tLN:2219\n@SQ\tSN:APMT01231454.1\tLN:2219\n@SQ\tSN:KB714534.1\tLN:2218\n@SQ\tSN:APMT01231455.1\tLN:2218\n@SQ\tSN:APMT01231457.1\tLN:2218\n@SQ\tSN:APMT01231462.1\tLN:2218\n@SQ\tSN:APMT01231195.1\tLN:2217\n@SQ\tSN:APMT01231238.1\tLN:2217\n@SQ\tSN:APMT01231456.1\tLN:2217\n@SQ\tSN:APMT01231066.1\tLN:2216\n@SQ\tSN:APMT01231463.1\tLN:2216\n@SQ\tSN:APMT01231464.1\tLN:2216\n@SQ\tSN:APMT01231465.1\tLN:2216\n@SQ\tSN:KB714482.1\tLN:2215\n@SQ\tSN:APMT01231369.1\tLN:2215\n@SQ\tSN:APMT01231389.1\tLN:2215\n@SQ\tSN:APMT01231466.1\tLN:2215\n@SQ\tSN:APMT01231467.1\tLN:2215\n@SQ\tSN:APMT01231201.1\tLN:2214\n@SQ\tSN:APMT01231468.1\tLN:2214\n@SQ\tSN:APMT01230278.1\tLN:2213\n@SQ\tSN:APMT01231477.1\tLN:2213\n@SQ\tSN:APMT01231478.1\tLN:2211\n@SQ\tSN:APMT01231479.1\tLN:2211\n@SQ\tSN:APMT01231482.1\tLN:2210\n@SQ\tSN:APMT01231483.1\tLN:2210\n@SQ\tSN:APMT01231484.1\tLN:2210\n@SQ\tSN:KB714461.1\tLN:2209\n@SQ\tSN:APMT01231494.1\tLN:2209\n@SQ\tSN:KB714250.1\tLN:2208\n@SQ\tSN:APMT01231489.1\tLN:2208\n@SQ\tSN:APMT01230904.1\tLN:2207\n@SQ\tSN:KB714491.1\tLN:2207\n@SQ\tSN:APMT01231283.1\tLN:2207\n@SQ\tSN:APMT01231318.1\tLN:2207\n@SQ\tSN:APMT01231495.1\tLN:2207\n@SQ\tSN:APMT01231496.1\tLN:2207\n@SQ\tSN:APMT01231497.1\tLN:2207\n@SQ\tSN:APMT01231498.1\tLN:2207\n@SQ\tSN:APMT01231254.1\tLN:2206\n@SQ\tSN:APMT01231289.1\tLN:2206\n@SQ\tSN:APMT01231501.1\tLN:2206\n@SQ\tSN:APMT01231502.1\tLN:2206\n@SQ\tSN:APMT01231385.1\tLN:2205\n@SQ\tSN:APMT01231508.1\tLN:2205\n@SQ\tSN:APMT01231509.1\tLN:2204\n@SQ\tSN:APMT01231510.1\tLN:2204\n@SQ\tSN:APMT01231514.1\tLN:2204\n@SQ\tSN:APMT01231327.1\tLN:2203\n@SQ\tSN:APMT01231517.1\tLN:2203\n@SQ\tSN:KB714518.1\tLN:2202\n@SQ\tSN:APMT01231490.1\tLN:2202\n@SQ\tSN:APMT01231505.1\tLN:2202\n@SQ\tSN:APMT01231519.1\tLN:2202\n@SQ\tSN:APMT01231257.1\tLN:2200\n@SQ\tSN:APMT01231511.1\tLN:2200\n@SQ\tSN:APMT01231527.1\tLN:2200\n@SQ\tSN:APMT01231528.1\tLN:2200\n@SQ\tSN:APMT01231529.1\tLN:2200\n@SQ\tSN:APMT01231531.1\tLN:2200\n@SQ\tSN:KB714025.1\tLN:2199\n@SQ\tSN:KB714511.1\tLN:2199\n@SQ\tSN:APMT01231533.1\tLN:2199\n@SQ\tSN:APMT01231534.1\tLN:2198\n@SQ\tSN:KB714428.1\tLN:2197\n@SQ\tSN:APMT01231532.1\tLN:2197\n@SQ\tSN:APMT01231535.1\tLN:2197\n@SQ\tSN:APMT01231538.1\tLN:2197\n@SQ\tSN:APMT01231542.1\tLN:2197\n@SQ\tSN:APMT01231543.1\tLN:2197\n@SQ\tSN:KB714536.1\tLN:2196\n@SQ\tSN:APMT01231310.1\tLN:2196\n@SQ\tSN:APMT01231544.1\tLN:2196\n@SQ\tSN:APMT01231545.1\tLN:2196\n@SQ\tSN:APMT01231546.1\tLN:2196\n@SQ\tSN:KB714509.1\tLN:2195\n@SQ\tSN:APMT01231548.1\tLN:2195\n@SQ\tSN:KB714394.1\tLN:2194\n@SQ\tSN:APMT01231192.1\tLN:2194\n@SQ\tSN:APMT01231547.1\tLN:2194\n@SQ\tSN:APMT01231550.1\tLN:2194\n@SQ\tSN:APMT01231333.1\tLN:2193\n@SQ\tSN:APMT01231444.1\tLN:2193\n@SQ\tSN:APMT01231553.1\tLN:2193\n@SQ\tSN:APMT01231459.1\tLN:2192\n@SQ\tSN:APMT01231555.1\tLN:2192\n@SQ\tSN:APMT01231556.1\tLN:2192\n@SQ\tSN:APMT01231557.1\tLN:2192\n@SQ\tSN:APMT01231558.1\tLN:2192\n@SQ\tSN:KB714403.1\tLN:2191\n@SQ\tSN:KB714513.1\tLN:2191\n@SQ\tSN:APMT01231559.1\tLN:2191\n@SQ\tSN:APMT01231561.1\tLN:2190\n@SQ\tSN:APMT01231562.1\tLN:2190\n@SQ\tSN:KB712402.1\tLN:2189\n@SQ\tSN:KB714492.1\tLN:2189\n@SQ\tSN:APMT01231565.1\tLN:2189\n@SQ\tSN:APMT01231566.1\tLN:2189\n@SQ\tSN:APMT01231334.1\tLN:2188\n@SQ\tSN:APMT01231567.1\tLN:2188\n@SQ\tSN:KB714168.1\tLN:2187\n@SQ\tSN:APMT01231381.1\tLN:2187\n@SQ\tSN:APMT01231569.1\tLN:2187\n@SQ\tSN:APMT01231570.1\tLN:2187\n@SQ\tSN:APMT01231343.1\tLN:2186\n@SQ\tSN:APMT01231573.1\tLN:2186\n@SQ\tSN:APMT01231574.1\tLN:2186\n@SQ\tSN:APMT01231578.1\tLN:2185\n@SQ\tSN:APMT01231864.1\tLN:2185\n@SQ\tSN:KB714483.1\tLN:2184\n@SQ\tSN:KB714517.1\tLN:2184\n@SQ\tSN:APMT01231438.1\tLN:2184\n@SQ\tSN:APMT01231579.1\tLN:2184\n@SQ\tSN:APMT01231581.1\tLN:2183\n@SQ\tSN:APMT01231367.1\tLN:2182\n@SQ\tSN:APMT01231403.1\tLN:2182\n@SQ\tSN:APMT01231441.1\tLN:2182\n@SQ\tSN:APMT01231585.1\tLN:2182\n@SQ\tSN:APMT01231586.1\tLN:2182\n@SQ\tSN:APMT01231587.1\tLN:2182\n@SQ\tSN:APMT01231588.1\tLN:2182\n@SQ\tSN:APMT01231423.1\tLN:2181\n@SQ\tSN:APMT01231874.1\tLN:2181\n@SQ\tSN:APMT01231366.1\tLN:2180\n@SQ\tSN:APMT01231436.1\tLN:2180\n@SQ\tSN:APMT01231458.1\tLN:2180\n@SQ\tSN:APMT01231571.1\tLN:2180\n@SQ\tSN:APMT01231590.1\tLN:2180\n@SQ\tSN:APMT01231591.1\tLN:2180\n@SQ\tSN:APMT01231589.1\tLN:2179\n@SQ\tSN:APMT01231377.1\tLN:2178\n@SQ\tSN:APMT01231594.1\tLN:2178\n@SQ\tSN:APMT01231595.1\tLN:2178\n@SQ\tSN:APMT01231598.1\tLN:2178\n@SQ\tSN:APMT01231353.1\tLN:2177\n@SQ\tSN:APMT01231599.1\tLN:2177\n@SQ\tSN:APMT01231392.1\tLN:2175\n@SQ\tSN:APMT01231604.1\tLN:2175\n@SQ\tSN:KB714501.1\tLN:2174\n@SQ\tSN:APMT01231607.1\tLN:2174\n@SQ\tSN:APMT01231387.1\tLN:2173\n@SQ\tSN:APMT01231609.1\tLN:2173\n@SQ\tSN:APMT01231612.1\tLN:2173\n@SQ\tSN:KB712677.1\tLN:2172\n@SQ\tSN:KB714484.1\tLN:2172\n@SQ\tSN:APMT01231615.1\tLN:2172\n@SQ\tSN:APMT01231616.1\tLN:2172\n@SQ\tSN:APMT01231617.1\tLN:2172\n@SQ\tSN:APMT01231618.1\tLN:2172\n@SQ\tSN:KB714550.1\tLN:2171\n@SQ\tSN:APMT01231619.1\tLN:2171\n@SQ\tSN:APMT01231621.1\tLN:2171\n@SQ\tSN:APMT01231622.1\tLN:2171\n@SQ\tSN:APMT01231624.1\tLN:2171\n@SQ\tSN:APMT01231625.1\tLN:2171\n@SQ\tSN:APMT01231503.1\tLN:2170\n@SQ\tSN:APMT01231552.1\tLN:2170\n@SQ\tSN:APMT01231628.1\tLN:2170\n@SQ\tSN:APMT01231629.1\tLN:2170\n@SQ\tSN:APMT01231630.1\tLN:2170\n@SQ\tSN:APMT01231632.1\tLN:2170\n@SQ\tSN:APMT01231633.1\tLN:2170\n@SQ\tSN:APMT01231634.1\tLN:2170\n@SQ\tSN:APMT01231635.1\tLN:2170\n@SQ\tSN:APMT01231729.1\tLN:2169\n@SQ\tSN:KB714499.1\tLN:2168\n@SQ\tSN:APMT01231631.1\tLN:2168\n@SQ\tSN:APMT01231608.1\tLN:2167\n@SQ\tSN:APMT01231638.1\tLN:2167\n@SQ\tSN:KB714528.1\tLN:2166\n@SQ\tSN:APMT01231639.1\tLN:2166\n@SQ\tSN:APMT01231640.1\tLN:2166\n@SQ\tSN:KB713889.1\tLN:2165\n@SQ\tSN:APMT01231645.1\tLN:2165\n@SQ\tSN:KB714527.1\tLN:2164\n@SQ\tSN:APMT01231646.1\tLN:2164\n@SQ\tSN:APMT01231451.1\tLN:2163\n@SQ\tSN:APMT01231551.1\tLN:2163\n@SQ\tSN:APMT01231647.1\tLN:2163\n@SQ\tSN:APMT01231649.1\tLN:2163\n@SQ\tSN:APMT01231650.1\tLN:2163\n@SQ\tSN:APMT01231651.1\tLN:2163\n@SQ\tSN:APMT01231486.1\tLN:2162\n@SQ\tSN:APMT01231652.1\tLN:2162\n@SQ\tSN:APMT01231653.1\tLN:2162\n@SQ\tSN:APMT01231636.1\tLN:2161\n@SQ\tSN:APMT01231655.1\tLN:2161\n@SQ\tSN:KB714546.1\tLN:2160\n@SQ\tSN:APMT01231549.1\tLN:2160\n@SQ\tSN:APMT01231659.1\tLN:2160\n@SQ\tSN:APMT01231661.1\tLN:2160\n@SQ\tSN:APMT01231664.1\tLN:2159\n@SQ\tSN:APMT01231666.1\tLN:2159\n@SQ\tSN:APMT01231665.1\tLN:2158\n@SQ\tSN:APMT01230945.1\tLN:2156\n@SQ\tSN:KB714535.1\tLN:2155\n@SQ\tSN:APMT01231357.1\tLN:2155\n@SQ\tSN:APMT01231671.1\tLN:2155\n@SQ\tSN:APMT01231672.1\tLN:2155\n@SQ\tSN:APMT01231673.1\tLN:2155\n@SQ\tSN:KB714181.1\tLN:2153\n@SQ\tSN:APMT01231480.1\tLN:2153\n@SQ\tSN:APMT01231678.1\tLN:2153\n@SQ\tSN:APMT01231681.1\tLN:2153\n@SQ\tSN:APMT01231682.1\tLN:2153\n@SQ\tSN:KB714139.1\tLN:2152\n@SQ\tSN:APMT01231390.1\tLN:2152\n@SQ\tSN:APMT01231481.1\tLN:2152\n@SQ\tSN:APMT01231485.1\tLN:2152\n@SQ\tSN:APMT01231563.1\tLN:2152\n@SQ\tSN:APMT01231576.1\tLN:2152\n@SQ\tSN:APMT01231239.1\tLN:2151\n@SQ\tSN:APMT01231470.1\tLN:2151\n@SQ\tSN:APMT01231493.1\tLN:2151\n@SQ\tSN:APMT01231685.1\tLN:2151\n@SQ\tSN:APMT01231686.1\tLN:2151\n@SQ\tSN:APMT01231687.1\tLN:2151\n@SQ\tSN:APMT01231688.1\tLN:2151\n@SQ\tSN:APMT01231684.1\tLN:2150\n@SQ\tSN:APMT01231691.1\tLN:2150\n@SQ\tSN:APMT01231692.1\tLN:2150\n@SQ\tSN:KB709557.1\tLN:2149\n@SQ\tSN:APMT01231674.1\tLN:2149\n@SQ\tSN:APMT01231698.1\tLN:2149\n@SQ\tSN:KB714473.1\tLN:2148\n@SQ\tSN:APMT01231504.1\tLN:2148\n@SQ\tSN:APMT01231575.1\tLN:2148\n@SQ\tSN:APMT01231610.1\tLN:2148\n@SQ\tSN:APMT01231697.1\tLN:2148\n@SQ\tSN:APMT01231700.1\tLN:2148\n@SQ\tSN:APMT01231702.1\tLN:2148\n@SQ\tSN:APMT01231703.1\tLN:2148\n@SQ\tSN:APMT01231704.1\tLN:2147\n@SQ\tSN:APMT01231705.1\tLN:2147\n@SQ\tSN:APMT01231707.1\tLN:2147\n@SQ\tSN:APMT01231709.1\tLN:2146\n@SQ\tSN:APMT01231710.1\tLN:2146\n@SQ\tSN:APMT01231711.1\tLN:2146\n@SQ\tSN:APMT01231715.1\tLN:2144\n@SQ\tSN:APMT01231716.1\tLN:2144\n@SQ\tSN:APMT01231717.1\tLN:2144\n@SQ\tSN:APMT01231718.1\tLN:2143\n@SQ\tSN:APMT01231719.1\tLN:2143\n@SQ\tSN:APMT01231841.1\tLN:2143\n@SQ\tSN:APMT01230883.1\tLN:2142\n@SQ\tSN:APMT01231582.1\tLN:2142\n@SQ\tSN:APMT01231723.1\tLN:2142\n@SQ\tSN:KB711054.1\tLN:2141\n@SQ\tSN:KB713605.1\tLN:2141\n@SQ\tSN:APMT01231696.1\tLN:2141\n@SQ\tSN:APMT01231724.1\tLN:2141\n@SQ\tSN:APMT01231727.1\tLN:2141\n@SQ\tSN:KB714504.1\tLN:2140\n@SQ\tSN:APMT01231592.1\tLN:2140\n@SQ\tSN:APMT01231627.1\tLN:2140\n@SQ\tSN:APMT01231730.1\tLN:2140\n@SQ\tSN:APMT01231731.1\tLN:2140\n@SQ\tSN:APMT01231732.1\tLN:2140\n@SQ\tSN:APMT01231733.1\tLN:2140\n@SQ\tSN:APMT01231735.1\tLN:2140\n@SQ\tSN:APMT01231530.1\tLN:2139\n@SQ\tSN:APMT01231728.1\tLN:2139\n@SQ\tSN:APMT01231737.1\tLN:2139\n@SQ\tSN:APMT01231738.1\tLN:2139\n@SQ\tSN:APMT01231741.1\tLN:2138\n@SQ\tSN:APMT01231742.1\tLN:2138\n@SQ\tSN:APMT01231745.1\tLN:2138\n@SQ\tSN:APMT01231754.1\tLN:2138\n@SQ\tSN:KB714370.1\tLN:2137\n@SQ\tSN:APMT01231605.1\tLN:2137\n@SQ\tSN:APMT01231739.1\tLN:2137\n@SQ\tSN:APMT01231749.1\tLN:2137\n@SQ\tSN:APMT01231751.1\tLN:2137\n@SQ\tSN:APMT01231734.1\tLN:2136\n@SQ\tSN:APMT01231755.1\tLN:2135\n@SQ\tSN:APMT01231756.1\tLN:2135\n@SQ\tSN:APMT01231757.1\tLN:2135\n@SQ\tSN:APMT01231701.1\tLN:2134\n@SQ\tSN:APMT01231760.1\tLN:2134\n@SQ\tSN:APMT01231763.1\tLN:2133\n@SQ\tSN:APMT01231662.1\tLN:2132\n@SQ\tSN:APMT01231761.1\tLN:2132\n@SQ\tSN:APMT01231769.1\tLN:2132\n@SQ\tSN:APMT01231620.1\tLN:2131\n@SQ\tSN:APMT01231907.1\tLN:2131\n@SQ\tSN:APMT01231564.1\tLN:2129\n@SQ\tSN:APMT01231775.1\tLN:2129\n@SQ\tSN:APMT01231776.1\tLN:2129\n@SQ\tSN:APMT01231777.1\tLN:2129\n@SQ\tSN:KB714443.1\tLN:2128\n@SQ\tSN:APMT01231623.1\tLN:2128\n@SQ\tSN:APMT01231779.1\tLN:2128\n@SQ\tSN:APMT01231780.1\tLN:2128\n@SQ\tSN:APMT01231781.1\tLN:2128\n@SQ\tSN:APMT01231782.1\tLN:2128\n@SQ\tSN:APMT01231568.1\tLN:2127\n@SQ\tSN:APMT01231783.1\tLN:2127\n@SQ\tSN:APMT01231572.1\tLN:2126\n@SQ\tSN:APMT01231611.1\tLN:2126\n@SQ\tSN:APMT01231770.1\tLN:2126\n@SQ\tSN:APMT01231785.1\tLN:2126\n@SQ\tSN:APMT01231786.1\tLN:2126\n@SQ\tSN:APMT01231787.1\tLN:2126\n@SQ\tSN:APMT01231788.1\tLN:2126\n@SQ\tSN:APMT01231789.1\tLN:2126\n@SQ\tSN:APMT01231626.1\tLN:2125\n@SQ\tSN:APMT01231790.1\tLN:2125\n@SQ\tSN:KB714566.1\tLN:2124\n@SQ\tSN:APMT01231706.1\tLN:2124\n@SQ\tSN:APMT01231791.1\tLN:2124\n@SQ\tSN:APMT01231792.1\tLN:2124\n@SQ\tSN:APMT01231793.1\tLN:2124\n@SQ\tSN:APMT01231794.1\tLN:2124\n@SQ\tSN:APMT01231795.1\tLN:2123\n@SQ\tSN:APMT01231796.1\tLN:2123\n@SQ\tSN:APMT01231811.1\tLN:2123\n@SQ\tSN:APMT01231798.1\tLN:2122\n@SQ\tSN:APMT01231799.1\tLN:2122\n@SQ\tSN:APMT01231800.1\tLN:2122\n@SQ\tSN:APMT01231801.1\tLN:2122\n@SQ\tSN:APMT01231802.1\tLN:2122\n@SQ\tSN:APMT01231596.1\tLN:2121\n@SQ\tSN:APMT01231803.1\tLN:2121\n@SQ\tSN:APMT01231804.1\tLN:2121\n@SQ\tSN:APMT01231806.1\tLN:2121\n@SQ\tSN:APMT01231606.1\tLN:2120\n@SQ\tSN:APMT01231644.1\tLN:2120\n@SQ\tSN:APMT01231808.1\tLN:2120\n@SQ\tSN:APMT01231809.1\tLN:2120\n@SQ\tSN:APMT01231414.1\tLN:2119\n@SQ\tSN:APMT01231810.1\tLN:2119\n@SQ\tSN:APMT01232093.1\tLN:2119\n@SQ\tSN:KB714415.1\tLN:2118\n@SQ\tSN:APMT01231541.1\tLN:2118\n@SQ\tSN:APMT01231593.1\tLN:2118\n@SQ\tSN:APMT01231812.1\tLN:2118\n@SQ\tSN:APMT01231813.1\tLN:2118\n@SQ\tSN:KB710009.1\tLN:2117\n@SQ\tSN:APMT01231597.1\tLN:2117\n@SQ\tSN:APMT01231663.1\tLN:2117\n@SQ\tSN:APMT01231683.1\tLN:2117\n@SQ\tSN:APMT01231712.1\tLN:2117\n@SQ\tSN:APMT01231816.1\tLN:2117\n@SQ\tSN:APMT01231817.1\tLN:2117\n@SQ\tSN:APMT01231818.1\tLN:2117\n@SQ\tSN:APMT01231819.1\tLN:2117\n@SQ\tSN:APMT01231820.1\tLN:2117\n@SQ\tSN:APMT01231822.1\tLN:2117\n@SQ\tSN:APMT01231415.1\tLN:2116\n@SQ\tSN:APMT01231815.1\tLN:2116\n@SQ\tSN:APMT01231823.1\tLN:2116\n@SQ\tSN:APMT01231824.1\tLN:2116\n@SQ\tSN:APMT01231827.1\tLN:2115\n@SQ\tSN:KB714488.1\tLN:2114\n@SQ\tSN:APMT01231829.1\tLN:2114\n@SQ\tSN:APMT01231830.1\tLN:2114\n@SQ\tSN:APMT01231831.1\tLN:2114\n@SQ\tSN:APMT01231834.1\tLN:2113\n@SQ\tSN:APMT01231840.1\tLN:2113\n@SQ\tSN:KB714532.1\tLN:2112\n@SQ\tSN:APMT01231842.1\tLN:2112\n@SQ\tSN:APMT01231843.1\tLN:2112\n@SQ\tSN:APMT01230320.1\tLN:2111\n@SQ\tSN:KB714562.1\tLN:2111\n@SQ\tSN:APMT01231600.1\tLN:2111\n@SQ\tSN:APMT01231613.1\tLN:2111\n@SQ\tSN:APMT01231846.1\tLN:2111\n@SQ\tSN:APMT01231601.1\tLN:2110\n@SQ\tSN:APMT01231847.1\tLN:2110\n@SQ\tSN:APMT01231848.1\tLN:2110\n@SQ\tSN:APMT01231850.1\tLN:2110\n@SQ\tSN:APMT01231748.1\tLN:2109\n@SQ\tSN:APMT01231849.1\tLN:2109\n@SQ\tSN:APMT01231852.1\tLN:2109\n@SQ\tSN:KB714429.1\tLN:2108\n@SQ\tSN:APMT01231854.1\tLN:2108\n@SQ\tSN:APMT01231855.1\tLN:2108\n@SQ\tSN:APMT01231856.1\tLN:2107\n@SQ\tSN:APMT01231857.1\tLN:2107\n@SQ\tSN:APMT01231859.1\tLN:2107\n@SQ\tSN:APMT01231654.1\tLN:2106\n@SQ\tSN:APMT01231861.1\tLN:2106\n@SQ\tSN:APMT01231862.1\tLN:2106\n@SQ\tSN:APMT01231863.1\tLN:2106\n@SQ\tSN:APMT01231660.1\tLN:2105\n@SQ\tSN:APMT01231858.1\tLN:2105\n@SQ\tSN:APMT01231648.1\tLN:2104\n@SQ\tSN:APMT01231865.1\tLN:2104\n@SQ\tSN:APMT01231866.1\tLN:2104\n@SQ\tSN:APMT01231669.1\tLN:2103\n@SQ\tSN:APMT01231867.1\tLN:2103\n@SQ\tSN:APMT01231868.1\tLN:2103\n@SQ\tSN:APMT01231869.1\tLN:2103\n@SQ\tSN:APMT01231870.1\tLN:2103\n@SQ\tSN:APMT01231871.1\tLN:2103\n@SQ\tSN:KB714564.1\tLN:2102\n@SQ\tSN:APMT01231872.1\tLN:2102\n@SQ\tSN:APMT01231875.1\tLN:2102\n@SQ\tSN:APMT01231876.1\tLN:2102\n@SQ\tSN:APMT01231835.1\tLN:2101\n@SQ\tSN:APMT01231877.1\tLN:2101\n@SQ\tSN:APMT01231879.1\tLN:2101\n@SQ\tSN:APMT01231766.1\tLN:2100\n@SQ\tSN:APMT01231880.1\tLN:2100\n@SQ\tSN:APMT01231882.1\tLN:2100\n@SQ\tSN:APMT01231883.1\tLN:2100\n@SQ\tSN:APMT01231885.1\tLN:2099\n@SQ\tSN:APMT01231886.1\tLN:2099\n@SQ\tSN:KB714576.1\tLN:2098\n@SQ\tSN:APMT01231888.1\tLN:2098\n@SQ\tSN:APMT01231889.1\tLN:2098\n@SQ\tSN:APMT01231890.1\tLN:2098\n@SQ\tSN:KB714519.1\tLN:2097\n@SQ\tSN:KB714548.1\tLN:2097\n@SQ\tSN:APMT01231807.1\tLN:2097\n@SQ\tSN:APMT01231891.1\tLN:2097\n@SQ\tSN:KB714413.1\tLN:2096\n@SQ\tSN:APMT01231896.1\tLN:2096\n@SQ\tSN:APMT01231897.1\tLN:2096\n@SQ\tSN:APMT01231901.1\tLN:2096\n@SQ\tSN:APMT01231902.1\tLN:2096\n@SQ\tSN:APMT01231898.1\tLN:2095\n@SQ\tSN:KB714430.1\tLN:2093\n@SQ\tSN:KB714477.1\tLN:2093\n@SQ\tSN:APMT01231908.1\tLN:2093\n@SQ\tSN:APMT01230913.1\tLN:2092\n@SQ\tSN:APMT01231909.1\tLN:2092\n@SQ\tSN:APMT01231910.1\tLN:2092\n@SQ\tSN:APMT01231911.1\tLN:2092\n@SQ\tSN:APMT01231912.1\tLN:2092\n@SQ\tSN:APMT01231913.1\tLN:2091\n@SQ\tSN:APMT01231982.1\tLN:2090\n@SQ\tSN:KB712398.1\tLN:2089\n@SQ\tSN:KB714547.1\tLN:2089\n@SQ\tSN:APMT01231577.1\tLN:2089\n@SQ\tSN:APMT01231918.1\tLN:2089\n@SQ\tSN:APMT01231919.1\tLN:2089\n@SQ\tSN:APMT01231920.1\tLN:2089\n@SQ\tSN:APMT01231922.1\tLN:2089\n@SQ\tSN:APMT01231923.1\tLN:2089\n@SQ\tSN:APMT01231924.1\tLN:2089\n@SQ\tSN:APMT01231750.1\tLN:2088\n@SQ\tSN:APMT01231925.1\tLN:2088\n@SQ\tSN:APMT01231926.1\tLN:2088\n@SQ\tSN:APMT01231927.1\tLN:2088\n@SQ\tSN:APMT01231928.1\tLN:2088\n@SQ\tSN:APMT01231930.1\tLN:2088\n@SQ\tSN:APMT01231931.1\tLN:2087\n@SQ\tSN:APMT01231933.1\tLN:2087\n@SQ\tSN:APMT01231934.1\tLN:2087\n@SQ\tSN:APMT01231752.1\tLN:2086\n@SQ\tSN:APMT01231929.1\tLN:2086\n@SQ\tSN:APMT01231935.1\tLN:2086\n@SQ\tSN:APMT01231936.1\tLN:2086\n@SQ\tSN:APMT01231937.1\tLN:2086\n@SQ\tSN:APMT01231938.1\tLN:2086\n@SQ\tSN:APMT01231708.1\tLN:2085\n@SQ\tSN:APMT01231747.1\tLN:2085\n@SQ\tSN:APMT01231939.1\tLN:2084\n@SQ\tSN:APMT01231940.1\tLN:2084\n@SQ\tSN:APMT01231720.1\tLN:2083\n@SQ\tSN:APMT01231736.1\tLN:2083\n@SQ\tSN:APMT01231941.1\tLN:2083\n@SQ\tSN:APMT01231942.1\tLN:2083\n@SQ\tSN:KB714508.1\tLN:2082\n@SQ\tSN:APMT01231746.1\tLN:2082\n@SQ\tSN:APMT01231699.1\tLN:2081\n@SQ\tSN:APMT01231784.1\tLN:2081\n@SQ\tSN:APMT01231887.1\tLN:2081\n@SQ\tSN:APMT01231944.1\tLN:2081\n@SQ\tSN:APMT01231945.1\tLN:2081\n@SQ\tSN:APMT01231873.1\tLN:2080\n@SQ\tSN:APMT01231947.1\tLN:2080\n@SQ\tSN:APMT01231948.1\tLN:2080\n@SQ\tSN:KB713908.1\tLN:2079\n@SQ\tSN:APMT01231949.1\tLN:2079\n@SQ\tSN:APMT01231950.1\tLN:2079\n@SQ\tSN:APMT01231951.1\tLN:2079\n@SQ\tSN:APMT01231952.1\tLN:2079\n@SQ\tSN:APMT01231953.1\tLN:2079\n@SQ\tSN:APMT01231580.1\tLN:2078\n@SQ\tSN:APMT01231675.1\tLN:2078\n@SQ\tSN:APMT01231954.1\tLN:2078\n@SQ\tSN:APMT01231740.1\tLN:2077\n@SQ\tSN:APMT01231839.1\tLN:2077\n@SQ\tSN:APMT01231957.1\tLN:2076\n@SQ\tSN:APMT01231958.1\tLN:2076\n@SQ\tSN:APMT01231961.1\tLN:2074\n@SQ\tSN:APMT01231962.1\tLN:2074\n@SQ\tSN:APMT01231771.1\tLN:2073\n@SQ\tSN:APMT01231964.1\tLN:2073\n@SQ\tSN:APMT01231965.1\tLN:2073\n@SQ\tSN:APMT01231966.1\tLN:2073\n@SQ\tSN:APMT01231967.1\tLN:2072\n@SQ\tSN:APMT01231968.1\tLN:2072\n@SQ\tSN:APMT01231670.1\tLN:2071\n@SQ\tSN:APMT01231969.1\tLN:2071\n@SQ\tSN:APMT01231970.1\tLN:2071\n@SQ\tSN:APMT01231971.1\tLN:2071\n@SQ\tSN:APMT01231828.1\tLN:2070\n@SQ\tSN:APMT01231974.1\tLN:2070\n@SQ\tSN:APMT01231975.1\tLN:2070\n@SQ\tSN:APMT01231976.1\tLN:2070\n@SQ\tSN:APMT01231778.1\tLN:2069\n@SQ\tSN:APMT01231853.1\tLN:2069\n@SQ\tSN:APMT01231973.1\tLN:2069\n@SQ\tSN:APMT01231977.1\tLN:2069\n@SQ\tSN:APMT01231979.1\tLN:2069\n@SQ\tSN:APMT01231774.1\tLN:2068\n@SQ\tSN:APMT01231980.1\tLN:2068\n@SQ\tSN:APMT01231981.1\tLN:2068\n@SQ\tSN:APMT01231983.1\tLN:2068\n@SQ\tSN:APMT01231984.1\tLN:2068\n@SQ\tSN:APMT01231753.1\tLN:2067\n@SQ\tSN:APMT01231892.1\tLN:2067\n@SQ\tSN:APMT01231985.1\tLN:2067\n@SQ\tSN:APMT01231987.1\tLN:2066\n@SQ\tSN:APMT01231988.1\tLN:2066\n@SQ\tSN:APMT01231989.1\tLN:2066\n@SQ\tSN:APMT01231990.1\tLN:2066\n@SQ\tSN:APMT01231991.1\tLN:2065\n@SQ\tSN:APMT01231992.1\tLN:2065\n@SQ\tSN:APMT01231993.1\tLN:2065\n@SQ\tSN:APMT01231994.1\tLN:2064\n@SQ\tSN:APMT01226349.1\tLN:2063\n@SQ\tSN:APMT01231797.1\tLN:2063\n@SQ\tSN:APMT01231614.1\tLN:2062\n@SQ\tSN:APMT01231996.1\tLN:2062\n@SQ\tSN:APMT01231997.1\tLN:2062\n@SQ\tSN:APMT01230540.1\tLN:2061\n@SQ\tSN:KB714563.1\tLN:2061\n@SQ\tSN:APMT01232001.1\tLN:2061\n@SQ\tSN:APMT01232002.1\tLN:2061\n@SQ\tSN:APMT01231805.1\tLN:2060\n@SQ\tSN:APMT01231998.1\tLN:2060\n@SQ\tSN:APMT01232000.1\tLN:2060\n@SQ\tSN:APMT01231814.1\tLN:2059\n@SQ\tSN:APMT01232004.1\tLN:2059\n@SQ\tSN:APMT01232005.1\tLN:2059\n@SQ\tSN:APMT01231963.1\tLN:2058\n@SQ\tSN:APMT01232008.1\tLN:2058\n@SQ\tSN:APMT01232009.1\tLN:2058\n@SQ\tSN:APMT01232010.1\tLN:2058\n@SQ\tSN:APMT01229710.1\tLN:2057\n@SQ\tSN:APMT01231838.1\tLN:2057\n@SQ\tSN:APMT01232007.1\tLN:2057\n@SQ\tSN:APMT01231821.1\tLN:2056\n@SQ\tSN:APMT01232011.1\tLN:2056\n@SQ\tSN:APMT01231851.1\tLN:2055\n@SQ\tSN:APMT01232012.1\tLN:2055\n@SQ\tSN:APMT01232013.1\tLN:2055\n@SQ\tSN:APMT01232014.1\tLN:2055\n@SQ\tSN:APMT01232015.1\tLN:2055\n@SQ\tSN:KB714433.1\tLN:2053\n@SQ\tSN:KB714533.1\tLN:2053\n@SQ\tSN:APMT01231999.1\tLN:2053\n@SQ\tSN:APMT01232016.1\tLN:2053\n@SQ\tSN:APMT01232018.1\tLN:2053\n@SQ\tSN:APMT01232019.1\tLN:2053\n@SQ\tSN:KB714506.1\tLN:2052\n@SQ\tSN:APMT01231637.1\tLN:2052\n@SQ\tSN:APMT01232021.1\tLN:2052\n@SQ\tSN:APMT01231900.1\tLN:2051\n@SQ\tSN:APMT01232022.1\tLN:2051\n@SQ\tSN:APMT01232023.1\tLN:2051\n@SQ\tSN:APMT01232024.1\tLN:2051\n@SQ\tSN:APMT01232025.1\tLN:2051\n@SQ\tSN:APMT01232027.1\tLN:2051\n@SQ\tSN:KB714507.1\tLN:2050\n@SQ\tSN:APMT01231884.1\tLN:2050\n@SQ\tSN:APMT01231895.1\tLN:2050\n@SQ\tSN:APMT01231905.1\tLN:2050\n@SQ\tSN:APMT01231956.1\tLN:2050\n@SQ\tSN:APMT01231972.1\tLN:2050\n@SQ\tSN:APMT01232028.1\tLN:2050\n@SQ\tSN:APMT01232029.1\tLN:2050\n@SQ\tSN:APMT01232030.1\tLN:2050\n@SQ\tSN:KB712280.1\tLN:2049\n@SQ\tSN:KB714549.1\tLN:2049\n@SQ\tSN:APMT01232034.1\tLN:2049\n@SQ\tSN:APMT01232033.1\tLN:2048\n@SQ\tSN:APMT01232038.1\tLN:2047\n@SQ\tSN:APMT01232039.1\tLN:2047\n@SQ\tSN:APMT01232041.1\tLN:2047\n@SQ\tSN:KB714108.1\tLN:2046\n@SQ\tSN:APMT01231921.1\tLN:2046\n@SQ\tSN:APMT01232043.1\tLN:2046\n@SQ\tSN:APMT01232044.1\tLN:2046\n@SQ\tSN:KB714559.1\tLN:2044\n@SQ\tSN:APMT01232020.1\tLN:2044\n@SQ\tSN:APMT01232216.1\tLN:2044\n@SQ\tSN:APMT01231906.1\tLN:2043\n@SQ\tSN:KB714537.1\tLN:2042\n@SQ\tSN:APMT01232048.1\tLN:2042\n@SQ\tSN:APMT01231695.1\tLN:2041\n@SQ\tSN:APMT01231899.1\tLN:2041\n@SQ\tSN:APMT01231943.1\tLN:2041\n@SQ\tSN:APMT01232051.1\tLN:2041\n@SQ\tSN:APMT01232052.1\tLN:2041\n@SQ\tSN:APMT01231878.1\tLN:2040\n@SQ\tSN:APMT01232054.1\tLN:2040\n@SQ\tSN:APMT01232055.1\tLN:2040\n@SQ\tSN:APMT01232056.1\tLN:2040\n@SQ\tSN:APMT01232057.1\tLN:2040\n@SQ\tSN:APMT01231986.1\tLN:2039\n@SQ\tSN:APMT01232058.1\tLN:2039\n@SQ\tSN:APMT01232062.1\tLN:2038\n@SQ\tSN:APMT01232063.1\tLN:2038\n@SQ\tSN:KB713437.1\tLN:2037\n@SQ\tSN:APMT01232049.1\tLN:2037\n@SQ\tSN:APMT01232064.1\tLN:2037\n@SQ\tSN:KB712879.1\tLN:2036\n@SQ\tSN:APMT01231959.1\tLN:2036\n@SQ\tSN:APMT01232065.1\tLN:2036\n@SQ\tSN:APMT01232066.1\tLN:2036\n@SQ\tSN:APMT01232067.1\tLN:2036\n@SQ\tSN:APMT01232006.1\tLN:2035\n@SQ\tSN:APMT01232069.1\tLN:2035\n@SQ\tSN:APMT01232071.1\tLN:2035\n@SQ\tSN:APMT01232072.1\tLN:2035\n@SQ\tSN:APMT01232073.1\tLN:2034\n@SQ\tSN:APMT01232074.1\tLN:2033\n@SQ\tSN:APMT01232075.1\tLN:2032\n@SQ\tSN:APMT01232076.1\tLN:2032\n@SQ\tSN:APMT01232077.1\tLN:2032\n@SQ\tSN:APMT01232078.1\tLN:2032\n@SQ\tSN:APMT01232080.1\tLN:2032\n@SQ\tSN:APMT01232082.1\tLN:2031\n@SQ\tSN:APMT01232083.1\tLN:2031\n@SQ\tSN:APMT01232084.1\tLN:2031\n@SQ\tSN:APMT01232085.1\tLN:2031\n@SQ\tSN:APMT01232086.1\tLN:2031\n@SQ\tSN:APMT01232088.1\tLN:2031\n@SQ\tSN:APMT01232089.1\tLN:2031\n@SQ\tSN:APMT01232090.1\tLN:2030\n@SQ\tSN:APMT01231916.1\tLN:2029\n@SQ\tSN:APMT01231917.1\tLN:2029\n@SQ\tSN:APMT01231946.1\tLN:2028\n@SQ\tSN:APMT01232061.1\tLN:2028\n@SQ\tSN:APMT01232095.1\tLN:2028\n@SQ\tSN:APMT01231955.1\tLN:2027\n@SQ\tSN:KB714457.1\tLN:2026\n@SQ\tSN:APMT01231932.1\tLN:2026\n@SQ\tSN:APMT01232100.1\tLN:2026\n@SQ\tSN:APMT01232102.1\tLN:2026\n@SQ\tSN:APMT01232081.1\tLN:2025\n@SQ\tSN:APMT01232103.1\tLN:2025\n@SQ\tSN:APMT01232104.1\tLN:2025\n@SQ\tSN:APMT01232105.1\tLN:2025\n@SQ\tSN:APMT01232107.1\tLN:2025\n@SQ\tSN:APMT01232108.1\tLN:2025\n@SQ\tSN:APMT01232109.1\tLN:2024\n@SQ\tSN:APMT01232113.1\tLN:2023\n@SQ\tSN:APMT01231762.1\tLN:2022\n@SQ\tSN:APMT01232110.1\tLN:2022\n@SQ\tSN:APMT01232053.1\tLN:2021\n@SQ\tSN:APMT01232115.1\tLN:2021\n@SQ\tSN:APMT01232116.1\tLN:2021\n@SQ\tSN:APMT01232117.1\tLN:2021\n@SQ\tSN:APMT01232118.1\tLN:2021\n@SQ\tSN:APMT01232046.1\tLN:2020\n@SQ\tSN:APMT01232119.1\tLN:2019\n@SQ\tSN:APMT01232122.1\tLN:2019\n@SQ\tSN:APMT01232124.1\tLN:2019\n@SQ\tSN:APMT01232042.1\tLN:2018\n@SQ\tSN:APMT01232125.1\tLN:2018\n@SQ\tSN:APMT01232126.1\tLN:2018\n@SQ\tSN:APMT01232127.1\tLN:2018\n@SQ\tSN:APMT01232123.1\tLN:2017\n@SQ\tSN:APMT01232129.1\tLN:2017\n@SQ\tSN:APMT01232131.1\tLN:2017\n@SQ\tSN:APMT01232130.1\tLN:2016\n@SQ\tSN:APMT01232134.1\tLN:2016\n@SQ\tSN:APMT01232135.1\tLN:2015\n@SQ\tSN:KB714545.1\tLN:2014\n@SQ\tSN:APMT01232136.1\tLN:2014\n@SQ\tSN:APMT01232137.1\tLN:2014\n@SQ\tSN:APMT01232138.1\tLN:2014\n@SQ\tSN:APMT01232139.1\tLN:2014\n@SQ\tSN:APMT01232140.1\tLN:2014\n@SQ\tSN:APMT01231960.1\tLN:2013\n@SQ\tSN:APMT01232141.1\tLN:2013\n@SQ\tSN:APMT01232142.1\tLN:2013\n@SQ\tSN:APMT01232144.1\tLN:2013\n@SQ\tSN:APMT01232146.1\tLN:2013\n@SQ\tSN:APMT01231301.1\tLN:2012\n@SQ\tSN:APMT01232031.1\tLN:2011\n@SQ\tSN:APMT01232079.1\tLN:2011\n@SQ\tSN:APMT01232094.1\tLN:2011\n@SQ\tSN:APMT01232121.1\tLN:2011\n@SQ\tSN:APMT01232147.1\tLN:2011\n@SQ\tSN:APMT01232153.1\tLN:2010\n@SQ\tSN:APMT01231978.1\tLN:2009\n@SQ\tSN:APMT01232154.1\tLN:2009\n@SQ\tSN:KB714279.1\tLN:2008\n@SQ\tSN:APMT01231522.1\tLN:2008\n@SQ\tSN:APMT01232026.1\tLN:2008\n@SQ\tSN:APMT01232112.1\tLN:2008\n@SQ\tSN:APMT01232155.1\tLN:2008\n@SQ\tSN:APMT01232156.1\tLN:2008\n@SQ\tSN:APMT01232157.1\tLN:2008\n@SQ\tSN:APMT01232159.1\tLN:2008\n@SQ\tSN:APMT01232160.1\tLN:2008\n@SQ\tSN:APMT01232161.1\tLN:2008\n@SQ\tSN:APMT01232162.1\tLN:2007\n@SQ\tSN:APMT01232163.1\tLN:2007\n@SQ\tSN:APMT01232164.1\tLN:2007\n@SQ\tSN:APMT01232070.1\tLN:2006\n@SQ\tSN:APMT01232166.1\tLN:2006\n@SQ\tSN:APMT01232167.1\tLN:2006\n@SQ\tSN:APMT01232168.1\tLN:2006\n@SQ\tSN:APMT01232170.1\tLN:2006\n@SQ\tSN:APMT01232171.1\tLN:2006\n@SQ\tSN:APMT01232172.1\tLN:2006\n@SQ\tSN:KB714579.1\tLN:2005\n@SQ\tSN:APMT01232003.1\tLN:2005\n@SQ\tSN:APMT01232175.1\tLN:2005\n@SQ\tSN:APMT01232176.1\tLN:2005\n@SQ\tSN:APMT01232150.1\tLN:2004\n@SQ\tSN:APMT01232178.1\tLN:2004\n@SQ\tSN:APMT01232179.1\tLN:2004\n@SQ\tSN:APMT01232174.1\tLN:2003\n@SQ\tSN:APMT01232177.1\tLN:2003\n@SQ\tSN:APMT01232183.1\tLN:2003\n@SQ\tSN:APMT01231995.1\tLN:2002\n@SQ\tSN:APMT01232098.1\tLN:2002\n@SQ\tSN:APMT01232185.1\tLN:2002\n@SQ\tSN:APMT01232187.1\tLN:2002\n@SQ\tSN:APMT01232050.1\tLN:2001\n@SQ\tSN:APMT01232190.1\tLN:2001\n@SQ\tSN:APMT01232193.1\tLN:2001\n@SQ\tSN:APMT01232035.1\tLN:2000\n@SQ\tSN:APMT01232152.1\tLN:2000\n@SQ\tSN:APMT01232188.1\tLN:2000\n@SQ\tSN:APMT01232189.1\tLN:2000\n@SQ\tSN:APMT01232040.1\tLN:1999\n@SQ\tSN:APMT01232194.1\tLN:1999\n@SQ\tSN:APMT01232195.1\tLN:1999\n@SQ\tSN:APMT01232196.1\tLN:1999\n@SQ\tSN:KB714597.1\tLN:1999\n@SQ\tSN:KB714330.1\tLN:1998\n@SQ\tSN:KB714567.1\tLN:1997\n@SQ\tSN:APMT01232184.1\tLN:1997\n@SQ\tSN:APMT01232197.1\tLN:1997\n@SQ\tSN:APMT01232198.1\tLN:1997\n@SQ\tSN:APMT01232199.1\tLN:1997\n@SQ\tSN:APMT01232200.1\tLN:1997\n@SQ\tSN:APMT01232201.1\tLN:1996\n@SQ\tSN:APMT01232204.1\tLN:1995\n@SQ\tSN:APMT01232205.1\tLN:1995\n@SQ\tSN:APMT01232206.1\tLN:1995\n@SQ\tSN:APMT01232207.1\tLN:1994\n@SQ\tSN:KB714238.1\tLN:1993\n@SQ\tSN:APMT01232017.1\tLN:1993\n@SQ\tSN:APMT01232099.1\tLN:1993\n@SQ\tSN:APMT01232208.1\tLN:1993\n@SQ\tSN:APMT01232209.1\tLN:1993\n@SQ\tSN:APMT01232210.1\tLN:1993\n@SQ\tSN:APMT01232211.1\tLN:1993\n@SQ\tSN:APMT01232212.1\tLN:1993\n@SQ\tSN:APMT01231860.1\tLN:1992\n@SQ\tSN:APMT01232217.1\tLN:1992\n@SQ\tSN:APMT01232032.1\tLN:1991\n@SQ\tSN:APMT01232218.1\tLN:1991\n@SQ\tSN:APMT01232219.1\tLN:1991\n@SQ\tSN:APMT01232220.1\tLN:1991\n@SQ\tSN:APMT01232221.1\tLN:1991\n@SQ\tSN:APMT01232345.1\tLN:1991\n@SQ\tSN:APMT01232037.1\tLN:1990\n@SQ\tSN:APMT01232223.1\tLN:1990\n@SQ\tSN:APMT01232047.1\tLN:1988\n@SQ\tSN:APMT01232226.1\tLN:1988\n@SQ\tSN:APMT01232227.1\tLN:1988\n@SQ\tSN:APMT01232229.1\tLN:1987\n@SQ\tSN:APMT01232230.1\tLN:1987\n@SQ\tSN:APMT01231881.1\tLN:1986\n@SQ\tSN:APMT01232120.1\tLN:1986\n@SQ\tSN:APMT01232222.1\tLN:1986\n@SQ\tSN:APMT01232231.1\tLN:1986\n@SQ\tSN:APMT01232232.1\tLN:1986\n@SQ\tSN:APMT01232233.1\tLN:1986\n@SQ\tSN:KB714540.1\tLN:1985\n@SQ\tSN:APMT01232234.1\tLN:1985\n@SQ\tSN:APMT01232236.1\tLN:1985\n@SQ\tSN:APMT01232132.1\tLN:1984\n@SQ\tSN:APMT01232045.1\tLN:1983\n@SQ\tSN:APMT01232239.1\tLN:1983\n@SQ\tSN:APMT01232240.1\tLN:1983\n@SQ\tSN:APMT01232241.1\tLN:1982\n@SQ\tSN:APMT01232243.1\tLN:1982\n@SQ\tSN:APMT01232173.1\tLN:1981\n@SQ\tSN:APMT01232244.1\tLN:1981\n@SQ\tSN:APMT01232245.1\tLN:1981\n@SQ\tSN:APMT01232246.1\tLN:1981\n@SQ\tSN:APMT01232247.1\tLN:1981\n@SQ\tSN:KB714561.1\tLN:1980\n@SQ\tSN:APMT01232060.1\tLN:1979\n@SQ\tSN:APMT01232250.1\tLN:1979\n@SQ\tSN:APMT01232251.1\tLN:1979\n@SQ\tSN:KB714538.1\tLN:1978\n@SQ\tSN:KB714577.1\tLN:1978\n@SQ\tSN:APMT01232059.1\tLN:1978\n@SQ\tSN:APMT01232068.1\tLN:1978\n@SQ\tSN:APMT01232249.1\tLN:1978\n@SQ\tSN:APMT01232253.1\tLN:1978\n@SQ\tSN:APMT01232092.1\tLN:1976\n@SQ\tSN:APMT01232254.1\tLN:1976\n@SQ\tSN:APMT01232255.1\tLN:1976\n@SQ\tSN:APMT01232256.1\tLN:1976\n@SQ\tSN:APMT01232258.1\tLN:1975\n@SQ\tSN:APMT01232259.1\tLN:1975\n@SQ\tSN:APMT01232165.1\tLN:1974\n@SQ\tSN:APMT01232181.1\tLN:1974\n@SQ\tSN:APMT01232260.1\tLN:1974\n@SQ\tSN:APMT01232262.1\tLN:1974\n@SQ\tSN:APMT01232263.1\tLN:1974\n@SQ\tSN:APMT01232265.1\tLN:1974\n@SQ\tSN:KB714553.1\tLN:1973\n@SQ\tSN:APMT01232106.1\tLN:1973\n@SQ\tSN:APMT01232268.1\tLN:1973\n@SQ\tSN:APMT01232269.1\tLN:1972\n@SQ\tSN:APMT01232270.1\tLN:1972\n@SQ\tSN:APMT01232271.1\tLN:1972\n@SQ\tSN:APMT01231469.1\tLN:1971\n@SQ\tSN:APMT01232087.1\tLN:1971\n@SQ\tSN:APMT01232096.1\tLN:1971\n@SQ\tSN:APMT01232238.1\tLN:1971\n@SQ\tSN:APMT01232091.1\tLN:1970\n@SQ\tSN:APMT01232273.1\tLN:1970\n@SQ\tSN:APMT01232274.1\tLN:1970\n@SQ\tSN:APMT01232275.1\tLN:1970\n@SQ\tSN:APMT01232276.1\tLN:1970\n@SQ\tSN:APMT01232277.1\tLN:1969\n@SQ\tSN:APMT01232280.1\tLN:1969\n@SQ\tSN:APMT01232111.1\tLN:1968\n@SQ\tSN:APMT01232158.1\tLN:1968\n@SQ\tSN:APMT01232213.1\tLN:1968\n@SQ\tSN:APMT01232278.1\tLN:1968\n@SQ\tSN:APMT01232282.1\tLN:1968\n@SQ\tSN:APMT01232283.1\tLN:1968\n@SQ\tSN:APMT01232284.1\tLN:1968\n@SQ\tSN:APMT01232285.1\tLN:1968\n@SQ\tSN:APMT01232267.1\tLN:1967\n@SQ\tSN:APMT01232101.1\tLN:1965\n@SQ\tSN:APMT01232149.1\tLN:1965\n@SQ\tSN:APMT01232292.1\tLN:1965\n@SQ\tSN:KB714589.1\tLN:1964\n@SQ\tSN:APMT01232294.1\tLN:1964\n@SQ\tSN:APMT01232261.1\tLN:1963\n@SQ\tSN:APMT01232290.1\tLN:1963\n@SQ\tSN:APMT01232296.1\tLN:1963\n@SQ\tSN:APMT01232299.1\tLN:1963\n@SQ\tSN:APMT01232114.1\tLN:1962\n@SQ\tSN:APMT01232301.1\tLN:1962\n@SQ\tSN:APMT01232302.1\tLN:1962\n@SQ\tSN:APMT01232303.1\tLN:1962\n@SQ\tSN:APMT01232304.1\tLN:1962\n@SQ\tSN:APMT01232305.1\tLN:1962\n@SQ\tSN:APMT01232306.1\tLN:1962\n@SQ\tSN:APMT01232310.1\tLN:1961\n@SQ\tSN:APMT01232311.1\tLN:1961\n@SQ\tSN:KB714199.1\tLN:1960\n@SQ\tSN:KB714531.1\tLN:1960\n@SQ\tSN:APMT01231554.1\tLN:1960\n@SQ\tSN:APMT01232133.1\tLN:1960\n@SQ\tSN:APMT01232309.1\tLN:1960\n@SQ\tSN:APMT01232312.1\tLN:1960\n@SQ\tSN:APMT01232313.1\tLN:1960\n@SQ\tSN:APMT01232314.1\tLN:1960\n@SQ\tSN:APMT01232315.1\tLN:1960\n@SQ\tSN:APMT01232316.1\tLN:1959\n@SQ\tSN:APMT01232317.1\tLN:1959\n@SQ\tSN:APMT01232323.1\tLN:1959\n@SQ\tSN:APMT01232300.1\tLN:1958\n@SQ\tSN:APMT01232318.1\tLN:1958\n@SQ\tSN:APMT01232319.1\tLN:1958\n@SQ\tSN:APMT01232320.1\tLN:1958\n@SQ\tSN:APMT01232332.1\tLN:1958\n@SQ\tSN:APMT01232322.1\tLN:1957\n@SQ\tSN:APMT01232324.1\tLN:1957\n@SQ\tSN:KB714512.1\tLN:1956\n@SQ\tSN:APMT01232264.1\tLN:1956\n@SQ\tSN:APMT01232325.1\tLN:1956\n@SQ\tSN:APMT01232326.1\tLN:1956\n@SQ\tSN:KB714595.1\tLN:1955\n@SQ\tSN:APMT01232148.1\tLN:1955\n@SQ\tSN:APMT01232224.1\tLN:1955\n@SQ\tSN:APMT01232327.1\tLN:1955\n@SQ\tSN:APMT01232328.1\tLN:1955\n@SQ\tSN:APMT01232329.1\tLN:1955\n@SQ\tSN:KB711371.1\tLN:1954\n@SQ\tSN:APMT01232036.1\tLN:1954\n@SQ\tSN:APMT01232330.1\tLN:1954\n@SQ\tSN:APMT01232331.1\tLN:1954\n@SQ\tSN:APMT01232291.1\tLN:1953\n@SQ\tSN:APMT01232333.1\tLN:1953\n@SQ\tSN:APMT01232334.1\tLN:1953\n@SQ\tSN:APMT01232335.1\tLN:1953\n@SQ\tSN:APMT01232337.1\tLN:1953\n@SQ\tSN:APMT01232338.1\tLN:1953\n@SQ\tSN:KB714578.1\tLN:1952\n@SQ\tSN:APMT01232145.1\tLN:1952\n@SQ\tSN:APMT01232340.1\tLN:1952\n@SQ\tSN:APMT01232341.1\tLN:1952\n@SQ\tSN:KB714587.1\tLN:1951\n@SQ\tSN:APMT01232343.1\tLN:1951\n@SQ\tSN:APMT01232344.1\tLN:1951\n@SQ\tSN:APMT01232346.1\tLN:1951\n@SQ\tSN:APMT01232347.1\tLN:1951\n@SQ\tSN:APMT01232348.1\tLN:1951\n@SQ\tSN:APMT01232151.1\tLN:1950\n@SQ\tSN:APMT01232349.1\tLN:1950\n@SQ\tSN:APMT01232350.1\tLN:1950\n@SQ\tSN:APMT01232339.1\tLN:1949\n@SQ\tSN:APMT01232351.1\tLN:1949\n@SQ\tSN:APMT01232352.1\tLN:1949\n@SQ\tSN:APMT01232353.1\tLN:1949\n@SQ\tSN:APMT01232354.1\tLN:1949\n@SQ\tSN:APMT01232356.1\tLN:1949\n@SQ\tSN:KB714124.1\tLN:1948\n@SQ\tSN:APMT01232169.1\tLN:1948\n@SQ\tSN:APMT01232359.1\tLN:1948\n@SQ\tSN:APMT01232360.1\tLN:1948\n@SQ\tSN:APMT01232355.1\tLN:1947\n@SQ\tSN:APMT01232363.1\tLN:1947\n@SQ\tSN:APMT01232419.1\tLN:1946\n@SQ\tSN:APMT01232191.1\tLN:1945\n@SQ\tSN:APMT01232298.1\tLN:1945\n@SQ\tSN:APMT01232365.1\tLN:1945\n@SQ\tSN:APMT01232321.1\tLN:1944\n@SQ\tSN:APMT01232364.1\tLN:1944\n@SQ\tSN:APMT01232370.1\tLN:1944\n@SQ\tSN:APMT01232371.1\tLN:1944\n@SQ\tSN:APMT01232372.1\tLN:1944\n@SQ\tSN:APMT01232235.1\tLN:1943\n@SQ\tSN:APMT01232293.1\tLN:1943\n@SQ\tSN:APMT01232373.1\tLN:1943\n@SQ\tSN:APMT01232374.1\tLN:1943\n@SQ\tSN:APMT01232375.1\tLN:1943\n@SQ\tSN:APMT01232376.1\tLN:1943\n@SQ\tSN:APMT01232377.1\tLN:1943\n@SQ\tSN:APMT01232378.1\tLN:1943\n@SQ\tSN:KB713661.1\tLN:1942\n@SQ\tSN:KB714458.1\tLN:1942\n@SQ\tSN:APMT01232361.1\tLN:1942\n@SQ\tSN:APMT01232379.1\tLN:1942\n@SQ\tSN:APMT01232380.1\tLN:1942\n@SQ\tSN:APMT01232381.1\tLN:1942\n@SQ\tSN:APMT01232192.1\tLN:1941\n@SQ\tSN:APMT01232382.1\tLN:1941\n@SQ\tSN:APMT01232383.1\tLN:1941\n@SQ\tSN:APMT01232384.1\tLN:1941\n@SQ\tSN:APMT01232266.1\tLN:1940\n@SQ\tSN:APMT01232386.1\tLN:1940\n@SQ\tSN:APMT01232390.1\tLN:1940\n@SQ\tSN:APMT01232391.1\tLN:1940\n@SQ\tSN:KB714505.1\tLN:1939\n@SQ\tSN:APMT01232202.1\tLN:1939\n@SQ\tSN:APMT01232388.1\tLN:1939\n@SQ\tSN:APMT01232389.1\tLN:1939\n@SQ\tSN:APMT01232392.1\tLN:1939\n@SQ\tSN:APMT01232393.1\tLN:1939\n@SQ\tSN:APMT01232397.1\tLN:1938\n@SQ\tSN:APMT01232400.1\tLN:1938\n@SQ\tSN:APMT01232387.1\tLN:1937\n@SQ\tSN:APMT01232402.1\tLN:1937\n@SQ\tSN:APMT01232403.1\tLN:1937\n@SQ\tSN:APMT01232404.1\tLN:1937\n@SQ\tSN:APMT01232281.1\tLN:1936\n@SQ\tSN:APMT01232406.1\tLN:1936\n@SQ\tSN:APMT01232407.1\tLN:1936\n@SQ\tSN:APMT01232408.1\tLN:1936\n@SQ\tSN:APMT01232409.1\tLN:1936\n@SQ\tSN:APMT01232186.1\tLN:1935\n@SQ\tSN:APMT01232203.1\tLN:1935\n@SQ\tSN:APMT01232215.1\tLN:1935\n@SQ\tSN:APMT01232257.1\tLN:1934\n@SQ\tSN:APMT01232410.1\tLN:1934\n@SQ\tSN:APMT01232411.1\tLN:1934\n@SQ\tSN:APMT01232412.1\tLN:1934\n@SQ\tSN:APMT01232405.1\tLN:1933\n@SQ\tSN:APMT01232396.1\tLN:1932\n@SQ\tSN:APMT01232420.1\tLN:1932\n@SQ\tSN:APMT01232421.1\tLN:1932\n@SQ\tSN:APMT01232422.1\tLN:1932\n@SQ\tSN:APMT01232425.1\tLN:1932\n@SQ\tSN:APMT01232433.1\tLN:1932\n@SQ\tSN:KB714426.1\tLN:1931\n@SQ\tSN:APMT01232426.1\tLN:1931\n@SQ\tSN:APMT01232428.1\tLN:1931\n@SQ\tSN:APMT01232429.1\tLN:1931\n@SQ\tSN:APMT01232430.1\tLN:1931\n@SQ\tSN:APMT01232427.1\tLN:1930\n@SQ\tSN:APMT01232432.1\tLN:1930\n@SQ\tSN:KB714570.1\tLN:1929\n@SQ\tSN:APMT01232214.1\tLN:1929\n@SQ\tSN:APMT01232336.1\tLN:1929\n@SQ\tSN:APMT01232436.1\tLN:1929\n@SQ\tSN:APMT01232437.1\tLN:1929\n@SQ\tSN:APMT01232438.1\tLN:1929\n@SQ\tSN:APMT01232439.1\tLN:1929\n@SQ\tSN:APMT01232440.1\tLN:1929\n@SQ\tSN:APMT01232441.1\tLN:1929\n@SQ\tSN:APMT01232242.1\tLN:1928\n@SQ\tSN:APMT01232367.1\tLN:1928\n@SQ\tSN:APMT01232442.1\tLN:1928\n@SQ\tSN:APMT01232443.1\tLN:1928\n@SQ\tSN:APMT01232444.1\tLN:1928\n@SQ\tSN:APMT01232445.1\tLN:1928\n@SQ\tSN:APMT01232446.1\tLN:1928\n@SQ\tSN:APMT01232447.1\tLN:1928\n@SQ\tSN:APMT01232448.1\tLN:1928\n@SQ\tSN:APMT01232471.1\tLN:1928\n@SQ\tSN:APMT01232450.1\tLN:1927\n@SQ\tSN:APMT01232453.1\tLN:1927\n@SQ\tSN:KB714582.1\tLN:1926\n@SQ\tSN:APMT01232452.1\tLN:1926\n@SQ\tSN:APMT01232454.1\tLN:1926\n@SQ\tSN:APMT01232455.1\tLN:1926\n@SQ\tSN:APMT01232456.1\tLN:1925\n@SQ\tSN:APMT01232457.1\tLN:1925\n@SQ\tSN:APMT01231560.1\tLN:1924\n@SQ\tSN:APMT01232459.1\tLN:1924\n@SQ\tSN:APMT01232460.1\tLN:1924\n@SQ\tSN:APMT01232461.1\tLN:1924\n@SQ\tSN:APMT01232462.1\tLN:1924\n@SQ\tSN:APMT01232463.1\tLN:1924\n@SQ\tSN:APMT01232237.1\tLN:1923\n@SQ\tSN:APMT01232252.1\tLN:1923\n@SQ\tSN:APMT01232464.1\tLN:1923\n@SQ\tSN:APMT01232465.1\tLN:1923\n@SQ\tSN:APMT01232466.1\tLN:1923\n@SQ\tSN:APMT01232467.1\tLN:1923\n@SQ\tSN:APMT01232468.1\tLN:1922\n@SQ\tSN:APMT01232288.1\tLN:1921\n@SQ\tSN:APMT01232490.1\tLN:1921\n@SQ\tSN:KB714522.1\tLN:1920\n@SQ\tSN:APMT01232472.1\tLN:1920\n@SQ\tSN:APMT01232474.1\tLN:1920\n@SQ\tSN:APMT01232097.1\tLN:1919\n@SQ\tSN:APMT01232415.1\tLN:1919\n@SQ\tSN:APMT01232475.1\tLN:1919\n@SQ\tSN:APMT01232476.1\tLN:1919\n@SQ\tSN:APMT01232477.1\tLN:1918\n@SQ\tSN:APMT01232480.1\tLN:1918\n@SQ\tSN:APMT01232481.1\tLN:1918\n@SQ\tSN:APMT01232366.1\tLN:1917\n@SQ\tSN:APMT01232484.1\tLN:1917\n@SQ\tSN:APMT01232485.1\tLN:1917\n@SQ\tSN:APMT01232487.1\tLN:1917\n@SQ\tSN:APMT01232458.1\tLN:1916\n@SQ\tSN:APMT01232488.1\tLN:1916\n@SQ\tSN:APMT01232491.1\tLN:1916\n@SQ\tSN:KB714489.1\tLN:1915\n@SQ\tSN:APMT01232128.1\tLN:1915\n@SQ\tSN:APMT01232272.1\tLN:1915\n@SQ\tSN:APMT01232493.1\tLN:1915\n@SQ\tSN:KB714574.1\tLN:1914\n@SQ\tSN:APMT01232297.1\tLN:1914\n@SQ\tSN:APMT01232486.1\tLN:1914\n@SQ\tSN:APMT01232494.1\tLN:1914\n@SQ\tSN:APMT01232495.1\tLN:1914\n@SQ\tSN:APMT01232496.1\tLN:1914\n@SQ\tSN:APMT01232498.1\tLN:1914\n@SQ\tSN:APMT01232500.1\tLN:1914\n@SQ\tSN:APMT01232143.1\tLN:1913\n@SQ\tSN:APMT01232501.1\tLN:1913\n@SQ\tSN:APMT01232362.1\tLN:1912\n@SQ\tSN:APMT01232279.1\tLN:1911\n@SQ\tSN:APMT01232504.1\tLN:1911\n@SQ\tSN:APMT01232506.1\tLN:1911\n@SQ\tSN:APMT01232508.1\tLN:1911\n@SQ\tSN:APMT01230260.1\tLN:1910\n@SQ\tSN:APMT01232509.1\tLN:1910\n@SQ\tSN:APMT01232510.1\tLN:1910\n@SQ\tSN:APMT01232287.1\tLN:1909\n@SQ\tSN:APMT01232357.1\tLN:1909\n@SQ\tSN:APMT01232492.1\tLN:1909\n@SQ\tSN:APMT01232503.1\tLN:1909\n@SQ\tSN:APMT01232513.1\tLN:1909\n@SQ\tSN:APMT01232514.1\tLN:1909\n@SQ\tSN:APMT01232515.1\tLN:1909\n@SQ\tSN:APMT01232516.1\tLN:1909\n@SQ\tSN:APMT01232518.1\tLN:1909\n@SQ\tSN:APMT01232286.1\tLN:1908\n@SQ\tSN:APMT01232519.1\tLN:1908\n@SQ\tSN:APMT01232520.1\tLN:1908\n@SQ\tSN:APMT01232521.1\tLN:1908\n@SQ\tSN:KB714592.1\tLN:1907\n@SQ\tSN:APMT01232307.1\tLN:1907\n@SQ\tSN:APMT01232522.1\tLN:1907\n@SQ\tSN:KB714594.1\tLN:1906\n@SQ\tSN:APMT01232523.1\tLN:1906\n@SQ\tSN:APMT01232524.1\tLN:1906\n@SQ\tSN:APMT01232289.1\tLN:1904\n@SQ\tSN:APMT01232417.1\tLN:1904\n@SQ\tSN:APMT01232526.1\tLN:1904\n@SQ\tSN:APMT01232527.1\tLN:1904\n@SQ\tSN:APMT01232470.1\tLN:1903\n@SQ\tSN:APMT01232528.1\tLN:1903\n@SQ\tSN:APMT01232248.1\tLN:1902\n@SQ\tSN:APMT01232295.1\tLN:1902\n@SQ\tSN:APMT01232478.1\tLN:1902\n@SQ\tSN:APMT01232530.1\tLN:1902\n@SQ\tSN:APMT01232532.1\tLN:1902\n@SQ\tSN:APMT01232534.1\tLN:1901\n@SQ\tSN:APMT01232535.1\tLN:1901\n@SQ\tSN:APMT01232529.1\tLN:1900\n@SQ\tSN:APMT01232536.1\tLN:1900\n@SQ\tSN:APMT01232537.1\tLN:1900\n@SQ\tSN:APMT01232539.1\tLN:1900\n@SQ\tSN:APMT01232541.1\tLN:1900\n@SQ\tSN:APMT01232542.1\tLN:1899\n@SQ\tSN:APMT01232543.1\tLN:1899\n@SQ\tSN:APMT01232544.1\tLN:1899\n@SQ\tSN:APMT01232546.1\tLN:1899\n@SQ\tSN:KB714556.1\tLN:1898\n@SQ\tSN:APMT01232547.1\tLN:1898\n@SQ\tSN:APMT01232550.1\tLN:1896\n@SQ\tSN:APMT01232414.1\tLN:1895\n@SQ\tSN:APMT01232551.1\tLN:1895\n@SQ\tSN:APMT01232225.1\tLN:1894\n@SQ\tSN:APMT01232368.1\tLN:1894\n@SQ\tSN:APMT01232553.1\tLN:1894\n@SQ\tSN:APMT01232182.1\tLN:1893\n@SQ\tSN:APMT01232556.1\tLN:1893\n@SQ\tSN:APMT01232782.1\tLN:1893\n@SQ\tSN:APMT01232228.1\tLN:1892\n@SQ\tSN:APMT01232342.1\tLN:1892\n@SQ\tSN:APMT01232554.1\tLN:1892\n@SQ\tSN:APMT01232558.1\tLN:1892\n@SQ\tSN:APMT01232559.1\tLN:1892\n@SQ\tSN:APMT01232560.1\tLN:1892\n@SQ\tSN:APMT01232180.1\tLN:1891\n@SQ\tSN:APMT01232385.1\tLN:1891\n@SQ\tSN:APMT01232562.1\tLN:1891\n@SQ\tSN:APMT01232563.1\tLN:1891\n@SQ\tSN:APMT01232369.1\tLN:1890\n@SQ\tSN:APMT01232525.1\tLN:1890\n@SQ\tSN:APMT01232565.1\tLN:1890\n@SQ\tSN:APMT01232566.1\tLN:1890\n@SQ\tSN:APMT01232567.1\tLN:1890\n@SQ\tSN:APMT01232568.1\tLN:1890\n@SQ\tSN:APMT01232517.1\tLN:1889\n@SQ\tSN:APMT01232569.1\tLN:1889\n@SQ\tSN:APMT01232570.1\tLN:1889\n@SQ\tSN:APMT01232571.1\tLN:1889\n@SQ\tSN:APMT01232572.1\tLN:1889\n@SQ\tSN:APMT01232574.1\tLN:1888\n@SQ\tSN:APMT01232575.1\tLN:1888\n@SQ\tSN:APMT01232395.1\tLN:1887\n@SQ\tSN:APMT01232578.1\tLN:1887\n@SQ\tSN:APMT01232579.1\tLN:1887\n@SQ\tSN:APMT01232581.1\tLN:1887\n@SQ\tSN:APMT01232596.1\tLN:1886\n@SQ\tSN:KB714530.1\tLN:1885\n@SQ\tSN:APMT01232561.1\tLN:1885\n@SQ\tSN:APMT01232583.1\tLN:1885\n@SQ\tSN:APMT01232585.1\tLN:1885\n@SQ\tSN:APMT01232586.1\tLN:1884\n@SQ\tSN:APMT01232308.1\tLN:1883\n@SQ\tSN:APMT01232587.1\tLN:1883\n@SQ\tSN:APMT01232591.1\tLN:1883\n@SQ\tSN:APMT01232593.1\tLN:1883\n@SQ\tSN:APMT01232594.1\tLN:1883\n@SQ\tSN:APMT01232449.1\tLN:1882\n@SQ\tSN:APMT01232497.1\tLN:1882\n@SQ\tSN:APMT01232589.1\tLN:1882\n@SQ\tSN:APMT01232595.1\tLN:1882\n@SQ\tSN:APMT01232597.1\tLN:1882\n@SQ\tSN:APMT01232398.1\tLN:1881\n@SQ\tSN:APMT01232416.1\tLN:1881\n@SQ\tSN:APMT01232418.1\tLN:1881\n@SQ\tSN:APMT01232599.1\tLN:1881\n@SQ\tSN:APMT01232600.1\tLN:1881\n@SQ\tSN:APMT01232601.1\tLN:1881\n@SQ\tSN:APMT01232602.1\tLN:1881\n@SQ\tSN:APMT01232394.1\tLN:1880\n@SQ\tSN:APMT01232413.1\tLN:1880\n@SQ\tSN:APMT01232604.1\tLN:1880\n@SQ\tSN:APMT01232605.1\tLN:1880\n@SQ\tSN:APMT01232608.1\tLN:1880\n@SQ\tSN:KB714309.1\tLN:1879\n@SQ\tSN:APMT01232499.1\tLN:1879\n@SQ\tSN:APMT01232610.1\tLN:1879\n@SQ\tSN:APMT01232507.1\tLN:1878\n@SQ\tSN:APMT01232598.1\tLN:1878\n@SQ\tSN:APMT01232614.1\tLN:1878\n@SQ\tSN:APMT01231656.1\tLN:1877\n@SQ\tSN:APMT01232399.1\tLN:1877\n@SQ\tSN:APMT01232611.1\tLN:1877\n@SQ\tSN:APMT01232615.1\tLN:1877\n@SQ\tSN:APMT01232617.1\tLN:1877\n@SQ\tSN:APMT01232619.1\tLN:1877\n@SQ\tSN:APMT01232434.1\tLN:1876\n@SQ\tSN:APMT01232606.1\tLN:1876\n@SQ\tSN:APMT01232620.1\tLN:1876\n@SQ\tSN:APMT01232622.1\tLN:1876\n@SQ\tSN:APMT01232623.1\tLN:1876\n@SQ\tSN:APMT01232624.1\tLN:1876\n@SQ\tSN:APMT01232625.1\tLN:1876\n@SQ\tSN:APMT01232431.1\tLN:1874\n@SQ\tSN:APMT01232435.1\tLN:1874\n@SQ\tSN:APMT01232626.1\tLN:1874\n@SQ\tSN:KB710411.1\tLN:1873\n@SQ\tSN:KB714554.1\tLN:1873\n@SQ\tSN:APMT01232423.1\tLN:1873\n@SQ\tSN:APMT01232603.1\tLN:1873\n@SQ\tSN:APMT01232627.1\tLN:1873\n@SQ\tSN:KB713709.1\tLN:1872\n@SQ\tSN:APMT01232424.1\tLN:1872\n@SQ\tSN:APMT01232505.1\tLN:1872\n@SQ\tSN:APMT01232631.1\tLN:1872\n@SQ\tSN:APMT01232632.1\tLN:1872\n@SQ\tSN:APMT01232633.1\tLN:1871\n@SQ\tSN:APMT01232634.1\tLN:1871\n@SQ\tSN:APMT01232636.1\tLN:1871\n@SQ\tSN:APMT01232637.1\tLN:1871\n@SQ\tSN:APMT01232639.1\tLN:1870\n@SQ\tSN:APMT01232640.1\tLN:1870\n@SQ\tSN:KB714487.1\tLN:1869\n@SQ\tSN:KB714565.1\tLN:1869\n@SQ\tSN:APMT01232641.1\tLN:1869\n@SQ\tSN:APMT01232644.1\tLN:1869\n@SQ\tSN:APMT01232646.1\tLN:1868\n@SQ\tSN:APMT01232648.1\tLN:1868\n@SQ\tSN:APMT01232650.1\tLN:1867\n@SQ\tSN:APMT01232451.1\tLN:1866\n@SQ\tSN:APMT01232651.1\tLN:1866\n@SQ\tSN:APMT01232652.1\tLN:1866\n@SQ\tSN:APMT01232653.1\tLN:1866\n@SQ\tSN:APMT01232654.1\tLN:1866\n@SQ\tSN:APMT01232655.1\tLN:1866\n@SQ\tSN:APMT01232669.1\tLN:1866\n@SQ\tSN:APMT01232656.1\tLN:1865\n@SQ\tSN:APMT01232660.1\tLN:1865\n@SQ\tSN:APMT01232479.1\tLN:1864\n@SQ\tSN:APMT01232661.1\tLN:1864\n@SQ\tSN:APMT01232662.1\tLN:1864\n@SQ\tSN:APMT01232469.1\tLN:1863\n@SQ\tSN:APMT01232666.1\tLN:1863\n@SQ\tSN:APMT01232667.1\tLN:1863\n@SQ\tSN:APMT01232668.1\tLN:1863\n@SQ\tSN:KB710016.1\tLN:1862\n@SQ\tSN:APMT01231054.1\tLN:1862\n@SQ\tSN:KB714542.1\tLN:1862\n@SQ\tSN:KB714560.1\tLN:1862\n@SQ\tSN:APMT01232584.1\tLN:1862\n@SQ\tSN:APMT01232670.1\tLN:1862\n@SQ\tSN:KB714541.1\tLN:1861\n@SQ\tSN:APMT01232672.1\tLN:1861\n@SQ\tSN:APMT01232674.1\tLN:1861\n@SQ\tSN:APMT01232677.1\tLN:1860\n@SQ\tSN:APMT01232678.1\tLN:1860\n@SQ\tSN:APMT01232679.1\tLN:1860\n@SQ\tSN:APMT01232511.1\tLN:1859\n@SQ\tSN:APMT01232588.1\tLN:1859\n@SQ\tSN:APMT01232680.1\tLN:1859\n@SQ\tSN:APMT01232681.1\tLN:1859\n@SQ\tSN:APMT01232683.1\tLN:1859\n@SQ\tSN:KB712327.1\tLN:1858\n@SQ\tSN:APMT01232675.1\tLN:1858\n@SQ\tSN:APMT01232682.1\tLN:1858\n@SQ\tSN:APMT01232684.1\tLN:1858\n@SQ\tSN:APMT01232744.1\tLN:1858\n@SQ\tSN:APMT01232685.1\tLN:1857\n@SQ\tSN:APMT01232687.1\tLN:1857\n@SQ\tSN:APMT01232483.1\tLN:1856\n@SQ\tSN:APMT01232489.1\tLN:1856\n@SQ\tSN:APMT01232502.1\tLN:1856\n@SQ\tSN:APMT01232645.1\tLN:1856\n@SQ\tSN:APMT01232688.1\tLN:1855\n@SQ\tSN:APMT01232689.1\tLN:1855\n@SQ\tSN:APMT01232512.1\tLN:1854\n@SQ\tSN:APMT01232691.1\tLN:1854\n@SQ\tSN:APMT01232564.1\tLN:1853\n@SQ\tSN:APMT01232693.1\tLN:1853\n@SQ\tSN:APMT01232695.1\tLN:1852\n@SQ\tSN:APMT01232696.1\tLN:1852\n@SQ\tSN:APMT01232697.1\tLN:1852\n@SQ\tSN:KB714593.1\tLN:1851\n@SQ\tSN:APMT01232676.1\tLN:1851\n@SQ\tSN:APMT01232700.1\tLN:1851\n@SQ\tSN:APMT01232701.1\tLN:1851\n@SQ\tSN:APMT01232703.1\tLN:1851\n@SQ\tSN:APMT01232533.1\tLN:1850\n@SQ\tSN:APMT01232664.1\tLN:1850\n@SQ\tSN:APMT01232704.1\tLN:1850\n@SQ\tSN:APMT01232705.1\tLN:1850\n@SQ\tSN:APMT01232706.1\tLN:1850\n@SQ\tSN:APMT01232708.1\tLN:1849\n@SQ\tSN:APMT01232709.1\tLN:1849\n@SQ\tSN:APMT01232710.1\tLN:1849\n@SQ\tSN:APMT01232711.1\tLN:1849\n@SQ\tSN:APMT01232540.1\tLN:1848\n@SQ\tSN:APMT01232713.1\tLN:1847\n@SQ\tSN:APMT01232592.1\tLN:1846\n@SQ\tSN:APMT01232714.1\tLN:1846\n@SQ\tSN:APMT01232715.1\tLN:1846\n@SQ\tSN:APMT01232718.1\tLN:1846\n@SQ\tSN:APMT01232719.1\tLN:1846\n@SQ\tSN:APMT01232720.1\tLN:1846\n@SQ\tSN:APMT01232721.1\tLN:1846\n@SQ\tSN:APMT01232557.1\tLN:1845\n@SQ\tSN:APMT01232725.1\tLN:1844\n@SQ\tSN:APMT01232726.1\tLN:1844\n@SQ\tSN:KB714529.1\tLN:1843\n@SQ\tSN:APMT01232727.1\tLN:1843\n@SQ\tSN:APMT01232730.1\tLN:1843\n@SQ\tSN:APMT01232582.1\tLN:1842\n@SQ\tSN:APMT01232657.1\tLN:1842\n@SQ\tSN:APMT01232728.1\tLN:1842\n@SQ\tSN:APMT01232531.1\tLN:1841\n@SQ\tSN:APMT01232731.1\tLN:1841\n@SQ\tSN:APMT01232732.1\tLN:1841\n@SQ\tSN:APMT01232735.1\tLN:1841\n@SQ\tSN:KB714050.1\tLN:1840\n@SQ\tSN:APMT01232663.1\tLN:1840\n@SQ\tSN:APMT01232707.1\tLN:1840\n@SQ\tSN:APMT01232736.1\tLN:1840\n@SQ\tSN:APMT01232737.1\tLN:1840\n@SQ\tSN:APMT01232738.1\tLN:1840\n@SQ\tSN:APMT01232739.1\tLN:1840\n@SQ\tSN:APMT01232740.1\tLN:1840\n@SQ\tSN:APMT01232790.1\tLN:1840\n@SQ\tSN:APMT01232401.1\tLN:1839\n@SQ\tSN:APMT01232545.1\tLN:1839\n@SQ\tSN:APMT01232577.1\tLN:1839\n@SQ\tSN:APMT01232742.1\tLN:1839\n@SQ\tSN:APMT01232538.1\tLN:1838\n@SQ\tSN:APMT01232743.1\tLN:1838\n@SQ\tSN:APMT01232747.1\tLN:1838\n@SQ\tSN:APMT01232749.1\tLN:1837\n@SQ\tSN:APMT01232750.1\tLN:1837\n@SQ\tSN:APMT01232751.1\tLN:1837\n@SQ\tSN:KB714347.1\tLN:1836\n@SQ\tSN:APMT01232746.1\tLN:1836\n@SQ\tSN:APMT01232753.1\tLN:1836\n@SQ\tSN:APMT01232754.1\tLN:1836\n@SQ\tSN:KB713111.1\tLN:1835\n@SQ\tSN:APMT01232673.1\tLN:1835\n@SQ\tSN:APMT01232757.1\tLN:1834\n@SQ\tSN:APMT01232758.1\tLN:1834\n@SQ\tSN:APMT01232552.1\tLN:1833\n@SQ\tSN:APMT01232573.1\tLN:1833\n@SQ\tSN:APMT01232618.1\tLN:1833\n@SQ\tSN:APMT01232752.1\tLN:1833\n@SQ\tSN:APMT01232759.1\tLN:1833\n@SQ\tSN:APMT01232760.1\tLN:1833\n@SQ\tSN:APMT01232761.1\tLN:1833\n@SQ\tSN:KB714571.1\tLN:1832\n@SQ\tSN:APMT01232358.1\tLN:1832\n@SQ\tSN:APMT01232555.1\tLN:1832\n@SQ\tSN:APMT01232762.1\tLN:1832\n@SQ\tSN:APMT01232659.1\tLN:1831\n@SQ\tSN:APMT01232765.1\tLN:1831\n@SQ\tSN:APMT01232766.1\tLN:1831\n@SQ\tSN:APMT01232767.1\tLN:1831\n@SQ\tSN:APMT01232768.1\tLN:1831\n@SQ\tSN:APMT01232770.1\tLN:1830\n@SQ\tSN:APMT01232658.1\tLN:1829\n@SQ\tSN:APMT01232774.1\tLN:1829\n@SQ\tSN:APMT01232776.1\tLN:1829\n@SQ\tSN:APMT01232777.1\tLN:1829\n@SQ\tSN:APMT01232628.1\tLN:1828\n@SQ\tSN:APMT01232778.1\tLN:1828\n@SQ\tSN:APMT01232779.1\tLN:1828\n@SQ\tSN:APMT01232780.1\tLN:1828\n@SQ\tSN:APMT01232781.1\tLN:1828\n@SQ\tSN:APMT01232576.1\tLN:1827\n@SQ\tSN:APMT01232590.1\tLN:1827\n@SQ\tSN:APMT01232783.1\tLN:1827\n@SQ\tSN:APMT01232784.1\tLN:1827\n@SQ\tSN:KB714581.1\tLN:1826\n@SQ\tSN:APMT01232580.1\tLN:1826\n@SQ\tSN:APMT01232629.1\tLN:1826\n@SQ\tSN:APMT01232786.1\tLN:1825\n@SQ\tSN:APMT01232787.1\tLN:1825\n@SQ\tSN:APMT01232788.1\tLN:1825\n@SQ\tSN:APMT01232609.1\tLN:1824\n@SQ\tSN:APMT01232665.1\tLN:1824\n@SQ\tSN:APMT01232789.1\tLN:1824\n@SQ\tSN:APMT01232791.1\tLN:1824\n@SQ\tSN:APMT01232630.1\tLN:1823\n@SQ\tSN:APMT01232793.1\tLN:1823\n@SQ\tSN:APMT01232794.1\tLN:1823\n@SQ\tSN:APMT01232795.1\tLN:1823\n@SQ\tSN:APMT01232796.1\tLN:1822\n@SQ\tSN:APMT01232797.1\tLN:1822\n@SQ\tSN:APMT01232799.1\tLN:1822\n@SQ\tSN:APMT01232473.1\tLN:1821\n@SQ\tSN:APMT01232607.1\tLN:1821\n@SQ\tSN:APMT01232801.1\tLN:1821\n@SQ\tSN:APMT01232802.1\tLN:1821\n@SQ\tSN:APMT01232803.1\tLN:1821\n@SQ\tSN:APMT01232482.1\tLN:1820\n@SQ\tSN:APMT01232771.1\tLN:1820\n@SQ\tSN:APMT01232805.1\tLN:1820\n@SQ\tSN:APMT01232613.1\tLN:1819\n@SQ\tSN:APMT01232616.1\tLN:1819\n@SQ\tSN:APMT01232798.1\tLN:1819\n@SQ\tSN:APMT01232807.1\tLN:1819\n@SQ\tSN:APMT01232826.1\tLN:1819\n@SQ\tSN:APMT01232612.1\tLN:1818\n@SQ\tSN:APMT01232810.1\tLN:1818\n@SQ\tSN:APMT01232811.1\tLN:1818\n@SQ\tSN:APMT01232809.1\tLN:1817\n@SQ\tSN:APMT01232814.1\tLN:1817\n@SQ\tSN:APMT01232815.1\tLN:1817\n@SQ\tSN:APMT01232817.1\tLN:1817\n@SQ\tSN:APMT01232818.1\tLN:1817\n@SQ\tSN:APMT01232772.1\tLN:1816\n@SQ\tSN:APMT01232820.1\tLN:1816\n@SQ\tSN:APMT01232821.1\tLN:1815\n@SQ\tSN:APMT01232822.1\tLN:1815\n@SQ\tSN:APMT01232823.1\tLN:1815\n@SQ\tSN:APMT01232816.1\tLN:1813\n@SQ\tSN:APMT01232824.1\tLN:1813\n@SQ\tSN:APMT01232825.1\tLN:1813\n@SQ\tSN:APMT01232827.1\tLN:1812\n@SQ\tSN:APMT01232828.1\tLN:1812\n@SQ\tSN:KB714572.1\tLN:1811\n@SQ\tSN:APMT01232702.1\tLN:1811\n@SQ\tSN:APMT01232829.1\tLN:1811\n@SQ\tSN:APMT01232830.1\tLN:1811\n@SQ\tSN:APMT01232831.1\tLN:1811\n@SQ\tSN:APMT01232734.1\tLN:1810\n@SQ\tSN:APMT01232635.1\tLN:1809\n@SQ\tSN:APMT01232638.1\tLN:1809\n@SQ\tSN:APMT01232698.1\tLN:1809\n@SQ\tSN:APMT01232832.1\tLN:1809\n@SQ\tSN:APMT01232834.1\tLN:1809\n@SQ\tSN:APMT01232835.1\tLN:1809\n@SQ\tSN:APMT01232836.1\tLN:1809\n@SQ\tSN:APMT01232686.1\tLN:1808\n@SQ\tSN:APMT01232837.1\tLN:1808\n@SQ\tSN:APMT01232839.1\tLN:1808\n@SQ\tSN:APMT01232840.1\tLN:1808\n@SQ\tSN:APMT01232841.1\tLN:1808\n@SQ\tSN:APMT01232843.1\tLN:1808\n@SQ\tSN:APMT01232647.1\tLN:1807\n@SQ\tSN:APMT01232844.1\tLN:1807\n@SQ\tSN:APMT01232845.1\tLN:1807\n@SQ\tSN:APMT01232848.1\tLN:1806\n@SQ\tSN:APMT01232849.1\tLN:1806\n@SQ\tSN:APMT01232851.1\tLN:1806\n@SQ\tSN:APMT01232852.1\tLN:1806\n@SQ\tSN:APMT01232717.1\tLN:1805\n@SQ\tSN:APMT01232854.1\tLN:1805\n@SQ\tSN:KB714551.1\tLN:1804\n@SQ\tSN:APMT01232858.1\tLN:1804\n@SQ\tSN:APMT01232859.1\tLN:1804\n@SQ\tSN:KB713717.1\tLN:1803\n@SQ\tSN:APMT01232621.1\tLN:1803\n@SQ\tSN:APMT01232699.1\tLN:1803\n@SQ\tSN:APMT01232857.1\tLN:1803\n@SQ\tSN:APMT01232862.1\tLN:1803\n@SQ\tSN:APMT01232863.1\tLN:1803\n@SQ\tSN:APMT01232722.1\tLN:1802\n@SQ\tSN:APMT01232856.1\tLN:1802\n@SQ\tSN:APMT01232874.1\tLN:1802\n@SQ\tSN:KB713659.1\tLN:1801\n@SQ\tSN:APMT01232806.1\tLN:1801\n@SQ\tSN:APMT01232865.1\tLN:1801\n@SQ\tSN:APMT01232866.1\tLN:1801\n@SQ\tSN:APMT01232868.1\tLN:1801\n@SQ\tSN:APMT01232869.1\tLN:1801\n@SQ\tSN:KB714090.1\tLN:1800\n@SQ\tSN:APMT01232671.1\tLN:1800\n@SQ\tSN:APMT01232871.1\tLN:1800\n@SQ\tSN:APMT01232873.1\tLN:1800\n@SQ\tSN:APMT01232875.1\tLN:1799\n@SQ\tSN:APMT01232876.1\tLN:1799\n@SQ\tSN:APMT01232877.1\tLN:1799\n@SQ\tSN:APMT01232879.1\tLN:1799\n@SQ\tSN:APMT01232741.1\tLN:1798\n@SQ\tSN:APMT01232881.1\tLN:1798\n@SQ\tSN:APMT01232842.1\tLN:1797\n@SQ\tSN:APMT01232882.1\tLN:1797\n@SQ\tSN:APMT01232549.1\tLN:1796\n@SQ\tSN:APMT01232883.1\tLN:1796\n@SQ\tSN:APMT01232884.1\tLN:1796\n@SQ\tSN:APMT01232885.1\tLN:1796\n@SQ\tSN:KB714568.1\tLN:1795\n@SQ\tSN:APMT01232690.1\tLN:1795\n@SQ\tSN:APMT01232886.1\tLN:1795\n@SQ\tSN:APMT01232888.1\tLN:1795\n@SQ\tSN:APMT01232890.1\tLN:1795\n@SQ\tSN:APMT01232939.1\tLN:1795\n@SQ\tSN:APMT01232887.1\tLN:1794\n@SQ\tSN:APMT01232891.1\tLN:1794\n@SQ\tSN:APMT01232800.1\tLN:1793\n@SQ\tSN:APMT01232892.1\tLN:1793\n@SQ\tSN:APMT01232894.1\tLN:1793\n@SQ\tSN:APMT01232692.1\tLN:1792\n@SQ\tSN:APMT01232694.1\tLN:1792\n@SQ\tSN:APMT01232895.1\tLN:1792\n@SQ\tSN:APMT01232897.1\tLN:1792\n@SQ\tSN:APMT01232898.1\tLN:1792\n@SQ\tSN:APMT01232900.1\tLN:1792\n@SQ\tSN:APMT01232901.1\tLN:1792\n@SQ\tSN:APMT01232902.1\tLN:1792\n@SQ\tSN:APMT01232904.1\tLN:1791\n@SQ\tSN:APMT01232905.1\tLN:1791\n@SQ\tSN:APMT01232906.1\tLN:1791\n@SQ\tSN:KB714068.1\tLN:1790\n@SQ\tSN:APMT01232911.1\tLN:1790\n@SQ\tSN:APMT01232912.1\tLN:1790\n@SQ\tSN:APMT01232729.1\tLN:1789\n@SQ\tSN:APMT01232913.1\tLN:1789\n@SQ\tSN:APMT01232915.1\tLN:1789\n@SQ\tSN:APMT01232916.1\tLN:1789\n@SQ\tSN:APMT01232917.1\tLN:1789\n@SQ\tSN:APMT01232716.1\tLN:1788\n@SQ\tSN:APMT01232763.1\tLN:1788\n@SQ\tSN:APMT01232918.1\tLN:1788\n@SQ\tSN:APMT01232919.1\tLN:1788\n@SQ\tSN:APMT01232920.1\tLN:1788\n@SQ\tSN:APMT01232922.1\tLN:1788\n@SQ\tSN:APMT01232923.1\tLN:1788\n@SQ\tSN:APMT01232924.1\tLN:1787\n@SQ\tSN:APMT01232925.1\tLN:1787\n@SQ\tSN:APMT01232926.1\tLN:1786\n@SQ\tSN:APMT01232927.1\tLN:1786\n@SQ\tSN:APMT01232929.1\tLN:1786\n@SQ\tSN:APMT01232930.1\tLN:1786\n@SQ\tSN:APMT01232642.1\tLN:1785\n@SQ\tSN:APMT01232785.1\tLN:1785\n@SQ\tSN:APMT01232896.1\tLN:1785\n@SQ\tSN:APMT01232931.1\tLN:1785\n@SQ\tSN:APMT01232932.1\tLN:1785\n@SQ\tSN:APMT01232724.1\tLN:1784\n@SQ\tSN:APMT01232935.1\tLN:1784\n@SQ\tSN:APMT01232936.1\tLN:1784\n@SQ\tSN:APMT01232937.1\tLN:1784\n@SQ\tSN:APMT01232941.1\tLN:1783\n@SQ\tSN:APMT01232942.1\tLN:1783\n@SQ\tSN:APMT01232748.1\tLN:1782\n@SQ\tSN:APMT01232943.1\tLN:1782\n@SQ\tSN:APMT01232944.1\tLN:1782\n@SQ\tSN:APMT01232945.1\tLN:1782\n@SQ\tSN:APMT01232946.1\tLN:1782\n@SQ\tSN:KB713940.1\tLN:1781\n@SQ\tSN:APMT01232948.1\tLN:1781\n@SQ\tSN:APMT01232952.1\tLN:1781\n@SQ\tSN:APMT01232955.1\tLN:1780\n@SQ\tSN:APMT01232833.1\tLN:1779\n@SQ\tSN:APMT01232949.1\tLN:1779\n@SQ\tSN:APMT01232951.1\tLN:1779\n@SQ\tSN:APMT01232957.1\tLN:1779\n@SQ\tSN:APMT01232958.1\tLN:1779\n@SQ\tSN:APMT01232959.1\tLN:1779\n@SQ\tSN:APMT01232960.1\tLN:1779\n@SQ\tSN:APMT01232812.1\tLN:1778\n@SQ\tSN:APMT01232548.1\tLN:1777\n@SQ\tSN:APMT01232961.1\tLN:1777\n@SQ\tSN:APMT01232962.1\tLN:1777\n@SQ\tSN:APMT01232964.1\tLN:1777\n@SQ\tSN:APMT01232965.1\tLN:1777\n@SQ\tSN:APMT01232967.1\tLN:1776\n@SQ\tSN:APMT01232755.1\tLN:1775\n@SQ\tSN:APMT01232969.1\tLN:1775\n@SQ\tSN:APMT01232970.1\tLN:1775\n@SQ\tSN:APMT01232756.1\tLN:1774\n@SQ\tSN:APMT01232870.1\tLN:1774\n@SQ\tSN:APMT01232972.1\tLN:1774\n@SQ\tSN:APMT01232973.1\tLN:1774\n@SQ\tSN:APMT01232974.1\tLN:1774\n@SQ\tSN:APMT01232764.1\tLN:1773\n@SQ\tSN:APMT01232975.1\tLN:1773\n@SQ\tSN:APMT01232792.1\tLN:1772\n@SQ\tSN:APMT01232860.1\tLN:1772\n@SQ\tSN:APMT01232977.1\tLN:1772\n@SQ\tSN:APMT01232978.1\tLN:1772\n@SQ\tSN:APMT01232819.1\tLN:1771\n@SQ\tSN:APMT01232979.1\tLN:1771\n@SQ\tSN:APMT01232980.1\tLN:1771\n@SQ\tSN:APMT01232981.1\tLN:1771\n@SQ\tSN:APMT01232982.1\tLN:1771\n@SQ\tSN:APMT01232984.1\tLN:1771\n@SQ\tSN:APMT01232769.1\tLN:1770\n@SQ\tSN:APMT01232966.1\tLN:1770\n@SQ\tSN:APMT01232985.1\tLN:1770\n@SQ\tSN:APMT01232986.1\tLN:1769\n@SQ\tSN:APMT01232987.1\tLN:1769\n@SQ\tSN:APMT01232988.1\tLN:1769\n@SQ\tSN:APMT01232775.1\tLN:1768\n@SQ\tSN:APMT01232989.1\tLN:1768\n@SQ\tSN:APMT01230864.1\tLN:1767\n@SQ\tSN:APMT01232991.1\tLN:1767\n@SQ\tSN:APMT01232992.1\tLN:1767\n@SQ\tSN:APMT01232994.1\tLN:1767\n@SQ\tSN:APMT01232995.1\tLN:1767\n@SQ\tSN:APMT01233020.1\tLN:1767\n@SQ\tSN:APMT01232996.1\tLN:1766\n@SQ\tSN:APMT01232998.1\tLN:1766\n@SQ\tSN:APMT01232999.1\tLN:1766\n@SQ\tSN:APMT01233000.1\tLN:1766\n@SQ\tSN:APMT01232733.1\tLN:1765\n@SQ\tSN:APMT01233001.1\tLN:1765\n@SQ\tSN:APMT01233002.1\tLN:1765\n@SQ\tSN:APMT01233005.1\tLN:1764\n@SQ\tSN:APMT01233006.1\tLN:1764\n@SQ\tSN:APMT01233007.1\tLN:1764\n@SQ\tSN:APMT01233008.1\tLN:1764\n@SQ\tSN:APMT01232643.1\tLN:1763\n@SQ\tSN:APMT01232649.1\tLN:1763\n@SQ\tSN:APMT01232940.1\tLN:1763\n@SQ\tSN:APMT01233009.1\tLN:1763\n@SQ\tSN:APMT01233010.1\tLN:1763\n@SQ\tSN:APMT01233011.1\tLN:1763\n@SQ\tSN:APMT01233013.1\tLN:1763\n@SQ\tSN:APMT01233014.1\tLN:1763\n@SQ\tSN:APMT01233015.1\tLN:1763\n@SQ\tSN:APMT01225063.1\tLN:1762\n@SQ\tSN:APMT01233016.1\tLN:1762\n@SQ\tSN:APMT01233017.1\tLN:1762\n@SQ\tSN:APMT01233018.1\tLN:1762\n@SQ\tSN:APMT01233019.1\tLN:1762\n@SQ\tSN:APMT01232773.1\tLN:1761\n@SQ\tSN:APMT01232850.1\tLN:1761\n@SQ\tSN:APMT01233021.1\tLN:1761\n@SQ\tSN:APMT01233022.1\tLN:1761\n@SQ\tSN:KB714584.1\tLN:1760\n@SQ\tSN:APMT01233023.1\tLN:1760\n@SQ\tSN:APMT01233025.1\tLN:1760\n@SQ\tSN:APMT01232864.1\tLN:1759\n@SQ\tSN:APMT01233004.1\tLN:1759\n@SQ\tSN:APMT01233026.1\tLN:1759\n@SQ\tSN:APMT01233027.1\tLN:1759\n@SQ\tSN:APMT01232745.1\tLN:1758\n@SQ\tSN:APMT01232808.1\tLN:1758\n@SQ\tSN:APMT01232846.1\tLN:1758\n@SQ\tSN:APMT01233028.1\tLN:1758\n@SQ\tSN:APMT01233029.1\tLN:1758\n@SQ\tSN:APMT01233030.1\tLN:1757\n@SQ\tSN:KB712682.1\tLN:1756\n@SQ\tSN:APMT01233031.1\tLN:1756\n@SQ\tSN:APMT01233165.1\tLN:1756\n@SQ\tSN:APMT01232855.1\tLN:1755\n@SQ\tSN:APMT01232899.1\tLN:1755\n@SQ\tSN:APMT01233032.1\tLN:1755\n@SQ\tSN:APMT01233035.1\tLN:1754\n@SQ\tSN:APMT01233036.1\tLN:1754\n@SQ\tSN:APMT01233037.1\tLN:1754\n@SQ\tSN:APMT01233039.1\tLN:1753\n@SQ\tSN:KB710012.1\tLN:1752\n@SQ\tSN:APMT01232993.1\tLN:1751\n@SQ\tSN:APMT01233040.1\tLN:1751\n@SQ\tSN:APMT01233042.1\tLN:1751\n@SQ\tSN:APMT01233043.1\tLN:1751\n@SQ\tSN:APMT01233044.1\tLN:1751\n@SQ\tSN:APMT01233045.1\tLN:1751\n@SQ\tSN:APMT01233046.1\tLN:1750\n@SQ\tSN:KB714588.1\tLN:1749\n@SQ\tSN:APMT01232872.1\tLN:1749\n@SQ\tSN:APMT01233048.1\tLN:1749\n@SQ\tSN:APMT01232861.1\tLN:1748\n@SQ\tSN:APMT01233049.1\tLN:1748\n@SQ\tSN:APMT01233052.1\tLN:1748\n@SQ\tSN:APMT01233053.1\tLN:1748\n@SQ\tSN:APMT01232813.1\tLN:1747\n@SQ\tSN:APMT01233055.1\tLN:1747\n@SQ\tSN:APMT01233056.1\tLN:1747\n@SQ\tSN:APMT01232712.1\tLN:1746\n@SQ\tSN:APMT01232847.1\tLN:1746\n@SQ\tSN:APMT01232853.1\tLN:1746\n@SQ\tSN:APMT01232997.1\tLN:1746\n@SQ\tSN:APMT01233058.1\tLN:1746\n@SQ\tSN:APMT01233059.1\tLN:1746\n@SQ\tSN:APMT01233060.1\tLN:1746\n@SQ\tSN:APMT01233061.1\tLN:1746\n@SQ\tSN:APMT01233062.1\tLN:1746\n@SQ\tSN:APMT01233063.1\tLN:1746\n@SQ\tSN:APMT01232723.1\tLN:1745\n@SQ\tSN:APMT01232867.1\tLN:1745\n@SQ\tSN:APMT01233064.1\tLN:1745\n@SQ\tSN:APMT01233065.1\tLN:1745\n@SQ\tSN:APMT01233067.1\tLN:1744\n@SQ\tSN:APMT01233068.1\tLN:1744\n@SQ\tSN:APMT01233070.1\tLN:1744\n@SQ\tSN:APMT01233012.1\tLN:1743\n@SQ\tSN:APMT01233072.1\tLN:1743\n@SQ\tSN:KB712640.1\tLN:1742\n@SQ\tSN:APMT01233076.1\tLN:1742\n@SQ\tSN:APMT01233073.1\tLN:1741\n@SQ\tSN:APMT01233077.1\tLN:1740\n@SQ\tSN:APMT01233080.1\tLN:1740\n@SQ\tSN:APMT01233081.1\tLN:1740\n@SQ\tSN:APMT01233084.1\tLN:1739\n@SQ\tSN:APMT01232878.1\tLN:1738\n@SQ\tSN:APMT01232953.1\tLN:1738\n@SQ\tSN:APMT01233085.1\tLN:1738\n@SQ\tSN:APMT01232893.1\tLN:1737\n@SQ\tSN:APMT01233087.1\tLN:1737\n@SQ\tSN:APMT01233086.1\tLN:1736\n@SQ\tSN:APMT01233088.1\tLN:1736\n@SQ\tSN:APMT01233089.1\tLN:1736\n@SQ\tSN:APMT01233253.1\tLN:1736\n@SQ\tSN:KB714557.1\tLN:1735\n@SQ\tSN:KB714573.1\tLN:1735\n@SQ\tSN:APMT01232934.1\tLN:1735\n@SQ\tSN:APMT01233090.1\tLN:1735\n@SQ\tSN:APMT01232889.1\tLN:1734\n@SQ\tSN:APMT01232907.1\tLN:1734\n@SQ\tSN:APMT01233091.1\tLN:1734\n@SQ\tSN:APMT01233092.1\tLN:1734\n@SQ\tSN:APMT01233093.1\tLN:1734\n@SQ\tSN:APMT01233094.1\tLN:1734\n@SQ\tSN:APMT01233095.1\tLN:1733\n@SQ\tSN:APMT01233096.1\tLN:1733\n@SQ\tSN:APMT01232950.1\tLN:1732\n@SQ\tSN:APMT01233100.1\tLN:1732\n@SQ\tSN:APMT01233103.1\tLN:1732\n@SQ\tSN:APMT01233104.1\tLN:1732\n@SQ\tSN:KB711991.1\tLN:1731\n@SQ\tSN:APMT01232909.1\tLN:1731\n@SQ\tSN:APMT01232976.1\tLN:1731\n@SQ\tSN:APMT01233098.1\tLN:1731\n@SQ\tSN:APMT01233106.1\tLN:1731\n@SQ\tSN:APMT01233107.1\tLN:1731\n@SQ\tSN:APMT01233041.1\tLN:1730\n@SQ\tSN:APMT01233109.1\tLN:1730\n@SQ\tSN:KB714591.1\tLN:1729\n@SQ\tSN:APMT01232914.1\tLN:1729\n@SQ\tSN:APMT01232921.1\tLN:1728\n@SQ\tSN:APMT01232971.1\tLN:1728\n@SQ\tSN:APMT01233111.1\tLN:1728\n@SQ\tSN:APMT01233112.1\tLN:1728\n@SQ\tSN:APMT01233121.1\tLN:1728\n@SQ\tSN:APMT01233024.1\tLN:1727\n@SQ\tSN:APMT01233114.1\tLN:1727\n@SQ\tSN:APMT01233116.1\tLN:1727\n@SQ\tSN:APMT01233117.1\tLN:1727\n@SQ\tSN:APMT01233118.1\tLN:1727\n@SQ\tSN:APMT01233119.1\tLN:1727\n@SQ\tSN:APMT01233122.1\tLN:1726\n@SQ\tSN:APMT01233124.1\tLN:1726\n@SQ\tSN:APMT01233102.1\tLN:1725\n@SQ\tSN:APMT01233126.1\tLN:1725\n@SQ\tSN:APMT01233127.1\tLN:1725\n@SQ\tSN:APMT01233128.1\tLN:1725\n@SQ\tSN:APMT01233129.1\tLN:1725\n@SQ\tSN:APMT01233123.1\tLN:1724\n@SQ\tSN:APMT01233130.1\tLN:1724\n@SQ\tSN:APMT01233131.1\tLN:1724\n@SQ\tSN:APMT01233132.1\tLN:1724\n@SQ\tSN:KB714558.1\tLN:1723\n@SQ\tSN:APMT01232938.1\tLN:1723\n@SQ\tSN:APMT01233133.1\tLN:1723\n@SQ\tSN:APMT01233134.1\tLN:1723\n@SQ\tSN:APMT01233135.1\tLN:1722\n@SQ\tSN:APMT01233136.1\tLN:1722\n@SQ\tSN:APMT01233137.1\tLN:1722\n@SQ\tSN:APMT01233138.1\tLN:1722\n@SQ\tSN:APMT01233139.1\tLN:1722\n@SQ\tSN:APMT01233143.1\tLN:1722\n@SQ\tSN:APMT01233141.1\tLN:1721\n@SQ\tSN:APMT01233142.1\tLN:1721\n@SQ\tSN:APMT01233144.1\tLN:1721\n@SQ\tSN:APMT01233145.1\tLN:1721\n@SQ\tSN:APMT01233146.1\tLN:1721\n@SQ\tSN:APMT01233147.1\tLN:1721\n@SQ\tSN:APMT01233148.1\tLN:1721\n@SQ\tSN:APMT01233149.1\tLN:1721\n@SQ\tSN:APMT01233150.1\tLN:1721\n@SQ\tSN:APMT01232804.1\tLN:1720\n@SQ\tSN:APMT01233151.1\tLN:1720\n@SQ\tSN:APMT01233152.1\tLN:1720\n@SQ\tSN:APMT01233153.1\tLN:1720\n@SQ\tSN:APMT01233154.1\tLN:1720\n@SQ\tSN:APMT01232838.1\tLN:1719\n@SQ\tSN:APMT01233157.1\tLN:1719\n@SQ\tSN:APMT01233161.1\tLN:1719\n@SQ\tSN:APMT01233075.1\tLN:1718\n@SQ\tSN:APMT01233158.1\tLN:1718\n@SQ\tSN:APMT01233160.1\tLN:1718\n@SQ\tSN:APMT01233163.1\tLN:1718\n@SQ\tSN:APMT01233164.1\tLN:1717\n@SQ\tSN:APMT01233166.1\tLN:1717\n@SQ\tSN:APMT01233167.1\tLN:1717\n@SQ\tSN:APMT01233169.1\tLN:1716\n@SQ\tSN:APMT01233171.1\tLN:1716\n@SQ\tSN:APMT01233156.1\tLN:1715\n@SQ\tSN:APMT01233176.1\tLN:1715\n@SQ\tSN:APMT01233173.1\tLN:1714\n@SQ\tSN:APMT01233174.1\tLN:1714\n@SQ\tSN:APMT01233177.1\tLN:1714\n@SQ\tSN:APMT01230798.1\tLN:1713\n@SQ\tSN:KB714596.1\tLN:1713\n@SQ\tSN:APMT01233179.1\tLN:1712\n@SQ\tSN:APMT01233180.1\tLN:1711\n@SQ\tSN:APMT01233181.1\tLN:1711\n@SQ\tSN:APMT01233003.1\tLN:1710\n@SQ\tSN:APMT01233186.1\tLN:1710\n@SQ\tSN:APMT01233187.1\tLN:1709\n@SQ\tSN:APMT01233188.1\tLN:1709\n@SQ\tSN:KB714200.1\tLN:1708\n@SQ\tSN:KB714590.1\tLN:1708\n@SQ\tSN:APMT01232908.1\tLN:1708\n@SQ\tSN:APMT01233192.1\tLN:1708\n@SQ\tSN:APMT01232990.1\tLN:1707\n@SQ\tSN:APMT01233101.1\tLN:1707\n@SQ\tSN:APMT01233183.1\tLN:1707\n@SQ\tSN:APMT01233184.1\tLN:1707\n@SQ\tSN:APMT01233193.1\tLN:1707\n@SQ\tSN:APMT01233194.1\tLN:1707\n@SQ\tSN:APMT01232947.1\tLN:1706\n@SQ\tSN:APMT01233197.1\tLN:1706\n@SQ\tSN:APMT01233199.1\tLN:1706\n@SQ\tSN:APMT01233200.1\tLN:1706\n@SQ\tSN:APMT01233201.1\tLN:1706\n@SQ\tSN:APMT01233202.1\tLN:1706\n@SQ\tSN:APMT01233205.1\tLN:1706\n@SQ\tSN:APMT01221391.1\tLN:1705\n@SQ\tSN:APMT01233204.1\tLN:1705\n@SQ\tSN:APMT01233206.1\tLN:1705\n@SQ\tSN:APMT01233207.1\tLN:1705\n@SQ\tSN:APMT01233210.1\tLN:1704\n@SQ\tSN:APMT01233212.1\tLN:1704\n@SQ\tSN:APMT01233213.1\tLN:1704\n@SQ\tSN:APMT01233214.1\tLN:1704\n@SQ\tSN:APMT01233038.1\tLN:1703\n@SQ\tSN:APMT01233216.1\tLN:1703\n@SQ\tSN:APMT01233217.1\tLN:1703\n@SQ\tSN:APMT01233218.1\tLN:1703\n@SQ\tSN:APMT01233219.1\tLN:1703\n@SQ\tSN:APMT01233033.1\tLN:1702\n@SQ\tSN:APMT01233209.1\tLN:1702\n@SQ\tSN:APMT01233215.1\tLN:1702\n@SQ\tSN:APMT01233221.1\tLN:1702\n@SQ\tSN:APMT01233222.1\tLN:1702\n@SQ\tSN:APMT01233191.1\tLN:1701\n@SQ\tSN:APMT01233203.1\tLN:1701\n@SQ\tSN:APMT01233224.1\tLN:1701\n@SQ\tSN:APMT01233225.1\tLN:1701\n@SQ\tSN:APMT01233226.1\tLN:1701\n@SQ\tSN:APMT01233227.1\tLN:1701\n@SQ\tSN:APMT01233228.1\tLN:1700\n@SQ\tSN:APMT01233229.1\tLN:1700\n@SQ\tSN:APMT01233230.1\tLN:1700\n@SQ\tSN:APMT01233231.1\tLN:1700\n@SQ\tSN:APMT01233232.1\tLN:1700\n@SQ\tSN:APMT01233233.1\tLN:1700\n@SQ\tSN:APMT01233234.1\tLN:1700\n@SQ\tSN:APMT01232880.1\tLN:1698\n@SQ\tSN:APMT01233182.1\tLN:1698\n@SQ\tSN:APMT01233237.1\tLN:1698\n@SQ\tSN:APMT01233238.1\tLN:1698\n@SQ\tSN:APMT01233097.1\tLN:1697\n@SQ\tSN:APMT01233239.1\tLN:1697\n@SQ\tSN:APMT01233078.1\tLN:1696\n@SQ\tSN:APMT01233241.1\tLN:1696\n@SQ\tSN:APMT01233242.1\tLN:1696\n@SQ\tSN:APMT01233243.1\tLN:1696\n@SQ\tSN:APMT01233244.1\tLN:1696\n@SQ\tSN:APMT01233245.1\tLN:1696\n@SQ\tSN:APMT01233246.1\tLN:1696\n@SQ\tSN:APMT01232963.1\tLN:1695\n@SQ\tSN:APMT01233248.1\tLN:1695\n@SQ\tSN:APMT01233249.1\tLN:1695\n@SQ\tSN:APMT01233235.1\tLN:1694\n@SQ\tSN:APMT01233047.1\tLN:1693\n@SQ\tSN:APMT01233252.1\tLN:1693\n@SQ\tSN:APMT01233255.1\tLN:1693\n@SQ\tSN:APMT01233069.1\tLN:1692\n@SQ\tSN:APMT01233254.1\tLN:1692\n@SQ\tSN:APMT01233256.1\tLN:1692\n@SQ\tSN:APMT01233257.1\tLN:1692\n@SQ\tSN:APMT01233258.1\tLN:1691\n@SQ\tSN:APMT01233259.1\tLN:1691\n@SQ\tSN:APMT01233050.1\tLN:1690\n@SQ\tSN:APMT01233083.1\tLN:1690\n@SQ\tSN:APMT01233190.1\tLN:1690\n@SQ\tSN:APMT01232968.1\tLN:1689\n@SQ\tSN:APMT01233051.1\tLN:1689\n@SQ\tSN:APMT01233262.1\tLN:1689\n@SQ\tSN:APMT01233263.1\tLN:1689\n@SQ\tSN:APMT01233264.1\tLN:1689\n@SQ\tSN:APMT01233265.1\tLN:1689\n@SQ\tSN:APMT01233054.1\tLN:1688\n@SQ\tSN:APMT01233110.1\tLN:1688\n@SQ\tSN:APMT01233189.1\tLN:1688\n@SQ\tSN:APMT01233266.1\tLN:1688\n@SQ\tSN:APMT01233268.1\tLN:1688\n@SQ\tSN:APMT01233271.1\tLN:1688\n@SQ\tSN:APMT01232910.1\tLN:1687\n@SQ\tSN:APMT01233057.1\tLN:1687\n@SQ\tSN:APMT01233099.1\tLN:1687\n@SQ\tSN:APMT01233269.1\tLN:1687\n@SQ\tSN:APMT01233272.1\tLN:1687\n@SQ\tSN:APMT01233273.1\tLN:1687\n@SQ\tSN:APMT01233113.1\tLN:1686\n@SQ\tSN:APMT01233274.1\tLN:1686\n@SQ\tSN:APMT01233275.1\tLN:1686\n@SQ\tSN:APMT01233276.1\tLN:1686\n@SQ\tSN:APMT01233074.1\tLN:1685\n@SQ\tSN:APMT01233277.1\tLN:1685\n@SQ\tSN:APMT01233280.1\tLN:1684\n@SQ\tSN:APMT01233281.1\tLN:1684\n@SQ\tSN:KB714097.1\tLN:1683\n@SQ\tSN:KB714400.1\tLN:1683\n@SQ\tSN:APMT01233125.1\tLN:1683\n@SQ\tSN:APMT01233178.1\tLN:1683\n@SQ\tSN:APMT01233283.1\tLN:1683\n@SQ\tSN:APMT01233284.1\tLN:1683\n@SQ\tSN:APMT01233285.1\tLN:1683\n@SQ\tSN:APMT01233071.1\tLN:1682\n@SQ\tSN:APMT01233170.1\tLN:1682\n@SQ\tSN:APMT01233288.1\tLN:1682\n@SQ\tSN:APMT01233289.1\tLN:1682\n@SQ\tSN:APMT01233290.1\tLN:1682\n@SQ\tSN:APMT01233292.1\tLN:1682\n@SQ\tSN:APMT01232956.1\tLN:1681\n@SQ\tSN:APMT01233293.1\tLN:1681\n@SQ\tSN:APMT01233294.1\tLN:1681\n@SQ\tSN:APMT01233295.1\tLN:1681\n@SQ\tSN:APMT01233296.1\tLN:1681\n@SQ\tSN:APMT01233297.1\tLN:1681\n@SQ\tSN:APMT01233298.1\tLN:1680\n@SQ\tSN:APMT01233299.1\tLN:1680\n@SQ\tSN:APMT01233079.1\tLN:1679\n@SQ\tSN:APMT01233082.1\tLN:1679\n@SQ\tSN:APMT01233300.1\tLN:1679\n@SQ\tSN:APMT01233302.1\tLN:1679\n@SQ\tSN:APMT01233304.1\tLN:1679\n@SQ\tSN:APMT01233105.1\tLN:1678\n@SQ\tSN:APMT01233305.1\tLN:1678\n@SQ\tSN:APMT01233306.1\tLN:1678\n@SQ\tSN:APMT01233260.1\tLN:1677\n@SQ\tSN:APMT01233307.1\tLN:1677\n@SQ\tSN:APMT01233168.1\tLN:1676\n@SQ\tSN:APMT01233679.1\tLN:1676\n@SQ\tSN:APMT01233310.1\tLN:1675\n@SQ\tSN:APMT01233311.1\tLN:1675\n@SQ\tSN:APMT01233314.1\tLN:1675\n@SQ\tSN:APMT01233315.1\tLN:1675\n@SQ\tSN:APMT01233247.1\tLN:1674\n@SQ\tSN:APMT01233316.1\tLN:1674\n@SQ\tSN:APMT01233319.1\tLN:1673\n@SQ\tSN:APMT01233321.1\tLN:1673\n@SQ\tSN:APMT01233322.1\tLN:1673\n@SQ\tSN:APMT01233323.1\tLN:1673\n@SQ\tSN:APMT01233324.1\tLN:1673\n@SQ\tSN:APMT01232928.1\tLN:1672\n@SQ\tSN:APMT01233325.1\tLN:1672\n@SQ\tSN:APMT01233326.1\tLN:1672\n@SQ\tSN:APMT01233328.1\tLN:1672\n@SQ\tSN:APMT01233329.1\tLN:1672\n@SQ\tSN:APMT01233330.1\tLN:1672\n@SQ\tSN:APMT01233331.1\tLN:1672\n@SQ\tSN:APMT01233332.1\tLN:1671\n@SQ\tSN:APMT01233334.1\tLN:1671\n@SQ\tSN:APMT01233335.1\tLN:1670\n@SQ\tSN:APMT01233336.1\tLN:1670\n@SQ\tSN:APMT01233338.1\tLN:1669\n@SQ\tSN:APMT01233339.1\tLN:1669\n@SQ\tSN:APMT01233340.1\tLN:1669\n@SQ\tSN:APMT01233342.1\tLN:1669\n@SQ\tSN:APMT01232933.1\tLN:1668\n@SQ\tSN:APMT01233343.1\tLN:1668\n@SQ\tSN:APMT01233344.1\tLN:1668\n@SQ\tSN:APMT01233345.1\tLN:1668\n@SQ\tSN:APMT01233347.1\tLN:1667\n@SQ\tSN:APMT01233348.1\tLN:1667\n@SQ\tSN:APMT01233350.1\tLN:1667\n@SQ\tSN:APMT01233351.1\tLN:1667\n@SQ\tSN:APMT01233353.1\tLN:1667\n@SQ\tSN:APMT01233115.1\tLN:1666\n@SQ\tSN:APMT01233120.1\tLN:1666\n@SQ\tSN:KB712285.1\tLN:1665\n@SQ\tSN:APMT01233282.1\tLN:1665\n@SQ\tSN:APMT01233355.1\tLN:1665\n@SQ\tSN:APMT01233357.1\tLN:1665\n@SQ\tSN:APMT01233358.1\tLN:1665\n@SQ\tSN:APMT01233359.1\tLN:1665\n@SQ\tSN:APMT01233360.1\tLN:1665\n@SQ\tSN:APMT01233175.1\tLN:1664\n@SQ\tSN:APMT01233361.1\tLN:1664\n@SQ\tSN:APMT01232954.1\tLN:1663\n@SQ\tSN:APMT01233367.1\tLN:1663\n@SQ\tSN:KB714260.1\tLN:1662\n@SQ\tSN:APMT01233140.1\tLN:1662\n@SQ\tSN:APMT01233159.1\tLN:1662\n@SQ\tSN:APMT01233172.1\tLN:1662\n@SQ\tSN:APMT01233220.1\tLN:1662\n@SQ\tSN:APMT01233250.1\tLN:1662\n@SQ\tSN:APMT01233363.1\tLN:1662\n@SQ\tSN:APMT01233368.1\tLN:1662\n@SQ\tSN:APMT01233369.1\tLN:1662\n@SQ\tSN:APMT01233370.1\tLN:1662\n@SQ\tSN:APMT01233372.1\tLN:1662\n@SQ\tSN:APMT01233162.1\tLN:1661\n@SQ\tSN:APMT01233195.1\tLN:1661\n@SQ\tSN:APMT01233375.1\tLN:1661\n@SQ\tSN:APMT01233155.1\tLN:1660\n@SQ\tSN:APMT01233236.1\tLN:1660\n@SQ\tSN:APMT01233346.1\tLN:1660\n@SQ\tSN:APMT01233376.1\tLN:1660\n@SQ\tSN:APMT01233377.1\tLN:1660\n@SQ\tSN:APMT01233378.1\tLN:1660\n@SQ\tSN:APMT01233379.1\tLN:1659\n@SQ\tSN:APMT01233380.1\tLN:1659\n@SQ\tSN:APMT01233381.1\tLN:1659\n@SQ\tSN:APMT01233034.1\tLN:1658\n@SQ\tSN:APMT01233383.1\tLN:1657\n@SQ\tSN:APMT01233385.1\tLN:1657\n@SQ\tSN:APMT01233386.1\tLN:1657\n@SQ\tSN:APMT01233387.1\tLN:1657\n@SQ\tSN:APMT01233337.1\tLN:1656\n@SQ\tSN:APMT01233365.1\tLN:1656\n@SQ\tSN:APMT01233389.1\tLN:1656\n@SQ\tSN:APMT01233390.1\tLN:1656\n@SQ\tSN:APMT01233392.1\tLN:1655\n@SQ\tSN:APMT01233394.1\tLN:1654\n@SQ\tSN:APMT01233397.1\tLN:1653\n@SQ\tSN:APMT01233398.1\tLN:1653\n@SQ\tSN:APMT01233399.1\tLN:1653\n@SQ\tSN:APMT01222941.1\tLN:1652\n@SQ\tSN:APMT01233211.1\tLN:1652\n@SQ\tSN:APMT01233402.1\tLN:1652\n@SQ\tSN:APMT01233403.1\tLN:1651\n@SQ\tSN:APMT01233404.1\tLN:1651\n@SQ\tSN:APMT01233405.1\tLN:1651\n@SQ\tSN:APMT01233066.1\tLN:1650\n@SQ\tSN:APMT01233406.1\tLN:1650\n@SQ\tSN:APMT01233407.1\tLN:1650\n@SQ\tSN:APMT01233683.1\tLN:1650\n@SQ\tSN:APMT01233185.1\tLN:1649\n@SQ\tSN:APMT01233396.1\tLN:1649\n@SQ\tSN:APMT01233409.1\tLN:1649\n@SQ\tSN:APMT01233410.1\tLN:1649\n@SQ\tSN:APMT01233411.1\tLN:1649\n@SQ\tSN:APMT01233412.1\tLN:1649\n@SQ\tSN:APMT01233413.1\tLN:1649\n@SQ\tSN:APMT01233414.1\tLN:1649\n@SQ\tSN:APMT01233415.1\tLN:1649\n@SQ\tSN:APMT01233416.1\tLN:1649\n@SQ\tSN:KB714583.1\tLN:1648\n@SQ\tSN:APMT01233417.1\tLN:1648\n@SQ\tSN:APMT01233418.1\tLN:1648\n@SQ\tSN:APMT01233419.1\tLN:1648\n@SQ\tSN:APMT01233425.1\tLN:1648\n@SQ\tSN:APMT01233198.1\tLN:1647\n@SQ\tSN:APMT01233423.1\tLN:1647\n@SQ\tSN:KB714523.1\tLN:1646\n@SQ\tSN:APMT01233223.1\tLN:1646\n@SQ\tSN:APMT01233427.1\tLN:1646\n@SQ\tSN:APMT01233429.1\tLN:1645\n@SQ\tSN:APMT01233430.1\tLN:1645\n@SQ\tSN:APMT01233433.1\tLN:1644\n@SQ\tSN:APMT01233408.1\tLN:1643\n@SQ\tSN:APMT01233432.1\tLN:1643\n@SQ\tSN:APMT01233434.1\tLN:1643\n@SQ\tSN:APMT01233435.1\tLN:1643\n@SQ\tSN:APMT01233436.1\tLN:1643\n@SQ\tSN:APMT01233437.1\tLN:1643\n@SQ\tSN:APMT01233349.1\tLN:1642\n@SQ\tSN:APMT01233439.1\tLN:1642\n@SQ\tSN:APMT01233440.1\tLN:1642\n@SQ\tSN:APMT01233240.1\tLN:1641\n@SQ\tSN:APMT01233267.1\tLN:1641\n@SQ\tSN:APMT01233438.1\tLN:1641\n@SQ\tSN:APMT01233364.1\tLN:1640\n@SQ\tSN:APMT01233443.1\tLN:1639\n@SQ\tSN:APMT01233445.1\tLN:1639\n@SQ\tSN:APMT01233447.1\tLN:1638\n@SQ\tSN:APMT01233451.1\tLN:1636\n@SQ\tSN:APMT01233453.1\tLN:1636\n@SQ\tSN:APMT01233454.1\tLN:1635\n@SQ\tSN:APMT01233108.1\tLN:1634\n@SQ\tSN:APMT01233286.1\tLN:1634\n@SQ\tSN:APMT01233457.1\tLN:1634\n@SQ\tSN:APMT01233458.1\tLN:1634\n@SQ\tSN:APMT01233459.1\tLN:1634\n@SQ\tSN:APMT01233460.1\tLN:1634\n@SQ\tSN:APMT01233461.1\tLN:1634\n@SQ\tSN:APMT01233462.1\tLN:1634\n@SQ\tSN:KB714358.1\tLN:1633\n@SQ\tSN:APMT01233251.1\tLN:1633\n@SQ\tSN:APMT01233465.1\tLN:1633\n@SQ\tSN:APMT01233466.1\tLN:1633\n@SQ\tSN:APMT01233467.1\tLN:1633\n@SQ\tSN:APMT01233303.1\tLN:1632\n@SQ\tSN:APMT01233313.1\tLN:1632\n@SQ\tSN:APMT01233463.1\tLN:1632\n@SQ\tSN:APMT01233468.1\tLN:1632\n@SQ\tSN:APMT01233469.1\tLN:1632\n@SQ\tSN:APMT01233470.1\tLN:1632\n@SQ\tSN:APMT01233471.1\tLN:1632\n@SQ\tSN:APMT01224014.1\tLN:1631\n@SQ\tSN:APMT01233270.1\tLN:1631\n@SQ\tSN:APMT01233472.1\tLN:1631\n@SQ\tSN:APMT01233261.1\tLN:1630\n@SQ\tSN:APMT01233476.1\tLN:1630\n@SQ\tSN:APMT01233477.1\tLN:1630\n@SQ\tSN:APMT01233479.1\tLN:1629\n@SQ\tSN:APMT01233291.1\tLN:1628\n@SQ\tSN:APMT01233480.1\tLN:1628\n@SQ\tSN:APMT01233481.1\tLN:1628\n@SQ\tSN:APMT01233482.1\tLN:1628\n@SQ\tSN:APMT01233483.1\tLN:1628\n@SQ\tSN:APMT01233541.1\tLN:1628\n@SQ\tSN:KB713797.1\tLN:1627\n@SQ\tSN:APMT01233485.1\tLN:1627\n@SQ\tSN:APMT01233486.1\tLN:1627\n@SQ\tSN:KB713137.1\tLN:1626\n@SQ\tSN:APMT01237663.1\tLN:1626\n@SQ\tSN:APMT01233488.1\tLN:1625\n@SQ\tSN:APMT01233489.1\tLN:1625\n@SQ\tSN:APMT01233301.1\tLN:1624\n@SQ\tSN:APMT01233490.1\tLN:1624\n@SQ\tSN:APMT01233491.1\tLN:1624\n@SQ\tSN:APMT01233279.1\tLN:1623\n@SQ\tSN:APMT01233287.1\tLN:1623\n@SQ\tSN:APMT01233493.1\tLN:1623\n@SQ\tSN:APMT01233494.1\tLN:1623\n@SQ\tSN:APMT01233309.1\tLN:1622\n@SQ\tSN:APMT01233495.1\tLN:1622\n@SQ\tSN:APMT01233496.1\tLN:1622\n@SQ\tSN:APMT01233497.1\tLN:1622\n@SQ\tSN:APMT01233498.1\tLN:1621\n@SQ\tSN:APMT01233500.1\tLN:1621\n@SQ\tSN:APMT01233317.1\tLN:1620\n@SQ\tSN:APMT01233502.1\tLN:1620\n@SQ\tSN:APMT01233503.1\tLN:1620\n@SQ\tSN:APMT01233505.1\tLN:1620\n@SQ\tSN:APMT01233506.1\tLN:1620\n@SQ\tSN:APMT01233507.1\tLN:1620\n@SQ\tSN:APMT01232903.1\tLN:1619\n@SQ\tSN:APMT01233308.1\tLN:1619\n@SQ\tSN:APMT01233508.1\tLN:1619\n@SQ\tSN:APMT01233327.1\tLN:1618\n@SQ\tSN:APMT01233511.1\tLN:1618\n@SQ\tSN:APMT01233512.1\tLN:1618\n@SQ\tSN:APMT01233514.1\tLN:1618\n@SQ\tSN:APMT01233312.1\tLN:1617\n@SQ\tSN:APMT01233515.1\tLN:1617\n@SQ\tSN:APMT01233517.1\tLN:1617\n@SQ\tSN:APMT01233518.1\tLN:1617\n@SQ\tSN:APMT01233519.1\tLN:1617\n@SQ\tSN:APMT01233520.1\tLN:1617\n@SQ\tSN:APMT01233523.1\tLN:1616\n@SQ\tSN:APMT01233525.1\tLN:1616\n@SQ\tSN:APMT01233529.1\tLN:1616\n@SQ\tSN:APMT01233526.1\tLN:1615\n@SQ\tSN:APMT01233528.1\tLN:1615\n@SQ\tSN:APMT01233530.1\tLN:1614\n@SQ\tSN:APMT01233531.1\tLN:1614\n@SQ\tSN:APMT01233532.1\tLN:1614\n@SQ\tSN:APMT01233533.1\tLN:1614\n@SQ\tSN:APMT01233534.1\tLN:1614\n@SQ\tSN:APMT01233535.1\tLN:1614\n@SQ\tSN:APMT01233536.1\tLN:1614\n@SQ\tSN:APMT01230019.1\tLN:1613\n@SQ\tSN:APMT01233318.1\tLN:1613\n@SQ\tSN:APMT01233320.1\tLN:1613\n@SQ\tSN:APMT01233537.1\tLN:1613\n@SQ\tSN:APMT01233539.1\tLN:1613\n@SQ\tSN:APMT01233540.1\tLN:1613\n@SQ\tSN:APMT01233352.1\tLN:1612\n@SQ\tSN:APMT01233543.1\tLN:1612\n@SQ\tSN:APMT01233544.1\tLN:1612\n@SQ\tSN:APMT01233545.1\tLN:1612\n@SQ\tSN:APMT01233547.1\tLN:1612\n@SQ\tSN:APMT01233373.1\tLN:1611\n@SQ\tSN:APMT01233548.1\tLN:1611\n@SQ\tSN:APMT01233549.1\tLN:1611\n@SQ\tSN:APMT01233550.1\tLN:1611\n@SQ\tSN:APMT01233341.1\tLN:1610\n@SQ\tSN:APMT01233551.1\tLN:1610\n@SQ\tSN:APMT01233552.1\tLN:1610\n@SQ\tSN:APMT01233553.1\tLN:1610\n@SQ\tSN:APMT01233374.1\tLN:1609\n@SQ\tSN:APMT01233558.1\tLN:1609\n@SQ\tSN:APMT01233560.1\tLN:1609\n@SQ\tSN:APMT01233561.1\tLN:1609\n@SQ\tSN:APMT01233562.1\tLN:1609\n@SQ\tSN:KB713765.1\tLN:1608\n@SQ\tSN:KB714585.1\tLN:1608\n@SQ\tSN:APMT01233354.1\tLN:1608\n@SQ\tSN:APMT01233538.1\tLN:1608\n@SQ\tSN:APMT01233559.1\tLN:1608\n@SQ\tSN:APMT01233563.1\tLN:1608\n@SQ\tSN:APMT01233565.1\tLN:1608\n@SQ\tSN:APMT01233566.1\tLN:1608\n@SQ\tSN:APMT01233567.1\tLN:1608\n@SQ\tSN:APMT01233568.1\tLN:1607\n@SQ\tSN:APMT01233570.1\tLN:1607\n@SQ\tSN:APMT01233571.1\tLN:1607\n@SQ\tSN:APMT01233208.1\tLN:1606\n@SQ\tSN:APMT01233424.1\tLN:1606\n@SQ\tSN:APMT01233572.1\tLN:1606\n@SQ\tSN:APMT01233573.1\tLN:1606\n@SQ\tSN:APMT01233574.1\tLN:1606\n@SQ\tSN:APMT01233575.1\tLN:1606\n@SQ\tSN:APMT01233647.1\tLN:1606\n@SQ\tSN:APMT01233196.1\tLN:1605\n@SQ\tSN:APMT01233356.1\tLN:1605\n@SQ\tSN:APMT01233362.1\tLN:1605\n@SQ\tSN:APMT01233391.1\tLN:1604\n@SQ\tSN:APMT01233579.1\tLN:1604\n@SQ\tSN:APMT01233593.1\tLN:1604\n@SQ\tSN:APMT01233428.1\tLN:1603\n@SQ\tSN:APMT01233582.1\tLN:1603\n@SQ\tSN:APMT01233584.1\tLN:1603\n@SQ\tSN:APMT01233366.1\tLN:1602\n@SQ\tSN:APMT01233388.1\tLN:1602\n@SQ\tSN:APMT01233585.1\tLN:1602\n@SQ\tSN:APMT01233586.1\tLN:1602\n@SQ\tSN:APMT01233587.1\tLN:1602\n@SQ\tSN:APMT01233588.1\tLN:1602\n@SQ\tSN:APMT01233278.1\tLN:1601\n@SQ\tSN:APMT01233382.1\tLN:1601\n@SQ\tSN:APMT01233384.1\tLN:1601\n@SQ\tSN:APMT01233589.1\tLN:1601\n@SQ\tSN:APMT01233590.1\tLN:1601\n@SQ\tSN:APMT01233592.1\tLN:1601\n@SQ\tSN:APMT01233594.1\tLN:1601\n@SQ\tSN:APMT01233595.1\tLN:1601\n@SQ\tSN:APMT01233598.1\tLN:1600\n@SQ\tSN:APMT01233475.1\tLN:1599\n@SQ\tSN:APMT01233555.1\tLN:1599\n@SQ\tSN:APMT01233580.1\tLN:1599\n@SQ\tSN:APMT01233599.1\tLN:1599\n@SQ\tSN:APMT01233393.1\tLN:1598\n@SQ\tSN:APMT01233601.1\tLN:1598\n@SQ\tSN:APMT01233400.1\tLN:1597\n@SQ\tSN:APMT01233603.1\tLN:1597\n@SQ\tSN:APMT01233401.1\tLN:1596\n@SQ\tSN:APMT01233569.1\tLN:1596\n@SQ\tSN:APMT01233605.1\tLN:1596\n@SQ\tSN:KB714460.1\tLN:1595\n@SQ\tSN:APMT01233606.1\tLN:1595\n@SQ\tSN:APMT01233609.1\tLN:1595\n@SQ\tSN:APMT01233455.1\tLN:1594\n@SQ\tSN:APMT01233608.1\tLN:1594\n@SQ\tSN:APMT01233610.1\tLN:1594\n@SQ\tSN:APMT01233611.1\tLN:1593\n@SQ\tSN:APMT01233614.1\tLN:1593\n@SQ\tSN:APMT01233615.1\tLN:1592\n@SQ\tSN:APMT01233616.1\tLN:1592\n@SQ\tSN:APMT01233618.1\tLN:1592\n@SQ\tSN:APMT01233619.1\tLN:1592\n@SQ\tSN:APMT01233620.1\tLN:1592\n@SQ\tSN:APMT01233624.1\tLN:1591\n@SQ\tSN:APMT01233441.1\tLN:1590\n@SQ\tSN:APMT01233442.1\tLN:1590\n@SQ\tSN:APMT01233448.1\tLN:1590\n@SQ\tSN:APMT01233626.1\tLN:1590\n@SQ\tSN:APMT01233627.1\tLN:1590\n@SQ\tSN:APMT01233628.1\tLN:1590\n@SQ\tSN:APMT01233629.1\tLN:1590\n@SQ\tSN:APMT01233522.1\tLN:1589\n@SQ\tSN:APMT01233556.1\tLN:1589\n@SQ\tSN:APMT01233623.1\tLN:1589\n@SQ\tSN:APMT01233632.1\tLN:1589\n@SQ\tSN:APMT01233633.1\tLN:1589\n@SQ\tSN:APMT01233420.1\tLN:1588\n@SQ\tSN:APMT01233634.1\tLN:1588\n@SQ\tSN:APMT01233635.1\tLN:1588\n@SQ\tSN:APMT01233421.1\tLN:1587\n@SQ\tSN:APMT01233422.1\tLN:1587\n@SQ\tSN:APMT01233452.1\tLN:1587\n@SQ\tSN:APMT01233631.1\tLN:1587\n@SQ\tSN:APMT01233426.1\tLN:1586\n@SQ\tSN:APMT01233444.1\tLN:1586\n@SQ\tSN:APMT01233639.1\tLN:1586\n@SQ\tSN:APMT01233641.1\tLN:1586\n@SQ\tSN:APMT01233643.1\tLN:1586\n@SQ\tSN:KB714580.1\tLN:1585\n@SQ\tSN:APMT01233431.1\tLN:1585\n@SQ\tSN:APMT01233446.1\tLN:1585\n@SQ\tSN:APMT01233583.1\tLN:1585\n@SQ\tSN:APMT01233644.1\tLN:1585\n@SQ\tSN:APMT01233645.1\tLN:1585\n@SQ\tSN:APMT01233646.1\tLN:1585\n@SQ\tSN:APMT01233648.1\tLN:1585\n@SQ\tSN:APMT01233625.1\tLN:1584\n@SQ\tSN:APMT01233649.1\tLN:1584\n@SQ\tSN:APMT01233652.1\tLN:1584\n@SQ\tSN:APMT01233655.1\tLN:1583\n@SQ\tSN:APMT01233656.1\tLN:1582\n@SQ\tSN:APMT01233658.1\tLN:1582\n@SQ\tSN:APMT01233660.1\tLN:1582\n@SQ\tSN:APMT01233661.1\tLN:1582\n@SQ\tSN:APMT01233662.1\tLN:1581\n@SQ\tSN:APMT01233664.1\tLN:1581\n@SQ\tSN:APMT01233665.1\tLN:1581\n@SQ\tSN:APMT01233456.1\tLN:1580\n@SQ\tSN:APMT01233659.1\tLN:1580\n@SQ\tSN:APMT01233666.1\tLN:1580\n@SQ\tSN:APMT01233667.1\tLN:1580\n@SQ\tSN:APMT01233668.1\tLN:1580\n@SQ\tSN:APMT01233669.1\tLN:1580\n@SQ\tSN:APMT01233670.1\tLN:1580\n@SQ\tSN:APMT01233622.1\tLN:1579\n@SQ\tSN:APMT01233671.1\tLN:1579\n@SQ\tSN:APMT01233673.1\tLN:1579\n@SQ\tSN:APMT01233674.1\tLN:1579\n@SQ\tSN:APMT01233675.1\tLN:1579\n@SQ\tSN:APMT01233504.1\tLN:1578\n@SQ\tSN:APMT01233672.1\tLN:1578\n@SQ\tSN:APMT01233677.1\tLN:1578\n@SQ\tSN:APMT01233678.1\tLN:1578\n@SQ\tSN:APMT01233680.1\tLN:1578\n@SQ\tSN:APMT01233484.1\tLN:1577\n@SQ\tSN:APMT01233681.1\tLN:1577\n@SQ\tSN:APMT01233682.1\tLN:1577\n@SQ\tSN:APMT01233449.1\tLN:1576\n@SQ\tSN:APMT01233685.1\tLN:1576\n@SQ\tSN:APMT01233478.1\tLN:1575\n@SQ\tSN:APMT01233687.1\tLN:1575\n@SQ\tSN:APMT01233688.1\tLN:1575\n@SQ\tSN:APMT01233689.1\tLN:1575\n@SQ\tSN:APMT01233690.1\tLN:1575\n@SQ\tSN:APMT01233691.1\tLN:1575\n@SQ\tSN:APMT01233692.1\tLN:1575\n@SQ\tSN:APMT01233694.1\tLN:1575\n@SQ\tSN:APMT01233695.1\tLN:1574\n@SQ\tSN:APMT01233698.1\tLN:1574\n@SQ\tSN:APMT01233699.1\tLN:1574\n@SQ\tSN:APMT01233701.1\tLN:1574\n@SQ\tSN:APMT01233638.1\tLN:1573\n@SQ\tSN:APMT01233464.1\tLN:1572\n@SQ\tSN:APMT01233474.1\tLN:1572\n@SQ\tSN:APMT01233604.1\tLN:1572\n@SQ\tSN:APMT01233703.1\tLN:1572\n@SQ\tSN:APMT01233704.1\tLN:1572\n@SQ\tSN:APMT01233705.1\tLN:1572\n@SQ\tSN:APMT01233509.1\tLN:1571\n@SQ\tSN:APMT01233663.1\tLN:1571\n@SQ\tSN:APMT01233706.1\tLN:1571\n@SQ\tSN:APMT01233708.1\tLN:1571\n@SQ\tSN:APMT01233709.1\tLN:1571\n@SQ\tSN:APMT01233710.1\tLN:1571\n@SQ\tSN:APMT01233473.1\tLN:1570\n@SQ\tSN:APMT01233557.1\tLN:1570\n@SQ\tSN:APMT01233686.1\tLN:1570\n@SQ\tSN:APMT01233653.1\tLN:1569\n@SQ\tSN:APMT01233713.1\tLN:1569\n@SQ\tSN:APMT01233714.1\tLN:1569\n@SQ\tSN:APMT01233715.1\tLN:1569\n@SQ\tSN:APMT01233716.1\tLN:1569\n@SQ\tSN:APMT01233621.1\tLN:1567\n@SQ\tSN:APMT01233723.1\tLN:1567\n@SQ\tSN:APMT01233725.1\tLN:1567\n@SQ\tSN:APMT01233726.1\tLN:1567\n@SQ\tSN:APMT01233727.1\tLN:1567\n@SQ\tSN:APMT01233728.1\tLN:1567\n@SQ\tSN:APMT01233729.1\tLN:1567\n@SQ\tSN:KB711517.1\tLN:1565\n@SQ\tSN:APMT01233730.1\tLN:1565\n@SQ\tSN:APMT01233732.1\tLN:1565\n@SQ\tSN:APMT01233735.1\tLN:1565\n@SQ\tSN:APMT01233736.1\tLN:1565\n@SQ\tSN:APMT01233740.1\tLN:1565\n@SQ\tSN:APMT01233513.1\tLN:1564\n@SQ\tSN:APMT01233578.1\tLN:1564\n@SQ\tSN:APMT01233581.1\tLN:1564\n@SQ\tSN:APMT01233697.1\tLN:1564\n@SQ\tSN:APMT01233722.1\tLN:1564\n@SQ\tSN:APMT01233737.1\tLN:1564\n@SQ\tSN:APMT01233739.1\tLN:1564\n@SQ\tSN:APMT01233542.1\tLN:1563\n@SQ\tSN:APMT01233554.1\tLN:1563\n@SQ\tSN:APMT01233630.1\tLN:1563\n@SQ\tSN:APMT01233742.1\tLN:1563\n@SQ\tSN:APMT01233743.1\tLN:1563\n@SQ\tSN:APMT01233744.1\tLN:1563\n@SQ\tSN:APMT01233564.1\tLN:1562\n@SQ\tSN:APMT01233748.1\tLN:1562\n@SQ\tSN:APMT01233749.1\tLN:1562\n@SQ\tSN:APMT01233499.1\tLN:1561\n@SQ\tSN:APMT01233576.1\tLN:1561\n@SQ\tSN:APMT01233753.1\tLN:1561\n@SQ\tSN:APMT01233754.1\tLN:1561\n@SQ\tSN:APMT01233755.1\tLN:1561\n@SQ\tSN:APMT01233510.1\tLN:1560\n@SQ\tSN:APMT01233521.1\tLN:1560\n@SQ\tSN:APMT01233607.1\tLN:1560\n@SQ\tSN:APMT01233757.1\tLN:1560\n@SQ\tSN:APMT01233759.1\tLN:1560\n@SQ\tSN:APMT01233760.1\tLN:1560\n@SQ\tSN:APMT01233762.1\tLN:1559\n@SQ\tSN:APMT01233763.1\tLN:1559\n@SQ\tSN:APMT01233333.1\tLN:1558\n@SQ\tSN:APMT01233617.1\tLN:1558\n@SQ\tSN:APMT01233764.1\tLN:1558\n@SQ\tSN:APMT01233765.1\tLN:1558\n@SQ\tSN:APMT01233766.1\tLN:1558\n@SQ\tSN:APMT01233768.1\tLN:1558\n@SQ\tSN:APMT01233769.1\tLN:1558\n@SQ\tSN:APMT01233770.1\tLN:1558\n@SQ\tSN:APMT01233524.1\tLN:1557\n@SQ\tSN:APMT01233527.1\tLN:1557\n@SQ\tSN:APMT01233772.1\tLN:1557\n@SQ\tSN:APMT01233650.1\tLN:1556\n@SQ\tSN:APMT01233773.1\tLN:1556\n@SQ\tSN:APMT01233774.1\tLN:1556\n@SQ\tSN:APMT01233775.1\tLN:1556\n@SQ\tSN:APMT01233776.1\tLN:1556\n@SQ\tSN:APMT01233718.1\tLN:1555\n@SQ\tSN:APMT01233777.1\tLN:1555\n@SQ\tSN:APMT01233779.1\tLN:1555\n@SQ\tSN:APMT01233780.1\tLN:1555\n@SQ\tSN:APMT01233781.1\tLN:1555\n@SQ\tSN:APMT01233782.1\tLN:1554\n@SQ\tSN:APMT01233637.1\tLN:1553\n@SQ\tSN:APMT01233783.1\tLN:1553\n@SQ\tSN:APMT01233784.1\tLN:1553\n@SQ\tSN:APMT01233785.1\tLN:1553\n@SQ\tSN:APMT01233786.1\tLN:1553\n@SQ\tSN:APMT01233787.1\tLN:1553\n@SQ\tSN:APMT01233788.1\tLN:1553\n@SQ\tSN:APMT01233789.1\tLN:1553\n@SQ\tSN:APMT01233717.1\tLN:1552\n@SQ\tSN:APMT01233790.1\tLN:1552\n@SQ\tSN:APMT01233371.1\tLN:1551\n@SQ\tSN:APMT01233546.1\tLN:1551\n@SQ\tSN:APMT01233792.1\tLN:1551\n@SQ\tSN:APMT01233796.1\tLN:1551\n@SQ\tSN:APMT01233750.1\tLN:1550\n@SQ\tSN:APMT01233794.1\tLN:1550\n@SQ\tSN:APMT01233795.1\tLN:1550\n@SQ\tSN:APMT01233799.1\tLN:1550\n@SQ\tSN:APMT01233800.1\tLN:1550\n@SQ\tSN:APMT01233802.1\tLN:1549\n@SQ\tSN:APMT01233803.1\tLN:1549\n@SQ\tSN:APMT01233804.1\tLN:1549\n@SQ\tSN:APMT01233805.1\tLN:1549\n@SQ\tSN:APMT01233761.1\tLN:1548\n@SQ\tSN:APMT01233807.1\tLN:1546\n@SQ\tSN:APMT01233808.1\tLN:1546\n@SQ\tSN:APMT01233811.1\tLN:1546\n@SQ\tSN:APMT01233812.1\tLN:1546\n@SQ\tSN:APMT01233813.1\tLN:1546\n@SQ\tSN:APMT01233814.1\tLN:1546\n@SQ\tSN:APMT01233818.1\tLN:1546\n@SQ\tSN:APMT01233819.1\tLN:1546\n@SQ\tSN:APMT01233810.1\tLN:1545\n@SQ\tSN:APMT01233816.1\tLN:1545\n@SQ\tSN:APMT01233821.1\tLN:1545\n@SQ\tSN:APMT01233501.1\tLN:1544\n@SQ\tSN:APMT01233657.1\tLN:1544\n@SQ\tSN:APMT01233823.1\tLN:1544\n@SQ\tSN:APMT01233824.1\tLN:1544\n@SQ\tSN:APMT01233825.1\tLN:1544\n@SQ\tSN:APMT01233826.1\tLN:1544\n@SQ\tSN:APMT01233827.1\tLN:1544\n@SQ\tSN:APMT01233395.1\tLN:1543\n@SQ\tSN:APMT01233597.1\tLN:1543\n@SQ\tSN:APMT01233829.1\tLN:1543\n@SQ\tSN:APMT01233832.1\tLN:1543\n@SQ\tSN:KB712720.1\tLN:1542\n@SQ\tSN:APMT01233815.1\tLN:1542\n@SQ\tSN:APMT01233833.1\tLN:1542\n@SQ\tSN:APMT01233834.1\tLN:1542\n@SQ\tSN:APMT01233836.1\tLN:1542\n@SQ\tSN:APMT01233837.1\tLN:1542\n@SQ\tSN:APMT01233838.1\tLN:1541\n@SQ\tSN:APMT01233839.1\tLN:1541\n@SQ\tSN:APMT01233840.1\tLN:1541\n@SQ\tSN:APMT01233591.1\tLN:1540\n@SQ\tSN:APMT01233841.1\tLN:1540\n@SQ\tSN:APMT01233842.1\tLN:1540\n@SQ\tSN:APMT01233843.1\tLN:1540\n@SQ\tSN:APMT01233844.1\tLN:1540\n@SQ\tSN:APMT01233846.1\tLN:1539\n@SQ\tSN:APMT01233847.1\tLN:1539\n@SQ\tSN:APMT01233849.1\tLN:1539\n@SQ\tSN:APMT01233850.1\tLN:1539\n@SQ\tSN:APMT01233450.1\tLN:1538\n@SQ\tSN:APMT01233602.1\tLN:1538\n@SQ\tSN:APMT01233640.1\tLN:1538\n@SQ\tSN:APMT01233851.1\tLN:1538\n@SQ\tSN:APMT01233817.1\tLN:1537\n@SQ\tSN:APMT01233852.1\tLN:1537\n@SQ\tSN:APMT01233853.1\tLN:1537\n@SQ\tSN:APMT01233854.1\tLN:1537\n@SQ\tSN:APMT01233856.1\tLN:1537\n@SQ\tSN:APMT01233613.1\tLN:1536\n@SQ\tSN:APMT01233858.1\tLN:1536\n@SQ\tSN:APMT01233860.1\tLN:1536\n@SQ\tSN:APMT01233861.1\tLN:1536\n@SQ\tSN:APMT01233862.1\tLN:1536\n@SQ\tSN:APMT01233863.1\tLN:1536\n@SQ\tSN:APMT01233864.1\tLN:1536\n@SQ\tSN:APMT01233693.1\tLN:1535\n@SQ\tSN:APMT01233712.1\tLN:1535\n@SQ\tSN:APMT01233865.1\tLN:1535\n@SQ\tSN:APMT01233866.1\tLN:1535\n@SQ\tSN:APMT01233868.1\tLN:1535\n@SQ\tSN:APMT01233869.1\tLN:1535\n@SQ\tSN:APMT01233612.1\tLN:1534\n@SQ\tSN:APMT01233870.1\tLN:1534\n@SQ\tSN:APMT01233871.1\tLN:1534\n@SQ\tSN:APMT01233872.1\tLN:1534\n@SQ\tSN:APMT01233873.1\tLN:1534\n@SQ\tSN:APMT01233874.1\tLN:1534\n@SQ\tSN:APMT01233875.1\tLN:1534\n@SQ\tSN:APMT01233876.1\tLN:1534\n@SQ\tSN:APMT01233877.1\tLN:1534\n@SQ\tSN:APMT01233721.1\tLN:1533\n@SQ\tSN:APMT01233879.1\tLN:1533\n@SQ\tSN:APMT01233880.1\tLN:1533\n@SQ\tSN:APMT01233651.1\tLN:1532\n@SQ\tSN:APMT01233720.1\tLN:1532\n@SQ\tSN:APMT01233859.1\tLN:1532\n@SQ\tSN:APMT01233882.1\tLN:1532\n@SQ\tSN:APMT01233883.1\tLN:1532\n@SQ\tSN:APMT01233884.1\tLN:1532\n@SQ\tSN:APMT01233885.1\tLN:1532\n@SQ\tSN:APMT01233886.1\tLN:1532\n@SQ\tSN:APMT01233887.1\tLN:1532\n@SQ\tSN:APMT01233888.1\tLN:1532\n@SQ\tSN:APMT01233889.1\tLN:1532\n@SQ\tSN:APMT01233890.1\tLN:1532\n@SQ\tSN:APMT01233891.1\tLN:1531\n@SQ\tSN:APMT01233893.1\tLN:1531\n@SQ\tSN:APMT01233895.1\tLN:1531\n@SQ\tSN:APMT01233654.1\tLN:1530\n@SQ\tSN:APMT01233855.1\tLN:1530\n@SQ\tSN:APMT01233897.1\tLN:1530\n@SQ\tSN:APMT01233898.1\tLN:1530\n@SQ\tSN:APMT01233901.1\tLN:1530\n@SQ\tSN:APMT01233902.1\tLN:1530\n@SQ\tSN:APMT01233903.1\tLN:1530\n@SQ\tSN:APMT01233904.1\tLN:1529\n@SQ\tSN:APMT01233905.1\tLN:1529\n@SQ\tSN:APMT01231299.1\tLN:1528\n@SQ\tSN:APMT01233909.1\tLN:1528\n@SQ\tSN:APMT01233910.1\tLN:1528\n@SQ\tSN:APMT01233911.1\tLN:1528\n@SQ\tSN:APMT01233912.1\tLN:1528\n@SQ\tSN:APMT01233913.1\tLN:1528\n@SQ\tSN:APMT01233492.1\tLN:1527\n@SQ\tSN:APMT01233915.1\tLN:1527\n@SQ\tSN:APMT01233636.1\tLN:1526\n@SQ\tSN:APMT01233642.1\tLN:1526\n@SQ\tSN:APMT01233916.1\tLN:1526\n@SQ\tSN:APMT01233917.1\tLN:1526\n@SQ\tSN:APMT01233516.1\tLN:1525\n@SQ\tSN:APMT01233702.1\tLN:1525\n@SQ\tSN:APMT01233919.1\tLN:1525\n@SQ\tSN:APMT01233920.1\tLN:1525\n@SQ\tSN:APMT01233922.1\tLN:1525\n@SQ\tSN:APMT01233700.1\tLN:1524\n@SQ\tSN:APMT01233878.1\tLN:1524\n@SQ\tSN:APMT01233921.1\tLN:1524\n@SQ\tSN:APMT01233923.1\tLN:1523\n@SQ\tSN:APMT01233925.1\tLN:1523\n@SQ\tSN:APMT01233926.1\tLN:1523\n@SQ\tSN:APMT01233927.1\tLN:1523\n@SQ\tSN:APMT01233900.1\tLN:1522\n@SQ\tSN:APMT01233930.1\tLN:1522\n@SQ\tSN:APMT01233487.1\tLN:1521\n@SQ\tSN:APMT01233820.1\tLN:1521\n@SQ\tSN:APMT01233933.1\tLN:1521\n@SQ\tSN:APMT01233934.1\tLN:1521\n@SQ\tSN:APMT01233935.1\tLN:1521\n@SQ\tSN:APMT01233828.1\tLN:1520\n@SQ\tSN:APMT01233937.1\tLN:1520\n@SQ\tSN:APMT01233939.1\tLN:1520\n@SQ\tSN:APMT01233940.1\tLN:1519\n@SQ\tSN:APMT01233942.1\tLN:1519\n@SQ\tSN:APMT01233943.1\tLN:1519\n@SQ\tSN:APMT01233944.1\tLN:1519\n@SQ\tSN:APMT01233945.1\tLN:1519\n@SQ\tSN:APMT01233719.1\tLN:1518\n@SQ\tSN:APMT01233676.1\tLN:1517\n@SQ\tSN:APMT01233948.1\tLN:1517\n@SQ\tSN:APMT01233949.1\tLN:1517\n@SQ\tSN:APMT01233950.1\tLN:1517\n@SQ\tSN:APMT01233835.1\tLN:1516\n@SQ\tSN:APMT01233951.1\tLN:1516\n@SQ\tSN:APMT01233952.1\tLN:1516\n@SQ\tSN:APMT01233954.1\tLN:1516\n@SQ\tSN:APMT01233955.1\tLN:1516\n@SQ\tSN:APMT01233684.1\tLN:1515\n@SQ\tSN:APMT01233957.1\tLN:1515\n@SQ\tSN:APMT01234067.1\tLN:1515\n@SQ\tSN:APMT01233959.1\tLN:1514\n@SQ\tSN:APMT01233960.1\tLN:1514\n@SQ\tSN:APMT01233961.1\tLN:1514\n@SQ\tSN:APMT01233963.1\tLN:1513\n@SQ\tSN:APMT01233964.1\tLN:1513\n@SQ\tSN:APMT01233965.1\tLN:1513\n@SQ\tSN:APMT01233881.1\tLN:1512\n@SQ\tSN:APMT01233966.1\tLN:1512\n@SQ\tSN:APMT01233968.1\tLN:1512\n@SQ\tSN:APMT01233724.1\tLN:1511\n@SQ\tSN:APMT01233972.1\tLN:1511\n@SQ\tSN:APMT01233973.1\tLN:1511\n@SQ\tSN:APMT01233975.1\tLN:1511\n@SQ\tSN:APMT01233976.1\tLN:1511\n@SQ\tSN:APMT01233707.1\tLN:1510\n@SQ\tSN:APMT01233741.1\tLN:1510\n@SQ\tSN:APMT01233969.1\tLN:1510\n@SQ\tSN:APMT01233979.1\tLN:1510\n@SQ\tSN:APMT01233980.1\tLN:1510\n@SQ\tSN:APMT01233596.1\tLN:1509\n@SQ\tSN:APMT01233981.1\tLN:1509\n@SQ\tSN:APMT01233982.1\tLN:1509\n@SQ\tSN:APMT01233983.1\tLN:1509\n@SQ\tSN:APMT01233984.1\tLN:1509\n@SQ\tSN:APMT01233985.1\tLN:1509\n@SQ\tSN:KB712994.1\tLN:1508\n@SQ\tSN:APMT01233752.1\tLN:1508\n@SQ\tSN:APMT01233892.1\tLN:1508\n@SQ\tSN:APMT01233989.1\tLN:1508\n@SQ\tSN:APMT01233990.1\tLN:1508\n@SQ\tSN:APMT01233991.1\tLN:1508\n@SQ\tSN:APMT01233992.1\tLN:1507\n@SQ\tSN:APMT01233994.1\tLN:1507\n@SQ\tSN:APMT01233767.1\tLN:1506\n@SQ\tSN:APMT01233798.1\tLN:1506\n@SQ\tSN:APMT01233894.1\tLN:1506\n@SQ\tSN:APMT01233993.1\tLN:1506\n@SQ\tSN:APMT01233996.1\tLN:1506\n@SQ\tSN:APMT01233998.1\tLN:1506\n@SQ\tSN:APMT01234002.1\tLN:1506\n@SQ\tSN:APMT01233733.1\tLN:1505\n@SQ\tSN:APMT01233771.1\tLN:1505\n@SQ\tSN:APMT01233995.1\tLN:1505\n@SQ\tSN:APMT01233997.1\tLN:1505\n@SQ\tSN:APMT01234003.1\tLN:1505\n@SQ\tSN:APMT01234007.1\tLN:1505\n@SQ\tSN:APMT01234008.1\tLN:1505\n@SQ\tSN:APMT01233731.1\tLN:1504\n@SQ\tSN:APMT01233734.1\tLN:1504\n@SQ\tSN:APMT01233896.1\tLN:1504\n@SQ\tSN:APMT01234013.1\tLN:1504\n@SQ\tSN:APMT01234016.1\tLN:1504\n@SQ\tSN:APMT01234017.1\tLN:1504\n@SQ\tSN:APMT01233845.1\tLN:1503\n@SQ\tSN:APMT01233987.1\tLN:1503\n@SQ\tSN:APMT01234018.1\tLN:1503\n@SQ\tSN:APMT01234019.1\tLN:1503\n@SQ\tSN:APMT01234020.1\tLN:1503\n@SQ\tSN:APMT01234022.1\tLN:1503\n@SQ\tSN:APMT01233914.1\tLN:1502\n@SQ\tSN:APMT01234023.1\tLN:1502\n@SQ\tSN:APMT01234024.1\tLN:1502\n@SQ\tSN:APMT01234025.1\tLN:1502\n@SQ\tSN:APMT01234028.1\tLN:1502\n@SQ\tSN:APMT01233778.1\tLN:1501\n@SQ\tSN:APMT01233929.1\tLN:1501\n@SQ\tSN:APMT01234029.1\tLN:1501\n@SQ\tSN:APMT01234030.1\tLN:1501\n@SQ\tSN:APMT01234031.1\tLN:1501\n@SQ\tSN:APMT01234032.1\tLN:1501\n@SQ\tSN:APMT01234033.1\tLN:1501\n@SQ\tSN:APMT01233758.1\tLN:1500\n@SQ\tSN:APMT01234034.1\tLN:1500\n@SQ\tSN:APMT01234037.1\tLN:1499\n@SQ\tSN:APMT01234038.1\tLN:1499\n@SQ\tSN:APMT01234039.1\tLN:1499\n@SQ\tSN:APMT01234040.1\tLN:1499\n@SQ\tSN:APMT01234041.1\tLN:1499\n@SQ\tSN:APMT01234043.1\tLN:1499\n@SQ\tSN:APMT01234044.1\tLN:1499\n@SQ\tSN:APMT01233938.1\tLN:1498\n@SQ\tSN:APMT01234026.1\tLN:1498\n@SQ\tSN:APMT01234047.1\tLN:1498\n@SQ\tSN:APMT01234048.1\tLN:1497\n@SQ\tSN:APMT01234049.1\tLN:1497\n@SQ\tSN:APMT01234051.1\tLN:1497\n@SQ\tSN:APMT01234052.1\tLN:1497\n@SQ\tSN:APMT01233577.1\tLN:1496\n@SQ\tSN:APMT01234053.1\tLN:1496\n@SQ\tSN:APMT01234054.1\tLN:1496\n@SQ\tSN:APMT01234055.1\tLN:1496\n@SQ\tSN:APMT01234056.1\tLN:1496\n@SQ\tSN:APMT01234057.1\tLN:1496\n@SQ\tSN:APMT01233793.1\tLN:1495\n@SQ\tSN:APMT01233809.1\tLN:1495\n@SQ\tSN:APMT01233848.1\tLN:1495\n@SQ\tSN:APMT01234058.1\tLN:1495\n@SQ\tSN:APMT01234059.1\tLN:1495\n@SQ\tSN:APMT01234061.1\tLN:1495\n@SQ\tSN:APMT01234060.1\tLN:1494\n@SQ\tSN:APMT01234063.1\tLN:1494\n@SQ\tSN:APMT01234064.1\tLN:1494\n@SQ\tSN:APMT01234065.1\tLN:1493\n@SQ\tSN:APMT01234066.1\tLN:1493\n@SQ\tSN:APMT01234178.1\tLN:1493\n@SQ\tSN:APMT01233822.1\tLN:1492\n@SQ\tSN:APMT01234068.1\tLN:1492\n@SQ\tSN:APMT01234070.1\tLN:1492\n@SQ\tSN:APMT01234071.1\tLN:1492\n@SQ\tSN:APMT01234035.1\tLN:1491\n@SQ\tSN:APMT01234073.1\tLN:1491\n@SQ\tSN:APMT01234074.1\tLN:1491\n@SQ\tSN:APMT01234075.1\tLN:1491\n@SQ\tSN:APMT01233899.1\tLN:1490\n@SQ\tSN:APMT01234000.1\tLN:1490\n@SQ\tSN:APMT01234072.1\tLN:1490\n@SQ\tSN:APMT01234077.1\tLN:1490\n@SQ\tSN:APMT01234079.1\tLN:1489\n@SQ\tSN:APMT01234080.1\tLN:1489\n@SQ\tSN:APMT01234081.1\tLN:1489\n@SQ\tSN:APMT01233711.1\tLN:1488\n@SQ\tSN:APMT01233801.1\tLN:1488\n@SQ\tSN:APMT01234014.1\tLN:1488\n@SQ\tSN:APMT01234084.1\tLN:1488\n@SQ\tSN:APMT01234085.1\tLN:1488\n@SQ\tSN:APMT01233936.1\tLN:1487\n@SQ\tSN:APMT01234086.1\tLN:1487\n@SQ\tSN:APMT01234087.1\tLN:1487\n@SQ\tSN:APMT01234089.1\tLN:1487\n@SQ\tSN:APMT01234090.1\tLN:1487\n@SQ\tSN:APMT01234092.1\tLN:1487\n@SQ\tSN:APMT01234093.1\tLN:1487\n@SQ\tSN:APMT01233791.1\tLN:1486\n@SQ\tSN:APMT01234096.1\tLN:1486\n@SQ\tSN:APMT01234011.1\tLN:1485\n@SQ\tSN:APMT01234095.1\tLN:1485\n@SQ\tSN:APMT01234097.1\tLN:1485\n@SQ\tSN:APMT01234099.1\tLN:1485\n@SQ\tSN:APMT01234101.1\tLN:1485\n@SQ\tSN:APMT01234103.1\tLN:1485\n@SQ\tSN:APMT01234078.1\tLN:1484\n@SQ\tSN:APMT01234105.1\tLN:1484\n@SQ\tSN:APMT01234106.1\tLN:1484\n@SQ\tSN:APMT01233907.1\tLN:1483\n@SQ\tSN:APMT01234110.1\tLN:1483\n@SQ\tSN:APMT01234111.1\tLN:1483\n@SQ\tSN:APMT01234112.1\tLN:1483\n@SQ\tSN:APMT01234115.1\tLN:1482\n@SQ\tSN:APMT01234116.1\tLN:1481\n@SQ\tSN:APMT01233928.1\tLN:1480\n@SQ\tSN:APMT01234108.1\tLN:1480\n@SQ\tSN:APMT01234117.1\tLN:1480\n@SQ\tSN:APMT01234118.1\tLN:1480\n@SQ\tSN:APMT01234119.1\tLN:1480\n@SQ\tSN:APMT01234121.1\tLN:1480\n@SQ\tSN:APMT01233600.1\tLN:1479\n@SQ\tSN:APMT01234122.1\tLN:1479\n@SQ\tSN:APMT01234123.1\tLN:1479\n@SQ\tSN:APMT01234124.1\tLN:1479\n@SQ\tSN:APMT01234125.1\tLN:1479\n@SQ\tSN:APMT01234126.1\tLN:1479\n@SQ\tSN:APMT01233974.1\tLN:1478\n@SQ\tSN:APMT01234127.1\tLN:1478\n@SQ\tSN:APMT01234131.1\tLN:1478\n@SQ\tSN:APMT01233746.1\tLN:1477\n@SQ\tSN:APMT01234091.1\tLN:1477\n@SQ\tSN:APMT01234132.1\tLN:1477\n@SQ\tSN:APMT01234133.1\tLN:1477\n@SQ\tSN:APMT01234134.1\tLN:1477\n@SQ\tSN:APMT01234135.1\tLN:1477\n@SQ\tSN:APMT01233971.1\tLN:1476\n@SQ\tSN:APMT01234076.1\tLN:1476\n@SQ\tSN:APMT01234109.1\tLN:1476\n@SQ\tSN:APMT01234138.1\tLN:1476\n@SQ\tSN:APMT01234139.1\tLN:1476\n@SQ\tSN:APMT01233867.1\tLN:1475\n@SQ\tSN:APMT01234141.1\tLN:1475\n@SQ\tSN:APMT01234144.1\tLN:1475\n@SQ\tSN:APMT01234145.1\tLN:1475\n@SQ\tSN:APMT01233941.1\tLN:1474\n@SQ\tSN:APMT01234006.1\tLN:1474\n@SQ\tSN:APMT01234143.1\tLN:1474\n@SQ\tSN:APMT01234146.1\tLN:1474\n@SQ\tSN:APMT01234147.1\tLN:1474\n@SQ\tSN:APMT01234149.1\tLN:1474\n@SQ\tSN:APMT01234152.1\tLN:1474\n@SQ\tSN:APMT01234154.1\tLN:1474\n@SQ\tSN:APMT01234130.1\tLN:1473\n@SQ\tSN:APMT01233830.1\tLN:1472\n@SQ\tSN:APMT01233956.1\tLN:1472\n@SQ\tSN:APMT01234157.1\tLN:1472\n@SQ\tSN:APMT01234167.1\tLN:1472\n@SQ\tSN:APMT01234159.1\tLN:1471\n@SQ\tSN:APMT01234161.1\tLN:1471\n@SQ\tSN:APMT01234162.1\tLN:1471\n@SQ\tSN:APMT01234163.1\tLN:1470\n@SQ\tSN:APMT01234165.1\tLN:1470\n@SQ\tSN:APMT01234168.1\tLN:1470\n@SQ\tSN:APMT01234169.1\tLN:1470\n@SQ\tSN:APMT01233924.1\tLN:1469\n@SQ\tSN:APMT01234045.1\tLN:1469\n@SQ\tSN:APMT01234171.1\tLN:1469\n@SQ\tSN:APMT01234172.1\tLN:1469\n@SQ\tSN:APMT01234173.1\tLN:1469\n@SQ\tSN:APMT01234177.1\tLN:1469\n@SQ\tSN:APMT01234473.1\tLN:1469\n@SQ\tSN:APMT01234180.1\tLN:1468\n@SQ\tSN:APMT01224647.1\tLN:1467\n@SQ\tSN:APMT01234175.1\tLN:1467\n@SQ\tSN:APMT01234181.1\tLN:1467\n@SQ\tSN:APMT01234184.1\tLN:1467\n@SQ\tSN:APMT01234185.1\tLN:1467\n@SQ\tSN:APMT01234186.1\tLN:1467\n@SQ\tSN:APMT01234187.1\tLN:1467\n@SQ\tSN:APMT01234176.1\tLN:1466\n@SQ\tSN:APMT01234188.1\tLN:1466\n@SQ\tSN:APMT01234189.1\tLN:1466\n@SQ\tSN:APMT01234191.1\tLN:1466\n@SQ\tSN:APMT01233953.1\tLN:1465\n@SQ\tSN:APMT01234193.1\tLN:1465\n@SQ\tSN:APMT01234069.1\tLN:1464\n@SQ\tSN:APMT01234194.1\tLN:1464\n@SQ\tSN:APMT01234195.1\tLN:1464\n@SQ\tSN:APMT01234196.1\tLN:1464\n@SQ\tSN:APMT01234198.1\tLN:1464\n@SQ\tSN:APMT01233696.1\tLN:1463\n@SQ\tSN:APMT01228948.1\tLN:1462\n@SQ\tSN:APMT01233947.1\tLN:1462\n@SQ\tSN:APMT01234142.1\tLN:1462\n@SQ\tSN:APMT01234205.1\tLN:1462\n@SQ\tSN:APMT01234206.1\tLN:1462\n@SQ\tSN:APMT01234207.1\tLN:1461\n@SQ\tSN:APMT01234208.1\tLN:1461\n@SQ\tSN:APMT01234210.1\tLN:1461\n@SQ\tSN:APMT01234211.1\tLN:1461\n@SQ\tSN:APMT01234212.1\tLN:1461\n@SQ\tSN:APMT01234213.1\tLN:1461\n@SQ\tSN:APMT01233978.1\tLN:1460\n@SQ\tSN:APMT01234204.1\tLN:1460\n@SQ\tSN:APMT01234215.1\tLN:1460\n@SQ\tSN:APMT01234170.1\tLN:1459\n@SQ\tSN:APMT01234216.1\tLN:1459\n@SQ\tSN:APMT01234217.1\tLN:1459\n@SQ\tSN:APMT01234218.1\tLN:1459\n@SQ\tSN:APMT01234219.1\tLN:1459\n@SQ\tSN:APMT01234221.1\tLN:1459\n@SQ\tSN:APMT01234223.1\tLN:1459\n@SQ\tSN:APMT01234224.1\tLN:1459\n@SQ\tSN:APMT01234225.1\tLN:1459\n@SQ\tSN:APMT01233970.1\tLN:1458\n@SQ\tSN:APMT01234010.1\tLN:1458\n@SQ\tSN:APMT01234222.1\tLN:1458\n@SQ\tSN:APMT01234226.1\tLN:1458\n@SQ\tSN:APMT01234227.1\tLN:1458\n@SQ\tSN:APMT01234231.1\tLN:1458\n@SQ\tSN:APMT01234230.1\tLN:1457\n@SQ\tSN:APMT01234233.1\tLN:1457\n@SQ\tSN:KB714091.1\tLN:1456\n@SQ\tSN:APMT01233988.1\tLN:1456\n@SQ\tSN:APMT01234235.1\tLN:1456\n@SQ\tSN:APMT01234237.1\tLN:1456\n@SQ\tSN:APMT01234239.1\tLN:1456\n@SQ\tSN:APMT01233806.1\tLN:1455\n@SQ\tSN:APMT01233999.1\tLN:1455\n@SQ\tSN:APMT01234242.1\tLN:1455\n@SQ\tSN:APMT01234179.1\tLN:1454\n@SQ\tSN:APMT01234246.1\tLN:1454\n@SQ\tSN:APMT01234247.1\tLN:1454\n@SQ\tSN:APMT01234248.1\tLN:1454\n@SQ\tSN:APMT01233747.1\tLN:1453\n@SQ\tSN:APMT01233958.1\tLN:1453\n@SQ\tSN:APMT01233962.1\tLN:1453\n@SQ\tSN:APMT01234202.1\tLN:1453\n@SQ\tSN:APMT01234250.1\tLN:1453\n@SQ\tSN:APMT01234251.1\tLN:1453\n@SQ\tSN:APMT01234252.1\tLN:1453\n@SQ\tSN:APMT01234253.1\tLN:1453\n@SQ\tSN:APMT01234254.1\tLN:1453\n@SQ\tSN:APMT01233738.1\tLN:1452\n@SQ\tSN:APMT01233967.1\tLN:1452\n@SQ\tSN:APMT01234255.1\tLN:1452\n@SQ\tSN:APMT01234256.1\tLN:1452\n@SQ\tSN:APMT01234258.1\tLN:1452\n@SQ\tSN:APMT01234261.1\tLN:1452\n@SQ\tSN:APMT01233745.1\tLN:1451\n@SQ\tSN:APMT01234199.1\tLN:1451\n@SQ\tSN:APMT01234260.1\tLN:1451\n@SQ\tSN:APMT01234263.1\tLN:1451\n@SQ\tSN:APMT01234265.1\tLN:1451\n@SQ\tSN:APMT01234266.1\tLN:1451\n@SQ\tSN:APMT01234316.1\tLN:1451\n@SQ\tSN:APMT01234153.1\tLN:1450\n@SQ\tSN:APMT01234267.1\tLN:1450\n@SQ\tSN:APMT01234268.1\tLN:1450\n@SQ\tSN:APMT01234269.1\tLN:1450\n@SQ\tSN:APMT01234273.1\tLN:1450\n@SQ\tSN:APMT01234012.1\tLN:1449\n@SQ\tSN:APMT01234102.1\tLN:1449\n@SQ\tSN:APMT01234270.1\tLN:1449\n@SQ\tSN:APMT01234272.1\tLN:1449\n@SQ\tSN:KB712544.1\tLN:1448\n@SQ\tSN:APMT01233986.1\tLN:1448\n@SQ\tSN:APMT01234275.1\tLN:1448\n@SQ\tSN:APMT01234276.1\tLN:1448\n@SQ\tSN:APMT01234277.1\tLN:1448\n@SQ\tSN:APMT01234278.1\tLN:1448\n@SQ\tSN:APMT01234280.1\tLN:1448\n@SQ\tSN:APMT01234281.1\tLN:1448\n@SQ\tSN:APMT01234282.1\tLN:1448\n@SQ\tSN:APMT01234283.1\tLN:1447\n@SQ\tSN:APMT01234285.1\tLN:1447\n@SQ\tSN:APMT01234291.1\tLN:1447\n@SQ\tSN:KB712748.1\tLN:1446\n@SQ\tSN:APMT01227511.1\tLN:1446\n@SQ\tSN:APMT01233797.1\tLN:1446\n@SQ\tSN:APMT01234009.1\tLN:1446\n@SQ\tSN:APMT01234289.1\tLN:1446\n@SQ\tSN:APMT01234290.1\tLN:1446\n@SQ\tSN:APMT01234001.1\tLN:1445\n@SQ\tSN:APMT01234004.1\tLN:1445\n@SQ\tSN:APMT01234200.1\tLN:1445\n@SQ\tSN:APMT01234214.1\tLN:1445\n@SQ\tSN:APMT01234243.1\tLN:1445\n@SQ\tSN:APMT01234292.1\tLN:1445\n@SQ\tSN:APMT01234293.1\tLN:1445\n@SQ\tSN:APMT01234294.1\tLN:1445\n@SQ\tSN:APMT01234295.1\tLN:1445\n@SQ\tSN:APMT01234296.1\tLN:1445\n@SQ\tSN:APMT01233756.1\tLN:1444\n@SQ\tSN:APMT01233857.1\tLN:1444\n@SQ\tSN:APMT01234298.1\tLN:1444\n@SQ\tSN:APMT01234300.1\tLN:1444\n@SQ\tSN:APMT01233751.1\tLN:1443\n@SQ\tSN:APMT01233946.1\tLN:1443\n@SQ\tSN:APMT01234015.1\tLN:1443\n@SQ\tSN:APMT01234042.1\tLN:1443\n@SQ\tSN:APMT01234302.1\tLN:1443\n@SQ\tSN:APMT01234306.1\tLN:1443\n@SQ\tSN:APMT01234021.1\tLN:1442\n@SQ\tSN:APMT01234307.1\tLN:1442\n@SQ\tSN:APMT01234308.1\tLN:1442\n@SQ\tSN:APMT01234309.1\tLN:1442\n@SQ\tSN:APMT01234312.1\tLN:1442\n@SQ\tSN:APMT01234120.1\tLN:1441\n@SQ\tSN:APMT01234313.1\tLN:1441\n@SQ\tSN:APMT01234314.1\tLN:1441\n@SQ\tSN:APMT01234315.1\tLN:1441\n@SQ\tSN:APMT01234232.1\tLN:1440\n@SQ\tSN:APMT01234317.1\tLN:1440\n@SQ\tSN:APMT01234318.1\tLN:1440\n@SQ\tSN:APMT01234319.1\tLN:1440\n@SQ\tSN:APMT01234323.1\tLN:1439\n@SQ\tSN:APMT01234324.1\tLN:1439\n@SQ\tSN:APMT01234320.1\tLN:1438\n@SQ\tSN:APMT01234326.1\tLN:1438\n@SQ\tSN:APMT01234327.1\tLN:1438\n@SQ\tSN:APMT01234328.1\tLN:1438\n@SQ\tSN:APMT01234331.1\tLN:1438\n@SQ\tSN:APMT01234046.1\tLN:1437\n@SQ\tSN:APMT01234094.1\tLN:1437\n@SQ\tSN:APMT01234140.1\tLN:1437\n@SQ\tSN:APMT01234333.1\tLN:1437\n@SQ\tSN:APMT01234336.1\tLN:1437\n@SQ\tSN:APMT01234050.1\tLN:1436\n@SQ\tSN:APMT01234107.1\tLN:1436\n@SQ\tSN:APMT01234338.1\tLN:1436\n@SQ\tSN:APMT01234339.1\tLN:1436\n@SQ\tSN:APMT01234340.1\tLN:1436\n@SQ\tSN:APMT01234341.1\tLN:1436\n@SQ\tSN:APMT01234342.1\tLN:1436\n@SQ\tSN:APMT01234344.1\tLN:1436\n@SQ\tSN:APMT01234104.1\tLN:1434\n@SQ\tSN:APMT01234345.1\tLN:1434\n@SQ\tSN:APMT01234346.1\tLN:1434\n@SQ\tSN:APMT01234347.1\tLN:1434\n@SQ\tSN:APMT01234348.1\tLN:1434\n@SQ\tSN:APMT01234349.1\tLN:1434\n@SQ\tSN:APMT01234182.1\tLN:1433\n@SQ\tSN:APMT01234274.1\tLN:1433\n@SQ\tSN:APMT01234352.1\tLN:1433\n@SQ\tSN:APMT01234353.1\tLN:1433\n@SQ\tSN:APMT01234354.1\tLN:1433\n@SQ\tSN:APMT01234525.1\tLN:1433\n@SQ\tSN:APMT01234287.1\tLN:1432\n@SQ\tSN:APMT01234335.1\tLN:1432\n@SQ\tSN:APMT01234355.1\tLN:1432\n@SQ\tSN:APMT01234375.1\tLN:1432\n@SQ\tSN:APMT01226577.1\tLN:1431\n@SQ\tSN:APMT01233906.1\tLN:1431\n@SQ\tSN:APMT01234088.1\tLN:1431\n@SQ\tSN:APMT01234151.1\tLN:1431\n@SQ\tSN:APMT01234358.1\tLN:1431\n@SQ\tSN:APMT01234234.1\tLN:1430\n@SQ\tSN:APMT01234303.1\tLN:1430\n@SQ\tSN:APMT01234356.1\tLN:1430\n@SQ\tSN:APMT01234362.1\tLN:1430\n@SQ\tSN:APMT01234363.1\tLN:1430\n@SQ\tSN:APMT01234365.1\tLN:1430\n@SQ\tSN:APMT01234082.1\tLN:1429\n@SQ\tSN:APMT01234098.1\tLN:1429\n@SQ\tSN:APMT01234201.1\tLN:1429\n@SQ\tSN:APMT01234322.1\tLN:1429\n@SQ\tSN:APMT01234367.1\tLN:1429\n@SQ\tSN:APMT01234368.1\tLN:1429\n@SQ\tSN:APMT01234371.1\tLN:1429\n@SQ\tSN:APMT01234374.1\tLN:1429\n@SQ\tSN:APMT01233831.1\tLN:1428\n@SQ\tSN:APMT01234114.1\tLN:1428\n@SQ\tSN:APMT01234376.1\tLN:1428\n@SQ\tSN:APMT01234377.1\tLN:1428\n@SQ\tSN:APMT01234378.1\tLN:1428\n@SQ\tSN:APMT01234381.1\tLN:1428\n@SQ\tSN:APMT01234382.1\tLN:1428\n@SQ\tSN:APMT01234360.1\tLN:1427\n@SQ\tSN:APMT01234384.1\tLN:1427\n@SQ\tSN:APMT01234385.1\tLN:1427\n@SQ\tSN:APMT01234100.1\tLN:1426\n@SQ\tSN:APMT01234387.1\tLN:1426\n@SQ\tSN:APMT01234388.1\tLN:1426\n@SQ\tSN:APMT01234389.1\tLN:1426\n@SQ\tSN:APMT01234113.1\tLN:1425\n@SQ\tSN:APMT01234392.1\tLN:1425\n@SQ\tSN:APMT01234394.1\tLN:1425\n@SQ\tSN:APMT01234299.1\tLN:1424\n@SQ\tSN:APMT01234311.1\tLN:1424\n@SQ\tSN:APMT01234396.1\tLN:1424\n@SQ\tSN:APMT01234397.1\tLN:1424\n@SQ\tSN:APMT01234399.1\tLN:1424\n@SQ\tSN:APMT01234400.1\tLN:1424\n@SQ\tSN:APMT01234401.1\tLN:1424\n@SQ\tSN:APMT01234361.1\tLN:1423\n@SQ\tSN:APMT01234386.1\tLN:1423\n@SQ\tSN:APMT01234403.1\tLN:1423\n@SQ\tSN:APMT01234404.1\tLN:1423\n@SQ\tSN:APMT01234197.1\tLN:1422\n@SQ\tSN:APMT01234236.1\tLN:1422\n@SQ\tSN:APMT01234406.1\tLN:1422\n@SQ\tSN:APMT01234408.1\tLN:1422\n@SQ\tSN:APMT01234409.1\tLN:1422\n@SQ\tSN:APMT01234129.1\tLN:1421\n@SQ\tSN:APMT01234351.1\tLN:1421\n@SQ\tSN:APMT01234393.1\tLN:1421\n@SQ\tSN:APMT01234410.1\tLN:1421\n@SQ\tSN:APMT01234148.1\tLN:1420\n@SQ\tSN:APMT01234156.1\tLN:1420\n@SQ\tSN:APMT01234412.1\tLN:1420\n@SQ\tSN:APMT01234414.1\tLN:1420\n@SQ\tSN:APMT01234415.1\tLN:1420\n@SQ\tSN:APMT01234416.1\tLN:1420\n@SQ\tSN:APMT01234417.1\tLN:1420\n@SQ\tSN:APMT01234136.1\tLN:1418\n@SQ\tSN:APMT01234419.1\tLN:1418\n@SQ\tSN:APMT01234420.1\tLN:1418\n@SQ\tSN:APMT01234421.1\tLN:1418\n@SQ\tSN:APMT01234422.1\tLN:1418\n@SQ\tSN:APMT01234137.1\tLN:1417\n@SQ\tSN:APMT01234150.1\tLN:1417\n@SQ\tSN:APMT01234203.1\tLN:1417\n@SQ\tSN:APMT01234423.1\tLN:1417\n@SQ\tSN:APMT01234425.1\tLN:1417\n@SQ\tSN:APMT01234427.1\tLN:1417\n@SQ\tSN:APMT01234428.1\tLN:1417\n@SQ\tSN:APMT01234429.1\tLN:1417\n@SQ\tSN:APMT01234430.1\tLN:1417\n@SQ\tSN:APMT01234160.1\tLN:1415\n@SQ\tSN:APMT01234434.1\tLN:1415\n@SQ\tSN:APMT01234435.1\tLN:1415\n@SQ\tSN:APMT01234437.1\tLN:1415\n@SQ\tSN:APMT01234244.1\tLN:1414\n@SQ\tSN:APMT01234440.1\tLN:1414\n@SQ\tSN:APMT01234441.1\tLN:1414\n@SQ\tSN:APMT01233918.1\tLN:1413\n@SQ\tSN:APMT01234036.1\tLN:1413\n@SQ\tSN:APMT01234411.1\tLN:1413\n@SQ\tSN:APMT01234444.1\tLN:1413\n@SQ\tSN:APMT01234445.1\tLN:1413\n@SQ\tSN:APMT01234446.1\tLN:1413\n@SQ\tSN:APMT01233908.1\tLN:1412\n@SQ\tSN:APMT01234183.1\tLN:1412\n@SQ\tSN:APMT01234442.1\tLN:1412\n@SQ\tSN:APMT01234448.1\tLN:1412\n@SQ\tSN:APMT01234450.1\tLN:1412\n@SQ\tSN:APMT01234451.1\tLN:1412\n@SQ\tSN:APMT01234452.1\tLN:1412\n@SQ\tSN:APMT01234453.1\tLN:1411\n@SQ\tSN:APMT01234455.1\tLN:1411\n@SQ\tSN:APMT01234456.1\tLN:1411\n@SQ\tSN:APMT01234457.1\tLN:1411\n@SQ\tSN:APMT01234458.1\tLN:1411\n@SQ\tSN:APMT01234459.1\tLN:1411\n@SQ\tSN:APMT01234460.1\tLN:1411\n@SQ\tSN:APMT01234461.1\tLN:1411\n@SQ\tSN:APMT01234229.1\tLN:1410\n@SQ\tSN:APMT01234462.1\tLN:1410\n@SQ\tSN:APMT01234463.1\tLN:1410\n@SQ\tSN:APMT01234464.1\tLN:1410\n@SQ\tSN:APMT01234465.1\tLN:1410\n@SQ\tSN:APMT01234466.1\tLN:1410\n@SQ\tSN:APMT01234249.1\tLN:1409\n@SQ\tSN:APMT01234467.1\tLN:1409\n@SQ\tSN:APMT01234468.1\tLN:1409\n@SQ\tSN:APMT01234469.1\tLN:1409\n@SQ\tSN:APMT01234470.1\tLN:1409\n@SQ\tSN:APMT01234240.1\tLN:1408\n@SQ\tSN:APMT01234286.1\tLN:1408\n@SQ\tSN:APMT01234337.1\tLN:1408\n@SQ\tSN:APMT01234449.1\tLN:1408\n@SQ\tSN:APMT01234472.1\tLN:1408\n@SQ\tSN:APMT01234474.1\tLN:1408\n@SQ\tSN:APMT01234475.1\tLN:1408\n@SQ\tSN:APMT01234476.1\tLN:1408\n@SQ\tSN:APMT01234477.1\tLN:1408\n@SQ\tSN:APMT01234478.1\tLN:1408\n@SQ\tSN:APMT01234192.1\tLN:1407\n@SQ\tSN:APMT01234301.1\tLN:1407\n@SQ\tSN:APMT01234359.1\tLN:1407\n@SQ\tSN:APMT01234364.1\tLN:1407\n@SQ\tSN:KB711574.1\tLN:1406\n@SQ\tSN:APMT01234228.1\tLN:1406\n@SQ\tSN:APMT01234480.1\tLN:1406\n@SQ\tSN:APMT01234481.1\tLN:1406\n@SQ\tSN:APMT01234482.1\tLN:1406\n@SQ\tSN:APMT01234484.1\tLN:1406\n@SQ\tSN:APMT01234486.1\tLN:1406\n@SQ\tSN:APMT01234487.1\tLN:1406\n@SQ\tSN:APMT01234164.1\tLN:1405\n@SQ\tSN:APMT01234485.1\tLN:1405\n@SQ\tSN:APMT01234488.1\tLN:1405\n@SQ\tSN:APMT01234490.1\tLN:1405\n@SQ\tSN:APMT01234027.1\tLN:1404\n@SQ\tSN:APMT01234483.1\tLN:1404\n@SQ\tSN:APMT01234493.1\tLN:1404\n@SQ\tSN:APMT01234494.1\tLN:1404\n@SQ\tSN:APMT01234496.1\tLN:1404\n@SQ\tSN:APMT01234431.1\tLN:1403\n@SQ\tSN:APMT01234489.1\tLN:1403\n@SQ\tSN:APMT01234499.1\tLN:1403\n@SQ\tSN:APMT01234501.1\tLN:1403\n@SQ\tSN:APMT01233977.1\tLN:1402\n@SQ\tSN:APMT01234503.1\tLN:1402\n@SQ\tSN:APMT01234505.1\tLN:1402\n@SQ\tSN:APMT01234506.1\tLN:1402\n@SQ\tSN:APMT01234507.1\tLN:1402\n@SQ\tSN:APMT01234508.1\tLN:1402\n@SQ\tSN:APMT01234509.1\tLN:1402\n@SQ\tSN:APMT01234510.1\tLN:1402\n@SQ\tSN:APMT01234083.1\tLN:1401\n@SQ\tSN:APMT01234511.1\tLN:1401\n@SQ\tSN:APMT01234516.1\tLN:1401\n@SQ\tSN:APMT01234517.1\tLN:1401\n@SQ\tSN:APMT01234518.1\tLN:1401\n@SQ\tSN:APMT01234005.1\tLN:1400\n@SQ\tSN:APMT01234245.1\tLN:1400\n@SQ\tSN:APMT01234520.1\tLN:1400\n@SQ\tSN:APMT01234521.1\tLN:1400\n@SQ\tSN:APMT01234522.1\tLN:1400\n@SQ\tSN:APMT01234524.1\tLN:1400\n@SQ\tSN:APMT01234284.1\tLN:1399\n@SQ\tSN:APMT01234310.1\tLN:1399\n@SQ\tSN:APMT01234526.1\tLN:1399\n@SQ\tSN:APMT01234530.1\tLN:1399\n@SQ\tSN:APMT01234531.1\tLN:1399\n@SQ\tSN:APMT01234418.1\tLN:1398\n@SQ\tSN:APMT01234443.1\tLN:1398\n@SQ\tSN:APMT01234533.1\tLN:1398\n@SQ\tSN:APMT01234535.1\tLN:1398\n@SQ\tSN:APMT01234536.1\tLN:1398\n@SQ\tSN:APMT01234537.1\tLN:1398\n@SQ\tSN:APMT01234405.1\tLN:1397\n@SQ\tSN:APMT01234540.1\tLN:1397\n@SQ\tSN:APMT01234541.1\tLN:1397\n@SQ\tSN:APMT01234543.1\tLN:1397\n@SQ\tSN:APMT01234209.1\tLN:1396\n@SQ\tSN:APMT01234544.1\tLN:1396\n@SQ\tSN:APMT01234546.1\tLN:1396\n@SQ\tSN:APMT01234241.1\tLN:1395\n@SQ\tSN:APMT01234325.1\tLN:1395\n@SQ\tSN:APMT01234549.1\tLN:1395\n@SQ\tSN:APMT01234552.1\tLN:1395\n@SQ\tSN:APMT01234553.1\tLN:1395\n@SQ\tSN:APMT01234556.1\tLN:1395\n@SQ\tSN:APMT01234557.1\tLN:1395\n@SQ\tSN:APMT01234558.1\tLN:1395\n@SQ\tSN:APMT01234559.1\tLN:1394\n@SQ\tSN:APMT01234561.1\tLN:1394\n@SQ\tSN:APMT01234562.1\tLN:1394\n@SQ\tSN:APMT01234563.1\tLN:1394\n@SQ\tSN:APMT01234564.1\tLN:1394\n@SQ\tSN:APMT01234565.1\tLN:1394\n@SQ\tSN:APMT01234567.1\tLN:1394\n@SQ\tSN:APMT01234568.1\tLN:1394\n@SQ\tSN:APMT01234257.1\tLN:1393\n@SQ\tSN:APMT01234569.1\tLN:1393\n@SQ\tSN:APMT01234571.1\tLN:1393\n@SQ\tSN:APMT01234574.1\tLN:1393\n@SQ\tSN:APMT01234577.1\tLN:1393\n@SQ\tSN:APMT01234572.1\tLN:1392\n@SQ\tSN:APMT01234578.1\tLN:1392\n@SQ\tSN:APMT01234580.1\tLN:1392\n@SQ\tSN:APMT01234581.1\tLN:1392\n@SQ\tSN:APMT01234583.1\tLN:1392\n@SQ\tSN:APMT01234584.1\tLN:1392\n@SQ\tSN:APMT01234262.1\tLN:1391\n@SQ\tSN:APMT01234288.1\tLN:1391\n@SQ\tSN:APMT01234538.1\tLN:1391\n@SQ\tSN:APMT01234585.1\tLN:1391\n@SQ\tSN:APMT01234589.1\tLN:1391\n@SQ\tSN:APMT01234555.1\tLN:1390\n@SQ\tSN:APMT01234590.1\tLN:1390\n@SQ\tSN:APMT01234591.1\tLN:1390\n@SQ\tSN:APMT01234593.1\tLN:1390\n@SQ\tSN:APMT01234595.1\tLN:1390\n@SQ\tSN:APMT01234596.1\tLN:1390\n@SQ\tSN:APMT01234597.1\tLN:1389\n@SQ\tSN:APMT01234598.1\tLN:1389\n@SQ\tSN:APMT01234271.1\tLN:1388\n@SQ\tSN:APMT01234279.1\tLN:1388\n@SQ\tSN:APMT01234305.1\tLN:1388\n@SQ\tSN:APMT01234601.1\tLN:1388\n@SQ\tSN:APMT01234602.1\tLN:1388\n@SQ\tSN:APMT01234604.1\tLN:1388\n@SQ\tSN:APMT01234062.1\tLN:1387\n@SQ\tSN:APMT01234607.1\tLN:1387\n@SQ\tSN:APMT01234609.1\tLN:1387\n@SQ\tSN:APMT01234610.1\tLN:1387\n@SQ\tSN:APMT01234611.1\tLN:1387\n@SQ\tSN:APMT01234612.1\tLN:1386\n@SQ\tSN:APMT01234613.1\tLN:1386\n@SQ\tSN:APMT01234614.1\tLN:1386\n@SQ\tSN:APMT01234615.1\tLN:1386\n@SQ\tSN:APMT01234616.1\tLN:1386\n@SQ\tSN:APMT01234608.1\tLN:1385\n@SQ\tSN:APMT01234619.1\tLN:1385\n@SQ\tSN:APMT01234621.1\tLN:1385\n@SQ\tSN:APMT01234622.1\tLN:1385\n@SQ\tSN:APMT01234623.1\tLN:1385\n@SQ\tSN:APMT01234515.1\tLN:1384\n@SQ\tSN:APMT01234625.1\tLN:1384\n@SQ\tSN:APMT01234297.1\tLN:1383\n@SQ\tSN:APMT01234628.1\tLN:1383\n@SQ\tSN:APMT01234629.1\tLN:1383\n@SQ\tSN:APMT01234633.1\tLN:1382\n@SQ\tSN:APMT01234634.1\tLN:1382\n@SQ\tSN:APMT01234636.1\tLN:1382\n@SQ\tSN:APMT01234332.1\tLN:1381\n@SQ\tSN:APMT01234637.1\tLN:1381\n@SQ\tSN:APMT01234638.1\tLN:1381\n@SQ\tSN:APMT01234640.1\tLN:1381\n@SQ\tSN:APMT01234641.1\tLN:1381\n@SQ\tSN:APMT01234642.1\tLN:1381\n@SQ\tSN:APMT01234643.1\tLN:1381\n@SQ\tSN:APMT01234128.1\tLN:1380\n@SQ\tSN:APMT01234398.1\tLN:1380\n@SQ\tSN:APMT01234436.1\tLN:1380\n@SQ\tSN:APMT01234539.1\tLN:1380\n@SQ\tSN:APMT01234644.1\tLN:1380\n@SQ\tSN:APMT01234646.1\tLN:1380\n@SQ\tSN:APMT01234649.1\tLN:1380\n@SQ\tSN:APMT01234650.1\tLN:1380\n@SQ\tSN:APMT01234492.1\tLN:1379\n@SQ\tSN:APMT01234603.1\tLN:1379\n@SQ\tSN:APMT01234653.1\tLN:1379\n@SQ\tSN:APMT01234655.1\tLN:1379\n@SQ\tSN:APMT01234656.1\tLN:1379\n@SQ\tSN:APMT01234321.1\tLN:1378\n@SQ\tSN:APMT01234329.1\tLN:1378\n@SQ\tSN:APMT01234343.1\tLN:1378\n@SQ\tSN:APMT01234350.1\tLN:1378\n@SQ\tSN:APMT01234391.1\tLN:1378\n@SQ\tSN:APMT01234395.1\tLN:1378\n@SQ\tSN:APMT01234657.1\tLN:1378\n@SQ\tSN:APMT01234659.1\tLN:1378\n@SQ\tSN:APMT01234660.1\tLN:1378\n@SQ\tSN:APMT01234513.1\tLN:1377\n@SQ\tSN:APMT01234662.1\tLN:1377\n@SQ\tSN:APMT01234664.1\tLN:1377\n@SQ\tSN:APMT01234166.1\tLN:1376\n@SQ\tSN:APMT01234380.1\tLN:1376\n@SQ\tSN:APMT01234665.1\tLN:1376\n@SQ\tSN:APMT01234666.1\tLN:1376\n@SQ\tSN:APMT01234668.1\tLN:1376\n@SQ\tSN:APMT01234379.1\tLN:1375\n@SQ\tSN:APMT01234383.1\tLN:1375\n@SQ\tSN:APMT01234498.1\tLN:1375\n@SQ\tSN:APMT01234630.1\tLN:1375\n@SQ\tSN:APMT01234631.1\tLN:1375\n@SQ\tSN:APMT01234670.1\tLN:1375\n@SQ\tSN:APMT01234671.1\tLN:1375\n@SQ\tSN:KB713196.1\tLN:1374\n@SQ\tSN:APMT01234357.1\tLN:1374\n@SQ\tSN:APMT01234366.1\tLN:1374\n@SQ\tSN:APMT01234372.1\tLN:1374\n@SQ\tSN:APMT01234676.1\tLN:1374\n@SQ\tSN:APMT01234678.1\tLN:1374\n@SQ\tSN:APMT01234679.1\tLN:1374\n@SQ\tSN:APMT01234680.1\tLN:1374\n@SQ\tSN:APMT01234682.1\tLN:1374\n@SQ\tSN:APMT01234684.1\tLN:1374\n@SQ\tSN:APMT01234373.1\tLN:1373\n@SQ\tSN:APMT01234632.1\tLN:1373\n@SQ\tSN:APMT01234685.1\tLN:1373\n@SQ\tSN:APMT01234686.1\tLN:1373\n@SQ\tSN:APMT01234174.1\tLN:1372\n@SQ\tSN:APMT01234690.1\tLN:1372\n@SQ\tSN:APMT01234691.1\tLN:1372\n@SQ\tSN:APMT01234692.1\tLN:1372\n@SQ\tSN:APMT01234693.1\tLN:1372\n@SQ\tSN:APMT01234647.1\tLN:1371\n@SQ\tSN:APMT01234697.1\tLN:1371\n@SQ\tSN:APMT01234698.1\tLN:1370\n@SQ\tSN:APMT01234699.1\tLN:1370\n@SQ\tSN:APMT01234369.1\tLN:1369\n@SQ\tSN:APMT01234701.1\tLN:1369\n@SQ\tSN:APMT01234702.1\tLN:1369\n@SQ\tSN:APMT01234703.1\tLN:1369\n@SQ\tSN:APMT01234534.1\tLN:1368\n@SQ\tSN:APMT01234705.1\tLN:1368\n@SQ\tSN:APMT01234706.1\tLN:1368\n@SQ\tSN:APMT01234708.1\tLN:1368\n@SQ\tSN:APMT01234709.1\tLN:1368\n@SQ\tSN:APMT01234710.1\tLN:1367\n@SQ\tSN:APMT01234711.1\tLN:1367\n@SQ\tSN:APMT01234714.1\tLN:1367\n@SQ\tSN:APMT01222612.1\tLN:1366\n@SQ\tSN:APMT01234155.1\tLN:1366\n@SQ\tSN:APMT01234716.1\tLN:1366\n@SQ\tSN:APMT01234718.1\tLN:1366\n@SQ\tSN:APMT01234720.1\tLN:1366\n@SQ\tSN:APMT01234390.1\tLN:1365\n@SQ\tSN:APMT01234721.1\tLN:1365\n@SQ\tSN:APMT01234722.1\tLN:1365\n@SQ\tSN:APMT01234723.1\tLN:1365\n@SQ\tSN:APMT01234725.1\tLN:1365\n@SQ\tSN:APMT01234695.1\tLN:1364\n@SQ\tSN:APMT01234727.1\tLN:1364\n@SQ\tSN:APMT01234728.1\tLN:1364\n@SQ\tSN:APMT01234729.1\tLN:1364\n@SQ\tSN:APMT01234730.1\tLN:1364\n@SQ\tSN:APMT01234731.1\tLN:1364\n@SQ\tSN:APMT01234733.1\tLN:1363\n@SQ\tSN:APMT01234734.1\tLN:1363\n@SQ\tSN:APMT01234735.1\tLN:1363\n@SQ\tSN:APMT01234438.1\tLN:1362\n@SQ\tSN:APMT01234439.1\tLN:1362\n@SQ\tSN:APMT01234560.1\tLN:1362\n@SQ\tSN:APMT01234736.1\tLN:1362\n@SQ\tSN:APMT01234737.1\tLN:1362\n@SQ\tSN:APMT01234739.1\tLN:1361\n@SQ\tSN:APMT01234741.1\tLN:1361\n@SQ\tSN:APMT01234742.1\tLN:1361\n@SQ\tSN:APMT01234744.1\tLN:1361\n@SQ\tSN:APMT01234158.1\tLN:1360\n@SQ\tSN:APMT01234519.1\tLN:1360\n@SQ\tSN:APMT01234724.1\tLN:1360\n@SQ\tSN:APMT01234746.1\tLN:1360\n@SQ\tSN:APMT01234747.1\tLN:1360\n@SQ\tSN:APMT01234751.1\tLN:1360\n@SQ\tSN:APMT01234752.1\tLN:1360\n@SQ\tSN:APMT01234238.1\tLN:1359\n@SQ\tSN:APMT01234426.1\tLN:1359\n@SQ\tSN:APMT01234432.1\tLN:1359\n@SQ\tSN:APMT01234754.1\tLN:1359\n@SQ\tSN:APMT01234756.1\tLN:1359\n@SQ\tSN:APMT01234757.1\tLN:1359\n@SQ\tSN:APMT01234502.1\tLN:1358\n@SQ\tSN:APMT01234618.1\tLN:1358\n@SQ\tSN:APMT01234627.1\tLN:1358\n@SQ\tSN:APMT01234759.1\tLN:1358\n@SQ\tSN:APMT01234760.1\tLN:1358\n@SQ\tSN:APMT01234761.1\tLN:1358\n@SQ\tSN:APMT01234763.1\tLN:1358\n@SQ\tSN:APMT01234764.1\tLN:1358\n@SQ\tSN:APMT01234765.1\tLN:1358\n@SQ\tSN:APMT01234766.1\tLN:1358\n@SQ\tSN:APMT01234767.1\tLN:1358\n@SQ\tSN:APMT01234528.1\tLN:1357\n@SQ\tSN:APMT01234768.1\tLN:1357\n@SQ\tSN:APMT01234769.1\tLN:1357\n@SQ\tSN:APMT01234770.1\tLN:1357\n@SQ\tSN:APMT01234771.1\tLN:1357\n@SQ\tSN:APMT01234772.1\tLN:1357\n@SQ\tSN:APMT01234773.1\tLN:1357\n@SQ\tSN:APMT01234774.1\tLN:1357\n@SQ\tSN:APMT01234775.1\tLN:1357\n@SQ\tSN:APMT01234776.1\tLN:1357\n@SQ\tSN:APMT01234424.1\tLN:1356\n@SQ\tSN:APMT01234504.1\tLN:1356\n@SQ\tSN:APMT01234527.1\tLN:1356\n@SQ\tSN:APMT01234778.1\tLN:1356\n@SQ\tSN:APMT01234779.1\tLN:1356\n@SQ\tSN:APMT01234433.1\tLN:1355\n@SQ\tSN:APMT01234606.1\tLN:1355\n@SQ\tSN:APMT01234780.1\tLN:1355\n@SQ\tSN:APMT01234781.1\tLN:1355\n@SQ\tSN:APMT01234782.1\tLN:1355\n@SQ\tSN:APMT01234784.1\tLN:1355\n@SQ\tSN:APMT01234785.1\tLN:1355\n@SQ\tSN:APMT01234786.1\tLN:1355\n@SQ\tSN:APMT01234497.1\tLN:1354\n@SQ\tSN:APMT01234787.1\tLN:1354\n@SQ\tSN:APMT01234788.1\tLN:1354\n@SQ\tSN:APMT01234789.1\tLN:1354\n@SQ\tSN:APMT01234790.1\tLN:1354\n@SQ\tSN:APMT01234791.1\tLN:1354\n@SQ\tSN:APMT01234792.1\tLN:1354\n@SQ\tSN:APMT01234793.1\tLN:1354\n@SQ\tSN:APMT01234330.1\tLN:1353\n@SQ\tSN:APMT01234471.1\tLN:1353\n@SQ\tSN:APMT01234220.1\tLN:1352\n@SQ\tSN:APMT01234264.1\tLN:1352\n@SQ\tSN:APMT01234447.1\tLN:1352\n@SQ\tSN:APMT01234796.1\tLN:1352\n@SQ\tSN:APMT01234798.1\tLN:1352\n@SQ\tSN:APMT01234799.1\tLN:1352\n@SQ\tSN:APMT01234190.1\tLN:1351\n@SQ\tSN:APMT01234800.1\tLN:1351\n@SQ\tSN:APMT01234801.1\tLN:1351\n@SQ\tSN:APMT01234802.1\tLN:1351\n@SQ\tSN:APMT01234803.1\tLN:1351\n@SQ\tSN:APMT01234804.1\tLN:1351\n@SQ\tSN:APMT01234805.1\tLN:1351\n@SQ\tSN:APMT01234806.1\tLN:1351\n@SQ\tSN:APMT01234454.1\tLN:1350\n@SQ\tSN:APMT01234532.1\tLN:1350\n@SQ\tSN:APMT01234687.1\tLN:1350\n@SQ\tSN:APMT01234809.1\tLN:1350\n@SQ\tSN:APMT01234810.1\tLN:1350\n@SQ\tSN:APMT01234811.1\tLN:1350\n@SQ\tSN:APMT01234812.1\tLN:1350\n@SQ\tSN:APMT01234491.1\tLN:1349\n@SQ\tSN:APMT01234514.1\tLN:1349\n@SQ\tSN:APMT01234545.1\tLN:1349\n@SQ\tSN:APMT01234700.1\tLN:1349\n@SQ\tSN:APMT01234715.1\tLN:1349\n@SQ\tSN:APMT01234815.1\tLN:1349\n@SQ\tSN:APMT01234816.1\tLN:1349\n@SQ\tSN:APMT01234817.1\tLN:1348\n@SQ\tSN:APMT01234818.1\tLN:1348\n@SQ\tSN:APMT01234819.1\tLN:1348\n@SQ\tSN:APMT01234821.1\tLN:1348\n@SQ\tSN:APMT01234822.1\tLN:1348\n@SQ\tSN:KB713329.1\tLN:1347\n@SQ\tSN:KB714066.1\tLN:1347\n@SQ\tSN:APMT01234500.1\tLN:1347\n@SQ\tSN:APMT01234529.1\tLN:1347\n@SQ\tSN:APMT01234582.1\tLN:1347\n@SQ\tSN:APMT01234823.1\tLN:1347\n@SQ\tSN:APMT01234825.1\tLN:1347\n@SQ\tSN:APMT01234830.1\tLN:1347\n@SQ\tSN:APMT01234831.1\tLN:1347\n@SQ\tSN:APMT01234833.1\tLN:1346\n@SQ\tSN:APMT01234834.1\tLN:1346\n@SQ\tSN:APMT01234835.1\tLN:1346\n@SQ\tSN:APMT01234838.1\tLN:1346\n@SQ\tSN:APMT01234334.1\tLN:1345\n@SQ\tSN:APMT01234512.1\tLN:1345\n@SQ\tSN:APMT01234837.1\tLN:1345\n@SQ\tSN:APMT01234839.1\tLN:1345\n@SQ\tSN:APMT01234840.1\tLN:1345\n@SQ\tSN:APMT01234841.1\tLN:1345\n@SQ\tSN:APMT01234842.1\tLN:1345\n@SQ\tSN:APMT01234550.1\tLN:1344\n@SQ\tSN:APMT01234843.1\tLN:1344\n@SQ\tSN:APMT01234844.1\tLN:1344\n@SQ\tSN:APMT01234845.1\tLN:1344\n@SQ\tSN:APMT01234848.1\tLN:1344\n@SQ\tSN:APMT01234849.1\tLN:1344\n@SQ\tSN:APMT01234495.1\tLN:1343\n@SQ\tSN:APMT01234851.1\tLN:1343\n@SQ\tSN:APMT01234852.1\tLN:1343\n@SQ\tSN:APMT01234853.1\tLN:1343\n@SQ\tSN:APMT01234854.1\tLN:1343\n@SQ\tSN:APMT01234855.1\tLN:1343\n@SQ\tSN:APMT01234523.1\tLN:1342\n@SQ\tSN:APMT01234859.1\tLN:1342\n@SQ\tSN:APMT01234861.1\tLN:1341\n@SQ\tSN:APMT01234862.1\tLN:1341\n@SQ\tSN:APMT01234554.1\tLN:1340\n@SQ\tSN:APMT01234600.1\tLN:1340\n@SQ\tSN:APMT01234726.1\tLN:1340\n@SQ\tSN:APMT01234866.1\tLN:1340\n@SQ\tSN:APMT01234867.1\tLN:1340\n@SQ\tSN:APMT01234868.1\tLN:1340\n@SQ\tSN:APMT01234869.1\tLN:1340\n@SQ\tSN:APMT01234870.1\tLN:1340\n@SQ\tSN:APMT01234871.1\tLN:1340\n@SQ\tSN:APMT01234872.1\tLN:1339\n@SQ\tSN:APMT01234875.1\tLN:1339\n@SQ\tSN:APMT01234876.1\tLN:1339\n@SQ\tSN:APMT01234877.1\tLN:1339\n@SQ\tSN:APMT01234878.1\tLN:1339\n@SQ\tSN:APMT01234259.1\tLN:1338\n@SQ\tSN:APMT01234570.1\tLN:1338\n@SQ\tSN:APMT01234587.1\tLN:1338\n@SQ\tSN:APMT01234677.1\tLN:1338\n@SQ\tSN:APMT01234707.1\tLN:1338\n@SQ\tSN:APMT01234882.1\tLN:1338\n@SQ\tSN:APMT01234883.1\tLN:1338\n@SQ\tSN:APMT01234884.1\tLN:1338\n@SQ\tSN:APMT01234886.1\tLN:1338\n@SQ\tSN:APMT01234551.1\tLN:1337\n@SQ\tSN:APMT01234586.1\tLN:1337\n@SQ\tSN:APMT01234887.1\tLN:1337\n@SQ\tSN:APMT01234890.1\tLN:1337\n@SQ\tSN:APMT01234891.1\tLN:1337\n@SQ\tSN:APMT01234892.1\tLN:1337\n@SQ\tSN:APMT01234928.1\tLN:1337\n@SQ\tSN:APMT01234542.1\tLN:1336\n@SQ\tSN:APMT01234547.1\tLN:1336\n@SQ\tSN:APMT01234661.1\tLN:1336\n@SQ\tSN:APMT01234893.1\tLN:1336\n@SQ\tSN:APMT01234894.1\tLN:1336\n@SQ\tSN:APMT01234895.1\tLN:1336\n@SQ\tSN:APMT01234896.1\tLN:1336\n@SQ\tSN:APMT01234898.1\tLN:1336\n@SQ\tSN:APMT01234900.1\tLN:1336\n@SQ\tSN:APMT01234987.1\tLN:1336\n@SQ\tSN:APMT01234548.1\tLN:1335\n@SQ\tSN:APMT01234899.1\tLN:1335\n@SQ\tSN:APMT01234905.1\tLN:1335\n@SQ\tSN:APMT01234906.1\tLN:1335\n@SQ\tSN:APMT01234907.1\tLN:1335\n@SQ\tSN:APMT01234304.1\tLN:1334\n@SQ\tSN:APMT01234579.1\tLN:1334\n@SQ\tSN:APMT01234750.1\tLN:1334\n@SQ\tSN:APMT01234881.1\tLN:1334\n@SQ\tSN:APMT01234910.1\tLN:1334\n@SQ\tSN:APMT01234911.1\tLN:1334\n@SQ\tSN:APMT01234912.1\tLN:1334\n@SQ\tSN:APMT01234913.1\tLN:1334\n@SQ\tSN:APMT01234914.1\tLN:1334\n@SQ\tSN:APMT01234917.1\tLN:1334\n@SQ\tSN:APMT01234479.1\tLN:1333\n@SQ\tSN:APMT01234575.1\tLN:1333\n@SQ\tSN:APMT01234651.1\tLN:1333\n@SQ\tSN:APMT01234712.1\tLN:1333\n@SQ\tSN:APMT01234814.1\tLN:1333\n@SQ\tSN:APMT01234836.1\tLN:1333\n@SQ\tSN:APMT01234919.1\tLN:1333\n@SQ\tSN:APMT01234920.1\tLN:1333\n@SQ\tSN:APMT01234921.1\tLN:1333\n@SQ\tSN:APMT01234922.1\tLN:1333\n@SQ\tSN:APMT01234925.1\tLN:1332\n@SQ\tSN:APMT01234926.1\tLN:1332\n@SQ\tSN:APMT01234594.1\tLN:1331\n@SQ\tSN:APMT01234915.1\tLN:1331\n@SQ\tSN:APMT01234929.1\tLN:1331\n@SQ\tSN:APMT01234930.1\tLN:1331\n@SQ\tSN:APMT01234931.1\tLN:1331\n@SQ\tSN:APMT01234932.1\tLN:1331\n@SQ\tSN:APMT01234933.1\tLN:1331\n@SQ\tSN:APMT01234617.1\tLN:1330\n@SQ\tSN:APMT01234934.1\tLN:1330\n@SQ\tSN:APMT01234937.1\tLN:1330\n@SQ\tSN:APMT01234938.1\tLN:1330\n@SQ\tSN:APMT01234940.1\tLN:1330\n@SQ\tSN:APMT01234941.1\tLN:1330\n@SQ\tSN:APMT01234949.1\tLN:1330\n@SQ\tSN:APMT01234407.1\tLN:1329\n@SQ\tSN:APMT01234908.1\tLN:1329\n@SQ\tSN:APMT01234943.1\tLN:1329\n@SQ\tSN:APMT01234944.1\tLN:1329\n@SQ\tSN:APMT01234945.1\tLN:1329\n@SQ\tSN:APMT01234946.1\tLN:1329\n@SQ\tSN:APMT01234948.1\tLN:1329\n@SQ\tSN:APMT01234950.1\tLN:1329\n@SQ\tSN:APMT01234624.1\tLN:1328\n@SQ\tSN:APMT01234951.1\tLN:1328\n@SQ\tSN:APMT01234953.1\tLN:1328\n@SQ\tSN:APMT01234954.1\tLN:1328\n@SQ\tSN:APMT01234605.1\tLN:1327\n@SQ\tSN:APMT01234635.1\tLN:1327\n@SQ\tSN:APMT01234674.1\tLN:1327\n@SQ\tSN:APMT01234713.1\tLN:1327\n@SQ\tSN:APMT01234956.1\tLN:1327\n@SQ\tSN:APMT01234957.1\tLN:1327\n@SQ\tSN:APMT01234958.1\tLN:1327\n@SQ\tSN:APMT01234959.1\tLN:1327\n@SQ\tSN:APMT01234626.1\tLN:1326\n@SQ\tSN:APMT01234681.1\tLN:1326\n@SQ\tSN:APMT01234961.1\tLN:1326\n@SQ\tSN:APMT01234962.1\tLN:1326\n@SQ\tSN:APMT01234963.1\tLN:1326\n@SQ\tSN:APMT01234967.1\tLN:1325\n@SQ\tSN:APMT01234968.1\tLN:1325\n@SQ\tSN:APMT01234969.1\tLN:1325\n@SQ\tSN:APMT01234620.1\tLN:1324\n@SQ\tSN:APMT01234663.1\tLN:1324\n@SQ\tSN:APMT01234694.1\tLN:1324\n@SQ\tSN:APMT01234918.1\tLN:1324\n@SQ\tSN:APMT01234972.1\tLN:1324\n@SQ\tSN:APMT01234973.1\tLN:1324\n@SQ\tSN:APMT01234975.1\tLN:1324\n@SQ\tSN:APMT01234976.1\tLN:1324\n@SQ\tSN:APMT01234977.1\tLN:1324\n@SQ\tSN:APMT01234639.1\tLN:1323\n@SQ\tSN:APMT01234978.1\tLN:1323\n@SQ\tSN:APMT01234980.1\tLN:1323\n@SQ\tSN:APMT01234981.1\tLN:1323\n@SQ\tSN:APMT01234982.1\tLN:1323\n@SQ\tSN:APMT01234983.1\tLN:1323\n@SQ\tSN:APMT01234986.1\tLN:1323\n@SQ\tSN:APMT01234965.1\tLN:1322\n@SQ\tSN:APMT01234370.1\tLN:1321\n@SQ\tSN:APMT01234588.1\tLN:1321\n@SQ\tSN:APMT01234652.1\tLN:1321\n@SQ\tSN:APMT01234672.1\tLN:1321\n@SQ\tSN:APMT01234850.1\tLN:1321\n@SQ\tSN:APMT01234988.1\tLN:1321\n@SQ\tSN:APMT01234990.1\tLN:1321\n@SQ\tSN:APMT01234992.1\tLN:1321\n@SQ\tSN:APMT01234993.1\tLN:1321\n@SQ\tSN:APMT01234402.1\tLN:1320\n@SQ\tSN:APMT01234645.1\tLN:1320\n@SQ\tSN:APMT01234696.1\tLN:1320\n@SQ\tSN:APMT01234991.1\tLN:1320\n@SQ\tSN:APMT01234994.1\tLN:1320\n@SQ\tSN:APMT01234996.1\tLN:1320\n@SQ\tSN:APMT01234997.1\tLN:1320\n@SQ\tSN:APMT01234654.1\tLN:1319\n@SQ\tSN:APMT01234675.1\tLN:1319\n@SQ\tSN:APMT01234999.1\tLN:1319\n@SQ\tSN:APMT01235001.1\tLN:1319\n@SQ\tSN:APMT01235002.1\tLN:1319\n@SQ\tSN:APMT01235003.1\tLN:1319\n@SQ\tSN:APMT01235005.1\tLN:1319\n@SQ\tSN:APMT01235006.1\tLN:1319\n@SQ\tSN:APMT01234748.1\tLN:1318\n@SQ\tSN:APMT01234995.1\tLN:1318\n@SQ\tSN:APMT01235008.1\tLN:1318\n@SQ\tSN:APMT01235010.1\tLN:1318\n@SQ\tSN:APMT01235011.1\tLN:1318\n@SQ\tSN:APMT01235012.1\tLN:1318\n@SQ\tSN:APMT01235013.1\tLN:1318\n@SQ\tSN:APMT01234658.1\tLN:1317\n@SQ\tSN:APMT01234667.1\tLN:1317\n@SQ\tSN:APMT01234669.1\tLN:1317\n@SQ\tSN:APMT01234683.1\tLN:1317\n@SQ\tSN:APMT01234704.1\tLN:1317\n@SQ\tSN:APMT01235015.1\tLN:1317\n@SQ\tSN:APMT01235016.1\tLN:1317\n@SQ\tSN:APMT01235017.1\tLN:1317\n@SQ\tSN:APMT01235018.1\tLN:1317\n@SQ\tSN:APMT01235019.1\tLN:1317\n@SQ\tSN:APMT01235020.1\tLN:1317\n@SQ\tSN:APMT01234688.1\tLN:1316\n@SQ\tSN:APMT01235021.1\tLN:1316\n@SQ\tSN:APMT01235022.1\tLN:1316\n@SQ\tSN:APMT01235024.1\tLN:1316\n@SQ\tSN:APMT01235025.1\tLN:1316\n@SQ\tSN:APMT01235030.1\tLN:1316\n@SQ\tSN:APMT01234879.1\tLN:1315\n@SQ\tSN:APMT01235000.1\tLN:1315\n@SQ\tSN:APMT01235028.1\tLN:1315\n@SQ\tSN:APMT01235029.1\tLN:1315\n@SQ\tSN:APMT01235031.1\tLN:1315\n@SQ\tSN:APMT01235032.1\tLN:1315\n@SQ\tSN:APMT01235035.1\tLN:1315\n@SQ\tSN:APMT01234673.1\tLN:1314\n@SQ\tSN:APMT01235026.1\tLN:1314\n@SQ\tSN:APMT01235034.1\tLN:1314\n@SQ\tSN:APMT01235036.1\tLN:1314\n@SQ\tSN:APMT01235037.1\tLN:1314\n@SQ\tSN:APMT01235004.1\tLN:1313\n@SQ\tSN:APMT01235039.1\tLN:1313\n@SQ\tSN:APMT01235040.1\tLN:1313\n@SQ\tSN:APMT01235041.1\tLN:1313\n@SQ\tSN:APMT01235042.1\tLN:1312\n@SQ\tSN:APMT01235043.1\tLN:1312\n@SQ\tSN:APMT01235044.1\tLN:1312\n@SQ\tSN:APMT01234749.1\tLN:1311\n@SQ\tSN:APMT01234832.1\tLN:1311\n@SQ\tSN:APMT01234984.1\tLN:1311\n@SQ\tSN:APMT01235045.1\tLN:1311\n@SQ\tSN:APMT01235047.1\tLN:1311\n@SQ\tSN:APMT01235048.1\tLN:1311\n@SQ\tSN:APMT01235049.1\tLN:1311\n@SQ\tSN:APMT01235050.1\tLN:1311\n@SQ\tSN:APMT01235051.1\tLN:1311\n@SQ\tSN:APMT01234795.1\tLN:1310\n@SQ\tSN:APMT01234885.1\tLN:1310\n@SQ\tSN:APMT01235053.1\tLN:1310\n@SQ\tSN:APMT01235055.1\tLN:1310\n@SQ\tSN:APMT01235056.1\tLN:1309\n@SQ\tSN:APMT01235058.1\tLN:1309\n@SQ\tSN:APMT01235060.1\tLN:1309\n@SQ\tSN:APMT01235063.1\tLN:1309\n@SQ\tSN:APMT01235064.1\tLN:1309\n@SQ\tSN:APMT01235067.1\tLN:1308\n@SQ\tSN:APMT01235068.1\tLN:1308\n@SQ\tSN:APMT01235069.1\tLN:1308\n@SQ\tSN:APMT01234719.1\tLN:1307\n@SQ\tSN:APMT01234971.1\tLN:1307\n@SQ\tSN:APMT01235072.1\tLN:1307\n@SQ\tSN:APMT01235073.1\tLN:1307\n@SQ\tSN:APMT01235074.1\tLN:1307\n@SQ\tSN:APMT01235075.1\tLN:1307\n@SQ\tSN:APMT01235076.1\tLN:1307\n@SQ\tSN:APMT01235077.1\tLN:1307\n@SQ\tSN:APMT01235078.1\tLN:1307\n@SQ\tSN:APMT01234413.1\tLN:1306\n@SQ\tSN:APMT01234740.1\tLN:1306\n@SQ\tSN:APMT01234935.1\tLN:1306\n@SQ\tSN:APMT01234942.1\tLN:1306\n@SQ\tSN:APMT01235061.1\tLN:1306\n@SQ\tSN:APMT01235080.1\tLN:1306\n@SQ\tSN:APMT01234717.1\tLN:1305\n@SQ\tSN:APMT01235082.1\tLN:1305\n@SQ\tSN:APMT01235083.1\tLN:1305\n@SQ\tSN:APMT01235084.1\tLN:1305\n@SQ\tSN:APMT01235085.1\tLN:1305\n@SQ\tSN:APMT01235086.1\tLN:1305\n@SQ\tSN:APMT01235087.1\tLN:1305\n@SQ\tSN:APMT01235088.1\tLN:1304\n@SQ\tSN:APMT01235089.1\tLN:1304\n@SQ\tSN:APMT01235090.1\tLN:1304\n@SQ\tSN:APMT01235093.1\tLN:1304\n@SQ\tSN:APMT01234599.1\tLN:1303\n@SQ\tSN:APMT01235009.1\tLN:1303\n@SQ\tSN:APMT01235094.1\tLN:1303\n@SQ\tSN:APMT01235095.1\tLN:1303\n@SQ\tSN:APMT01234783.1\tLN:1302\n@SQ\tSN:APMT01234797.1\tLN:1302\n@SQ\tSN:APMT01235097.1\tLN:1302\n@SQ\tSN:APMT01235099.1\tLN:1302\n@SQ\tSN:APMT01235101.1\tLN:1302\n@SQ\tSN:APMT01234743.1\tLN:1301\n@SQ\tSN:APMT01234813.1\tLN:1301\n@SQ\tSN:APMT01235092.1\tLN:1301\n@SQ\tSN:APMT01235100.1\tLN:1301\n@SQ\tSN:APMT01235106.1\tLN:1301\n@SQ\tSN:APMT01235109.1\tLN:1301\n@SQ\tSN:APMT01235110.1\tLN:1300\n@SQ\tSN:APMT01235112.1\tLN:1300\n@SQ\tSN:APMT01235113.1\tLN:1300\n@SQ\tSN:APMT01235114.1\tLN:1300\n@SQ\tSN:APMT01235115.1\tLN:1300\n@SQ\tSN:APMT01234762.1\tLN:1299\n@SQ\tSN:APMT01234924.1\tLN:1299\n@SQ\tSN:APMT01235102.1\tLN:1299\n@SQ\tSN:APMT01235116.1\tLN:1299\n@SQ\tSN:APMT01235118.1\tLN:1299\n@SQ\tSN:APMT01234755.1\tLN:1298\n@SQ\tSN:APMT01234856.1\tLN:1298\n@SQ\tSN:APMT01234865.1\tLN:1298\n@SQ\tSN:APMT01235108.1\tLN:1298\n@SQ\tSN:APMT01235120.1\tLN:1298\n@SQ\tSN:APMT01235122.1\tLN:1298\n@SQ\tSN:APMT01235096.1\tLN:1297\n@SQ\tSN:APMT01235123.1\tLN:1297\n@SQ\tSN:APMT01235124.1\tLN:1297\n@SQ\tSN:APMT01235125.1\tLN:1297\n@SQ\tSN:APMT01234794.1\tLN:1296\n@SQ\tSN:APMT01235126.1\tLN:1296\n@SQ\tSN:APMT01235127.1\tLN:1296\n@SQ\tSN:APMT01235129.1\tLN:1296\n@SQ\tSN:APMT01235131.1\tLN:1296\n@SQ\tSN:APMT01235132.1\tLN:1296\n@SQ\tSN:APMT01235133.1\tLN:1296\n@SQ\tSN:APMT01235134.1\tLN:1296\n@SQ\tSN:APMT01235135.1\tLN:1296\n@SQ\tSN:APMT01234897.1\tLN:1295\n@SQ\tSN:APMT01234903.1\tLN:1295\n@SQ\tSN:APMT01234916.1\tLN:1295\n@SQ\tSN:APMT01234979.1\tLN:1295\n@SQ\tSN:APMT01235136.1\tLN:1295\n@SQ\tSN:APMT01235137.1\tLN:1295\n@SQ\tSN:APMT01235138.1\tLN:1295\n@SQ\tSN:APMT01235139.1\tLN:1295\n@SQ\tSN:APMT01235140.1\tLN:1295\n@SQ\tSN:APMT01235142.1\tLN:1294\n@SQ\tSN:APMT01235143.1\tLN:1294\n@SQ\tSN:APMT01235147.1\tLN:1294\n@SQ\tSN:APMT01235149.1\tLN:1294\n@SQ\tSN:APMT01235150.1\tLN:1294\n@SQ\tSN:APMT01235152.1\tLN:1294\n@SQ\tSN:APMT01234909.1\tLN:1293\n@SQ\tSN:APMT01235091.1\tLN:1293\n@SQ\tSN:APMT01235130.1\tLN:1293\n@SQ\tSN:APMT01235154.1\tLN:1293\n@SQ\tSN:APMT01235156.1\tLN:1293\n@SQ\tSN:APMT01235157.1\tLN:1293\n@SQ\tSN:APMT01235158.1\tLN:1293\n@SQ\tSN:APMT01235160.1\tLN:1293\n@SQ\tSN:APMT01235162.1\tLN:1292\n@SQ\tSN:APMT01235164.1\tLN:1292\n@SQ\tSN:APMT01235165.1\tLN:1292\n@SQ\tSN:APMT01235166.1\tLN:1292\n@SQ\tSN:APMT01234846.1\tLN:1291\n@SQ\tSN:APMT01234880.1\tLN:1291\n@SQ\tSN:APMT01235144.1\tLN:1291\n@SQ\tSN:APMT01235167.1\tLN:1291\n@SQ\tSN:APMT01235170.1\tLN:1291\n@SQ\tSN:APMT01235171.1\tLN:1291\n@SQ\tSN:APMT01235187.1\tLN:1291\n@SQ\tSN:APMT01235844.1\tLN:1291\n@SQ\tSN:APMT01234808.1\tLN:1290\n@SQ\tSN:APMT01235174.1\tLN:1290\n@SQ\tSN:APMT01235175.1\tLN:1290\n@SQ\tSN:APMT01235176.1\tLN:1290\n@SQ\tSN:APMT01235177.1\tLN:1290\n@SQ\tSN:APMT01234858.1\tLN:1289\n@SQ\tSN:APMT01234860.1\tLN:1289\n@SQ\tSN:APMT01234901.1\tLN:1289\n@SQ\tSN:APMT01235178.1\tLN:1289\n@SQ\tSN:APMT01235180.1\tLN:1289\n@SQ\tSN:APMT01235182.1\tLN:1289\n@SQ\tSN:APMT01235183.1\tLN:1289\n@SQ\tSN:APMT01235184.1\tLN:1289\n@SQ\tSN:APMT01235185.1\tLN:1289\n@SQ\tSN:APMT01235169.1\tLN:1288\n@SQ\tSN:APMT01235189.1\tLN:1287\n@SQ\tSN:APMT01235190.1\tLN:1287\n@SQ\tSN:APMT01235192.1\tLN:1287\n@SQ\tSN:APMT01235193.1\tLN:1287\n@SQ\tSN:APMT01235195.1\tLN:1287\n@SQ\tSN:APMT01234824.1\tLN:1286\n@SQ\tSN:APMT01235199.1\tLN:1286\n@SQ\tSN:APMT01235200.1\tLN:1286\n@SQ\tSN:APMT01235201.1\tLN:1286\n@SQ\tSN:APMT01235202.1\tLN:1286\n@SQ\tSN:APMT01234573.1\tLN:1285\n@SQ\tSN:APMT01234873.1\tLN:1285\n@SQ\tSN:APMT01235203.1\tLN:1285\n@SQ\tSN:APMT01235204.1\tLN:1285\n@SQ\tSN:APMT01234864.1\tLN:1284\n@SQ\tSN:APMT01234936.1\tLN:1284\n@SQ\tSN:APMT01235197.1\tLN:1284\n@SQ\tSN:APMT01235205.1\tLN:1284\n@SQ\tSN:APMT01235206.1\tLN:1284\n@SQ\tSN:APMT01235207.1\tLN:1284\n@SQ\tSN:APMT01235208.1\tLN:1284\n@SQ\tSN:APMT01234576.1\tLN:1283\n@SQ\tSN:APMT01234863.1\tLN:1283\n@SQ\tSN:APMT01235111.1\tLN:1283\n@SQ\tSN:APMT01235210.1\tLN:1283\n@SQ\tSN:APMT01235211.1\tLN:1283\n@SQ\tSN:APMT01235212.1\tLN:1283\n@SQ\tSN:APMT01235213.1\tLN:1283\n@SQ\tSN:APMT01235214.1\tLN:1283\n@SQ\tSN:APMT01235215.1\tLN:1283\n@SQ\tSN:APMT01235216.1\tLN:1283\n@SQ\tSN:APMT01235218.1\tLN:1282\n@SQ\tSN:APMT01235219.1\tLN:1282\n@SQ\tSN:APMT01235221.1\tLN:1282\n@SQ\tSN:APMT01235222.1\tLN:1282\n@SQ\tSN:APMT01234648.1\tLN:1281\n@SQ\tSN:APMT01234829.1\tLN:1281\n@SQ\tSN:APMT01234857.1\tLN:1281\n@SQ\tSN:APMT01235065.1\tLN:1281\n@SQ\tSN:APMT01235186.1\tLN:1281\n@SQ\tSN:APMT01235225.1\tLN:1281\n@SQ\tSN:APMT01235227.1\tLN:1281\n@SQ\tSN:APMT01235236.1\tLN:1281\n@SQ\tSN:APMT01234566.1\tLN:1280\n@SQ\tSN:APMT01235231.1\tLN:1280\n@SQ\tSN:APMT01235234.1\tLN:1279\n@SQ\tSN:APMT01235235.1\tLN:1279\n@SQ\tSN:APMT01235237.1\tLN:1279\n@SQ\tSN:APMT01235239.1\tLN:1279\n@SQ\tSN:APMT01235241.1\tLN:1279\n@SQ\tSN:APMT01235230.1\tLN:1278\n@SQ\tSN:APMT01235242.1\tLN:1278\n@SQ\tSN:APMT01234888.1\tLN:1277\n@SQ\tSN:APMT01235247.1\tLN:1277\n@SQ\tSN:APMT01235248.1\tLN:1277\n@SQ\tSN:APMT01235249.1\tLN:1277\n@SQ\tSN:APMT01235251.1\tLN:1277\n@SQ\tSN:APMT01234970.1\tLN:1276\n@SQ\tSN:APMT01235252.1\tLN:1276\n@SQ\tSN:APMT01235253.1\tLN:1276\n@SQ\tSN:APMT01235254.1\tLN:1276\n@SQ\tSN:APMT01235255.1\tLN:1276\n@SQ\tSN:APMT01235256.1\tLN:1276\n@SQ\tSN:APMT01235257.1\tLN:1276\n@SQ\tSN:APMT01235258.1\tLN:1276\n@SQ\tSN:APMT01235244.1\tLN:1275\n@SQ\tSN:APMT01235259.1\tLN:1275\n@SQ\tSN:APMT01235260.1\tLN:1275\n@SQ\tSN:APMT01235261.1\tLN:1275\n@SQ\tSN:APMT01235262.1\tLN:1275\n@SQ\tSN:APMT01235263.1\tLN:1275\n@SQ\tSN:APMT01235264.1\tLN:1275\n@SQ\tSN:APMT01235265.1\tLN:1274\n@SQ\tSN:APMT01235266.1\tLN:1274\n@SQ\tSN:APMT01235269.1\tLN:1274\n@SQ\tSN:APMT01234689.1\tLN:1273\n@SQ\tSN:APMT01234923.1\tLN:1273\n@SQ\tSN:APMT01234939.1\tLN:1273\n@SQ\tSN:APMT01234964.1\tLN:1273\n@SQ\tSN:APMT01235271.1\tLN:1273\n@SQ\tSN:APMT01235245.1\tLN:1272\n@SQ\tSN:APMT01235274.1\tLN:1272\n@SQ\tSN:APMT01235275.1\tLN:1272\n@SQ\tSN:APMT01235277.1\tLN:1272\n@SQ\tSN:APMT01234966.1\tLN:1271\n@SQ\tSN:APMT01234989.1\tLN:1271\n@SQ\tSN:APMT01235038.1\tLN:1271\n@SQ\tSN:APMT01235081.1\tLN:1271\n@SQ\tSN:APMT01235278.1\tLN:1271\n@SQ\tSN:APMT01235279.1\tLN:1271\n@SQ\tSN:APMT01235280.1\tLN:1271\n@SQ\tSN:APMT01235281.1\tLN:1271\n@SQ\tSN:APMT01235282.1\tLN:1271\n@SQ\tSN:APMT01235284.1\tLN:1270\n@SQ\tSN:APMT01235285.1\tLN:1270\n@SQ\tSN:APMT01235286.1\tLN:1270\n@SQ\tSN:APMT01235287.1\tLN:1270\n@SQ\tSN:APMT01235288.1\tLN:1270\n@SQ\tSN:APMT01235289.1\tLN:1270\n@SQ\tSN:APMT01235291.1\tLN:1270\n@SQ\tSN:APMT01234732.1\tLN:1269\n@SQ\tSN:APMT01234753.1\tLN:1269\n@SQ\tSN:APMT01235079.1\tLN:1269\n@SQ\tSN:APMT01235293.1\tLN:1269\n@SQ\tSN:APMT01235296.1\tLN:1269\n@SQ\tSN:APMT01234847.1\tLN:1268\n@SQ\tSN:APMT01234952.1\tLN:1268\n@SQ\tSN:APMT01235300.1\tLN:1268\n@SQ\tSN:APMT01235302.1\tLN:1268\n@SQ\tSN:KB713295.1\tLN:1267\n@SQ\tSN:APMT01235304.1\tLN:1267\n@SQ\tSN:APMT01235305.1\tLN:1267\n@SQ\tSN:APMT01235306.1\tLN:1267\n@SQ\tSN:APMT01235307.1\tLN:1267\n@SQ\tSN:APMT01235308.1\tLN:1267\n@SQ\tSN:APMT01235309.1\tLN:1267\n@SQ\tSN:APMT01235310.1\tLN:1267\n@SQ\tSN:APMT01235313.1\tLN:1267\n@SQ\tSN:APMT01235314.1\tLN:1267\n@SQ\tSN:APMT01234592.1\tLN:1266\n@SQ\tSN:APMT01234826.1\tLN:1266\n@SQ\tSN:APMT01234955.1\tLN:1266\n@SQ\tSN:APMT01235226.1\tLN:1266\n@SQ\tSN:APMT01235316.1\tLN:1266\n@SQ\tSN:APMT01235317.1\tLN:1266\n@SQ\tSN:APMT01235318.1\tLN:1266\n@SQ\tSN:APMT01235319.1\tLN:1266\n@SQ\tSN:APMT01235320.1\tLN:1266\n@SQ\tSN:APMT01235179.1\tLN:1265\n@SQ\tSN:APMT01235315.1\tLN:1265\n@SQ\tSN:APMT01235321.1\tLN:1265\n@SQ\tSN:APMT01235322.1\tLN:1265\n@SQ\tSN:APMT01235323.1\tLN:1265\n@SQ\tSN:APMT01235325.1\tLN:1265\n@SQ\tSN:APMT01235027.1\tLN:1264\n@SQ\tSN:APMT01235326.1\tLN:1264\n@SQ\tSN:APMT01235328.1\tLN:1264\n@SQ\tSN:APMT01235329.1\tLN:1264\n@SQ\tSN:APMT01235330.1\tLN:1264\n@SQ\tSN:APMT01235331.1\tLN:1264\n@SQ\tSN:APMT01235332.1\tLN:1264\n@SQ\tSN:APMT01235333.1\tLN:1264\n@SQ\tSN:APMT01235334.1\tLN:1264\n@SQ\tSN:APMT01235337.1\tLN:1263\n@SQ\tSN:APMT01235338.1\tLN:1263\n@SQ\tSN:APMT01235339.1\tLN:1263\n@SQ\tSN:APMT01235356.1\tLN:1263\n@SQ\tSN:APMT01235343.1\tLN:1262\n@SQ\tSN:APMT01235344.1\tLN:1262\n@SQ\tSN:APMT01235345.1\tLN:1262\n@SQ\tSN:APMT01235346.1\tLN:1262\n@SQ\tSN:APMT01235348.1\tLN:1262\n@SQ\tSN:APMT01235349.1\tLN:1262\n@SQ\tSN:APMT01235350.1\tLN:1262\n@SQ\tSN:APMT01235351.1\tLN:1262\n@SQ\tSN:APMT01235352.1\tLN:1262\n@SQ\tSN:APMT01235066.1\tLN:1261\n@SQ\tSN:APMT01235188.1\tLN:1261\n@SQ\tSN:APMT01235353.1\tLN:1261\n@SQ\tSN:APMT01235354.1\tLN:1261\n@SQ\tSN:APMT01235355.1\tLN:1261\n@SQ\tSN:APMT01235357.1\tLN:1261\n@SQ\tSN:APMT01235358.1\tLN:1261\n@SQ\tSN:APMT01235294.1\tLN:1260\n@SQ\tSN:APMT01235360.1\tLN:1260\n@SQ\tSN:APMT01235361.1\tLN:1260\n@SQ\tSN:APMT01235362.1\tLN:1260\n@SQ\tSN:APMT01235363.1\tLN:1260\n@SQ\tSN:APMT01235366.1\tLN:1260\n@SQ\tSN:APMT01235367.1\tLN:1260\n@SQ\tSN:APMT01235365.1\tLN:1259\n@SQ\tSN:APMT01235368.1\tLN:1259\n@SQ\tSN:APMT01235369.1\tLN:1259\n@SQ\tSN:APMT01235371.1\tLN:1259\n@SQ\tSN:APMT01235373.1\tLN:1259\n@SQ\tSN:APMT01235033.1\tLN:1258\n@SQ\tSN:APMT01235375.1\tLN:1258\n@SQ\tSN:APMT01235378.1\tLN:1258\n@SQ\tSN:APMT01235379.1\tLN:1258\n@SQ\tSN:APMT01235381.1\tLN:1258\n@SQ\tSN:APMT01235382.1\tLN:1258\n@SQ\tSN:APMT01235384.1\tLN:1258\n@SQ\tSN:APMT01235385.1\tLN:1258\n@SQ\tSN:APMT01234777.1\tLN:1257\n@SQ\tSN:APMT01235023.1\tLN:1257\n@SQ\tSN:APMT01235105.1\tLN:1257\n@SQ\tSN:APMT01235374.1\tLN:1257\n@SQ\tSN:APMT01235387.1\tLN:1257\n@SQ\tSN:APMT01235388.1\tLN:1257\n@SQ\tSN:APMT01235389.1\tLN:1257\n@SQ\tSN:APMT01235390.1\tLN:1257\n@SQ\tSN:APMT01235391.1\tLN:1257\n@SQ\tSN:APMT01235394.1\tLN:1257\n@SQ\tSN:APMT01234807.1\tLN:1256\n@SQ\tSN:APMT01235014.1\tLN:1256\n@SQ\tSN:APMT01235057.1\tLN:1256\n@SQ\tSN:APMT01235397.1\tLN:1256\n@SQ\tSN:APMT01235399.1\tLN:1256\n@SQ\tSN:APMT01235427.1\tLN:1256\n@SQ\tSN:APMT01235103.1\tLN:1255\n@SQ\tSN:APMT01235403.1\tLN:1255\n@SQ\tSN:APMT01235404.1\tLN:1255\n@SQ\tSN:APMT01235406.1\tLN:1255\n@SQ\tSN:APMT01235408.1\tLN:1255\n@SQ\tSN:APMT01235409.1\tLN:1255\n@SQ\tSN:APMT01235410.1\tLN:1255\n@SQ\tSN:APMT01235411.1\tLN:1255\n@SQ\tSN:APMT01235412.1\tLN:1255\n@SQ\tSN:APMT01235414.1\tLN:1255\n@SQ\tSN:APMT01235415.1\tLN:1255\n@SQ\tSN:APMT01235098.1\tLN:1254\n@SQ\tSN:APMT01235181.1\tLN:1254\n@SQ\tSN:APMT01235335.1\tLN:1254\n@SQ\tSN:APMT01235416.1\tLN:1254\n@SQ\tSN:APMT01235419.1\tLN:1254\n@SQ\tSN:APMT01235209.1\tLN:1253\n@SQ\tSN:APMT01235421.1\tLN:1253\n@SQ\tSN:APMT01235422.1\tLN:1253\n@SQ\tSN:APMT01235423.1\tLN:1253\n@SQ\tSN:APMT01235425.1\tLN:1253\n@SQ\tSN:APMT01235430.1\tLN:1252\n@SQ\tSN:APMT01234828.1\tLN:1251\n@SQ\tSN:APMT01235433.1\tLN:1251\n@SQ\tSN:APMT01235434.1\tLN:1251\n@SQ\tSN:APMT01235104.1\tLN:1250\n@SQ\tSN:APMT01235146.1\tLN:1250\n@SQ\tSN:APMT01235435.1\tLN:1250\n@SQ\tSN:APMT01235436.1\tLN:1250\n@SQ\tSN:APMT01235437.1\tLN:1250\n@SQ\tSN:APMT01235438.1\tLN:1250\n@SQ\tSN:APMT01234738.1\tLN:1249\n@SQ\tSN:APMT01235052.1\tLN:1249\n@SQ\tSN:APMT01235054.1\tLN:1249\n@SQ\tSN:APMT01235059.1\tLN:1249\n@SQ\tSN:APMT01235062.1\tLN:1249\n@SQ\tSN:APMT01235070.1\tLN:1249\n@SQ\tSN:APMT01235440.1\tLN:1249\n@SQ\tSN:APMT01235442.1\tLN:1249\n@SQ\tSN:APMT01235443.1\tLN:1249\n@SQ\tSN:APMT01235444.1\tLN:1249\n@SQ\tSN:APMT01235445.1\tLN:1249\n@SQ\tSN:APMT01234820.1\tLN:1248\n@SQ\tSN:APMT01234889.1\tLN:1248\n@SQ\tSN:APMT01235173.1\tLN:1248\n@SQ\tSN:APMT01235393.1\tLN:1248\n@SQ\tSN:APMT01235446.1\tLN:1248\n@SQ\tSN:APMT01235447.1\tLN:1248\n@SQ\tSN:APMT01235448.1\tLN:1248\n@SQ\tSN:APMT01235071.1\tLN:1247\n@SQ\tSN:APMT01235303.1\tLN:1247\n@SQ\tSN:APMT01235450.1\tLN:1247\n@SQ\tSN:APMT01235451.1\tLN:1247\n@SQ\tSN:APMT01235453.1\tLN:1247\n@SQ\tSN:APMT01234904.1\tLN:1246\n@SQ\tSN:APMT01235117.1\tLN:1246\n@SQ\tSN:APMT01235161.1\tLN:1246\n@SQ\tSN:APMT01235243.1\tLN:1246\n@SQ\tSN:APMT01235455.1\tLN:1246\n@SQ\tSN:APMT01235457.1\tLN:1246\n@SQ\tSN:APMT01235458.1\tLN:1246\n@SQ\tSN:APMT01235459.1\tLN:1246\n@SQ\tSN:APMT01235462.1\tLN:1246\n@SQ\tSN:APMT01235194.1\tLN:1245\n@SQ\tSN:APMT01235460.1\tLN:1245\n@SQ\tSN:APMT01235463.1\tLN:1245\n@SQ\tSN:APMT01235464.1\tLN:1245\n@SQ\tSN:APMT01235465.1\tLN:1245\n@SQ\tSN:APMT01235469.1\tLN:1245\n@SQ\tSN:APMT01235470.1\tLN:1245\n@SQ\tSN:APMT01235471.1\tLN:1245\n@SQ\tSN:APMT01235191.1\tLN:1244\n@SQ\tSN:APMT01235240.1\tLN:1244\n@SQ\tSN:APMT01235472.1\tLN:1244\n@SQ\tSN:APMT01235474.1\tLN:1244\n@SQ\tSN:APMT01235475.1\tLN:1244\n@SQ\tSN:APMT01235476.1\tLN:1244\n@SQ\tSN:APMT01234927.1\tLN:1243\n@SQ\tSN:APMT01235478.1\tLN:1243\n@SQ\tSN:APMT01235479.1\tLN:1243\n@SQ\tSN:APMT01235480.1\tLN:1243\n@SQ\tSN:APMT01235481.1\tLN:1243\n@SQ\tSN:APMT01235484.1\tLN:1243\n@SQ\tSN:APMT01235486.1\tLN:1243\n@SQ\tSN:APMT01235488.1\tLN:1243\n@SQ\tSN:APMT01234745.1\tLN:1242\n@SQ\tSN:APMT01235489.1\tLN:1242\n@SQ\tSN:APMT01235490.1\tLN:1242\n@SQ\tSN:APMT01235495.1\tLN:1242\n@SQ\tSN:APMT01234758.1\tLN:1241\n@SQ\tSN:APMT01235107.1\tLN:1241\n@SQ\tSN:APMT01235119.1\tLN:1241\n@SQ\tSN:APMT01235493.1\tLN:1241\n@SQ\tSN:APMT01235496.1\tLN:1241\n@SQ\tSN:APMT01235499.1\tLN:1241\n@SQ\tSN:APMT01235500.1\tLN:1241\n@SQ\tSN:APMT01235503.1\tLN:1241\n@SQ\tSN:APMT01235505.1\tLN:1241\n@SQ\tSN:APMT01235506.1\tLN:1241\n@SQ\tSN:APMT01235386.1\tLN:1240\n@SQ\tSN:APMT01235497.1\tLN:1240\n@SQ\tSN:APMT01235507.1\tLN:1240\n@SQ\tSN:APMT01235509.1\tLN:1240\n@SQ\tSN:APMT01235511.1\tLN:1240\n@SQ\tSN:APMT01235512.1\tLN:1240\n@SQ\tSN:APMT01235517.1\tLN:1239\n@SQ\tSN:APMT01235519.1\tLN:1239\n@SQ\tSN:APMT01235521.1\tLN:1239\n@SQ\tSN:APMT01235522.1\tLN:1239\n@SQ\tSN:APMT01235524.1\tLN:1239\n@SQ\tSN:APMT01235121.1\tLN:1238\n@SQ\tSN:APMT01235228.1\tLN:1238\n@SQ\tSN:APMT01235229.1\tLN:1238\n@SQ\tSN:APMT01235525.1\tLN:1238\n@SQ\tSN:APMT01235526.1\tLN:1238\n@SQ\tSN:APMT01235527.1\tLN:1238\n@SQ\tSN:APMT01235528.1\tLN:1238\n@SQ\tSN:APMT01235529.1\tLN:1238\n@SQ\tSN:APMT01235128.1\tLN:1237\n@SQ\tSN:APMT01235238.1\tLN:1237\n@SQ\tSN:APMT01235530.1\tLN:1237\n@SQ\tSN:APMT01235532.1\tLN:1237\n@SQ\tSN:APMT01235534.1\tLN:1237\n@SQ\tSN:APMT01235535.1\tLN:1237\n@SQ\tSN:APMT01235549.1\tLN:1237\n@SQ\tSN:APMT01235533.1\tLN:1236\n@SQ\tSN:APMT01235537.1\tLN:1236\n@SQ\tSN:APMT01235538.1\tLN:1236\n@SQ\tSN:APMT01235539.1\tLN:1236\n@SQ\tSN:APMT01235540.1\tLN:1236\n@SQ\tSN:APMT01235542.1\tLN:1236\n@SQ\tSN:APMT01235544.1\tLN:1235\n@SQ\tSN:APMT01235545.1\tLN:1235\n@SQ\tSN:APMT01235546.1\tLN:1235\n@SQ\tSN:APMT01235547.1\tLN:1235\n@SQ\tSN:APMT01235550.1\tLN:1235\n@SQ\tSN:APMT01235148.1\tLN:1234\n@SQ\tSN:APMT01235405.1\tLN:1234\n@SQ\tSN:APMT01235543.1\tLN:1234\n@SQ\tSN:APMT01235551.1\tLN:1234\n@SQ\tSN:APMT01235553.1\tLN:1234\n@SQ\tSN:APMT01235554.1\tLN:1234\n@SQ\tSN:APMT01235555.1\tLN:1234\n@SQ\tSN:APMT01235556.1\tLN:1234\n@SQ\tSN:APMT01235557.1\tLN:1234\n@SQ\tSN:APMT01235558.1\tLN:1234\n@SQ\tSN:APMT01235145.1\tLN:1233\n@SQ\tSN:APMT01235159.1\tLN:1233\n@SQ\tSN:APMT01235168.1\tLN:1233\n@SQ\tSN:APMT01235233.1\tLN:1233\n@SQ\tSN:APMT01235276.1\tLN:1233\n@SQ\tSN:APMT01235290.1\tLN:1233\n@SQ\tSN:APMT01235531.1\tLN:1233\n@SQ\tSN:APMT01235541.1\tLN:1233\n@SQ\tSN:APMT01235560.1\tLN:1233\n@SQ\tSN:APMT01235561.1\tLN:1233\n@SQ\tSN:APMT01235562.1\tLN:1233\n@SQ\tSN:APMT01235563.1\tLN:1233\n@SQ\tSN:APMT01235564.1\tLN:1233\n@SQ\tSN:APMT01235153.1\tLN:1232\n@SQ\tSN:APMT01235155.1\tLN:1232\n@SQ\tSN:APMT01235568.1\tLN:1232\n@SQ\tSN:APMT01235569.1\tLN:1232\n@SQ\tSN:APMT01235570.1\tLN:1232\n@SQ\tSN:APMT01235571.1\tLN:1232\n@SQ\tSN:APMT01235575.1\tLN:1232\n@SQ\tSN:APMT01235007.1\tLN:1231\n@SQ\tSN:APMT01235220.1\tLN:1231\n@SQ\tSN:APMT01235573.1\tLN:1231\n@SQ\tSN:APMT01235574.1\tLN:1231\n@SQ\tSN:APMT01235579.1\tLN:1231\n@SQ\tSN:APMT01235581.1\tLN:1231\n@SQ\tSN:APMT01235582.1\tLN:1231\n@SQ\tSN:APMT01235364.1\tLN:1230\n@SQ\tSN:APMT01235584.1\tLN:1230\n@SQ\tSN:APMT01235588.1\tLN:1230\n@SQ\tSN:APMT01235590.1\tLN:1230\n@SQ\tSN:APMT01235591.1\tLN:1230\n@SQ\tSN:APMT01235592.1\tLN:1230\n@SQ\tSN:APMT01234827.1\tLN:1229\n@SQ\tSN:APMT01235224.1\tLN:1229\n@SQ\tSN:APMT01235383.1\tLN:1229\n@SQ\tSN:APMT01235432.1\tLN:1229\n@SQ\tSN:APMT01235594.1\tLN:1229\n@SQ\tSN:APMT01235595.1\tLN:1229\n@SQ\tSN:APMT01235599.1\tLN:1229\n@SQ\tSN:APMT01235477.1\tLN:1228\n@SQ\tSN:APMT01235498.1\tLN:1228\n@SQ\tSN:APMT01235600.1\tLN:1228\n@SQ\tSN:APMT01235602.1\tLN:1228\n@SQ\tSN:APMT01225519.1\tLN:1227\n@SQ\tSN:APMT01235566.1\tLN:1227\n@SQ\tSN:APMT01235605.1\tLN:1227\n@SQ\tSN:APMT01235606.1\tLN:1227\n@SQ\tSN:APMT01235607.1\tLN:1227\n@SQ\tSN:APMT01235612.1\tLN:1227\n@SQ\tSN:APMT01235617.1\tLN:1227\n@SQ\tSN:APMT01234902.1\tLN:1226\n@SQ\tSN:APMT01235196.1\tLN:1226\n@SQ\tSN:APMT01235232.1\tLN:1226\n@SQ\tSN:APMT01235604.1\tLN:1226\n@SQ\tSN:APMT01235609.1\tLN:1226\n@SQ\tSN:APMT01235620.1\tLN:1226\n@SQ\tSN:APMT01235621.1\tLN:1226\n@SQ\tSN:APMT01235623.1\tLN:1226\n@SQ\tSN:APMT01235624.1\tLN:1226\n@SQ\tSN:APMT01235626.1\tLN:1226\n@SQ\tSN:APMT01234874.1\tLN:1225\n@SQ\tSN:APMT01235619.1\tLN:1225\n@SQ\tSN:APMT01235628.1\tLN:1225\n@SQ\tSN:APMT01235630.1\tLN:1225\n@SQ\tSN:APMT01235631.1\tLN:1225\n@SQ\tSN:APMT01234960.1\tLN:1224\n@SQ\tSN:APMT01235615.1\tLN:1224\n@SQ\tSN:APMT01235634.1\tLN:1224\n@SQ\tSN:APMT01235635.1\tLN:1224\n@SQ\tSN:APMT01235636.1\tLN:1224\n@SQ\tSN:APMT01235637.1\tLN:1224\n@SQ\tSN:APMT01235250.1\tLN:1223\n@SQ\tSN:APMT01235431.1\tLN:1223\n@SQ\tSN:APMT01235640.1\tLN:1223\n@SQ\tSN:APMT01235641.1\tLN:1223\n@SQ\tSN:APMT01235642.1\tLN:1223\n@SQ\tSN:APMT01235643.1\tLN:1223\n@SQ\tSN:APMT01235644.1\tLN:1223\n@SQ\tSN:APMT01235646.1\tLN:1223\n@SQ\tSN:APMT01235649.1\tLN:1223\n@SQ\tSN:APMT01235268.1\tLN:1222\n@SQ\tSN:APMT01235652.1\tLN:1222\n@SQ\tSN:APMT01235653.1\tLN:1222\n@SQ\tSN:APMT01235654.1\tLN:1222\n@SQ\tSN:APMT01234947.1\tLN:1221\n@SQ\tSN:APMT01235217.1\tLN:1221\n@SQ\tSN:APMT01235223.1\tLN:1221\n@SQ\tSN:APMT01235292.1\tLN:1221\n@SQ\tSN:APMT01235655.1\tLN:1221\n@SQ\tSN:APMT01235656.1\tLN:1221\n@SQ\tSN:APMT01235657.1\tLN:1221\n@SQ\tSN:APMT01235658.1\tLN:1221\n@SQ\tSN:APMT01235659.1\tLN:1221\n@SQ\tSN:APMT01235660.1\tLN:1221\n@SQ\tSN:APMT01235661.1\tLN:1221\n@SQ\tSN:APMT01235662.1\tLN:1221\n@SQ\tSN:APMT01234974.1\tLN:1220\n@SQ\tSN:APMT01235267.1\tLN:1220\n@SQ\tSN:APMT01235645.1\tLN:1220\n@SQ\tSN:APMT01235665.1\tLN:1220\n@SQ\tSN:APMT01235667.1\tLN:1220\n@SQ\tSN:APMT01235669.1\tLN:1220\n@SQ\tSN:APMT01235670.1\tLN:1220\n@SQ\tSN:APMT01235340.1\tLN:1219\n@SQ\tSN:APMT01235674.1\tLN:1219\n@SQ\tSN:APMT01235675.1\tLN:1219\n@SQ\tSN:APMT01235676.1\tLN:1219\n@SQ\tSN:APMT01235677.1\tLN:1219\n@SQ\tSN:APMT01235678.1\tLN:1219\n@SQ\tSN:APMT01235376.1\tLN:1218\n@SQ\tSN:APMT01235679.1\tLN:1218\n@SQ\tSN:APMT01235680.1\tLN:1218\n@SQ\tSN:APMT01235681.1\tLN:1218\n@SQ\tSN:APMT01235682.1\tLN:1218\n@SQ\tSN:APMT01235683.1\tLN:1218\n@SQ\tSN:APMT01235684.1\tLN:1218\n@SQ\tSN:APMT01235685.1\tLN:1218\n@SQ\tSN:APMT01235686.1\tLN:1218\n@SQ\tSN:APMT01235687.1\tLN:1218\n@SQ\tSN:APMT01235688.1\tLN:1217\n@SQ\tSN:APMT01235689.1\tLN:1217\n@SQ\tSN:APMT01235690.1\tLN:1217\n@SQ\tSN:APMT01235691.1\tLN:1217\n@SQ\tSN:APMT01235692.1\tLN:1217\n@SQ\tSN:APMT01235377.1\tLN:1216\n@SQ\tSN:APMT01235593.1\tLN:1216\n@SQ\tSN:APMT01235693.1\tLN:1216\n@SQ\tSN:APMT01235696.1\tLN:1215\n@SQ\tSN:APMT01235698.1\tLN:1215\n@SQ\tSN:APMT01235699.1\tLN:1215\n@SQ\tSN:APMT01235700.1\tLN:1215\n@SQ\tSN:APMT01235701.1\tLN:1215\n@SQ\tSN:APMT01235702.1\tLN:1215\n@SQ\tSN:APMT01235704.1\tLN:1215\n@SQ\tSN:APMT01235706.1\tLN:1215\n@SQ\tSN:APMT01235707.1\tLN:1215\n@SQ\tSN:APMT01235552.1\tLN:1214\n@SQ\tSN:APMT01235596.1\tLN:1214\n@SQ\tSN:APMT01235694.1\tLN:1214\n@SQ\tSN:APMT01235708.1\tLN:1214\n@SQ\tSN:APMT01235709.1\tLN:1214\n@SQ\tSN:APMT01235710.1\tLN:1214\n@SQ\tSN:APMT01235711.1\tLN:1214\n@SQ\tSN:APMT01235712.1\tLN:1214\n@SQ\tSN:APMT01235713.1\tLN:1214\n@SQ\tSN:APMT01235714.1\tLN:1214\n@SQ\tSN:APMT01235715.1\tLN:1214\n@SQ\tSN:APMT01225054.1\tLN:1213\n@SQ\tSN:APMT01235297.1\tLN:1213\n@SQ\tSN:APMT01235312.1\tLN:1213\n@SQ\tSN:APMT01235341.1\tLN:1213\n@SQ\tSN:APMT01235717.1\tLN:1213\n@SQ\tSN:APMT01235718.1\tLN:1213\n@SQ\tSN:APMT01235719.1\tLN:1213\n@SQ\tSN:APMT01235720.1\tLN:1213\n@SQ\tSN:APMT01235272.1\tLN:1212\n@SQ\tSN:APMT01235273.1\tLN:1212\n@SQ\tSN:APMT01235671.1\tLN:1212\n@SQ\tSN:APMT01235725.1\tLN:1212\n@SQ\tSN:APMT01235727.1\tLN:1212\n@SQ\tSN:APMT01235730.1\tLN:1211\n@SQ\tSN:APMT01235731.1\tLN:1211\n@SQ\tSN:APMT01235732.1\tLN:1211\n@SQ\tSN:APMT01235733.1\tLN:1211\n@SQ\tSN:APMT01235734.1\tLN:1211\n@SQ\tSN:APMT01235735.1\tLN:1211\n@SQ\tSN:APMT01235736.1\tLN:1211\n@SQ\tSN:APMT01235737.1\tLN:1211\n@SQ\tSN:APMT01235301.1\tLN:1210\n@SQ\tSN:APMT01235413.1\tLN:1210\n@SQ\tSN:APMT01235426.1\tLN:1210\n@SQ\tSN:APMT01235559.1\tLN:1210\n@SQ\tSN:APMT01235666.1\tLN:1210\n@SQ\tSN:APMT01235726.1\tLN:1210\n@SQ\tSN:APMT01235740.1\tLN:1210\n@SQ\tSN:APMT01235741.1\tLN:1210\n@SQ\tSN:APMT01235742.1\tLN:1210\n@SQ\tSN:APMT01235743.1\tLN:1210\n@SQ\tSN:APMT01235745.1\tLN:1210\n@SQ\tSN:APMT01235746.1\tLN:1210\n@SQ\tSN:APMT01235748.1\tLN:1210\n@SQ\tSN:APMT01235749.1\tLN:1210\n@SQ\tSN:APMT01235750.1\tLN:1210\n@SQ\tSN:APMT01235454.1\tLN:1209\n@SQ\tSN:APMT01235752.1\tLN:1209\n@SQ\tSN:APMT01234985.1\tLN:1208\n@SQ\tSN:APMT01235295.1\tLN:1208\n@SQ\tSN:APMT01235751.1\tLN:1208\n@SQ\tSN:APMT01235754.1\tLN:1208\n@SQ\tSN:APMT01235755.1\tLN:1208\n@SQ\tSN:APMT01235757.1\tLN:1208\n@SQ\tSN:APMT01235758.1\tLN:1208\n@SQ\tSN:APMT01235760.1\tLN:1208\n@SQ\tSN:APMT01235370.1\tLN:1207\n@SQ\tSN:APMT01235392.1\tLN:1207\n@SQ\tSN:APMT01235753.1\tLN:1207\n@SQ\tSN:APMT01235762.1\tLN:1207\n@SQ\tSN:APMT01235763.1\tLN:1207\n@SQ\tSN:APMT01235765.1\tLN:1207\n@SQ\tSN:APMT01235766.1\tLN:1207\n@SQ\tSN:APMT01235767.1\tLN:1207\n@SQ\tSN:APMT01235769.1\tLN:1207\n@SQ\tSN:APMT01235771.1\tLN:1207\n@SQ\tSN:APMT01235492.1\tLN:1206\n@SQ\tSN:APMT01235772.1\tLN:1206\n@SQ\tSN:APMT01235773.1\tLN:1206\n@SQ\tSN:APMT01235776.1\tLN:1206\n@SQ\tSN:APMT01235283.1\tLN:1205\n@SQ\tSN:APMT01235418.1\tLN:1205\n@SQ\tSN:APMT01235638.1\tLN:1205\n@SQ\tSN:APMT01235770.1\tLN:1205\n@SQ\tSN:APMT01235777.1\tLN:1205\n@SQ\tSN:APMT01235198.1\tLN:1204\n@SQ\tSN:APMT01235299.1\tLN:1204\n@SQ\tSN:APMT01235347.1\tLN:1204\n@SQ\tSN:APMT01235428.1\tLN:1204\n@SQ\tSN:APMT01235785.1\tLN:1204\n@SQ\tSN:APMT01235786.1\tLN:1204\n@SQ\tSN:APMT01235787.1\tLN:1204\n@SQ\tSN:APMT01235789.1\tLN:1204\n@SQ\tSN:APMT01234998.1\tLN:1203\n@SQ\tSN:APMT01235141.1\tLN:1203\n@SQ\tSN:APMT01235336.1\tLN:1203\n@SQ\tSN:APMT01235502.1\tLN:1203\n@SQ\tSN:APMT01235729.1\tLN:1203\n@SQ\tSN:APMT01235739.1\tLN:1203\n@SQ\tSN:APMT01235792.1\tLN:1203\n@SQ\tSN:APMT01235795.1\tLN:1203\n@SQ\tSN:APMT01235796.1\tLN:1203\n@SQ\tSN:APMT01235797.1\tLN:1203\n@SQ\tSN:APMT01235781.1\tLN:1202\n@SQ\tSN:APMT01235788.1\tLN:1202\n@SQ\tSN:APMT01235799.1\tLN:1202\n@SQ\tSN:APMT01235802.1\tLN:1202\n@SQ\tSN:APMT01235803.1\tLN:1202\n@SQ\tSN:APMT01235804.1\tLN:1202\n@SQ\tSN:APMT01235806.1\tLN:1202\n@SQ\tSN:APMT01235807.1\tLN:1202\n@SQ\tSN:APMT01235808.1\tLN:1202\n@SQ\tSN:APMT01235809.1\tLN:1202\n@SQ\tSN:APMT01235810.1\tLN:1202\n@SQ\tSN:APMT01235468.1\tLN:1201\n@SQ\tSN:APMT01235814.1\tLN:1201\n@SQ\tSN:APMT01235815.1\tLN:1201\n@SQ\tSN:APMT01235816.1\tLN:1201\n@SQ\tSN:APMT01235818.1\tLN:1201\n@SQ\tSN:APMT01235820.1\tLN:1201\n@SQ\tSN:APMT01235172.1\tLN:1200\n@SQ\tSN:APMT01235311.1\tLN:1200\n@SQ\tSN:APMT01235523.1\tLN:1200\n@SQ\tSN:APMT01235764.1\tLN:1200\n@SQ\tSN:APMT01235821.1\tLN:1200\n@SQ\tSN:APMT01235822.1\tLN:1200\n@SQ\tSN:APMT01235823.1\tLN:1200\n@SQ\tSN:APMT01235824.1\tLN:1200\n@SQ\tSN:APMT01235395.1\tLN:1199\n@SQ\tSN:APMT01235827.1\tLN:1199\n@SQ\tSN:APMT01235828.1\tLN:1199\n@SQ\tSN:APMT01235830.1\tLN:1199\n@SQ\tSN:APMT01235832.1\tLN:1199\n@SQ\tSN:APMT01235833.1\tLN:1199\n@SQ\tSN:APMT01228520.1\tLN:1198\n@SQ\tSN:APMT01235487.1\tLN:1198\n@SQ\tSN:APMT01235834.1\tLN:1198\n@SQ\tSN:APMT01235838.1\tLN:1198\n@SQ\tSN:APMT01235840.1\tLN:1198\n@SQ\tSN:APMT01235842.1\tLN:1197\n@SQ\tSN:APMT01235401.1\tLN:1196\n@SQ\tSN:APMT01235845.1\tLN:1196\n@SQ\tSN:APMT01235846.1\tLN:1196\n@SQ\tSN:APMT01235847.1\tLN:1196\n@SQ\tSN:APMT01235848.1\tLN:1196\n@SQ\tSN:APMT01235372.1\tLN:1195\n@SQ\tSN:APMT01235400.1\tLN:1195\n@SQ\tSN:APMT01235851.1\tLN:1195\n@SQ\tSN:APMT01235852.1\tLN:1195\n@SQ\tSN:APMT01235854.1\tLN:1195\n@SQ\tSN:APMT01235855.1\tLN:1195\n@SQ\tSN:APMT01235402.1\tLN:1194\n@SQ\tSN:APMT01235859.1\tLN:1194\n@SQ\tSN:APMT01235860.1\tLN:1194\n@SQ\tSN:APMT01235861.1\tLN:1194\n@SQ\tSN:APMT01235516.1\tLN:1193\n@SQ\tSN:APMT01235744.1\tLN:1193\n@SQ\tSN:APMT01235839.1\tLN:1193\n@SQ\tSN:APMT01235862.1\tLN:1193\n@SQ\tSN:APMT01235863.1\tLN:1193\n@SQ\tSN:APMT01235864.1\tLN:1193\n@SQ\tSN:APMT01235867.1\tLN:1193\n@SQ\tSN:APMT01235868.1\tLN:1193\n@SQ\tSN:APMT01236125.1\tLN:1193\n@SQ\tSN:APMT01235417.1\tLN:1192\n@SQ\tSN:APMT01235482.1\tLN:1192\n@SQ\tSN:APMT01235870.1\tLN:1192\n@SQ\tSN:APMT01235871.1\tLN:1192\n@SQ\tSN:APMT01235872.1\tLN:1192\n@SQ\tSN:APMT01235873.1\tLN:1192\n@SQ\tSN:APMT01235874.1\tLN:1192\n@SQ\tSN:APMT01235875.1\tLN:1192\n@SQ\tSN:APMT01235876.1\tLN:1192\n@SQ\tSN:APMT01235877.1\tLN:1192\n@SQ\tSN:APMT01235466.1\tLN:1191\n@SQ\tSN:APMT01235857.1\tLN:1191\n@SQ\tSN:APMT01235878.1\tLN:1191\n@SQ\tSN:APMT01235880.1\tLN:1191\n@SQ\tSN:APMT01235046.1\tLN:1190\n@SQ\tSN:APMT01235501.1\tLN:1190\n@SQ\tSN:APMT01235504.1\tLN:1190\n@SQ\tSN:APMT01235611.1\tLN:1190\n@SQ\tSN:APMT01235627.1\tLN:1190\n@SQ\tSN:APMT01235885.1\tLN:1190\n@SQ\tSN:APMT01235439.1\tLN:1189\n@SQ\tSN:APMT01235893.1\tLN:1189\n@SQ\tSN:APMT01235895.1\tLN:1189\n@SQ\tSN:APMT01235896.1\tLN:1189\n@SQ\tSN:APMT01235897.1\tLN:1189\n@SQ\tSN:APMT01235898.1\tLN:1188\n@SQ\tSN:APMT01235899.1\tLN:1188\n@SQ\tSN:APMT01235901.1\tLN:1188\n@SQ\tSN:APMT01235903.1\tLN:1188\n@SQ\tSN:APMT01235905.1\tLN:1188\n@SQ\tSN:APMT01235151.1\tLN:1187\n@SQ\tSN:APMT01235473.1\tLN:1187\n@SQ\tSN:APMT01235520.1\tLN:1187\n@SQ\tSN:APMT01235879.1\tLN:1187\n@SQ\tSN:APMT01235911.1\tLN:1187\n@SQ\tSN:APMT01235915.1\tLN:1187\n@SQ\tSN:APMT01235916.1\tLN:1187\n@SQ\tSN:APMT01235461.1\tLN:1186\n@SQ\tSN:APMT01235467.1\tLN:1186\n@SQ\tSN:APMT01235494.1\tLN:1186\n@SQ\tSN:APMT01235918.1\tLN:1186\n@SQ\tSN:APMT01235919.1\tLN:1186\n@SQ\tSN:APMT01235920.1\tLN:1186\n@SQ\tSN:APMT01235921.1\tLN:1186\n@SQ\tSN:APMT01235922.1\tLN:1186\n@SQ\tSN:APMT01235923.1\tLN:1186\n@SQ\tSN:APMT01235924.1\tLN:1186\n@SQ\tSN:APMT01235925.1\tLN:1186\n@SQ\tSN:APMT01235597.1\tLN:1185\n@SQ\tSN:APMT01235926.1\tLN:1185\n@SQ\tSN:APMT01235927.1\tLN:1185\n@SQ\tSN:APMT01235929.1\tLN:1185\n@SQ\tSN:APMT01235930.1\tLN:1185\n@SQ\tSN:APMT01235931.1\tLN:1185\n@SQ\tSN:APMT01235932.1\tLN:1185\n@SQ\tSN:APMT01235933.1\tLN:1185\n@SQ\tSN:APMT01235936.1\tLN:1185\n@SQ\tSN:APMT01235937.1\tLN:1185\n@SQ\tSN:APMT01235938.1\tLN:1185\n@SQ\tSN:APMT01235515.1\tLN:1184\n@SQ\tSN:APMT01235578.1\tLN:1184\n@SQ\tSN:APMT01235928.1\tLN:1184\n@SQ\tSN:APMT01235939.1\tLN:1184\n@SQ\tSN:APMT01235940.1\tLN:1184\n@SQ\tSN:APMT01235942.1\tLN:1184\n@SQ\tSN:APMT01235943.1\tLN:1184\n@SQ\tSN:APMT01235944.1\tLN:1184\n@SQ\tSN:APMT01235945.1\tLN:1184\n@SQ\tSN:APMT01235946.1\tLN:1184\n@SQ\tSN:APMT01235949.1\tLN:1184\n@SQ\tSN:APMT01235950.1\tLN:1184\n@SQ\tSN:APMT01235951.1\tLN:1184\n@SQ\tSN:APMT01235396.1\tLN:1183\n@SQ\tSN:APMT01235891.1\tLN:1183\n@SQ\tSN:APMT01235953.1\tLN:1183\n@SQ\tSN:APMT01235954.1\tLN:1183\n@SQ\tSN:APMT01235955.1\tLN:1183\n@SQ\tSN:APMT01235956.1\tLN:1183\n@SQ\tSN:APMT01235957.1\tLN:1183\n@SQ\tSN:APMT01235958.1\tLN:1183\n@SQ\tSN:APMT01235510.1\tLN:1182\n@SQ\tSN:APMT01235909.1\tLN:1182\n@SQ\tSN:APMT01235960.1\tLN:1182\n@SQ\tSN:APMT01235961.1\tLN:1182\n@SQ\tSN:APMT01235962.1\tLN:1182\n@SQ\tSN:APMT01235964.1\tLN:1182\n@SQ\tSN:APMT01235965.1\tLN:1182\n@SQ\tSN:APMT01235966.1\tLN:1182\n@SQ\tSN:APMT01235967.1\tLN:1182\n@SQ\tSN:APMT01235968.1\tLN:1182\n@SQ\tSN:APMT01235485.1\tLN:1181\n@SQ\tSN:APMT01235794.1\tLN:1181\n@SQ\tSN:APMT01235970.1\tLN:1181\n@SQ\tSN:APMT01235971.1\tLN:1181\n@SQ\tSN:APMT01235972.1\tLN:1181\n@SQ\tSN:APMT01235974.1\tLN:1181\n@SQ\tSN:APMT01235270.1\tLN:1180\n@SQ\tSN:APMT01235601.1\tLN:1180\n@SQ\tSN:APMT01235973.1\tLN:1180\n@SQ\tSN:APMT01235975.1\tLN:1180\n@SQ\tSN:APMT01235976.1\tLN:1180\n@SQ\tSN:APMT01235977.1\tLN:1180\n@SQ\tSN:APMT01235980.1\tLN:1180\n@SQ\tSN:APMT01235981.1\tLN:1180\n@SQ\tSN:APMT01235513.1\tLN:1179\n@SQ\tSN:APMT01235565.1\tLN:1179\n@SQ\tSN:APMT01235947.1\tLN:1179\n@SQ\tSN:APMT01235983.1\tLN:1179\n@SQ\tSN:APMT01235984.1\tLN:1179\n@SQ\tSN:APMT01235987.1\tLN:1179\n@SQ\tSN:APMT01235988.1\tLN:1179\n@SQ\tSN:APMT01235989.1\tLN:1179\n@SQ\tSN:APMT01235991.1\tLN:1179\n@SQ\tSN:APMT01235993.1\tLN:1179\n@SQ\tSN:APMT01235508.1\tLN:1178\n@SQ\tSN:APMT01235587.1\tLN:1178\n@SQ\tSN:APMT01235616.1\tLN:1178\n@SQ\tSN:APMT01235994.1\tLN:1178\n@SQ\tSN:APMT01235996.1\tLN:1178\n@SQ\tSN:APMT01235997.1\tLN:1178\n@SQ\tSN:APMT01235998.1\tLN:1178\n@SQ\tSN:APMT01235999.1\tLN:1178\n@SQ\tSN:APMT01236000.1\tLN:1178\n@SQ\tSN:APMT01236001.1\tLN:1178\n@SQ\tSN:APMT01236002.1\tLN:1178\n@SQ\tSN:APMT01235576.1\tLN:1177\n@SQ\tSN:APMT01235583.1\tLN:1177\n@SQ\tSN:APMT01235906.1\tLN:1177\n@SQ\tSN:APMT01235990.1\tLN:1177\n@SQ\tSN:APMT01236004.1\tLN:1177\n@SQ\tSN:APMT01236005.1\tLN:1177\n@SQ\tSN:APMT01236007.1\tLN:1177\n@SQ\tSN:APMT01236008.1\tLN:1177\n@SQ\tSN:APMT01236168.1\tLN:1177\n@SQ\tSN:APMT01235598.1\tLN:1176\n@SQ\tSN:APMT01235779.1\tLN:1176\n@SQ\tSN:APMT01235934.1\tLN:1176\n@SQ\tSN:APMT01236012.1\tLN:1176\n@SQ\tSN:APMT01236013.1\tLN:1176\n@SQ\tSN:APMT01236014.1\tLN:1176\n@SQ\tSN:APMT01236015.1\tLN:1176\n@SQ\tSN:APMT01236016.1\tLN:1176\n@SQ\tSN:APMT01236017.1\tLN:1176\n@SQ\tSN:APMT01236019.1\tLN:1176\n@SQ\tSN:APMT01236021.1\tLN:1176\n@SQ\tSN:APMT01236022.1\tLN:1176\n@SQ\tSN:APMT01235342.1\tLN:1175\n@SQ\tSN:APMT01235622.1\tLN:1175\n@SQ\tSN:APMT01235721.1\tLN:1175\n@SQ\tSN:APMT01236023.1\tLN:1175\n@SQ\tSN:APMT01236025.1\tLN:1175\n@SQ\tSN:APMT01236026.1\tLN:1175\n@SQ\tSN:APMT01235572.1\tLN:1174\n@SQ\tSN:APMT01235910.1\tLN:1174\n@SQ\tSN:APMT01236029.1\tLN:1174\n@SQ\tSN:APMT01236031.1\tLN:1174\n@SQ\tSN:APMT01236032.1\tLN:1174\n@SQ\tSN:APMT01236034.1\tLN:1174\n@SQ\tSN:APMT01236041.1\tLN:1174\n@SQ\tSN:APMT01235163.1\tLN:1173\n@SQ\tSN:APMT01235585.1\tLN:1173\n@SQ\tSN:APMT01235632.1\tLN:1173\n@SQ\tSN:APMT01235650.1\tLN:1173\n@SQ\tSN:APMT01236038.1\tLN:1173\n@SQ\tSN:APMT01235580.1\tLN:1172\n@SQ\tSN:APMT01236042.1\tLN:1172\n@SQ\tSN:APMT01236043.1\tLN:1172\n@SQ\tSN:APMT01236044.1\tLN:1172\n@SQ\tSN:APMT01236045.1\tLN:1172\n@SQ\tSN:APMT01236046.1\tLN:1172\n@SQ\tSN:APMT01235914.1\tLN:1171\n@SQ\tSN:APMT01236050.1\tLN:1171\n@SQ\tSN:APMT01235883.1\tLN:1170\n@SQ\tSN:APMT01236054.1\tLN:1170\n@SQ\tSN:APMT01236055.1\tLN:1170\n@SQ\tSN:APMT01236056.1\tLN:1170\n@SQ\tSN:APMT01236057.1\tLN:1170\n@SQ\tSN:APMT01236058.1\tLN:1170\n@SQ\tSN:APMT01236059.1\tLN:1170\n@SQ\tSN:APMT01236061.1\tLN:1170\n@SQ\tSN:APMT01236062.1\tLN:1170\n@SQ\tSN:APMT01236063.1\tLN:1170\n@SQ\tSN:APMT01236064.1\tLN:1170\n@SQ\tSN:APMT01235586.1\tLN:1169\n@SQ\tSN:APMT01235648.1\tLN:1169\n@SQ\tSN:APMT01236047.1\tLN:1169\n@SQ\tSN:APMT01236065.1\tLN:1169\n@SQ\tSN:APMT01236066.1\tLN:1169\n@SQ\tSN:APMT01236067.1\tLN:1169\n@SQ\tSN:APMT01236071.1\tLN:1169\n@SQ\tSN:APMT01235647.1\tLN:1168\n@SQ\tSN:APMT01235866.1\tLN:1168\n@SQ\tSN:APMT01236073.1\tLN:1168\n@SQ\tSN:APMT01236075.1\tLN:1168\n@SQ\tSN:APMT01236076.1\tLN:1168\n@SQ\tSN:APMT01236077.1\tLN:1168\n@SQ\tSN:APMT01236078.1\tLN:1168\n@SQ\tSN:APMT01236080.1\tLN:1168\n@SQ\tSN:APMT01236081.1\tLN:1168\n@SQ\tSN:APMT01236082.1\tLN:1168\n@SQ\tSN:APMT01236083.1\tLN:1168\n@SQ\tSN:APMT01235778.1\tLN:1167\n@SQ\tSN:APMT01235790.1\tLN:1167\n@SQ\tSN:APMT01236079.1\tLN:1167\n@SQ\tSN:APMT01236085.1\tLN:1167\n@SQ\tSN:APMT01236086.1\tLN:1167\n@SQ\tSN:APMT01236092.1\tLN:1167\n@SQ\tSN:APMT01236094.1\tLN:1167\n@SQ\tSN:APMT01236102.1\tLN:1167\n@SQ\tSN:APMT01235407.1\tLN:1166\n@SQ\tSN:APMT01235608.1\tLN:1166\n@SQ\tSN:APMT01235610.1\tLN:1166\n@SQ\tSN:APMT01235613.1\tLN:1166\n@SQ\tSN:APMT01235614.1\tLN:1166\n@SQ\tSN:APMT01235703.1\tLN:1166\n@SQ\tSN:APMT01236096.1\tLN:1166\n@SQ\tSN:APMT01236097.1\tLN:1166\n@SQ\tSN:APMT01236098.1\tLN:1166\n@SQ\tSN:APMT01236099.1\tLN:1166\n@SQ\tSN:APMT01236100.1\tLN:1166\n@SQ\tSN:APMT01236101.1\tLN:1166\n@SQ\tSN:KB713545.1\tLN:1165\n@SQ\tSN:APMT01235420.1\tLN:1165\n@SQ\tSN:APMT01235625.1\tLN:1165\n@SQ\tSN:APMT01235629.1\tLN:1165\n@SQ\tSN:APMT01235761.1\tLN:1165\n@SQ\tSN:APMT01236090.1\tLN:1165\n@SQ\tSN:APMT01236103.1\tLN:1165\n@SQ\tSN:APMT01236105.1\tLN:1165\n@SQ\tSN:APMT01236106.1\tLN:1165\n@SQ\tSN:APMT01236108.1\tLN:1165\n@SQ\tSN:APMT01236109.1\tLN:1165\n@SQ\tSN:APMT01236110.1\tLN:1165\n@SQ\tSN:APMT01235603.1\tLN:1164\n@SQ\tSN:APMT01235889.1\tLN:1164\n@SQ\tSN:APMT01236113.1\tLN:1164\n@SQ\tSN:APMT01236114.1\tLN:1164\n@SQ\tSN:APMT01236115.1\tLN:1164\n@SQ\tSN:APMT01236117.1\tLN:1164\n@SQ\tSN:APMT01236118.1\tLN:1164\n@SQ\tSN:APMT01236119.1\tLN:1164\n@SQ\tSN:APMT01235673.1\tLN:1163\n@SQ\tSN:APMT01235724.1\tLN:1163\n@SQ\tSN:APMT01235793.1\tLN:1163\n@SQ\tSN:APMT01236120.1\tLN:1163\n@SQ\tSN:APMT01236121.1\tLN:1163\n@SQ\tSN:APMT01236122.1\tLN:1163\n@SQ\tSN:APMT01236124.1\tLN:1163\n@SQ\tSN:APMT01236126.1\tLN:1163\n@SQ\tSN:APMT01236127.1\tLN:1163\n@SQ\tSN:APMT01236128.1\tLN:1163\n@SQ\tSN:APMT01235651.1\tLN:1162\n@SQ\tSN:APMT01235747.1\tLN:1162\n@SQ\tSN:APMT01236116.1\tLN:1162\n@SQ\tSN:APMT01236129.1\tLN:1162\n@SQ\tSN:APMT01236130.1\tLN:1162\n@SQ\tSN:APMT01236133.1\tLN:1162\n@SQ\tSN:APMT01236134.1\tLN:1162\n@SQ\tSN:APMT01236135.1\tLN:1162\n@SQ\tSN:APMT01236138.1\tLN:1162\n@SQ\tSN:APMT01235298.1\tLN:1161\n@SQ\tSN:APMT01235819.1\tLN:1161\n@SQ\tSN:APMT01235912.1\tLN:1161\n@SQ\tSN:APMT01235969.1\tLN:1161\n@SQ\tSN:APMT01236139.1\tLN:1161\n@SQ\tSN:APMT01236145.1\tLN:1161\n@SQ\tSN:APMT01236146.1\tLN:1161\n@SQ\tSN:APMT01236148.1\tLN:1161\n@SQ\tSN:APMT01235429.1\tLN:1160\n@SQ\tSN:APMT01235663.1\tLN:1160\n@SQ\tSN:APMT01235668.1\tLN:1160\n@SQ\tSN:APMT01236150.1\tLN:1160\n@SQ\tSN:APMT01236151.1\tLN:1160\n@SQ\tSN:APMT01236153.1\tLN:1160\n@SQ\tSN:APMT01236154.1\tLN:1160\n@SQ\tSN:APMT01236155.1\tLN:1160\n@SQ\tSN:APMT01236171.1\tLN:1160\n@SQ\tSN:APMT01235398.1\tLN:1159\n@SQ\tSN:APMT01235672.1\tLN:1159\n@SQ\tSN:APMT01235812.1\tLN:1159\n@SQ\tSN:APMT01235836.1\tLN:1159\n@SQ\tSN:APMT01236142.1\tLN:1159\n@SQ\tSN:APMT01236158.1\tLN:1159\n@SQ\tSN:APMT01236162.1\tLN:1159\n@SQ\tSN:APMT01236164.1\tLN:1159\n@SQ\tSN:APMT01236165.1\tLN:1159\n@SQ\tSN:APMT01236166.1\tLN:1159\n@SQ\tSN:APMT01236169.1\tLN:1159\n@SQ\tSN:APMT01235246.1\tLN:1158\n@SQ\tSN:APMT01235881.1\tLN:1158\n@SQ\tSN:APMT01236037.1\tLN:1158\n@SQ\tSN:APMT01236170.1\tLN:1158\n@SQ\tSN:APMT01236172.1\tLN:1158\n@SQ\tSN:APMT01236173.1\tLN:1158\n@SQ\tSN:APMT01236174.1\tLN:1158\n@SQ\tSN:APMT01236175.1\tLN:1158\n@SQ\tSN:APMT01236176.1\tLN:1158\n@SQ\tSN:APMT01236177.1\tLN:1158\n@SQ\tSN:APMT01236179.1\tLN:1158\n@SQ\tSN:APMT01235548.1\tLN:1157\n@SQ\tSN:APMT01236180.1\tLN:1157\n@SQ\tSN:APMT01236181.1\tLN:1157\n@SQ\tSN:APMT01236183.1\tLN:1157\n@SQ\tSN:APMT01236184.1\tLN:1157\n@SQ\tSN:APMT01236185.1\tLN:1157\n@SQ\tSN:APMT01235324.1\tLN:1156\n@SQ\tSN:APMT01235716.1\tLN:1156\n@SQ\tSN:APMT01235963.1\tLN:1156\n@SQ\tSN:APMT01236186.1\tLN:1156\n@SQ\tSN:APMT01236188.1\tLN:1156\n@SQ\tSN:APMT01236189.1\tLN:1156\n@SQ\tSN:APMT01236190.1\tLN:1156\n@SQ\tSN:APMT01235695.1\tLN:1155\n@SQ\tSN:APMT01235705.1\tLN:1155\n@SQ\tSN:APMT01236192.1\tLN:1155\n@SQ\tSN:APMT01236193.1\tLN:1155\n@SQ\tSN:APMT01236196.1\tLN:1155\n@SQ\tSN:APMT01235900.1\tLN:1154\n@SQ\tSN:APMT01236191.1\tLN:1154\n@SQ\tSN:APMT01236198.1\tLN:1154\n@SQ\tSN:APMT01236199.1\tLN:1154\n@SQ\tSN:APMT01236200.1\tLN:1154\n@SQ\tSN:APMT01236201.1\tLN:1154\n@SQ\tSN:APMT01235327.1\tLN:1153\n@SQ\tSN:APMT01235882.1\tLN:1153\n@SQ\tSN:APMT01236204.1\tLN:1153\n@SQ\tSN:APMT01236205.1\tLN:1153\n@SQ\tSN:APMT01235359.1\tLN:1152\n@SQ\tSN:APMT01235380.1\tLN:1152\n@SQ\tSN:APMT01235865.1\tLN:1152\n@SQ\tSN:APMT01235890.1\tLN:1152\n@SQ\tSN:APMT01235982.1\tLN:1152\n@SQ\tSN:APMT01236048.1\tLN:1152\n@SQ\tSN:APMT01236209.1\tLN:1152\n@SQ\tSN:APMT01236211.1\tLN:1152\n@SQ\tSN:APMT01236213.1\tLN:1152\n@SQ\tSN:APMT01236214.1\tLN:1152\n@SQ\tSN:APMT01236217.1\tLN:1152\n@SQ\tSN:APMT01235728.1\tLN:1151\n@SQ\tSN:APMT01236219.1\tLN:1151\n@SQ\tSN:APMT01236222.1\tLN:1151\n@SQ\tSN:APMT01236225.1\tLN:1151\n@SQ\tSN:APMT01236226.1\tLN:1151\n@SQ\tSN:APMT01236228.1\tLN:1151\n@SQ\tSN:APMT01235784.1\tLN:1150\n@SQ\tSN:APMT01235986.1\tLN:1150\n@SQ\tSN:APMT01236216.1\tLN:1150\n@SQ\tSN:APMT01236229.1\tLN:1150\n@SQ\tSN:APMT01236232.1\tLN:1150\n@SQ\tSN:APMT01236233.1\tLN:1150\n@SQ\tSN:APMT01236234.1\tLN:1150\n@SQ\tSN:APMT01236237.1\tLN:1150\n@SQ\tSN:APMT01235759.1\tLN:1149\n@SQ\tSN:APMT01235798.1\tLN:1149\n@SQ\tSN:APMT01236147.1\tLN:1149\n@SQ\tSN:APMT01236161.1\tLN:1149\n@SQ\tSN:APMT01236238.1\tLN:1149\n@SQ\tSN:APMT01236239.1\tLN:1149\n@SQ\tSN:APMT01236241.1\tLN:1149\n@SQ\tSN:APMT01236242.1\tLN:1149\n@SQ\tSN:APMT01236245.1\tLN:1149\n@SQ\tSN:APMT01236246.1\tLN:1149\n@SQ\tSN:APMT01235633.1\tLN:1148\n@SQ\tSN:APMT01235756.1\tLN:1148\n@SQ\tSN:APMT01236036.1\tLN:1148\n@SQ\tSN:APMT01236123.1\tLN:1148\n@SQ\tSN:APMT01236240.1\tLN:1148\n@SQ\tSN:APMT01236249.1\tLN:1148\n@SQ\tSN:APMT01236250.1\tLN:1148\n@SQ\tSN:APMT01236251.1\tLN:1148\n@SQ\tSN:APMT01236252.1\tLN:1148\n@SQ\tSN:APMT01235536.1\tLN:1147\n@SQ\tSN:APMT01235811.1\tLN:1147\n@SQ\tSN:APMT01236254.1\tLN:1147\n@SQ\tSN:APMT01236255.1\tLN:1147\n@SQ\tSN:APMT01236256.1\tLN:1147\n@SQ\tSN:APMT01236260.1\tLN:1147\n@SQ\tSN:APMT01236261.1\tLN:1147\n@SQ\tSN:APMT01236264.1\tLN:1147\n@SQ\tSN:APMT01236265.1\tLN:1147\n@SQ\tSN:APMT01236266.1\tLN:1147\n@SQ\tSN:APMT01236267.1\tLN:1147\n@SQ\tSN:APMT01236268.1\tLN:1147\n@SQ\tSN:APMT01236269.1\tLN:1147\n@SQ\tSN:APMT01235849.1\tLN:1146\n@SQ\tSN:APMT01235853.1\tLN:1146\n@SQ\tSN:APMT01236248.1\tLN:1146\n@SQ\tSN:APMT01236259.1\tLN:1146\n@SQ\tSN:APMT01236271.1\tLN:1146\n@SQ\tSN:APMT01236272.1\tLN:1146\n@SQ\tSN:APMT01236274.1\tLN:1146\n@SQ\tSN:APMT01236275.1\tLN:1146\n@SQ\tSN:APMT01236279.1\tLN:1146\n@SQ\tSN:APMT01236280.1\tLN:1145\n@SQ\tSN:APMT01236281.1\tLN:1145\n@SQ\tSN:APMT01236282.1\tLN:1145\n@SQ\tSN:APMT01236283.1\tLN:1145\n@SQ\tSN:APMT01236284.1\tLN:1145\n@SQ\tSN:APMT01236285.1\tLN:1145\n@SQ\tSN:APMT01235639.1\tLN:1144\n@SQ\tSN:APMT01235780.1\tLN:1144\n@SQ\tSN:APMT01235800.1\tLN:1144\n@SQ\tSN:APMT01235884.1\tLN:1144\n@SQ\tSN:APMT01236277.1\tLN:1144\n@SQ\tSN:APMT01236288.1\tLN:1144\n@SQ\tSN:APMT01236289.1\tLN:1144\n@SQ\tSN:APMT01236294.1\tLN:1144\n@SQ\tSN:APMT01235441.1\tLN:1143\n@SQ\tSN:APMT01235801.1\tLN:1143\n@SQ\tSN:APMT01235817.1\tLN:1143\n@SQ\tSN:APMT01235886.1\tLN:1143\n@SQ\tSN:APMT01236297.1\tLN:1143\n@SQ\tSN:APMT01236298.1\tLN:1143\n@SQ\tSN:APMT01236300.1\tLN:1143\n@SQ\tSN:APMT01236302.1\tLN:1143\n@SQ\tSN:APMT01236304.1\tLN:1143\n@SQ\tSN:APMT01236305.1\tLN:1143\n@SQ\tSN:APMT01236307.1\tLN:1143\n@SQ\tSN:APMT01236308.1\tLN:1143\n@SQ\tSN:APMT01235424.1\tLN:1142\n@SQ\tSN:APMT01235791.1\tLN:1142\n@SQ\tSN:APMT01236309.1\tLN:1142\n@SQ\tSN:APMT01236312.1\tLN:1142\n@SQ\tSN:APMT01236314.1\tLN:1142\n@SQ\tSN:APMT01235452.1\tLN:1141\n@SQ\tSN:APMT01235831.1\tLN:1141\n@SQ\tSN:APMT01235856.1\tLN:1141\n@SQ\tSN:APMT01236315.1\tLN:1141\n@SQ\tSN:APMT01236316.1\tLN:1141\n@SQ\tSN:APMT01236317.1\tLN:1141\n@SQ\tSN:APMT01236318.1\tLN:1141\n@SQ\tSN:APMT01236319.1\tLN:1141\n@SQ\tSN:APMT01236320.1\tLN:1141\n@SQ\tSN:APMT01236321.1\tLN:1141\n@SQ\tSN:APMT01236324.1\tLN:1141\n@SQ\tSN:APMT01235491.1\tLN:1140\n@SQ\tSN:APMT01235589.1\tLN:1140\n@SQ\tSN:APMT01235837.1\tLN:1140\n@SQ\tSN:APMT01235869.1\tLN:1140\n@SQ\tSN:APMT01235908.1\tLN:1140\n@SQ\tSN:APMT01236187.1\tLN:1140\n@SQ\tSN:APMT01236327.1\tLN:1140\n@SQ\tSN:APMT01236328.1\tLN:1140\n@SQ\tSN:APMT01236331.1\tLN:1140\n@SQ\tSN:APMT01235483.1\tLN:1139\n@SQ\tSN:APMT01235835.1\tLN:1139\n@SQ\tSN:APMT01235892.1\tLN:1139\n@SQ\tSN:APMT01236310.1\tLN:1139\n@SQ\tSN:APMT01236333.1\tLN:1139\n@SQ\tSN:APMT01236334.1\tLN:1139\n@SQ\tSN:APMT01235577.1\tLN:1138\n@SQ\tSN:APMT01236020.1\tLN:1138\n@SQ\tSN:APMT01236091.1\tLN:1138\n@SQ\tSN:APMT01236210.1\tLN:1138\n@SQ\tSN:APMT01236338.1\tLN:1138\n@SQ\tSN:APMT01236339.1\tLN:1138\n@SQ\tSN:APMT01236342.1\tLN:1138\n@SQ\tSN:APMT01236343.1\tLN:1138\n@SQ\tSN:APMT01235841.1\tLN:1137\n@SQ\tSN:APMT01235904.1\tLN:1137\n@SQ\tSN:APMT01236344.1\tLN:1137\n@SQ\tSN:APMT01236345.1\tLN:1137\n@SQ\tSN:APMT01236346.1\tLN:1137\n@SQ\tSN:APMT01236347.1\tLN:1137\n@SQ\tSN:APMT01236349.1\tLN:1137\n@SQ\tSN:APMT01236350.1\tLN:1137\n@SQ\tSN:APMT01236351.1\tLN:1137\n@SQ\tSN:APMT01236352.1\tLN:1137\n@SQ\tSN:APMT01236356.1\tLN:1137\n@SQ\tSN:APMT01236357.1\tLN:1137\n@SQ\tSN:APMT01235843.1\tLN:1136\n@SQ\tSN:APMT01235850.1\tLN:1136\n@SQ\tSN:APMT01236009.1\tLN:1136\n@SQ\tSN:APMT01236152.1\tLN:1136\n@SQ\tSN:APMT01236359.1\tLN:1136\n@SQ\tSN:APMT01236360.1\tLN:1136\n@SQ\tSN:APMT01236363.1\tLN:1136\n@SQ\tSN:APMT01236366.1\tLN:1136\n@SQ\tSN:APMT01236367.1\tLN:1136\n@SQ\tSN:APMT01236369.1\tLN:1136\n@SQ\tSN:APMT01235456.1\tLN:1135\n@SQ\tSN:APMT01236024.1\tLN:1135\n@SQ\tSN:APMT01236273.1\tLN:1135\n@SQ\tSN:APMT01236322.1\tLN:1135\n@SQ\tSN:APMT01236362.1\tLN:1135\n@SQ\tSN:APMT01236371.1\tLN:1135\n@SQ\tSN:APMT01236372.1\tLN:1135\n@SQ\tSN:APMT01236374.1\tLN:1135\n@SQ\tSN:APMT01236375.1\tLN:1135\n@SQ\tSN:APMT01236376.1\tLN:1135\n@SQ\tSN:APMT01236379.1\tLN:1135\n@SQ\tSN:APMT01235449.1\tLN:1134\n@SQ\tSN:APMT01236377.1\tLN:1134\n@SQ\tSN:APMT01236382.1\tLN:1134\n@SQ\tSN:APMT01236384.1\tLN:1134\n@SQ\tSN:APMT01236385.1\tLN:1134\n@SQ\tSN:APMT01236386.1\tLN:1134\n@SQ\tSN:APMT01236390.1\tLN:1134\n@SQ\tSN:APMT01236392.1\tLN:1134\n@SQ\tSN:APMT01236394.1\tLN:1134\n@SQ\tSN:APMT01236396.1\tLN:1134\n@SQ\tSN:APMT01236353.1\tLN:1133\n@SQ\tSN:APMT01236378.1\tLN:1133\n@SQ\tSN:APMT01236399.1\tLN:1133\n@SQ\tSN:APMT01236401.1\tLN:1133\n@SQ\tSN:APMT01236404.1\tLN:1133\n@SQ\tSN:APMT01236405.1\tLN:1133\n@SQ\tSN:APMT01235567.1\tLN:1132\n@SQ\tSN:APMT01235888.1\tLN:1132\n@SQ\tSN:APMT01236107.1\tLN:1132\n@SQ\tSN:APMT01236408.1\tLN:1132\n@SQ\tSN:APMT01236409.1\tLN:1132\n@SQ\tSN:APMT01236412.1\tLN:1132\n@SQ\tSN:APMT01236413.1\tLN:1132\n@SQ\tSN:APMT01236415.1\tLN:1132\n@SQ\tSN:APMT01236416.1\tLN:1132\n@SQ\tSN:APMT01235774.1\tLN:1131\n@SQ\tSN:APMT01236069.1\tLN:1131\n@SQ\tSN:APMT01236419.1\tLN:1131\n@SQ\tSN:APMT01236421.1\tLN:1131\n@SQ\tSN:APMT01236422.1\tLN:1131\n@SQ\tSN:APMT01235813.1\tLN:1130\n@SQ\tSN:APMT01235948.1\tLN:1130\n@SQ\tSN:APMT01236003.1\tLN:1130\n@SQ\tSN:APMT01236340.1\tLN:1130\n@SQ\tSN:APMT01236398.1\tLN:1130\n@SQ\tSN:APMT01236423.1\tLN:1130\n@SQ\tSN:APMT01236424.1\tLN:1130\n@SQ\tSN:APMT01236426.1\tLN:1130\n@SQ\tSN:APMT01236427.1\tLN:1130\n@SQ\tSN:APMT01236428.1\tLN:1130\n@SQ\tSN:APMT01236429.1\tLN:1130\n@SQ\tSN:APMT01236431.1\tLN:1130\n@SQ\tSN:APMT01236432.1\tLN:1130\n@SQ\tSN:APMT01236072.1\tLN:1129\n@SQ\tSN:APMT01236112.1\tLN:1129\n@SQ\tSN:APMT01236336.1\tLN:1129\n@SQ\tSN:APMT01236430.1\tLN:1129\n@SQ\tSN:APMT01236433.1\tLN:1129\n@SQ\tSN:APMT01236434.1\tLN:1129\n@SQ\tSN:APMT01236435.1\tLN:1129\n@SQ\tSN:APMT01236438.1\tLN:1129\n@SQ\tSN:APMT01236439.1\tLN:1129\n@SQ\tSN:APMT01236441.1\tLN:1129\n@SQ\tSN:APMT01235514.1\tLN:1128\n@SQ\tSN:APMT01235913.1\tLN:1128\n@SQ\tSN:APMT01236335.1\tLN:1128\n@SQ\tSN:APMT01236445.1\tLN:1128\n@SQ\tSN:APMT01236446.1\tLN:1128\n@SQ\tSN:APMT01236447.1\tLN:1128\n@SQ\tSN:APMT01236448.1\tLN:1128\n@SQ\tSN:APMT01236449.1\tLN:1128\n@SQ\tSN:APMT01236450.1\tLN:1128\n@SQ\tSN:APMT01236452.1\tLN:1127\n@SQ\tSN:APMT01236456.1\tLN:1127\n@SQ\tSN:APMT01236458.1\tLN:1127\n@SQ\tSN:APMT01235894.1\tLN:1126\n@SQ\tSN:APMT01235992.1\tLN:1126\n@SQ\tSN:APMT01236397.1\tLN:1126\n@SQ\tSN:APMT01236411.1\tLN:1126\n@SQ\tSN:APMT01236459.1\tLN:1126\n@SQ\tSN:APMT01236462.1\tLN:1126\n@SQ\tSN:APMT01236463.1\tLN:1126\n@SQ\tSN:APMT01236465.1\tLN:1126\n@SQ\tSN:APMT01236467.1\tLN:1126\n@SQ\tSN:APMT01236468.1\tLN:1126\n@SQ\tSN:APMT01236011.1\tLN:1125\n@SQ\tSN:APMT01236093.1\tLN:1125\n@SQ\tSN:APMT01236470.1\tLN:1125\n@SQ\tSN:APMT01236471.1\tLN:1125\n@SQ\tSN:APMT01236472.1\tLN:1125\n@SQ\tSN:APMT01236473.1\tLN:1125\n@SQ\tSN:APMT01236474.1\tLN:1125\n@SQ\tSN:APMT01236475.1\tLN:1125\n@SQ\tSN:APMT01236476.1\tLN:1125\n@SQ\tSN:APMT01236478.1\tLN:1125\n@SQ\tSN:APMT01236480.1\tLN:1125\n@SQ\tSN:APMT01236027.1\tLN:1124\n@SQ\tSN:APMT01236203.1\tLN:1124\n@SQ\tSN:APMT01236407.1\tLN:1124\n@SQ\tSN:APMT01236482.1\tLN:1124\n@SQ\tSN:APMT01236487.1\tLN:1124\n@SQ\tSN:APMT01236488.1\tLN:1124\n@SQ\tSN:APMT01236089.1\tLN:1123\n@SQ\tSN:APMT01236131.1\tLN:1123\n@SQ\tSN:APMT01236163.1\tLN:1123\n@SQ\tSN:APMT01236442.1\tLN:1123\n@SQ\tSN:APMT01236491.1\tLN:1123\n@SQ\tSN:APMT01236492.1\tLN:1123\n@SQ\tSN:APMT01236493.1\tLN:1123\n@SQ\tSN:APMT01236496.1\tLN:1123\n@SQ\tSN:APMT01236499.1\tLN:1123\n@SQ\tSN:APMT01236040.1\tLN:1122\n@SQ\tSN:APMT01236053.1\tLN:1122\n@SQ\tSN:APMT01236503.1\tLN:1122\n@SQ\tSN:APMT01236504.1\tLN:1122\n@SQ\tSN:APMT01236506.1\tLN:1122\n@SQ\tSN:APMT01236507.1\tLN:1122\n@SQ\tSN:APMT01235518.1\tLN:1121\n@SQ\tSN:APMT01235722.1\tLN:1121\n@SQ\tSN:APMT01236230.1\tLN:1121\n@SQ\tSN:APMT01236498.1\tLN:1121\n@SQ\tSN:APMT01236510.1\tLN:1121\n@SQ\tSN:APMT01236512.1\tLN:1121\n@SQ\tSN:APMT01236514.1\tLN:1121\n@SQ\tSN:APMT01236515.1\tLN:1121\n@SQ\tSN:APMT01236516.1\tLN:1121\n@SQ\tSN:APMT01236519.1\tLN:1121\n@SQ\tSN:APMT01236522.1\tLN:1121\n@SQ\tSN:APMT01236451.1\tLN:1120\n@SQ\tSN:APMT01236525.1\tLN:1120\n@SQ\tSN:APMT01236526.1\tLN:1120\n@SQ\tSN:APMT01236527.1\tLN:1120\n@SQ\tSN:APMT01236528.1\tLN:1120\n@SQ\tSN:APMT01236529.1\tLN:1120\n@SQ\tSN:APMT01236530.1\tLN:1120\n@SQ\tSN:APMT01236532.1\tLN:1120\n@SQ\tSN:APMT01236534.1\tLN:1120\n@SQ\tSN:APMT01236535.1\tLN:1120\n@SQ\tSN:APMT01236536.1\tLN:1120\n@SQ\tSN:APMT01236537.1\tLN:1120\n@SQ\tSN:APMT01236662.1\tLN:1120\n@SQ\tSN:APMT01236159.1\tLN:1119\n@SQ\tSN:APMT01236517.1\tLN:1119\n@SQ\tSN:APMT01236539.1\tLN:1119\n@SQ\tSN:APMT01236540.1\tLN:1119\n@SQ\tSN:APMT01236541.1\tLN:1119\n@SQ\tSN:APMT01236542.1\tLN:1119\n@SQ\tSN:APMT01236543.1\tLN:1119\n@SQ\tSN:APMT01236544.1\tLN:1119\n@SQ\tSN:APMT01236545.1\tLN:1119\n@SQ\tSN:APMT01236546.1\tLN:1119\n@SQ\tSN:APMT01236006.1\tLN:1118\n@SQ\tSN:APMT01236018.1\tLN:1118\n@SQ\tSN:APMT01236060.1\tLN:1118\n@SQ\tSN:APMT01236143.1\tLN:1118\n@SQ\tSN:APMT01236326.1\tLN:1118\n@SQ\tSN:APMT01236355.1\tLN:1118\n@SQ\tSN:APMT01236550.1\tLN:1118\n@SQ\tSN:APMT01236551.1\tLN:1118\n@SQ\tSN:APMT01236552.1\tLN:1118\n@SQ\tSN:APMT01236556.1\tLN:1118\n@SQ\tSN:APMT01235618.1\tLN:1117\n@SQ\tSN:APMT01236132.1\tLN:1117\n@SQ\tSN:APMT01236262.1\tLN:1117\n@SQ\tSN:APMT01236547.1\tLN:1117\n@SQ\tSN:APMT01236548.1\tLN:1117\n@SQ\tSN:APMT01236558.1\tLN:1117\n@SQ\tSN:APMT01236560.1\tLN:1117\n@SQ\tSN:APMT01236561.1\tLN:1117\n@SQ\tSN:APMT01236563.1\tLN:1117\n@SQ\tSN:APMT01236565.1\tLN:1117\n@SQ\tSN:APMT01236566.1\tLN:1117\n@SQ\tSN:APMT01236568.1\tLN:1117\n@SQ\tSN:APMT01236569.1\tLN:1117\n@SQ\tSN:APMT01236571.1\tLN:1117\n@SQ\tSN:APMT01236576.1\tLN:1117\n@SQ\tSN:APMT01235697.1\tLN:1116\n@SQ\tSN:APMT01235935.1\tLN:1116\n@SQ\tSN:APMT01236028.1\tLN:1116\n@SQ\tSN:APMT01236039.1\tLN:1116\n@SQ\tSN:APMT01236553.1\tLN:1116\n@SQ\tSN:APMT01236570.1\tLN:1116\n@SQ\tSN:APMT01236572.1\tLN:1116\n@SQ\tSN:APMT01236573.1\tLN:1116\n@SQ\tSN:APMT01236574.1\tLN:1116\n@SQ\tSN:APMT01236577.1\tLN:1116\n@SQ\tSN:APMT01236578.1\tLN:1116\n@SQ\tSN:APMT01236579.1\tLN:1116\n@SQ\tSN:APMT01236070.1\tLN:1115\n@SQ\tSN:APMT01236583.1\tLN:1115\n@SQ\tSN:APMT01236585.1\tLN:1115\n@SQ\tSN:APMT01236586.1\tLN:1115\n@SQ\tSN:APMT01236587.1\tLN:1115\n@SQ\tSN:APMT01235805.1\tLN:1114\n@SQ\tSN:APMT01236035.1\tLN:1114\n@SQ\tSN:APMT01236051.1\tLN:1114\n@SQ\tSN:APMT01236521.1\tLN:1114\n@SQ\tSN:APMT01236582.1\tLN:1114\n@SQ\tSN:APMT01236589.1\tLN:1114\n@SQ\tSN:APMT01236594.1\tLN:1114\n@SQ\tSN:APMT01236595.1\tLN:1114\n@SQ\tSN:APMT01236597.1\tLN:1114\n@SQ\tSN:APMT01236598.1\tLN:1114\n@SQ\tSN:APMT01236599.1\tLN:1114\n@SQ\tSN:APMT01236601.1\tLN:1114\n@SQ\tSN:APMT01236602.1\tLN:1114\n@SQ\tSN:APMT01236604.1\tLN:1114\n@SQ\tSN:APMT01236033.1\tLN:1113\n@SQ\tSN:APMT01236531.1\tLN:1113\n@SQ\tSN:APMT01236605.1\tLN:1113\n@SQ\tSN:APMT01236606.1\tLN:1113\n@SQ\tSN:APMT01236608.1\tLN:1113\n@SQ\tSN:APMT01236610.1\tLN:1113\n@SQ\tSN:APMT01236611.1\tLN:1113\n@SQ\tSN:APMT01236612.1\tLN:1113\n@SQ\tSN:APMT01236615.1\tLN:1113\n@SQ\tSN:APMT01235826.1\tLN:1112\n@SQ\tSN:APMT01236068.1\tLN:1112\n@SQ\tSN:APMT01236087.1\tLN:1112\n@SQ\tSN:APMT01236555.1\tLN:1112\n@SQ\tSN:APMT01236619.1\tLN:1112\n@SQ\tSN:APMT01236620.1\tLN:1112\n@SQ\tSN:APMT01236624.1\tLN:1112\n@SQ\tSN:APMT01236625.1\tLN:1112\n@SQ\tSN:APMT01236626.1\tLN:1112\n@SQ\tSN:APMT01236627.1\tLN:1112\n@SQ\tSN:APMT01236628.1\tLN:1112\n@SQ\tSN:APMT01235978.1\tLN:1111\n@SQ\tSN:APMT01236052.1\tLN:1111\n@SQ\tSN:APMT01236575.1\tLN:1111\n@SQ\tSN:APMT01236631.1\tLN:1111\n@SQ\tSN:APMT01236633.1\tLN:1111\n@SQ\tSN:APMT01236634.1\tLN:1111\n@SQ\tSN:APMT01236160.1\tLN:1110\n@SQ\tSN:APMT01236287.1\tLN:1110\n@SQ\tSN:APMT01236301.1\tLN:1110\n@SQ\tSN:APMT01236348.1\tLN:1110\n@SQ\tSN:APMT01236581.1\tLN:1110\n@SQ\tSN:APMT01236629.1\tLN:1110\n@SQ\tSN:APMT01236638.1\tLN:1110\n@SQ\tSN:APMT01236640.1\tLN:1110\n@SQ\tSN:APMT01236642.1\tLN:1110\n@SQ\tSN:APMT01236644.1\tLN:1110\n@SQ\tSN:APMT01236645.1\tLN:1110\n@SQ\tSN:APMT01236646.1\tLN:1110\n@SQ\tSN:APMT01236647.1\tLN:1110\n@SQ\tSN:APMT01236167.1\tLN:1109\n@SQ\tSN:APMT01236614.1\tLN:1109\n@SQ\tSN:APMT01236630.1\tLN:1109\n@SQ\tSN:APMT01236650.1\tLN:1109\n@SQ\tSN:APMT01236651.1\tLN:1109\n@SQ\tSN:APMT01236652.1\tLN:1109\n@SQ\tSN:APMT01236653.1\tLN:1109\n@SQ\tSN:APMT01236654.1\tLN:1109\n@SQ\tSN:APMT01236656.1\tLN:1109\n@SQ\tSN:APMT01236095.1\tLN:1108\n@SQ\tSN:APMT01236182.1\tLN:1108\n@SQ\tSN:APMT01236600.1\tLN:1108\n@SQ\tSN:APMT01236636.1\tLN:1108\n@SQ\tSN:APMT01236657.1\tLN:1108\n@SQ\tSN:APMT01236659.1\tLN:1108\n@SQ\tSN:APMT01236661.1\tLN:1108\n@SQ\tSN:APMT01236663.1\tLN:1108\n@SQ\tSN:APMT01236664.1\tLN:1108\n@SQ\tSN:APMT01236665.1\tLN:1108\n@SQ\tSN:APMT01236666.1\tLN:1108\n@SQ\tSN:APMT01236667.1\tLN:1108\n@SQ\tSN:APMT01236668.1\tLN:1108\n@SQ\tSN:APMT01236669.1\tLN:1108\n@SQ\tSN:APMT01236671.1\tLN:1108\n@SQ\tSN:APMT01236672.1\tLN:1108\n@SQ\tSN:APMT01236673.1\tLN:1108\n@SQ\tSN:APMT01236674.1\tLN:1108\n@SQ\tSN:APMT01236684.1\tLN:1108\n@SQ\tSN:APMT01237355.1\tLN:1108\n@SQ\tSN:APMT01236084.1\tLN:1107\n@SQ\tSN:APMT01236616.1\tLN:1107\n@SQ\tSN:APMT01236675.1\tLN:1107\n@SQ\tSN:APMT01236676.1\tLN:1107\n@SQ\tSN:APMT01236680.1\tLN:1107\n@SQ\tSN:APMT01236681.1\tLN:1107\n@SQ\tSN:APMT01236682.1\tLN:1107\n@SQ\tSN:APMT01236683.1\tLN:1107\n@SQ\tSN:APMT01236685.1\tLN:1107\n@SQ\tSN:APMT01236686.1\tLN:1107\n@SQ\tSN:APMT01236688.1\tLN:1107\n@SQ\tSN:APMT01236690.1\tLN:1107\n@SQ\tSN:APMT01236804.1\tLN:1107\n@SQ\tSN:APMT01235917.1\tLN:1106\n@SQ\tSN:APMT01236088.1\tLN:1106\n@SQ\tSN:APMT01236218.1\tLN:1106\n@SQ\tSN:APMT01236505.1\tLN:1106\n@SQ\tSN:APMT01236691.1\tLN:1106\n@SQ\tSN:APMT01236693.1\tLN:1106\n@SQ\tSN:APMT01236696.1\tLN:1106\n@SQ\tSN:APMT01236697.1\tLN:1106\n@SQ\tSN:APMT01236290.1\tLN:1105\n@SQ\tSN:APMT01236306.1\tLN:1105\n@SQ\tSN:APMT01236388.1\tLN:1105\n@SQ\tSN:APMT01236698.1\tLN:1105\n@SQ\tSN:APMT01236699.1\tLN:1105\n@SQ\tSN:APMT01236701.1\tLN:1105\n@SQ\tSN:APMT01236704.1\tLN:1105\n@SQ\tSN:APMT01236705.1\tLN:1105\n@SQ\tSN:APMT01236706.1\tLN:1105\n@SQ\tSN:APMT01236707.1\tLN:1105\n@SQ\tSN:APMT01236708.1\tLN:1105\n@SQ\tSN:APMT01235829.1\tLN:1104\n@SQ\tSN:APMT01235959.1\tLN:1104\n@SQ\tSN:APMT01236104.1\tLN:1104\n@SQ\tSN:APMT01236111.1\tLN:1104\n@SQ\tSN:APMT01236144.1\tLN:1104\n@SQ\tSN:APMT01236221.1\tLN:1104\n@SQ\tSN:APMT01236244.1\tLN:1104\n@SQ\tSN:APMT01236658.1\tLN:1104\n@SQ\tSN:APMT01236710.1\tLN:1104\n@SQ\tSN:APMT01236711.1\tLN:1104\n@SQ\tSN:APMT01236712.1\tLN:1104\n@SQ\tSN:APMT01236713.1\tLN:1104\n@SQ\tSN:APMT01236715.1\tLN:1104\n@SQ\tSN:APMT01236716.1\tLN:1104\n@SQ\tSN:APMT01236717.1\tLN:1104\n@SQ\tSN:APMT01236718.1\tLN:1104\n@SQ\tSN:APMT01236719.1\tLN:1104\n@SQ\tSN:APMT01236136.1\tLN:1103\n@SQ\tSN:APMT01236721.1\tLN:1103\n@SQ\tSN:APMT01236722.1\tLN:1103\n@SQ\tSN:APMT01236724.1\tLN:1103\n@SQ\tSN:APMT01236725.1\tLN:1103\n@SQ\tSN:APMT01236727.1\tLN:1103\n@SQ\tSN:APMT01236194.1\tLN:1102\n@SQ\tSN:APMT01236263.1\tLN:1102\n@SQ\tSN:APMT01236389.1\tLN:1102\n@SQ\tSN:APMT01236609.1\tLN:1102\n@SQ\tSN:APMT01236729.1\tLN:1102\n@SQ\tSN:APMT01236732.1\tLN:1102\n@SQ\tSN:APMT01236734.1\tLN:1102\n@SQ\tSN:APMT01236735.1\tLN:1102\n@SQ\tSN:APMT01236736.1\tLN:1102\n@SQ\tSN:APMT01236738.1\tLN:1102\n@SQ\tSN:APMT01236157.1\tLN:1101\n@SQ\tSN:APMT01236215.1\tLN:1101\n@SQ\tSN:APMT01236444.1\tLN:1101\n@SQ\tSN:APMT01236730.1\tLN:1101\n@SQ\tSN:APMT01236739.1\tLN:1101\n@SQ\tSN:APMT01236741.1\tLN:1101\n@SQ\tSN:APMT01236742.1\tLN:1101\n@SQ\tSN:APMT01236743.1\tLN:1101\n@SQ\tSN:APMT01236746.1\tLN:1101\n@SQ\tSN:APMT01236748.1\tLN:1101\n@SQ\tSN:APMT01236749.1\tLN:1101\n@SQ\tSN:APMT01236621.1\tLN:1100\n@SQ\tSN:APMT01236750.1\tLN:1100\n@SQ\tSN:APMT01236752.1\tLN:1100\n@SQ\tSN:APMT01236753.1\tLN:1100\n@SQ\tSN:APMT01236754.1\tLN:1100\n@SQ\tSN:APMT01236755.1\tLN:1100\n@SQ\tSN:APMT01236756.1\tLN:1100\n@SQ\tSN:APMT01236757.1\tLN:1100\n@SQ\tSN:APMT01236758.1\tLN:1100\n@SQ\tSN:APMT01236759.1\tLN:1100\n@SQ\tSN:APMT01236762.1\tLN:1100\n@SQ\tSN:APMT01236763.1\tLN:1100\n@SQ\tSN:APMT01236764.1\tLN:1100\n@SQ\tSN:APMT01236765.1\tLN:1100\n@SQ\tSN:APMT01235782.1\tLN:1099\n@SQ\tSN:APMT01236149.1\tLN:1099\n@SQ\tSN:APMT01236206.1\tLN:1099\n@SQ\tSN:APMT01236766.1\tLN:1099\n@SQ\tSN:APMT01236767.1\tLN:1099\n@SQ\tSN:APMT01236768.1\tLN:1099\n@SQ\tSN:APMT01236769.1\tLN:1099\n@SQ\tSN:APMT01236770.1\tLN:1099\n@SQ\tSN:APMT01235738.1\tLN:1098\n@SQ\tSN:APMT01236178.1\tLN:1098\n@SQ\tSN:APMT01236380.1\tLN:1098\n@SQ\tSN:APMT01236772.1\tLN:1098\n@SQ\tSN:APMT01236773.1\tLN:1098\n@SQ\tSN:APMT01236774.1\tLN:1098\n@SQ\tSN:APMT01236776.1\tLN:1098\n@SQ\tSN:APMT01236247.1\tLN:1097\n@SQ\tSN:APMT01236461.1\tLN:1097\n@SQ\tSN:APMT01236781.1\tLN:1097\n@SQ\tSN:APMT01236782.1\tLN:1097\n@SQ\tSN:APMT01236784.1\tLN:1097\n@SQ\tSN:APMT01236785.1\tLN:1097\n@SQ\tSN:APMT01236391.1\tLN:1096\n@SQ\tSN:APMT01236454.1\tLN:1096\n@SQ\tSN:APMT01236714.1\tLN:1096\n@SQ\tSN:APMT01236786.1\tLN:1096\n@SQ\tSN:APMT01236787.1\tLN:1096\n@SQ\tSN:APMT01236788.1\tLN:1096\n@SQ\tSN:APMT01236789.1\tLN:1096\n@SQ\tSN:APMT01236790.1\tLN:1096\n@SQ\tSN:APMT01236792.1\tLN:1096\n@SQ\tSN:APMT01236793.1\tLN:1096\n@SQ\tSN:APMT01236858.1\tLN:1096\n@SQ\tSN:APMT01235775.1\tLN:1095\n@SQ\tSN:APMT01236197.1\tLN:1095\n@SQ\tSN:APMT01236220.1\tLN:1095\n@SQ\tSN:APMT01236286.1\tLN:1095\n@SQ\tSN:APMT01236796.1\tLN:1095\n@SQ\tSN:APMT01236797.1\tLN:1095\n@SQ\tSN:APMT01236798.1\tLN:1095\n@SQ\tSN:APMT01236799.1\tLN:1095\n@SQ\tSN:APMT01236801.1\tLN:1095\n@SQ\tSN:APMT01236802.1\tLN:1095\n@SQ\tSN:APMT01236803.1\tLN:1095\n@SQ\tSN:APMT01236805.1\tLN:1095\n@SQ\tSN:APMT01235723.1\tLN:1094\n@SQ\tSN:APMT01235768.1\tLN:1094\n@SQ\tSN:APMT01236253.1\tLN:1094\n@SQ\tSN:APMT01236257.1\tLN:1094\n@SQ\tSN:APMT01236807.1\tLN:1094\n@SQ\tSN:APMT01236809.1\tLN:1094\n@SQ\tSN:APMT01236812.1\tLN:1094\n@SQ\tSN:APMT01236813.1\tLN:1094\n@SQ\tSN:APMT01236814.1\tLN:1094\n@SQ\tSN:APMT01236223.1\tLN:1093\n@SQ\tSN:APMT01236231.1\tLN:1093\n@SQ\tSN:APMT01236243.1\tLN:1093\n@SQ\tSN:APMT01236518.1\tLN:1093\n@SQ\tSN:APMT01236817.1\tLN:1093\n@SQ\tSN:APMT01236207.1\tLN:1092\n@SQ\tSN:APMT01236208.1\tLN:1092\n@SQ\tSN:APMT01236325.1\tLN:1092\n@SQ\tSN:APMT01236533.1\tLN:1092\n@SQ\tSN:APMT01236703.1\tLN:1092\n@SQ\tSN:APMT01236747.1\tLN:1092\n@SQ\tSN:APMT01236819.1\tLN:1092\n@SQ\tSN:APMT01236821.1\tLN:1092\n@SQ\tSN:APMT01236822.1\tLN:1092\n@SQ\tSN:APMT01236823.1\tLN:1092\n@SQ\tSN:APMT01236825.1\tLN:1092\n@SQ\tSN:APMT01236826.1\tLN:1092\n@SQ\tSN:APMT01236827.1\tLN:1092\n@SQ\tSN:APMT01236830.1\tLN:1092\n@SQ\tSN:APMT01236831.1\tLN:1092\n@SQ\tSN:APMT01236832.1\tLN:1092\n@SQ\tSN:APMT01236833.1\tLN:1092\n@SQ\tSN:APMT01235664.1\tLN:1091\n@SQ\tSN:APMT01236361.1\tLN:1091\n@SQ\tSN:APMT01236457.1\tLN:1091\n@SQ\tSN:APMT01236760.1\tLN:1091\n@SQ\tSN:APMT01236834.1\tLN:1091\n@SQ\tSN:APMT01236835.1\tLN:1091\n@SQ\tSN:APMT01236838.1\tLN:1091\n@SQ\tSN:APMT01236843.1\tLN:1091\n@SQ\tSN:APMT01236844.1\tLN:1091\n@SQ\tSN:APMT01236845.1\tLN:1091\n@SQ\tSN:APMT01236848.1\tLN:1091\n@SQ\tSN:APMT01236849.1\tLN:1091\n@SQ\tSN:APMT01236720.1\tLN:1090\n@SQ\tSN:APMT01236853.1\tLN:1090\n@SQ\tSN:APMT01236854.1\tLN:1090\n@SQ\tSN:APMT01236855.1\tLN:1090\n@SQ\tSN:APMT01236857.1\tLN:1090\n@SQ\tSN:APMT01236859.1\tLN:1090\n@SQ\tSN:APMT01236860.1\tLN:1090\n@SQ\tSN:APMT01236861.1\tLN:1090\n@SQ\tSN:APMT01236862.1\tLN:1090\n@SQ\tSN:APMT01236864.1\tLN:1090\n@SQ\tSN:APMT01235825.1\tLN:1089\n@SQ\tSN:APMT01236278.1\tLN:1089\n@SQ\tSN:APMT01236794.1\tLN:1089\n@SQ\tSN:APMT01236865.1\tLN:1089\n@SQ\tSN:APMT01236867.1\tLN:1089\n@SQ\tSN:APMT01236870.1\tLN:1089\n@SQ\tSN:APMT01236871.1\tLN:1089\n@SQ\tSN:APMT01236872.1\tLN:1089\n@SQ\tSN:APMT01236873.1\tLN:1089\n@SQ\tSN:APMT01236877.1\tLN:1089\n@SQ\tSN:APMT01235783.1\tLN:1088\n@SQ\tSN:APMT01236258.1\tLN:1088\n@SQ\tSN:APMT01236483.1\tLN:1088\n@SQ\tSN:APMT01236751.1\tLN:1088\n@SQ\tSN:APMT01236856.1\tLN:1088\n@SQ\tSN:APMT01236881.1\tLN:1088\n@SQ\tSN:APMT01236882.1\tLN:1088\n@SQ\tSN:APMT01236883.1\tLN:1088\n@SQ\tSN:APMT01235858.1\tLN:1087\n@SQ\tSN:APMT01235887.1\tLN:1087\n@SQ\tSN:APMT01236509.1\tLN:1087\n@SQ\tSN:APMT01236593.1\tLN:1087\n@SQ\tSN:APMT01236884.1\tLN:1087\n@SQ\tSN:APMT01236886.1\tLN:1087\n@SQ\tSN:APMT01236887.1\tLN:1087\n@SQ\tSN:APMT01236891.1\tLN:1087\n@SQ\tSN:APMT01236892.1\tLN:1087\n@SQ\tSN:APMT01236893.1\tLN:1087\n@SQ\tSN:APMT01236894.1\tLN:1087\n@SQ\tSN:APMT01236778.1\tLN:1086\n@SQ\tSN:APMT01236816.1\tLN:1086\n@SQ\tSN:APMT01236836.1\tLN:1086\n@SQ\tSN:APMT01236878.1\tLN:1086\n@SQ\tSN:APMT01236890.1\tLN:1086\n@SQ\tSN:APMT01236895.1\tLN:1086\n@SQ\tSN:APMT01236896.1\tLN:1086\n@SQ\tSN:APMT01236897.1\tLN:1086\n@SQ\tSN:APMT01236898.1\tLN:1086\n@SQ\tSN:APMT01236899.1\tLN:1086\n@SQ\tSN:APMT01236901.1\tLN:1086\n@SQ\tSN:APMT01236902.1\tLN:1086\n@SQ\tSN:APMT01236903.1\tLN:1086\n@SQ\tSN:APMT01236904.1\tLN:1086\n@SQ\tSN:APMT01236907.1\tLN:1086\n@SQ\tSN:APMT01236908.1\tLN:1086\n@SQ\tSN:APMT01236909.1\tLN:1086\n@SQ\tSN:APMT01236910.1\tLN:1086\n@SQ\tSN:APMT01236313.1\tLN:1085\n@SQ\tSN:APMT01236364.1\tLN:1085\n@SQ\tSN:APMT01236912.1\tLN:1085\n@SQ\tSN:APMT01236913.1\tLN:1085\n@SQ\tSN:APMT01236914.1\tLN:1085\n@SQ\tSN:APMT01236916.1\tLN:1085\n@SQ\tSN:APMT01236918.1\tLN:1085\n@SQ\tSN:APMT01236920.1\tLN:1085\n@SQ\tSN:APMT01236921.1\tLN:1085\n@SQ\tSN:APMT01236922.1\tLN:1085\n@SQ\tSN:APMT01236292.1\tLN:1084\n@SQ\tSN:APMT01236477.1\tLN:1084\n@SQ\tSN:APMT01236824.1\tLN:1084\n@SQ\tSN:APMT01236923.1\tLN:1084\n@SQ\tSN:APMT01236927.1\tLN:1084\n@SQ\tSN:APMT01236929.1\tLN:1084\n@SQ\tSN:APMT01236931.1\tLN:1084\n@SQ\tSN:APMT01236932.1\tLN:1084\n@SQ\tSN:APMT01236949.1\tLN:1084\n@SQ\tSN:APMT01235995.1\tLN:1083\n@SQ\tSN:APMT01236296.1\tLN:1083\n@SQ\tSN:APMT01236437.1\tLN:1083\n@SQ\tSN:APMT01236596.1\tLN:1083\n@SQ\tSN:APMT01236866.1\tLN:1083\n@SQ\tSN:APMT01236900.1\tLN:1083\n@SQ\tSN:APMT01236919.1\tLN:1083\n@SQ\tSN:APMT01236933.1\tLN:1083\n@SQ\tSN:APMT01236935.1\tLN:1083\n@SQ\tSN:APMT01236936.1\tLN:1083\n@SQ\tSN:APMT01236938.1\tLN:1083\n@SQ\tSN:APMT01236939.1\tLN:1083\n@SQ\tSN:APMT01236941.1\tLN:1083\n@SQ\tSN:APMT01236942.1\tLN:1083\n@SQ\tSN:APMT01236820.1\tLN:1082\n@SQ\tSN:APMT01236940.1\tLN:1082\n@SQ\tSN:APMT01236944.1\tLN:1082\n@SQ\tSN:APMT01236945.1\tLN:1082\n@SQ\tSN:APMT01236946.1\tLN:1082\n@SQ\tSN:APMT01236947.1\tLN:1082\n@SQ\tSN:APMT01236948.1\tLN:1082\n@SQ\tSN:APMT01236950.1\tLN:1082\n@SQ\tSN:APMT01236400.1\tLN:1081\n@SQ\tSN:APMT01236868.1\tLN:1081\n@SQ\tSN:APMT01236937.1\tLN:1081\n@SQ\tSN:APMT01236952.1\tLN:1081\n@SQ\tSN:APMT01236953.1\tLN:1081\n@SQ\tSN:APMT01236954.1\tLN:1081\n@SQ\tSN:APMT01236955.1\tLN:1081\n@SQ\tSN:APMT01236958.1\tLN:1081\n@SQ\tSN:APMT01236959.1\tLN:1081\n@SQ\tSN:APMT01236323.1\tLN:1080\n@SQ\tSN:APMT01236464.1\tLN:1080\n@SQ\tSN:APMT01236961.1\tLN:1080\n@SQ\tSN:APMT01236962.1\tLN:1080\n@SQ\tSN:APMT01236963.1\tLN:1080\n@SQ\tSN:APMT01236964.1\tLN:1080\n@SQ\tSN:APMT01236967.1\tLN:1080\n@SQ\tSN:APMT01236968.1\tLN:1080\n@SQ\tSN:APMT01236969.1\tLN:1080\n@SQ\tSN:APMT01236970.1\tLN:1080\n@SQ\tSN:APMT01236329.1\tLN:1079\n@SQ\tSN:APMT01236370.1\tLN:1079\n@SQ\tSN:APMT01236387.1\tLN:1079\n@SQ\tSN:APMT01236485.1\tLN:1079\n@SQ\tSN:APMT01236875.1\tLN:1079\n@SQ\tSN:APMT01236956.1\tLN:1079\n@SQ\tSN:APMT01236971.1\tLN:1079\n@SQ\tSN:APMT01236972.1\tLN:1079\n@SQ\tSN:APMT01236973.1\tLN:1079\n@SQ\tSN:APMT01236974.1\tLN:1079\n@SQ\tSN:APMT01236975.1\tLN:1079\n@SQ\tSN:APMT01236978.1\tLN:1079\n@SQ\tSN:APMT01236979.1\tLN:1079\n@SQ\tSN:APMT01236980.1\tLN:1079\n@SQ\tSN:APMT01236982.1\tLN:1079\n@SQ\tSN:APMT01235941.1\tLN:1078\n@SQ\tSN:APMT01236455.1\tLN:1078\n@SQ\tSN:APMT01236500.1\tLN:1078\n@SQ\tSN:APMT01236985.1\tLN:1078\n@SQ\tSN:APMT01236986.1\tLN:1078\n@SQ\tSN:APMT01236988.1\tLN:1078\n@SQ\tSN:APMT01236990.1\tLN:1078\n@SQ\tSN:APMT01236991.1\tLN:1078\n@SQ\tSN:APMT01236993.1\tLN:1078\n@SQ\tSN:APMT01236994.1\tLN:1078\n@SQ\tSN:APMT01236995.1\tLN:1078\n@SQ\tSN:APMT01236996.1\tLN:1078\n@SQ\tSN:APMT01236997.1\tLN:1078\n@SQ\tSN:APMT01235985.1\tLN:1077\n@SQ\tSN:APMT01236156.1\tLN:1077\n@SQ\tSN:APMT01236341.1\tLN:1077\n@SQ\tSN:APMT01236354.1\tLN:1077\n@SQ\tSN:APMT01236358.1\tLN:1077\n@SQ\tSN:APMT01236373.1\tLN:1077\n@SQ\tSN:APMT01236524.1\tLN:1077\n@SQ\tSN:APMT01236564.1\tLN:1077\n@SQ\tSN:APMT01236618.1\tLN:1077\n@SQ\tSN:APMT01236733.1\tLN:1077\n@SQ\tSN:APMT01236998.1\tLN:1077\n@SQ\tSN:APMT01237000.1\tLN:1077\n@SQ\tSN:APMT01237001.1\tLN:1077\n@SQ\tSN:APMT01237002.1\tLN:1077\n@SQ\tSN:APMT01237003.1\tLN:1077\n@SQ\tSN:APMT01237005.1\tLN:1077\n@SQ\tSN:APMT01237006.1\tLN:1077\n@SQ\tSN:APMT01237007.1\tLN:1077\n@SQ\tSN:APMT01237008.1\tLN:1077\n@SQ\tSN:APMT01236368.1\tLN:1076\n@SQ\tSN:APMT01236402.1\tLN:1076\n@SQ\tSN:APMT01237011.1\tLN:1076\n@SQ\tSN:APMT01237012.1\tLN:1076\n@SQ\tSN:APMT01237013.1\tLN:1076\n@SQ\tSN:APMT01237015.1\tLN:1076\n@SQ\tSN:APMT01236559.1\tLN:1075\n@SQ\tSN:APMT01236623.1\tLN:1075\n@SQ\tSN:APMT01237017.1\tLN:1075\n@SQ\tSN:APMT01237018.1\tLN:1075\n@SQ\tSN:APMT01237019.1\tLN:1075\n@SQ\tSN:APMT01237020.1\tLN:1075\n@SQ\tSN:APMT01237023.1\tLN:1075\n@SQ\tSN:APMT01237024.1\tLN:1075\n@SQ\tSN:APMT01236381.1\tLN:1074\n@SQ\tSN:APMT01236795.1\tLN:1074\n@SQ\tSN:APMT01237022.1\tLN:1074\n@SQ\tSN:APMT01237029.1\tLN:1074\n@SQ\tSN:APMT01237032.1\tLN:1074\n@SQ\tSN:APMT01237033.1\tLN:1074\n@SQ\tSN:APMT01237034.1\tLN:1074\n@SQ\tSN:APMT01237035.1\tLN:1074\n@SQ\tSN:APMT01237036.1\tLN:1074\n@SQ\tSN:APMT01237037.1\tLN:1074\n@SQ\tSN:APMT01237204.1\tLN:1074\n@SQ\tSN:APMT01235902.1\tLN:1073\n@SQ\tSN:APMT01236395.1\tLN:1073\n@SQ\tSN:APMT01236554.1\tLN:1073\n@SQ\tSN:APMT01236607.1\tLN:1073\n@SQ\tSN:APMT01236934.1\tLN:1073\n@SQ\tSN:APMT01237038.1\tLN:1073\n@SQ\tSN:APMT01237040.1\tLN:1073\n@SQ\tSN:APMT01237042.1\tLN:1073\n@SQ\tSN:APMT01237044.1\tLN:1073\n@SQ\tSN:APMT01235907.1\tLN:1072\n@SQ\tSN:APMT01236137.1\tLN:1072\n@SQ\tSN:APMT01236403.1\tLN:1072\n@SQ\tSN:APMT01236486.1\tLN:1072\n@SQ\tSN:APMT01236591.1\tLN:1072\n@SQ\tSN:APMT01236999.1\tLN:1072\n@SQ\tSN:APMT01237025.1\tLN:1072\n@SQ\tSN:APMT01237045.1\tLN:1072\n@SQ\tSN:APMT01237048.1\tLN:1072\n@SQ\tSN:APMT01237050.1\tLN:1072\n@SQ\tSN:APMT01237051.1\tLN:1072\n@SQ\tSN:APMT01237052.1\tLN:1072\n@SQ\tSN:APMT01237053.1\tLN:1072\n@SQ\tSN:APMT01237054.1\tLN:1072\n@SQ\tSN:APMT01237056.1\tLN:1072\n@SQ\tSN:APMT01237057.1\tLN:1072\n@SQ\tSN:APMT01236410.1\tLN:1071\n@SQ\tSN:APMT01236436.1\tLN:1071\n@SQ\tSN:APMT01236460.1\tLN:1071\n@SQ\tSN:APMT01236469.1\tLN:1071\n@SQ\tSN:APMT01236649.1\tLN:1071\n@SQ\tSN:APMT01236687.1\tLN:1071\n@SQ\tSN:APMT01236839.1\tLN:1071\n@SQ\tSN:APMT01236984.1\tLN:1071\n@SQ\tSN:APMT01237059.1\tLN:1071\n@SQ\tSN:APMT01237060.1\tLN:1071\n@SQ\tSN:APMT01237061.1\tLN:1071\n@SQ\tSN:APMT01237062.1\tLN:1071\n@SQ\tSN:APMT01236332.1\tLN:1070\n@SQ\tSN:APMT01236393.1\tLN:1070\n@SQ\tSN:APMT01236443.1\tLN:1070\n@SQ\tSN:APMT01236501.1\tLN:1070\n@SQ\tSN:APMT01236811.1\tLN:1070\n@SQ\tSN:APMT01237067.1\tLN:1070\n@SQ\tSN:APMT01237068.1\tLN:1070\n@SQ\tSN:APMT01237070.1\tLN:1070\n@SQ\tSN:APMT01237071.1\tLN:1070\n@SQ\tSN:APMT01237073.1\tLN:1070\n@SQ\tSN:APMT01237074.1\tLN:1070\n@SQ\tSN:APMT01237075.1\tLN:1070\n@SQ\tSN:APMT01237076.1\tLN:1070\n@SQ\tSN:APMT01236202.1\tLN:1069\n@SQ\tSN:APMT01236440.1\tLN:1069\n@SQ\tSN:APMT01236513.1\tLN:1069\n@SQ\tSN:APMT01236863.1\tLN:1069\n@SQ\tSN:APMT01236951.1\tLN:1069\n@SQ\tSN:APMT01237065.1\tLN:1069\n@SQ\tSN:APMT01237080.1\tLN:1069\n@SQ\tSN:APMT01237081.1\tLN:1069\n@SQ\tSN:APMT01237082.1\tLN:1069\n@SQ\tSN:APMT01236549.1\tLN:1068\n@SQ\tSN:APMT01236603.1\tLN:1068\n@SQ\tSN:APMT01236632.1\tLN:1068\n@SQ\tSN:APMT01237084.1\tLN:1068\n@SQ\tSN:APMT01237086.1\tLN:1068\n@SQ\tSN:APMT01237087.1\tLN:1068\n@SQ\tSN:APMT01237089.1\tLN:1068\n@SQ\tSN:APMT01235952.1\tLN:1067\n@SQ\tSN:APMT01236557.1\tLN:1067\n@SQ\tSN:APMT01236780.1\tLN:1067\n@SQ\tSN:APMT01237077.1\tLN:1067\n@SQ\tSN:APMT01237091.1\tLN:1067\n@SQ\tSN:APMT01237092.1\tLN:1067\n@SQ\tSN:APMT01237112.1\tLN:1067\n@SQ\tSN:APMT01225389.1\tLN:1066\n@SQ\tSN:APMT01236212.1\tLN:1066\n@SQ\tSN:APMT01236494.1\tLN:1066\n@SQ\tSN:APMT01236567.1\tLN:1066\n@SQ\tSN:APMT01237030.1\tLN:1066\n@SQ\tSN:APMT01237096.1\tLN:1066\n@SQ\tSN:APMT01237097.1\tLN:1066\n@SQ\tSN:APMT01237099.1\tLN:1066\n@SQ\tSN:APMT01237100.1\tLN:1066\n@SQ\tSN:APMT01237101.1\tLN:1066\n@SQ\tSN:APMT01237102.1\tLN:1066\n@SQ\tSN:APMT01237103.1\tLN:1066\n@SQ\tSN:APMT01237105.1\tLN:1066\n@SQ\tSN:APMT01237106.1\tLN:1066\n@SQ\tSN:APMT01237107.1\tLN:1066\n@SQ\tSN:APMT01236466.1\tLN:1065\n@SQ\tSN:APMT01237109.1\tLN:1065\n@SQ\tSN:APMT01237110.1\tLN:1065\n@SQ\tSN:APMT01237111.1\tLN:1065\n@SQ\tSN:APMT01226312.1\tLN:1064\n@SQ\tSN:APMT01236030.1\tLN:1064\n@SQ\tSN:APMT01236141.1\tLN:1064\n@SQ\tSN:APMT01236481.1\tLN:1064\n@SQ\tSN:APMT01236508.1\tLN:1064\n@SQ\tSN:APMT01236523.1\tLN:1064\n@SQ\tSN:APMT01236622.1\tLN:1064\n@SQ\tSN:APMT01236930.1\tLN:1064\n@SQ\tSN:APMT01237085.1\tLN:1064\n@SQ\tSN:APMT01237116.1\tLN:1064\n@SQ\tSN:APMT01237118.1\tLN:1064\n@SQ\tSN:APMT01237122.1\tLN:1064\n@SQ\tSN:APMT01237123.1\tLN:1064\n@SQ\tSN:APMT01237124.1\tLN:1064\n@SQ\tSN:APMT01236497.1\tLN:1063\n@SQ\tSN:APMT01236562.1\tLN:1063\n@SQ\tSN:APMT01237115.1\tLN:1063\n@SQ\tSN:APMT01237127.1\tLN:1063\n@SQ\tSN:APMT01237128.1\tLN:1063\n@SQ\tSN:APMT01237129.1\tLN:1063\n@SQ\tSN:APMT01237130.1\tLN:1063\n@SQ\tSN:APMT01237131.1\tLN:1063\n@SQ\tSN:APMT01237132.1\tLN:1063\n@SQ\tSN:APMT01237133.1\tLN:1063\n@SQ\tSN:APMT01237134.1\tLN:1063\n@SQ\tSN:APMT01237136.1\tLN:1063\n@SQ\tSN:APMT01237137.1\tLN:1063\n@SQ\tSN:APMT01235979.1\tLN:1062\n@SQ\tSN:APMT01236074.1\tLN:1062\n@SQ\tSN:APMT01236295.1\tLN:1062\n@SQ\tSN:APMT01236731.1\tLN:1062\n@SQ\tSN:APMT01236879.1\tLN:1062\n@SQ\tSN:APMT01237016.1\tLN:1062\n@SQ\tSN:APMT01237139.1\tLN:1062\n@SQ\tSN:APMT01237140.1\tLN:1062\n@SQ\tSN:APMT01237143.1\tLN:1062\n@SQ\tSN:APMT01237144.1\tLN:1062\n@SQ\tSN:APMT01237145.1\tLN:1062\n@SQ\tSN:APMT01237146.1\tLN:1062\n@SQ\tSN:APMT01237148.1\tLN:1062\n@SQ\tSN:APMT01237210.1\tLN:1062\n@SQ\tSN:APMT01236049.1\tLN:1061\n@SQ\tSN:APMT01236842.1\tLN:1061\n@SQ\tSN:APMT01236976.1\tLN:1061\n@SQ\tSN:APMT01237149.1\tLN:1061\n@SQ\tSN:APMT01237150.1\tLN:1061\n@SQ\tSN:APMT01236010.1\tLN:1060\n@SQ\tSN:APMT01236520.1\tLN:1060\n@SQ\tSN:APMT01236538.1\tLN:1060\n@SQ\tSN:APMT01237154.1\tLN:1060\n@SQ\tSN:APMT01237155.1\tLN:1060\n@SQ\tSN:APMT01237159.1\tLN:1060\n@SQ\tSN:APMT01237160.1\tLN:1060\n@SQ\tSN:APMT01237161.1\tLN:1060\n@SQ\tSN:APMT01237162.1\tLN:1060\n@SQ\tSN:APMT01237163.1\tLN:1060\n@SQ\tSN:APMT01237164.1\tLN:1060\n@SQ\tSN:APMT01237165.1\tLN:1060\n@SQ\tSN:APMT01236140.1\tLN:1059\n@SQ\tSN:APMT01236655.1\tLN:1059\n@SQ\tSN:APMT01237069.1\tLN:1059\n@SQ\tSN:APMT01237114.1\tLN:1059\n@SQ\tSN:APMT01237158.1\tLN:1059\n@SQ\tSN:APMT01237167.1\tLN:1059\n@SQ\tSN:APMT01237170.1\tLN:1059\n@SQ\tSN:APMT01237171.1\tLN:1059\n@SQ\tSN:APMT01237173.1\tLN:1058\n@SQ\tSN:APMT01237174.1\tLN:1058\n@SQ\tSN:APMT01237177.1\tLN:1058\n@SQ\tSN:APMT01237178.1\tLN:1058\n@SQ\tSN:APMT01237179.1\tLN:1058\n@SQ\tSN:APMT01237180.1\tLN:1058\n@SQ\tSN:APMT01237181.1\tLN:1058\n@SQ\tSN:APMT01237182.1\tLN:1058\n@SQ\tSN:APMT01237183.1\tLN:1058\n@SQ\tSN:APMT01237184.1\tLN:1058\n@SQ\tSN:APMT01237185.1\tLN:1058\n@SQ\tSN:APMT01237186.1\tLN:1058\n@SQ\tSN:APMT01237187.1\tLN:1058\n@SQ\tSN:APMT01237188.1\tLN:1058\n@SQ\tSN:APMT01237189.1\tLN:1058\n@SQ\tSN:APMT01236613.1\tLN:1057\n@SQ\tSN:APMT01237191.1\tLN:1057\n@SQ\tSN:APMT01237194.1\tLN:1057\n@SQ\tSN:APMT01237195.1\tLN:1057\n@SQ\tSN:APMT01237198.1\tLN:1057\n@SQ\tSN:APMT01237199.1\tLN:1057\n@SQ\tSN:APMT01236590.1\tLN:1056\n@SQ\tSN:APMT01236728.1\tLN:1056\n@SQ\tSN:APMT01237125.1\tLN:1056\n@SQ\tSN:APMT01237200.1\tLN:1056\n@SQ\tSN:APMT01237202.1\tLN:1056\n@SQ\tSN:APMT01237205.1\tLN:1056\n@SQ\tSN:APMT01237206.1\tLN:1056\n@SQ\tSN:APMT01237207.1\tLN:1056\n@SQ\tSN:APMT01237208.1\tLN:1056\n@SQ\tSN:APMT01237209.1\tLN:1056\n@SQ\tSN:APMT01237211.1\tLN:1056\n@SQ\tSN:APMT01237212.1\tLN:1056\n@SQ\tSN:APMT01237214.1\tLN:1056\n@SQ\tSN:APMT01237215.1\tLN:1056\n@SQ\tSN:APMT01237216.1\tLN:1055\n@SQ\tSN:APMT01237217.1\tLN:1055\n@SQ\tSN:APMT01237218.1\tLN:1055\n@SQ\tSN:APMT01237220.1\tLN:1055\n@SQ\tSN:APMT01237221.1\tLN:1055\n@SQ\tSN:APMT01237222.1\tLN:1055\n@SQ\tSN:APMT01237224.1\tLN:1055\n@SQ\tSN:APMT01237225.1\tLN:1055\n@SQ\tSN:APMT01236761.1\tLN:1054\n@SQ\tSN:APMT01237083.1\tLN:1054\n@SQ\tSN:APMT01237219.1\tLN:1054\n@SQ\tSN:APMT01237227.1\tLN:1054\n@SQ\tSN:APMT01237228.1\tLN:1054\n@SQ\tSN:APMT01237229.1\tLN:1054\n@SQ\tSN:APMT01237230.1\tLN:1054\n@SQ\tSN:APMT01237235.1\tLN:1054\n@SQ\tSN:APMT01236195.1\tLN:1053\n@SQ\tSN:APMT01236643.1\tLN:1053\n@SQ\tSN:APMT01236960.1\tLN:1053\n@SQ\tSN:APMT01237079.1\tLN:1053\n@SQ\tSN:APMT01237169.1\tLN:1053\n@SQ\tSN:APMT01237236.1\tLN:1053\n@SQ\tSN:APMT01237241.1\tLN:1053\n@SQ\tSN:APMT01237244.1\tLN:1053\n@SQ\tSN:APMT01237245.1\tLN:1053\n@SQ\tSN:APMT01237247.1\tLN:1053\n@SQ\tSN:APMT01236943.1\tLN:1052\n@SQ\tSN:APMT01237249.1\tLN:1052\n@SQ\tSN:APMT01237250.1\tLN:1052\n@SQ\tSN:APMT01237252.1\tLN:1052\n@SQ\tSN:APMT01237298.1\tLN:1052\n@SQ\tSN:APMT01236227.1\tLN:1051\n@SQ\tSN:APMT01236639.1\tLN:1051\n@SQ\tSN:APMT01236723.1\tLN:1051\n@SQ\tSN:APMT01236851.1\tLN:1051\n@SQ\tSN:APMT01236880.1\tLN:1051\n@SQ\tSN:APMT01236906.1\tLN:1051\n@SQ\tSN:APMT01236981.1\tLN:1051\n@SQ\tSN:APMT01237098.1\tLN:1051\n@SQ\tSN:APMT01237251.1\tLN:1051\n@SQ\tSN:APMT01237258.1\tLN:1051\n@SQ\tSN:APMT01237259.1\tLN:1051\n@SQ\tSN:APMT01237263.1\tLN:1051\n@SQ\tSN:APMT01237264.1\tLN:1051\n@SQ\tSN:APMT01237265.1\tLN:1051\n@SQ\tSN:APMT01237266.1\tLN:1051\n@SQ\tSN:APMT01237268.1\tLN:1051\n@SQ\tSN:APMT01237269.1\tLN:1051\n@SQ\tSN:APMT01237270.1\tLN:1051\n@SQ\tSN:APMT01237271.1\tLN:1051\n@SQ\tSN:APMT01236700.1\tLN:1050\n@SQ\tSN:APMT01237108.1\tLN:1050\n@SQ\tSN:APMT01237273.1\tLN:1050\n@SQ\tSN:APMT01237274.1\tLN:1050\n@SQ\tSN:APMT01237275.1\tLN:1050\n@SQ\tSN:APMT01237276.1\tLN:1050\n@SQ\tSN:APMT01237277.1\tLN:1050\n@SQ\tSN:APMT01237278.1\tLN:1050\n@SQ\tSN:APMT01236383.1\tLN:1049\n@SQ\tSN:APMT01236641.1\tLN:1049\n@SQ\tSN:APMT01236840.1\tLN:1049\n@SQ\tSN:APMT01237260.1\tLN:1049\n@SQ\tSN:APMT01237279.1\tLN:1049\n@SQ\tSN:APMT01237280.1\tLN:1049\n@SQ\tSN:APMT01237281.1\tLN:1049\n@SQ\tSN:APMT01237282.1\tLN:1049\n@SQ\tSN:APMT01237283.1\tLN:1049\n@SQ\tSN:APMT01237284.1\tLN:1049\n@SQ\tSN:APMT01237286.1\tLN:1049\n@SQ\tSN:APMT01237288.1\tLN:1049\n@SQ\tSN:APMT01237289.1\tLN:1049\n@SQ\tSN:APMT01237290.1\tLN:1049\n@SQ\tSN:APMT01237291.1\tLN:1049\n@SQ\tSN:APMT01237315.1\tLN:1049\n@SQ\tSN:APMT01236679.1\tLN:1048\n@SQ\tSN:APMT01237248.1\tLN:1048\n@SQ\tSN:APMT01237293.1\tLN:1048\n@SQ\tSN:APMT01237294.1\tLN:1048\n@SQ\tSN:APMT01237295.1\tLN:1048\n@SQ\tSN:APMT01237305.1\tLN:1048\n@SQ\tSN:APMT01236236.1\tLN:1047\n@SQ\tSN:APMT01236489.1\tLN:1047\n@SQ\tSN:APMT01236660.1\tLN:1047\n@SQ\tSN:APMT01236677.1\tLN:1047\n@SQ\tSN:APMT01236888.1\tLN:1047\n@SQ\tSN:APMT01237297.1\tLN:1047\n@SQ\tSN:APMT01237300.1\tLN:1047\n@SQ\tSN:APMT01237301.1\tLN:1047\n@SQ\tSN:APMT01237303.1\tLN:1047\n@SQ\tSN:APMT01237304.1\tLN:1047\n@SQ\tSN:APMT01236235.1\tLN:1046\n@SQ\tSN:APMT01236276.1\tLN:1046\n@SQ\tSN:APMT01236293.1\tLN:1046\n@SQ\tSN:APMT01236689.1\tLN:1046\n@SQ\tSN:APMT01236869.1\tLN:1046\n@SQ\tSN:APMT01237147.1\tLN:1046\n@SQ\tSN:APMT01237255.1\tLN:1046\n@SQ\tSN:APMT01237292.1\tLN:1046\n@SQ\tSN:APMT01237309.1\tLN:1046\n@SQ\tSN:APMT01237310.1\tLN:1046\n@SQ\tSN:APMT01237311.1\tLN:1046\n@SQ\tSN:APMT01237313.1\tLN:1046\n@SQ\tSN:APMT01229982.1\tLN:1045\n@SQ\tSN:APMT01230371.1\tLN:1045\n@SQ\tSN:APMT01236453.1\tLN:1045\n@SQ\tSN:APMT01236692.1\tLN:1045\n@SQ\tSN:APMT01236695.1\tLN:1045\n@SQ\tSN:APMT01236702.1\tLN:1045\n@SQ\tSN:APMT01236779.1\tLN:1045\n@SQ\tSN:APMT01237316.1\tLN:1045\n@SQ\tSN:APMT01237320.1\tLN:1045\n@SQ\tSN:APMT01237321.1\tLN:1045\n@SQ\tSN:APMT01237322.1\tLN:1045\n@SQ\tSN:APMT01237323.1\tLN:1045\n@SQ\tSN:APMT01236726.1\tLN:1044\n@SQ\tSN:APMT01236737.1\tLN:1044\n@SQ\tSN:APMT01236744.1\tLN:1044\n@SQ\tSN:APMT01236977.1\tLN:1044\n@SQ\tSN:APMT01237041.1\tLN:1044\n@SQ\tSN:APMT01237324.1\tLN:1044\n@SQ\tSN:APMT01237325.1\tLN:1044\n@SQ\tSN:APMT01237327.1\tLN:1044\n@SQ\tSN:APMT01237328.1\tLN:1044\n@SQ\tSN:APMT01237329.1\tLN:1044\n@SQ\tSN:APMT01237330.1\tLN:1044\n@SQ\tSN:APMT01237331.1\tLN:1044\n@SQ\tSN:APMT01237332.1\tLN:1044\n@SQ\tSN:APMT01237333.1\tLN:1044\n@SQ\tSN:APMT01237196.1\tLN:1043\n@SQ\tSN:APMT01237336.1\tLN:1043\n@SQ\tSN:APMT01237337.1\tLN:1043\n@SQ\tSN:APMT01237338.1\tLN:1043\n@SQ\tSN:APMT01237339.1\tLN:1043\n@SQ\tSN:APMT01236740.1\tLN:1042\n@SQ\tSN:APMT01236808.1\tLN:1042\n@SQ\tSN:APMT01237117.1\tLN:1042\n@SQ\tSN:APMT01237318.1\tLN:1042\n@SQ\tSN:APMT01237340.1\tLN:1042\n@SQ\tSN:APMT01237341.1\tLN:1042\n@SQ\tSN:APMT01237342.1\tLN:1042\n@SQ\tSN:APMT01237344.1\tLN:1042\n@SQ\tSN:APMT01237345.1\tLN:1042\n@SQ\tSN:APMT01237346.1\tLN:1042\n@SQ\tSN:APMT01237347.1\tLN:1042\n@SQ\tSN:APMT01237348.1\tLN:1042\n@SQ\tSN:APMT01237353.1\tLN:1042\n@SQ\tSN:APMT01237201.1\tLN:1041\n@SQ\tSN:APMT01237335.1\tLN:1041\n@SQ\tSN:APMT01237349.1\tLN:1041\n@SQ\tSN:APMT01237351.1\tLN:1041\n@SQ\tSN:APMT01236365.1\tLN:1040\n@SQ\tSN:APMT01236777.1\tLN:1040\n@SQ\tSN:APMT01237237.1\tLN:1040\n@SQ\tSN:APMT01237308.1\tLN:1040\n@SQ\tSN:APMT01237317.1\tLN:1040\n@SQ\tSN:APMT01237352.1\tLN:1040\n@SQ\tSN:APMT01237354.1\tLN:1040\n@SQ\tSN:APMT01237356.1\tLN:1040\n@SQ\tSN:APMT01237358.1\tLN:1040\n@SQ\tSN:APMT01237359.1\tLN:1040\n@SQ\tSN:APMT01237360.1\tLN:1040\n@SQ\tSN:APMT01237361.1\tLN:1040\n@SQ\tSN:APMT01236270.1\tLN:1039\n@SQ\tSN:APMT01236303.1\tLN:1039\n@SQ\tSN:APMT01236810.1\tLN:1039\n@SQ\tSN:APMT01237156.1\tLN:1039\n@SQ\tSN:APMT01237362.1\tLN:1039\n@SQ\tSN:APMT01237364.1\tLN:1039\n@SQ\tSN:APMT01237365.1\tLN:1039\n@SQ\tSN:APMT01237366.1\tLN:1039\n@SQ\tSN:APMT01236224.1\tLN:1038\n@SQ\tSN:APMT01236299.1\tLN:1038\n@SQ\tSN:APMT01236924.1\tLN:1038\n@SQ\tSN:APMT01236928.1\tLN:1038\n@SQ\tSN:APMT01236989.1\tLN:1038\n@SQ\tSN:APMT01237232.1\tLN:1038\n@SQ\tSN:APMT01237367.1\tLN:1038\n@SQ\tSN:APMT01237368.1\tLN:1038\n@SQ\tSN:APMT01237369.1\tLN:1038\n@SQ\tSN:APMT01237370.1\tLN:1038\n@SQ\tSN:APMT01237371.1\tLN:1038\n@SQ\tSN:APMT01237372.1\tLN:1038\n@SQ\tSN:APMT01237373.1\tLN:1038\n@SQ\tSN:APMT01237375.1\tLN:1038\n@SQ\tSN:APMT01237376.1\tLN:1038\n@SQ\tSN:APMT01236484.1\tLN:1037\n@SQ\tSN:APMT01236694.1\tLN:1037\n@SQ\tSN:APMT01236771.1\tLN:1037\n@SQ\tSN:APMT01236905.1\tLN:1037\n@SQ\tSN:APMT01237231.1\tLN:1037\n@SQ\tSN:APMT01237234.1\tLN:1037\n@SQ\tSN:APMT01237374.1\tLN:1037\n@SQ\tSN:APMT01237379.1\tLN:1037\n@SQ\tSN:APMT01237380.1\tLN:1037\n@SQ\tSN:APMT01237381.1\tLN:1037\n@SQ\tSN:APMT01237382.1\tLN:1037\n@SQ\tSN:APMT01237383.1\tLN:1037\n@SQ\tSN:APMT01237384.1\tLN:1037\n@SQ\tSN:APMT01237385.1\tLN:1037\n@SQ\tSN:APMT01237386.1\tLN:1037\n@SQ\tSN:APMT01237387.1\tLN:1037\n@SQ\tSN:APMT01237467.1\tLN:1037\n@SQ\tSN:APMT01236829.1\tLN:1036\n@SQ\tSN:APMT01236846.1\tLN:1036\n@SQ\tSN:APMT01236911.1\tLN:1036\n@SQ\tSN:APMT01237031.1\tLN:1036\n@SQ\tSN:APMT01237388.1\tLN:1036\n@SQ\tSN:APMT01237389.1\tLN:1036\n@SQ\tSN:APMT01237390.1\tLN:1036\n@SQ\tSN:APMT01237391.1\tLN:1036\n@SQ\tSN:APMT01237021.1\tLN:1035\n@SQ\tSN:APMT01237357.1\tLN:1035\n@SQ\tSN:APMT01237392.1\tLN:1035\n@SQ\tSN:APMT01237393.1\tLN:1035\n@SQ\tSN:APMT01237394.1\tLN:1035\n@SQ\tSN:APMT01237396.1\tLN:1035\n@SQ\tSN:APMT01237397.1\tLN:1035\n@SQ\tSN:APMT01237398.1\tLN:1035\n@SQ\tSN:APMT01236337.1\tLN:1034\n@SQ\tSN:APMT01236800.1\tLN:1034\n@SQ\tSN:APMT01237401.1\tLN:1034\n@SQ\tSN:APMT01237402.1\tLN:1034\n@SQ\tSN:APMT01237403.1\tLN:1034\n@SQ\tSN:APMT01237404.1\tLN:1034\n@SQ\tSN:APMT01237405.1\tLN:1034\n@SQ\tSN:APMT01237407.1\tLN:1034\n@SQ\tSN:APMT01236479.1\tLN:1033\n@SQ\tSN:APMT01236584.1\tLN:1033\n@SQ\tSN:APMT01236815.1\tLN:1033\n@SQ\tSN:APMT01236837.1\tLN:1033\n@SQ\tSN:APMT01236847.1\tLN:1033\n@SQ\tSN:APMT01237223.1\tLN:1033\n@SQ\tSN:APMT01237378.1\tLN:1033\n@SQ\tSN:APMT01237410.1\tLN:1033\n@SQ\tSN:APMT01237411.1\tLN:1033\n@SQ\tSN:APMT01237412.1\tLN:1033\n@SQ\tSN:APMT01223085.1\tLN:1032\n@SQ\tSN:APMT01236791.1\tLN:1032\n@SQ\tSN:APMT01236828.1\tLN:1032\n@SQ\tSN:APMT01236850.1\tLN:1032\n@SQ\tSN:APMT01236874.1\tLN:1032\n@SQ\tSN:APMT01236917.1\tLN:1032\n@SQ\tSN:APMT01237272.1\tLN:1032\n@SQ\tSN:APMT01237307.1\tLN:1032\n@SQ\tSN:APMT01237413.1\tLN:1032\n@SQ\tSN:APMT01237414.1\tLN:1032\n@SQ\tSN:APMT01237415.1\tLN:1032\n@SQ\tSN:APMT01237416.1\tLN:1032\n@SQ\tSN:APMT01237417.1\tLN:1032\n@SQ\tSN:APMT01237418.1\tLN:1032\n@SQ\tSN:APMT01237420.1\tLN:1032\n@SQ\tSN:APMT01236806.1\tLN:1031\n@SQ\tSN:APMT01236841.1\tLN:1031\n@SQ\tSN:APMT01236915.1\tLN:1031\n@SQ\tSN:APMT01237066.1\tLN:1031\n@SQ\tSN:APMT01237296.1\tLN:1031\n@SQ\tSN:APMT01237421.1\tLN:1031\n@SQ\tSN:APMT01237423.1\tLN:1031\n@SQ\tSN:APMT01237424.1\tLN:1031\n@SQ\tSN:APMT01237425.1\tLN:1031\n@SQ\tSN:APMT01237426.1\tLN:1031\n@SQ\tSN:APMT01236637.1\tLN:1030\n@SQ\tSN:APMT01236876.1\tLN:1030\n@SQ\tSN:APMT01237343.1\tLN:1030\n@SQ\tSN:APMT01237427.1\tLN:1030\n@SQ\tSN:APMT01237429.1\tLN:1030\n@SQ\tSN:APMT01237430.1\tLN:1030\n@SQ\tSN:APMT01237431.1\tLN:1030\n@SQ\tSN:APMT01237433.1\tLN:1030\n@SQ\tSN:APMT01237434.1\tLN:1030\n@SQ\tSN:APMT01236414.1\tLN:1029\n@SQ\tSN:APMT01236418.1\tLN:1029\n@SQ\tSN:APMT01236490.1\tLN:1029\n@SQ\tSN:APMT01236852.1\tLN:1029\n@SQ\tSN:APMT01237435.1\tLN:1029\n@SQ\tSN:APMT01237436.1\tLN:1029\n@SQ\tSN:APMT01236885.1\tLN:1028\n@SQ\tSN:APMT01237299.1\tLN:1028\n@SQ\tSN:APMT01237428.1\tLN:1028\n@SQ\tSN:APMT01237437.1\tLN:1028\n@SQ\tSN:APMT01237438.1\tLN:1028\n@SQ\tSN:APMT01237439.1\tLN:1028\n@SQ\tSN:APMT01237440.1\tLN:1028\n@SQ\tSN:APMT01237441.1\tLN:1028\n@SQ\tSN:APMT01237442.1\tLN:1028\n@SQ\tSN:APMT01237443.1\tLN:1028\n@SQ\tSN:APMT01236889.1\tLN:1027\n@SQ\tSN:APMT01237285.1\tLN:1027\n@SQ\tSN:APMT01237400.1\tLN:1027\n@SQ\tSN:APMT01237406.1\tLN:1027\n@SQ\tSN:APMT01237422.1\tLN:1027\n@SQ\tSN:APMT01237445.1\tLN:1027\n@SQ\tSN:APMT01237446.1\tLN:1027\n@SQ\tSN:APMT01237447.1\tLN:1027\n@SQ\tSN:APMT01237448.1\tLN:1027\n@SQ\tSN:APMT01237450.1\tLN:1027\n@SQ\tSN:APMT01237451.1\tLN:1027\n@SQ\tSN:APMT01236417.1\tLN:1026\n@SQ\tSN:APMT01236818.1\tLN:1026\n@SQ\tSN:APMT01237119.1\tLN:1026\n@SQ\tSN:APMT01237153.1\tLN:1026\n@SQ\tSN:APMT01237444.1\tLN:1026\n@SQ\tSN:APMT01237449.1\tLN:1026\n@SQ\tSN:APMT01237452.1\tLN:1026\n@SQ\tSN:APMT01237453.1\tLN:1026\n@SQ\tSN:APMT01237454.1\tLN:1026\n@SQ\tSN:APMT01237455.1\tLN:1026\n@SQ\tSN:APMT01237456.1\tLN:1026\n@SQ\tSN:APMT01237457.1\tLN:1026\n@SQ\tSN:APMT01237458.1\tLN:1026\n@SQ\tSN:APMT01237459.1\tLN:1026\n@SQ\tSN:APMT01237460.1\tLN:1026\n@SQ\tSN:APMT01237461.1\tLN:1026\n@SQ\tSN:APMT01236678.1\tLN:1025\n@SQ\tSN:APMT01237240.1\tLN:1025\n@SQ\tSN:APMT01237334.1\tLN:1025\n@SQ\tSN:APMT01237462.1\tLN:1025\n@SQ\tSN:APMT01237463.1\tLN:1025\n@SQ\tSN:APMT01237464.1\tLN:1025\n@SQ\tSN:APMT01237465.1\tLN:1025\n@SQ\tSN:APMT01237466.1\tLN:1025\n@SQ\tSN:APMT01237088.1\tLN:1024\n@SQ\tSN:APMT01237166.1\tLN:1024\n@SQ\tSN:APMT01237469.1\tLN:1024\n@SQ\tSN:APMT01237470.1\tLN:1024\n@SQ\tSN:APMT01237471.1\tLN:1024\n@SQ\tSN:APMT01237472.1\tLN:1024\n@SQ\tSN:APMT01237473.1\tLN:1024\n@SQ\tSN:APMT01236291.1\tLN:1023\n@SQ\tSN:APMT01236775.1\tLN:1023\n@SQ\tSN:APMT01236925.1\tLN:1023\n@SQ\tSN:APMT01236926.1\tLN:1023\n@SQ\tSN:APMT01236987.1\tLN:1023\n@SQ\tSN:APMT01237004.1\tLN:1023\n@SQ\tSN:APMT01237326.1\tLN:1023\n@SQ\tSN:APMT01237474.1\tLN:1023\n@SQ\tSN:APMT01237476.1\tLN:1023\n@SQ\tSN:APMT01237477.1\tLN:1023\n@SQ\tSN:APMT01237478.1\tLN:1023\n@SQ\tSN:APMT01237480.1\tLN:1023\n@SQ\tSN:APMT01237481.1\tLN:1023\n@SQ\tSN:APMT01237482.1\tLN:1023\n@SQ\tSN:APMT01236311.1\tLN:1022\n@SQ\tSN:APMT01237468.1\tLN:1022\n@SQ\tSN:APMT01237475.1\tLN:1022\n@SQ\tSN:APMT01237484.1\tLN:1022\n@SQ\tSN:APMT01237486.1\tLN:1022\n@SQ\tSN:APMT01237487.1\tLN:1022\n@SQ\tSN:APMT01237488.1\tLN:1022\n@SQ\tSN:APMT01236330.1\tLN:1021\n@SQ\tSN:APMT01236992.1\tLN:1021\n@SQ\tSN:APMT01237483.1\tLN:1021\n@SQ\tSN:APMT01237489.1\tLN:1021\n@SQ\tSN:APMT01237490.1\tLN:1021\n@SQ\tSN:APMT01237491.1\tLN:1021\n@SQ\tSN:APMT01237492.1\tLN:1021\n@SQ\tSN:APMT01237493.1\tLN:1021\n@SQ\tSN:APMT01237494.1\tLN:1021\n@SQ\tSN:APMT01237495.1\tLN:1021\n@SQ\tSN:APMT01237496.1\tLN:1021\n@SQ\tSN:APMT01237497.1\tLN:1021\n@SQ\tSN:APMT01237498.1\tLN:1021\n@SQ\tSN:APMT01237499.1\tLN:1021\n@SQ\tSN:APMT01236965.1\tLN:1020\n@SQ\tSN:APMT01237026.1\tLN:1020\n@SQ\tSN:APMT01237055.1\tLN:1020\n@SQ\tSN:APMT01237500.1\tLN:1020\n@SQ\tSN:APMT01237501.1\tLN:1020\n@SQ\tSN:APMT01237502.1\tLN:1020\n@SQ\tSN:APMT01237503.1\tLN:1020\n@SQ\tSN:APMT01237504.1\tLN:1020\n@SQ\tSN:APMT01237505.1\tLN:1020\n@SQ\tSN:APMT01237506.1\tLN:1020\n@SQ\tSN:APMT01237507.1\tLN:1020\n@SQ\tSN:APMT01237508.1\tLN:1020\n@SQ\tSN:APMT01236588.1\tLN:1019\n@SQ\tSN:APMT01236957.1\tLN:1019\n@SQ\tSN:APMT01236983.1\tLN:1019\n@SQ\tSN:APMT01237010.1\tLN:1019\n@SQ\tSN:APMT01237014.1\tLN:1019\n@SQ\tSN:APMT01237302.1\tLN:1019\n@SQ\tSN:APMT01237395.1\tLN:1019\n@SQ\tSN:APMT01237509.1\tLN:1019\n@SQ\tSN:APMT01237510.1\tLN:1019\n@SQ\tSN:APMT01237511.1\tLN:1019\n@SQ\tSN:APMT01237512.1\tLN:1019\n@SQ\tSN:APMT01237027.1\tLN:1018\n@SQ\tSN:APMT01237049.1\tLN:1018\n@SQ\tSN:APMT01237513.1\tLN:1018\n@SQ\tSN:APMT01237514.1\tLN:1018\n@SQ\tSN:APMT01237515.1\tLN:1018\n@SQ\tSN:APMT01237516.1\tLN:1018\n@SQ\tSN:APMT01237517.1\tLN:1018\n@SQ\tSN:APMT01237518.1\tLN:1018\n@SQ\tSN:APMT01237520.1\tLN:1018\n@SQ\tSN:APMT01236502.1\tLN:1017\n@SQ\tSN:APMT01236617.1\tLN:1017\n@SQ\tSN:APMT01237521.1\tLN:1017\n@SQ\tSN:APMT01237522.1\tLN:1017\n@SQ\tSN:APMT01237523.1\tLN:1017\n@SQ\tSN:APMT01236709.1\tLN:1016\n@SQ\tSN:APMT01237009.1\tLN:1016\n@SQ\tSN:APMT01237046.1\tLN:1016\n@SQ\tSN:APMT01237479.1\tLN:1016\n@SQ\tSN:APMT01237524.1\tLN:1016\n@SQ\tSN:APMT01237525.1\tLN:1016\n@SQ\tSN:APMT01237526.1\tLN:1016\n@SQ\tSN:APMT01237527.1\tLN:1016\n@SQ\tSN:APMT01237528.1\tLN:1016\n@SQ\tSN:APMT01237529.1\tLN:1016\n@SQ\tSN:APMT01237530.1\tLN:1016\n@SQ\tSN:APMT01237531.1\tLN:1016\n@SQ\tSN:APMT01237532.1\tLN:1016\n@SQ\tSN:APMT01237533.1\tLN:1016\n@SQ\tSN:APMT01237534.1\tLN:1016\n@SQ\tSN:APMT01237535.1\tLN:1016\n@SQ\tSN:APMT01237536.1\tLN:1016\n@SQ\tSN:APMT01236511.1\tLN:1015\n@SQ\tSN:APMT01237028.1\tLN:1015\n@SQ\tSN:APMT01237063.1\tLN:1015\n@SQ\tSN:APMT01237213.1\tLN:1015\n@SQ\tSN:APMT01237519.1\tLN:1015\n@SQ\tSN:APMT01237537.1\tLN:1015\n@SQ\tSN:APMT01237538.1\tLN:1015\n@SQ\tSN:APMT01237539.1\tLN:1015\n@SQ\tSN:APMT01237541.1\tLN:1015\n@SQ\tSN:APMT01237542.1\tLN:1015\n@SQ\tSN:APMT01237543.1\tLN:1015\n@SQ\tSN:APMT01236425.1\tLN:1014\n@SQ\tSN:APMT01237039.1\tLN:1014\n@SQ\tSN:APMT01237058.1\tLN:1014\n@SQ\tSN:APMT01237064.1\tLN:1014\n@SQ\tSN:APMT01237243.1\tLN:1014\n@SQ\tSN:APMT01237350.1\tLN:1014\n@SQ\tSN:APMT01237544.1\tLN:1014\n@SQ\tSN:APMT01237545.1\tLN:1014\n@SQ\tSN:APMT01237546.1\tLN:1014\n@SQ\tSN:APMT01237547.1\tLN:1014\n@SQ\tSN:APMT01237548.1\tLN:1014\n@SQ\tSN:APMT01237549.1\tLN:1014\n@SQ\tSN:APMT01237550.1\tLN:1014\n@SQ\tSN:APMT01237551.1\tLN:1014\n@SQ\tSN:APMT01236420.1\tLN:1013\n@SQ\tSN:APMT01237432.1\tLN:1013\n@SQ\tSN:APMT01237552.1\tLN:1013\n@SQ\tSN:APMT01237553.1\tLN:1013\n@SQ\tSN:APMT01237554.1\tLN:1013\n@SQ\tSN:APMT01237555.1\tLN:1013\n@SQ\tSN:APMT01237556.1\tLN:1013\n@SQ\tSN:APMT01237557.1\tLN:1013\n@SQ\tSN:APMT01237558.1\tLN:1013\n@SQ\tSN:APMT01237559.1\tLN:1013\n@SQ\tSN:APMT01236406.1\tLN:1012\n@SQ\tSN:APMT01237043.1\tLN:1012\n@SQ\tSN:APMT01237095.1\tLN:1012\n@SQ\tSN:APMT01237257.1\tLN:1012\n@SQ\tSN:APMT01237267.1\tLN:1012\n@SQ\tSN:APMT01237312.1\tLN:1012\n@SQ\tSN:APMT01237377.1\tLN:1012\n@SQ\tSN:APMT01237408.1\tLN:1012\n@SQ\tSN:APMT01237560.1\tLN:1012\n@SQ\tSN:APMT01237561.1\tLN:1012\n@SQ\tSN:APMT01237562.1\tLN:1012\n@SQ\tSN:APMT01237563.1\tLN:1012\n@SQ\tSN:APMT01237564.1\tLN:1012\n@SQ\tSN:APMT01237566.1\tLN:1012\n@SQ\tSN:APMT01237567.1\tLN:1012\n@SQ\tSN:APMT01237568.1\tLN:1012\n@SQ\tSN:APMT01237569.1\tLN:1012\n@SQ\tSN:APMT01237570.1\tLN:1012\n@SQ\tSN:APMT01236635.1\tLN:1011\n@SQ\tSN:APMT01237047.1\tLN:1011\n@SQ\tSN:APMT01237135.1\tLN:1011\n@SQ\tSN:APMT01237485.1\tLN:1011\n@SQ\tSN:APMT01237572.1\tLN:1011\n@SQ\tSN:APMT01237573.1\tLN:1011\n@SQ\tSN:APMT01237574.1\tLN:1011\n@SQ\tSN:APMT01237575.1\tLN:1011\n@SQ\tSN:APMT01237576.1\tLN:1011\n@SQ\tSN:APMT01237577.1\tLN:1011\n@SQ\tSN:APMT01237578.1\tLN:1011\n@SQ\tSN:APMT01237072.1\tLN:1010\n@SQ\tSN:APMT01237090.1\tLN:1010\n@SQ\tSN:APMT01237094.1\tLN:1010\n@SQ\tSN:APMT01237190.1\tLN:1010\n@SQ\tSN:APMT01237246.1\tLN:1010\n@SQ\tSN:APMT01237409.1\tLN:1010\n@SQ\tSN:APMT01237540.1\tLN:1010\n@SQ\tSN:APMT01237565.1\tLN:1010\n@SQ\tSN:APMT01237579.1\tLN:1010\n@SQ\tSN:APMT01237580.1\tLN:1010\n@SQ\tSN:APMT01237581.1\tLN:1010\n@SQ\tSN:APMT01237583.1\tLN:1010\n@SQ\tSN:APMT01237584.1\tLN:1010\n@SQ\tSN:APMT01237585.1\tLN:1010\n@SQ\tSN:APMT01237586.1\tLN:1010\n@SQ\tSN:APMT01237587.1\tLN:1010\n@SQ\tSN:APMT01236966.1\tLN:1009\n@SQ\tSN:APMT01237238.1\tLN:1009\n@SQ\tSN:APMT01237588.1\tLN:1009\n@SQ\tSN:APMT01237589.1\tLN:1009\n@SQ\tSN:APMT01237590.1\tLN:1009\n@SQ\tSN:APMT01237591.1\tLN:1009\n@SQ\tSN:APMT01237592.1\tLN:1009\n@SQ\tSN:APMT01236783.1\tLN:1008\n@SQ\tSN:APMT01237078.1\tLN:1008\n@SQ\tSN:APMT01237093.1\tLN:1008\n@SQ\tSN:APMT01237233.1\tLN:1008\n@SQ\tSN:APMT01237306.1\tLN:1008\n@SQ\tSN:APMT01237571.1\tLN:1008\n@SQ\tSN:APMT01237593.1\tLN:1008\n@SQ\tSN:APMT01237594.1\tLN:1008\n@SQ\tSN:APMT01237595.1\tLN:1008\n@SQ\tSN:APMT01237596.1\tLN:1008\n@SQ\tSN:APMT01237598.1\tLN:1008\n@SQ\tSN:APMT01237599.1\tLN:1008\n@SQ\tSN:APMT01237121.1\tLN:1007\n@SQ\tSN:APMT01237192.1\tLN:1007\n@SQ\tSN:APMT01237597.1\tLN:1007\n@SQ\tSN:APMT01237600.1\tLN:1007\n@SQ\tSN:APMT01237601.1\tLN:1007\n@SQ\tSN:APMT01237602.1\tLN:1007\n@SQ\tSN:APMT01237603.1\tLN:1007\n@SQ\tSN:APMT01237604.1\tLN:1007\n@SQ\tSN:APMT01237605.1\tLN:1007\n@SQ\tSN:APMT01237606.1\tLN:1007\n@SQ\tSN:APMT01237607.1\tLN:1007\n@SQ\tSN:APMT01237608.1\tLN:1007\n@SQ\tSN:APMT01237609.1\tLN:1007\n@SQ\tSN:APMT01237610.1\tLN:1007\n@SQ\tSN:APMT01236592.1\tLN:1006\n@SQ\tSN:APMT01237126.1\tLN:1006\n@SQ\tSN:APMT01237176.1\tLN:1006\n@SQ\tSN:APMT01237242.1\tLN:1006\n@SQ\tSN:APMT01237419.1\tLN:1006\n@SQ\tSN:APMT01237582.1\tLN:1006\n@SQ\tSN:APMT01237611.1\tLN:1006\n@SQ\tSN:APMT01237612.1\tLN:1006\n@SQ\tSN:APMT01237613.1\tLN:1006\n@SQ\tSN:APMT01237614.1\tLN:1006\n@SQ\tSN:APMT01237615.1\tLN:1006\n@SQ\tSN:APMT01237104.1\tLN:1005\n@SQ\tSN:APMT01237151.1\tLN:1005\n@SQ\tSN:APMT01237175.1\tLN:1005\n@SQ\tSN:APMT01237203.1\tLN:1005\n@SQ\tSN:APMT01237616.1\tLN:1005\n@SQ\tSN:APMT01237617.1\tLN:1005\n@SQ\tSN:APMT01237618.1\tLN:1005\n@SQ\tSN:APMT01237619.1\tLN:1005\n@SQ\tSN:APMT01237620.1\tLN:1005\n@SQ\tSN:APMT01237621.1\tLN:1005\n@SQ\tSN:APMT01229785.1\tLN:1004\n@SQ\tSN:APMT01236495.1\tLN:1004\n@SQ\tSN:APMT01236580.1\tLN:1004\n@SQ\tSN:APMT01237113.1\tLN:1004\n@SQ\tSN:APMT01237226.1\tLN:1004\n@SQ\tSN:APMT01237254.1\tLN:1004\n@SQ\tSN:APMT01237314.1\tLN:1004\n@SQ\tSN:APMT01237622.1\tLN:1004\n@SQ\tSN:APMT01237623.1\tLN:1004\n@SQ\tSN:APMT01237624.1\tLN:1004\n@SQ\tSN:APMT01237625.1\tLN:1004\n@SQ\tSN:APMT01237626.1\tLN:1004\n@SQ\tSN:APMT01237627.1\tLN:1004\n@SQ\tSN:APMT01237628.1\tLN:1004\n@SQ\tSN:APMT01236670.1\tLN:1003\n@SQ\tSN:APMT01236745.1\tLN:1003\n@SQ\tSN:APMT01237120.1\tLN:1003\n@SQ\tSN:APMT01237239.1\tLN:1003\n@SQ\tSN:APMT01237629.1\tLN:1003\n@SQ\tSN:APMT01237630.1\tLN:1003\n@SQ\tSN:APMT01237631.1\tLN:1003\n@SQ\tSN:APMT01237633.1\tLN:1003\n@SQ\tSN:APMT01237634.1\tLN:1003\n@SQ\tSN:APMT01237635.1\tLN:1003\n@SQ\tSN:APMT01237636.1\tLN:1003\n@SQ\tSN:APMT01237637.1\tLN:1003\n@SQ\tSN:APMT01237138.1\tLN:1002\n@SQ\tSN:APMT01237141.1\tLN:1002\n@SQ\tSN:APMT01237142.1\tLN:1002\n@SQ\tSN:APMT01237168.1\tLN:1002\n@SQ\tSN:APMT01237253.1\tLN:1002\n@SQ\tSN:APMT01237319.1\tLN:1002\n@SQ\tSN:APMT01237632.1\tLN:1002\n@SQ\tSN:APMT01237638.1\tLN:1002\n@SQ\tSN:APMT01237639.1\tLN:1002\n@SQ\tSN:APMT01237640.1\tLN:1002\n@SQ\tSN:APMT01237641.1\tLN:1002\n@SQ\tSN:APMT01237642.1\tLN:1002\n@SQ\tSN:APMT01237643.1\tLN:1002\n@SQ\tSN:APMT01237644.1\tLN:1002\n@SQ\tSN:APMT01237645.1\tLN:1002\n@SQ\tSN:APMT01237646.1\tLN:1002\n@SQ\tSN:APMT01236648.1\tLN:1001\n@SQ\tSN:APMT01237152.1\tLN:1001\n@SQ\tSN:APMT01237157.1\tLN:1001\n@SQ\tSN:APMT01237172.1\tLN:1001\n@SQ\tSN:APMT01237256.1\tLN:1001\n@SQ\tSN:APMT01237261.1\tLN:1001\n@SQ\tSN:APMT01237363.1\tLN:1001\n@SQ\tSN:APMT01237647.1\tLN:1001\n@SQ\tSN:APMT01237648.1\tLN:1001\n@SQ\tSN:APMT01237649.1\tLN:1001\n@SQ\tSN:APMT01237650.1\tLN:1001\n@SQ\tSN:APMT01237651.1\tLN:1001\n@SQ\tSN:APMT01237652.1\tLN:1001\n@SQ\tSN:APMT01237653.1\tLN:1001\n@SQ\tSN:APMT01237654.1\tLN:1001\n@SQ\tSN:APMT01237193.1\tLN:1000\n@SQ\tSN:APMT01237197.1\tLN:1000\n@SQ\tSN:APMT01237262.1\tLN:1000\n@SQ\tSN:APMT01237287.1\tLN:1000\n@SQ\tSN:APMT01237399.1\tLN:1000\n@SQ\tSN:APMT01237655.1\tLN:1000\n@SQ\tSN:APMT01237656.1\tLN:1000\n@SQ\tSN:APMT01237657.1\tLN:1000\n@SQ\tSN:APMT01237658.1\tLN:1000\n@SQ\tSN:APMT01237659.1\tLN:1000\n@PG\tID:Bowtie\tVN:1.2.3\tCL:\"bowtie-align-s --wrapper basic-0 sample_index sample.fastq -S -p 12\"\n"
    else:
        print("NOTE: At this point, it seems that you are using custom library build and therefore, please insert header corresponding to the custom library at the top of the SAM file, and follow the instruction to create BAM and BAM index files prior to visualization. At any point if you face difficulty in creating BAM files, please raise an issue in the GitHub page\n")
        header="@HD\tVN:1.0\tSO:unsorted\n"
    return header
